/* Standard DGN Definitions for ODOT Criteria */

/*********************************************************************
File Name: define.ex

Version: 07.25.02

Written: March 13, 1997 by Eric Thomas

Revision History:

  July 25, 2002 by Eric Thomas
    - added default values for the following redefinable variables:
      	_d_overlay1_file_processed
      	_d_widening slope
      The value of variables is reset by OVERLAY1.EX and then read by
      the shoulder criteria files to determine how to set the pavement
      slope for the purposes of calcluating the shoulder slope.  This
      was necessary in cases where the user set a FIXED WIDENING SLOPE
      value that did not equal the value of FIXED OVERLAY SLOPE.  The
      shoulders will not calculate the shoulder slope based on the value
      of FIXED WIDENING SLOPE when it is set to a non-zero value.  If
      FIXED WIDENING SLOPE is set to zero, the shoulder criteria files
      will base the shoulder slope on the pavement slope.

  March 22, 2001 by Eric Thomas
    - Added a new element variable "~existing conc removal top symbology"
      which is used by EXPAVE2.EX
      
  March 6, 2000 by Eric Thomas
    - Added _d_draw_steps_left and _d_draw_steps_right to accomodate changes
      made to the shoulder criteria files.

  November 16, 1999 by Eric Thomas
    - Added the subroutine current_side

  August 19, 1997 by Eric Thomas
    - Added "~proposed shoulder symbology"

  August 11, 1997 by Eric Thomas
    - Added "~pavement surface symbology"

Description:
http://www.dot.state.oh.us/prod/geopak/criteria/define.pdf

**********************************************************************/

if p1 then
  {

  /******************************************************************/
  /*               DEFINE VARIABLES FOR TEXT SIZES                  */
  /******************************************************************/

  define "~elev text 5 scale"   	elevation text lvname=default co=0 wt=1 offset=-0.39 th=0.78 tw=0.78 just=ct ft=83 number of dec places=1
  define "~elev text 10 scale"  	elevation text lvname=default co=0 wt=1 offset=-0.78 th=1.56 tw=1.56 just=ct ft=83 number of dec places=1
  define "~lv39 text 5 scale"   	lvname=default co=0 wt=1 th=0.78 tw=0.78 just=ct ft=83
  define "~lv40 text 10 scale"  	lvname=default co=0 wt=1 th=1.56 tw=1.56 just=ct ft=83
  define "~marked point text"		lvname=default ang=90 co=4 wt=1 th=0.5 tw=0.5 just=lc ft=83
  define "~slope text 5 scale"          lvname=default co=0 wt=1 offset=0.39 th=0.78 tw=0.78 just=cb ft=83 number of dec places=1
  define "~slope text 10 scale"         lvname=default co=0 wt=1 offset=0.78 th=1.56 tw=1.56 just=cb ft=83 number of dec places=1
  define "~slope text drive 5 scale"    format=% lvname=default co=0 wt=1 offset=0.39 th=0.78 tw=0.78 just=cb ft=83 number of dec places=2
  define "~slope text drive 10 scale"   format=% lvname=default co=0 wt=1 offset=0.78 th=1.56 tw=1.56 just=cb ft=83 number of dec places=2
  define "~slope text 5 scale x:x"    	format=: lvname=default co=0 wt=1 offset=0.39 th=0.78 tw=0.78 just=cb ft=83 number of dec places=0
  define "~slope text 10 scale x:x"   	format=: lvname=default co=0 wt=1 offset=0.78 th=1.56 tw=1.56 just=cb ft=83 number of dec places=0

  /******************************************************************/
  /*           DEFINE VARIABLES FOR ELEMENT SYMBOLOGY               */
  /******************************************************************/

  define "~curb elements symbology" 		set plot param lv=9 co=44 wt=1 lc=0
  define "~curb nonplot symbology"       	set plot param lv=9 co=30 wt=1 lc=0
  define "~driveway element symbology"		set plot param lv=9 co=44 wt=1 lc=0
  define "~proposed grading symbology"		set plot param lv=8 co=2 wt=2 lc=0
  define "~proposed grading nonplot symbology"	set plot param lv=9 co=2 wt=2 lc=0
  define "~proposed cross section symbology" 	set plot param lvname=Xsec:Prop Top of Pavement co=bylevel wt=bylevel lc=bylevel
  define "~proposed undercut symbology"		set plot param lv=8 co=8 wt=2 lc=0
  define "~pavement surface symbology"		set plot param lv=9 co=35 wt=1 lc=0
  define "~pavement layer 1 symbology"		set plot param lv=9 co=1 wt=1 lc=0
  define "~pavement layer 2 symbology"          set plot param lv=9 co=2 wt=1 lc=0
  define "~pavement layer 3 symbology"          set plot param lv=9 co=3 wt=1 lc=0
  define "~pavement layer 4 symbology"          set plot param lv=9 co=4 wt=1 lc=0
  define "~pavement layer 5 symbology"          set plot param lv=9 co=5 wt=1 lc=0
  define "~pavement layer 6 symbology"          set plot param lv=9 co=6 wt=1 lc=0
  define "~pavement wedge course symbology"     set plot param lv=9 co=10 wt=1 lc=0
  define "~proposed shoulder surface symbology"	set plot param lv=9 wt=1 co=40 lc=0
  define "~proposed shoulder symbology"		set plot param lv=9 wt=1 co=9 lc=0
  define "~side walk nonplot symbology"         set plot param lv=26 co=44 wt=1 lc=0
  define "~undercut layer symbology"		set plot param lv=10 co=8 wt=1 lc=0

  define "~existing pavement symbology"		set plot param lv=11 co=0 wt=0 lc=3
  define "~existing conc removal symbology"	set plot param lv=11 co=3 wt=0 lc=3
  define "~existing conc removal top symbology"	set plot param lv=11 co=88 wt=0 lc=3

  define "~proposed concrete barrier symbology"	set plot param lv=9 co=44 wt=1 lc=0

  /******************************************************************/
  /*          _d variables used by multiple criteria files          */
  /******************************************************************/

  /* These two variables are used by the shoulder and curb criteria files.  */
  /* If set to one, the pavement layers are drawn.  The file OVERLAY1.EX    */
  /* will set the value to zero in cases where the pavement layers should   */
  /* not be drawn.  The value must initially be set to one in order for the */
  /* shoulder and curb to process correctly when used along with PAVT.EX    */
  _d_draw_steps_left = 1
  _d_draw_steps_right = 1

  _d_shoulder_placed_left = 0
  _d_shoulder_placed_right = 0

  _d_paved_shoulder_slope = -4.17
  
  _d_overlay1_file_processed = 0
  _d_widening_slope = 0


  /*******************************************************************/
  /*                          Subroutines                            */
  /*******************************************************************/

  /* this subroutine is used by several of ODOT's standard criteria files */
  /* to determine which side is currently being processed                 */
  subroutine current_side
    {
    mark x900 y900
    draw skip dx = 1 dy = 0
    mark x901 y901
    if (x901 < x900) then
      {
      _d_side = 0  /* left side */
      }
    else 
      {
      _d_side = 1 /* right side */
      }
    draw skip to x900 y900
    }
  end subroutine

  }

