/* Plots Existing Subbase */

/*************************************************************************
EXSUBBASE.X -- This criteria file is meant to draw existing subbase on any
project. All the user should have to do is define the appropriate symbology
for the edges of pavement and shoulders, as well as the appropriate pavement
and shoulder thicknesses for his/her project. You can also define the symbology
with which the subbase will be plotted.

Written By: Derricke Gray
            GEOPAK Corp.
            850.942.4023
            derricke@geopak.com

This file should be run from side slope lt only or side slope rt only

ASSUMPTIONS:

Assumes that each shoulder found has an associated edge of pavement

Assumes that edges of pavement will be found in pairs. If you have an odd
number of edges of pavement, you will get irregular results for that
particular cross section. An error message will be written onto the
cross section if an odd number of pavement edges are found.

**************************************************************************/

/*************************************************************************
DEFINITIONS
**************************************************************************/

define_dgn "existing edge of pavement"\
dgn = topog file\
type = line,line_string,arc,curve,cmp_string\
lvname=PX:Ex Pavement  

define_dgn "existing paved shoulder" \
dgn = topog file\
type = line,line_string,arc,curve,cmp_string \
lvname=PX:Ex Shoulder

define "exist pavement thick" 0.8
define "exist shoulder thick" 0.1

define "~ex pavement symbology" lvname=PX:Ex Pavement co=ByLevel wt=ByLevel lc=ByLevel
define "~ex shoulder symbology" lvname=PX:Ex Shoulder


/*****************************************************************
This section of the file marks and labels each edge of pavement
and shoulder
*****************************************************************/

if p1 then
{
_d_eop_intersection = 0
_d_eop_intersection_counter = 0
_d_exshoulder_intersection = 0
_d_exshoulder_intersection_counter = 0

draw skip trace in off=0 for dx = 300
mark x900 y900

/*  mark  EXISTING EDGES OF PAVEMENT  X1 - X19 */

     if intersect dgn = "existing edge of pavement" then
          {
          _d_eop_intersection = 1
          _d_eop_intersection_counter = 1
          while intersect dgn = "existing edge of pavement"
               {
               draw skip dx = 1 dy = 0 to "existing edge of pavement"
               draw skip dx = 0 dy = 50
               draw skip dx = 0 dy = -1 to exist ground
               mark x[_d_eop_intersection_counter] y[_d_eop_intersection_counter]
               _d_eop_intersection_counter = _d_eop_intersection_counter + 1
               draw text angle=90 lv=62 char=^eop^ just=lc th=0.0125 tw=0.0125 co=0
               draw skip dx = (2 * tolerance) dy = 0
               }
          }
     _d_eop_intersection_counter = _d_eop_intersection_counter - 1

/*   MARK Existing EDGE OF PAVED SHOULDER  X21-X40    */
      draw skip to x900 y900
      if intersect dgn = "existing paved shoulder" then
          {
          _d_exshoulder_intersection = 1
          _d_exshoulder_intersection_counter = 21
          while intersect dgn = "existing paved shoulder"
               {
               draw skip dx = 1 dy = 0 to "existing paved shoulder"
               draw skip dx = 0 dy = 50
               draw skip dx = 0 dy = -1 to exist ground
               mark x[_d_exshoulder_intersection_counter] y[_d_exshoulder_intersection_counter]
               draw text angle=90 lv=62 char=^exist shoulder^ just=lc th=0.0125 tw=0.0125 co=0
               draw skip dx = (2 * tolerance) dy = 0
               _d_exshoulder_intersection_counter = _d_exshoulder_intersection_counter +1
               }
          }
       _d_exshoulder_intersection_counter = _d_exshoulder_intersection_counter - 1

}

/*********************************************************************************
Check for odd number of edges of pavement and issue error message
**********************************************************************************/

_d_temp = _d_eop_intersection_counter / 2
_d_temp_int = INT(_d_temp)

if _d_temp > _d_temp_int then
  draw skip to xpgl ypgl
  draw text lv=61 char=^Irregular Pavement Found^ th=2 tw=2 co=3

/***************************************************************************************
This while loop loops over each of the edge of pavement pairs and draws the existing
pavement and shoulder subbase
****************************************************************************************/

if not p2 then

   {
   _d_admin_counter = 1
   _d_median = 0
   while (_d_admin_counter < _d_eop_intersection_counter)

      {

      _d_global_counter = _d_admin_counter

/***************************************************************************
This section draws the existing pavement subbase
***************************************************************************/

 if p1 then
   {
   _d_rt_eop = _d_global_counter

   /* Draw Pavement */
   set plot parameters "~ex pavement symbology"
   draw skip to x[_d_rt_eop] y[_d_rt_eop]
   mark x601 y601
   mark x891 y891
   draw dx = 0 dy = -"exist pavement thick"
   draw trace out off = -"exist pavement thick" to x[_d_rt_eop+1]

   draw dx = 0 dy = 1 to existing ground
   /* save off mark points for subsequent use */
   draw skip to x[_d_rt_eop] y[_d_rt_eop]
   draw skip dx = 0 dy = -"exist pavement thick"
   mark x702 y702
   mark x802 y802
   draw skip to x[_d_rt_eop+1] y[_d_rt_eop+1]
   mark x602 y602
   mark x892 y892
   draw skip dx = 0 dy = -"exist pavement thick"
   mark x701 y701
   mark x801 y801

   }

/***************************************************************
This section draws the shoulder subbase if shoulders are found
***************************************************************/

/* Basic Assumption: Pair each shoulder with the closest pavement edge. */
if p1 then
 {
 _d_side = 1
 while (_d_side <= 2)
   {
   _d_sh_edge = 21  /* Edge of shoulder set by REHAB1.X to X21 - X30 */
   while (_d_sh_edge <= _d_exshoulder_intersection_counter)
      {
      /* Loop over all EOPs (set by REHAB1.X to X1 - X10) */
      _d_eop_counter = 1
      _d_dist_min = 9999999.0
      _d_dist_max = 0.0
      while (_d_eop_counter <= _d_eop_intersection_counter)
         {
         _d_dist_test = abs(x[_d_eop_counter] - x[_d_sh_edge])
         if (_d_dist_test < _d_dist_min) then
            {
            _d_dist_min = _d_dist_test
            _d_target_eop = _d_eop_counter
            }
         _d_eop_counter = _d_eop_counter + 1
         }
       if (_d_dist_min > _d_dist_max) then
         {
           _d_dist_max = _d_dist_min
         }

      /* DRAW SHOULDER */
      if ((_d_side = 1) and
          (abs(x601 - x[_d_target_eop]) < tolerance)) or
         ((_d_side = 2) and
          (abs(x602 - x[_d_target_eop]) < tolerance)) then
         {
         set plot parameters "~ex shoulder symbology"
         /* Shoulder to the right of EOP */
         if (x[_d_sh_edge] > x[_d_target_eop]) then
            {
            draw skip to x[_d_sh_edge] y[_d_sh_edge]
            draw dx = 0 dy = -"exist shoulder thick"
            draw trace out off = -"exist shoulder thick" to x[_d_target_eop]
            }
         /* shoulder to the left of eop */
         else
            {
            draw skip to x[_d_sh_edge] y[_d_sh_edge]
            draw dx = 0 dy = -"exist shoulder thick"
            draw trace in off = -"exist shoulder thick" to x[_d_target_eop]
            }
         }

      /* Increment While Looping Variable */
      _d_sh_edge = _d_sh_edge + 1
      }
   _d_side = _d_side + 1
   }
 }


/***************************************************************
Reset the counter and go to the next pair of eop's
/***************************************************************/

      _d_admin_counter = _d_admin_counter + 2
     }
   }











