/* Labels DGN elements on xsecs

   Description: Finds and annotates existing Plan view dgn elements
                onto cross sections. A label (text value) can be
                dictated by the user and the option to include an
                offset is included.

   Requirements: 1. Run as shapeless criteria
                 2. Run as Side Slope Lt ONLY or run as Side
                    Slope Rt ONLY.

THIS FILE IS FOR METRIC AND IMPERIAL
***************************************************************/




/*  DEFINE VARIABLES  */

define "xs scale" 10
define "Label Text" Label
define "Depth of Cover" 0

/*  DEFINE ON OR OFF VARIABLES  */

define "Offset (Y/N)" Y

/*  DEFINE PLOT SYMBOLOGY VARIABLES  */

define "~Pointer symbology" lv=30 co=70  lc=0 wt=3

define "~Label text symbology" th=_d_tx*"xs scale" tw=_d_tx*"xs scale" num of dec places=2 lv=30 co=70  wt=2 just=lc angle=90

/*  DEFINE DGN VARIABLES  */

define_dgn "DGN Element" \
        dgn = *.dgn \
        lvname = Default 

define "Baseline Name" Baseline Name

if p1 then 
	{
	   _s_unit = "'"
	   _d_line = 0.5*"xs scale"
	   _d_txoff = 0.2*"xs scale"
	   _d_tx = 0.125
	}

   /*  FIND AND ANNOTATE DGN ELEMENT  */

if P1 then
  {
    _s_YN << "Offset(Y/N)"
    _s_test = "y"
    set plot parameters "~pointer symbology"
    draw skip trace out offset = 0 for dx=1000
    draw skip dx=-1 dy=0 to chain "Baseline Name"
    mark x80 y80

    draw skip trace in off=0 for dx = 1000

    while intersect dgn = "dgn element"
      {

         draw skip dx=1 dy=0 to "dgn element"
         mark x500 y500
         draw skip dx=0 dy=50
         mark x501 y501
         draw skip dx=0 dy=-1 to existing ground
         mark x502 y502
         if not abs(y501-y502)>=tolerance then   /*  If did not move to existing ground  */
           {
             draw skip to x500 y500
           }
         draw skip dx=0 dy=-abs("depth of cover")
         mark x40 y40
         draw dx=0 dy=_d_line
         _s_text << "label text"
       if (_s_YN = _s_test) then
          {
             _d_off = abs(x40 - x80)
             _s_label = _s_text + " " + cvt_d_s2(_d_off) + _s_unit
          }

       else
          {
            _s_label = _s_text
          }

         draw skip dx=0 dy= _d_txoff
         draw text value=_s_label
                  "~label text symbology"

	      draw skip to x40 y40

	      draw skip dx = (2 * tolerance) dy = 0

      }
   }


