/***************************************************************************************************/
/*                                                                                                 */
/*                                                                                                 */
/* The purpose of this criteria file is to create a comma separated ASCII text file which contains */
/*     detailed slope stake information.  This file will work for divided roadways only.           */
/*                                                                                                 */
/* The proposed cross sections need to be previously completed in a separate run.                  */
/*   REVISED:  10/14/2014 Tom Sawyer                                                               */
/*                added logic to handle ditch bottoms that are more than one segment (OpenRoads)   */
/*      R1     04/30/2015 Tom Sawyer                                                               */
/*                added code to give the user the option of annotating the cross sections as the   */
/*                slope stake books are being generated.                                           */
/*                                                                                                 */
/*      R2     05/05/2015 Tom Sawyer                                                               */
/*                added code to annotate the inside edge of the ditch and the turf shoulder point  */
/*                as per a request by Jeff J. and approved by Lorraine L.                          */
/*                                                                                                 */
/*      R3     06/03/2015 Tom Sawyer                                                               */
/*                Added code to annotate the PGLs                                                  */
/*                                                                                                 */
/*      R3     08/23/2016 Tom Sawyer                                                               */
/*                Fixed code throughout the file to fix bugs and to handle the extra false         */
/*                break points in the linestrings that are happening when cutting cross sections   */
/*                from a model.                                                                    */
/*                                                                                                 */
/*                                                                                                 */
/***************************************************************************************************/

define "Plan View Scale" 100
define "XS Annotation Scale" 10

if p1 then
    {
      remove skew effect
    }

if "Plan View Scale" < 499 then             /*  It's Imperial  */
  {
   _d_text_size = "plan view scale" / 10
   _d_cell_scale = ("plan view scale" / 100) /* Conversion for cell size from plan scale */
   _d_dec  = 0
   _d_1ft  = 1
   _d_10ft = 10
   _d_2ft  = 2
   _d_20ft = 20
   _d_30ft = 30
   _d_50ft = 50
   _d_100ft = 100
   _d_tolerance = 0.01
   _s_units = ^imperial^
   define "~warning text symbology" off=0.000 LvName = XS Text Warning co=3  wt=1 ft=5 th=1.5 tw=1.5 just=lc angle=90
   
   /*   ADDED DEFINITIONS FOR LABELING OF CROSS SECTIONS  */
   _d_txoff = 0.15 * "XS Annotation Scale"
   define "~offset text symbology"    num of dec place=2 off=0.100*"XS Annotation Scale" LvName = XS Text Offset co=5 wt=1 ft=5 th=.125*"XS Annotation Scale" tw=.125*"XS Annotation Scale" just=lc angle=90
   define "~slope text symbology"     num of dec place=2 off=0.025*"XS Annotation Scale" LvName = XS Text Grading Slope co=4 wt=1 ft=5 th=.125*"XS Annotation Scale" tw=.125*"XS Annotation Scale" just=cb format = run:rise
   define "~elevation text symbology" num of dec place=2 off=-.025*"XS Annotation Scale" LvName = XS Text Elevation co=4 wt=1 ft=5 th=.125*"XS Annotation Scale" tw=.125*"XS Annotation Scale" just=ct
   define "~pgl elev text symbology"  num of dec place=2 off=0.000*"XS Annotation Scale" LvName = XS Text PGL Elevation co=10 wt=1 ft=5 th=.125*"XS Annotation Scale" tw=.125*"XS Annotation Scale" just=lc angle=90

   _s_HPTest = ^no^
   
  }
else                                        /*  It's Metric    */
  {
   _d_text_size = "plan view scale" / 400
   _d_cell_scale = ("plan view scale" / 1000) /* Conversion for cell size from plan scale */
   _d_dec  = 1
   _d_1ft  = 0.3
   _d_10ft = 3
   _d_2ft  = 0.6
   _d_20ft = 6
   _d_30ft = 9
   _d_50ft = 15
   _d_100ft = 30
   _d_tolerance = 0.01
   _s_units = ^metric^
   define "~warning text symbology" off=0.000 LvName = XS Text Warning co=3  wt=1 ft=5 th=0.5 tw=0.5 just=lc angle=90
  }

define "~rtloc text symbology" num of dec place=_d_dec off=0.0 LvName = RD Limits of Construction Text co=60 wt=1 ft=5 just=rc th=_d_text_size tw=_d_text_size 
define "~ltloc text symbology" num of dec place=_d_dec off=0.0 LvName = RD Limits of Construction Text co=60 wt=1 ft=5 just=lc th=_d_text_size tw=_d_text_size
define "~slope text symbology" num of dec place=_d_dec off=0.0 LvName = RD Ditch Flow Text co=62 wt=1 ft=5 just=cc th=_d_text_size tw=_d_text_size
define "~ditch line symbology" LvName = RD Ditch Flow Lines wt=0 co=16 lc=6
define "~loc symbology"        Lvname = RD Limits of Construction wt=1 co=73 lc=0


/******************** Define materials in sections to use for calculations *************************/


define_dgn "finished grade"  dgn= xs_file LvName=XS Grading co=4
define_dgn "subgrade"        dgn= xs_file LvName=XS Grading co=5
define_dgn "milling line"    dgn= xs_file LvName=XS Milling

/******************** Determine if working in side slope left or side slope right *****************/
if (1=1) then
{
  _s_DesignChainSpecified = ^no^
  mark x400 y400
  draw skip to xpgl ypgl
  mark x1 y1
  
  mark _mp_anchor
  mark _mp_hp1          /*  marked here and moved later if used  */
  mark _mp_fill_tie     /*  marked here and moved later if used  */
  mark _mp_in_fldit     /*  marked here and moved later if used  */
  mark _mp_out_fldit    /*  marked here and moved later if used  */
  mark _mp_tie_point    /*  marked here and moved later if used  */
  mark _mp_turf_shldr   /*  marked here and moved later if used  */
  
  draw skip dx=1 dy=0
  mark x2 y2
    if (x2<x1) then
      {
      _s_side="left"
      draw skip to xpgl ypgl
      }
    else
      {
      _s_side="right"
      draw skip to xpgl ypgl
      }
  draw skip dx=0 dy=_d_10ft  
  _s_subgrade_test = "passed"     /* Initialize for later  */
}

if not (_mp_prompt) then
   {
      /* ##################### Criteria Tolerance Check ###########*/

    if (tolerance > 0.01) then
      {
        prompt ^**ERROR** - Cross Section Run Tolerance Too Large, use 0.01^ mode = message
        exit
      }  
  
    /*##########################################################*/
      
      _s_test_left = "passed"
      _s_test_right = "passed"
      mark _mp_prompt
      _s_chain = chain name
      _s_filename = _s_chain + "_slpstk.csv"
      
      _s_section_type="divided"
      _s_display_units = _s_units
      ascii open file = _s_filename
      ascii write file = _s_filename
      format = ^%s,%s\n^
      var = _s_section_type,_s_display_units
            
      _s_XSAnnotate = "No"
      Prompt ^Annotate Cross Sections?  Yes or No^ variable = _s_XSAnnotate mode = option content = Yes, No
      if (CANCEL) then {EXIT}
      
      _s_plot = "Yes"
      Prompt ^Plot Limits of Construction and Ditch Lines?  Yes or No^ variable = _s_plot mode = option content = Yes, No
      if (CANCEL) then {EXIT}
       if (_s_plot="Yes") then
        {
         _s_planview = "Please Select"
         Prompt ^Select Plan View Drawing^ variable = _s_planview mode = file select filter = *.dgn
         if (CANCEL) then {EXIT}
         
         while _s_planview = "Please Select"
           {
            Prompt ^You MUST Select a Plan View Drawing^ variable = _s_planview mode = file select filter = *.dgn
            if (CANCEL) then {EXIT}
           }
         
         if "Plan view scale" < 499 then
           {  
            Prompt ^The MAST cell library must be attached!^ mode = message
            if (CANCEL) then {EXIT}
           }
         else
           {
            Prompt ^The MMAST cell library must be attached!^ mode = message
            if (CANCEL) then {EXIT}
           } 
         } 
                 
/********************* Determine if distances are to be from design line or base line **************/         
         _s_line = "CrossSectionCenterline"
         PROMPT ^Offsets computed from Cross Section Centerline or DesignLine?^ VARIABLE = _s_line MODE = OPTION CONTENT = CrossSectionCenterline, DesignLine
         if (CANCEL) then {EXIT}
         if (_s_line="DesignLine") then
           {
             _s_deschain = "Please Enter"
             Prompt ^Name of Chain that Offsets are computed from^ variable = _s_deschain mode = keyin
             if (CANCEL) then {EXIT}
                                              
             draw skip to x1 y1
             _s_DesignChainSpecified = ^yes^
             _s_chain = _s_deschain
           }         
                       
        
  
   }

/********************* Error checking for presence of completed tie slopes **************/
if (material below = "subgrade") then
{
   _s_clcondition = ^SGCLE^
   draw skip dx=0 dy=_d_10ft
   draw skip dx=0 dy=-1 to xs "subgrade"
   mark x199 y199
   draw skip trace "subgrade" out off = 0 for dx=1000
   mark x10 y10
   draw skip trace "subgrade" in off=0 for dx=_d_2ft
   mark x11 y11
   draw skip dx=abs(x10 - x11) dy=(y10 - y11) to xs "finished grade"
   mark x20 y20
   draw skip trace "finished grade" out off = 0 for dx = 2 
   mark x21 y21
   draw skip trace "finished grade" out off = 0 for dx=1000
   mark x30 y30
   draw skip dx=0 dy=_d_100ft
   mark x346 y346
   draw skip dx=0 dy=-1 to exist ground
   mark x345 y345
   draw skip to x30 y30
}

else if (material below = "milling line") then
{
   _s_clcondition = ^EXCLE^
   while material below = "milling line"
     {
      draw skip dx=_d_1ft dy=0
     }
   draw skip dx=_d_1ft dy=0
   draw skip dx=0 dy=_d_10ft
   draw skip dx=0 dy=-1 to xs "subgrade"
   mark x199 y199
   draw skip trace "subgrade" out off = 0 for dx=1000
   mark x10 y10
   draw skip trace "subgrade" in off=0 for dx=_d_2ft
   mark x11 y11
   draw skip dx=abs(x10 - x11) dy=(y10 - y11) to xs "finished grade"
   mark x20 y20
   draw skip trace "finished grade" out off = 0 for dx=1000
   mark x30 y30
   draw skip dx=0 dy=_d_100ft
   mark x346 y346
   draw skip dx=0 dy=-1 to exist ground
   mark x345 y345
   draw skip to x30 y30
}

else /* incomplete section stop processing*/
{
 _s_subgrade_test = "failed"
 mark x10 y10
 draw skip dx=_d_1ft dy=0
 mark x20 y20
 mark x30 y30   
 draw text char = ^Incomplete Section^ "~warning text symbology"

}

if (abs(x20-x10)> 100* tolerance) then /* Subgrade not close enough to proposed Finished Grade */
{
   
   /* determine station and chain values */
   _s_sta=cvt_d_sta(station)
   _s_problem = "Error, Proposed Subgrade Does Not Tie To Proposed Finished Grade"
   _s_chain_label = _s_chain + " " + _s_clcondition
   ascii append file = _s_filename
   ascii write file = _s_filename
   format = ^%s,%s,%s\n^
   var = _s_chain_label,_s_sta,_s_problem
   draw skip to x10 y10
   draw text char = ^Gap in Subgrade^ "~warning text symbology"
         
   if _s_side="left" and (median width > 1000) then
     {
      _s_test_left = "failed"
     }
   else if _s_side="right" and (median width > 1000) then
     {
      _s_test_right = "failed"
     }
     
     
}

else if _s_subgrade_test = "failed" then /* Subgrade or milling line not found */
{
   
   /* determine station and chain values */
   _s_sta=cvt_d_sta(station)
   _s_problem = "Error, Subgrade line not found"
   _s_chain_label = _s_chain + " " + _s_clcondition
   ascii append file = _s_filename
   ascii write file = _s_filename
   format = ^%s,%s,%s\n^
   var = _s_chain_label,_s_sta,_s_problem
   draw skip to x10 y10
   draw text char = ^Subgrade line not found^ "~warning text symbology"
         
   if _s_side="left" and (median width > 1000) then
     {
      _s_test_left = "failed"
     }
   else if _s_side="right" and (median width > 1000) then
     {
      _s_test_right = "failed"
     }
     
     
}

else if (abs(x11-x20) < 2 * tolerance) then /* Incomplete section subgrade does not intersect Finished Grade */
{
   
  /* determine station and chain values */
  _s_sta=cvt_d_sta(station)
  _s_problem = "Error, Proposed Subgrade Does Not Tie To Proposed Finished Grade"
  _s_chain_label = _s_chain + " " + _s_clcondition
  ascii append file = _s_filename
  ascii write file = _s_filename
  format = ^%s,%s,%s\n^
  var = _s_chain_label,_s_sta,_s_problem
  draw skip to x10 y10
  draw text char = ^Subgrade Does Not Intersect^ "~warning text symbology"
          
  if _s_side="left" and (median width > 1000) then
     {
      _s_test_left = "failed"
     }
   else if _s_side="right" and (median width > 1000) then
     {
      _s_test_right = "failed"
     }
}

else if (abs(y346-y345) < 2*tol) and (median width > 1000) then /*  existing ground not present at tie point check */
{
  /* determine station and chain values */
  _s_sta=cvt_d_sta(station)
  _s_problem = "Error, Proposed Finished Grade Does Not Tie To Existing Ground"
  _s_chain_label = _s_chain + " " + _s_clcondition
  ascii append file = _s_filename
  ascii write file = _s_filename
  format = ^%s,%s,%s\n^
  var = _s_chain_label,_s_sta,_s_problem
  draw skip to x30 y30
  draw text char = ^Section Does Not Close^ "~warning text symbology"
     
 
  if _s_side="left" and (median width > 1000) then
     {
      _s_test_left = "failed"
     }
   else if _s_side="right" and (median width > 1000) then
     {
      _s_test_right = "failed"
     }
}


else if (abs(elev diff at x30 y30) > 4* tolerance) and (median width > 1000) then /* Incomplete section, and not in median  */
{
   
  /* determine station and chain values */
  _s_sta=cvt_d_sta(station)
  _s_problem = "Error, Proposed Finished Grade Does Not Tie To Existing Ground"
  _s_chain_label = _s_chain + " " + _s_clcondition
  ascii append file = _s_filename
  ascii write file = _s_filename
  format = ^%s,%s,%s\n^
  var = _s_chain_label,_s_sta,_s_problem
  draw skip to x30 y30
  draw text char = ^Section Does Not Close^ "~warning text symbology"
     
 
  if _s_side="left" and (median width > 1000) then
     {
      _s_test_left = "failed"
     }
   else if _s_side="right" and (median width > 1000) then
     {
      _s_test_right = "failed"
     }
 }

else if (abs(x400-x10) > (Median Width)*.666) then  /* Pavement Cross Over, Median does not exist */
{
  /* determine station and chain values */
  _s_sta=cvt_d_sta(station)
  _s_problem = "Note, Median Not Present"
  _s_chain_label = _s_chain + " " + _s_clcondition
  ascii append file = _s_filename
  ascii write file = _s_filename
  format = ^%s,%s,%s\n^
  var = _s_chain_label,_s_sta,_s_problem
  
 }

else if (abs(y20 - y21) < 2 * tolerance) then  /* flat bottom ditch at subgrade point, irregular xsec */
{
  /* determine station and chain values */
  _s_sta=cvt_d_sta(station)
  _s_problem = "Note, Irregular Median - See Cross Sections"
  _s_chain_label = _s_chain + " " + _s_clcondition
  ascii append file = _s_filename
  ascii write file = _s_filename
  format = ^%s,%s,%s\n^
  var = _s_chain_label,_s_sta,_s_problem
  draw skip to x20 y20
  draw text char = ^Irregular Median^ "~warning text symbology"
 } 
 

else /* Proposed ties are in place, continue with processing */
{
if (1=1) then
{
/******************* Intialize all out put variables **********************************************/
    _s_sta="n/a"
    _d_cle=999
    _d_cle_dy=999
    _d_hpdy=999
    _d_hpdx=999
    _d_hp1dy=999
    _d_hp1dx=999
    _s_tie_type="n/a"
    _d_in_fldit_dy=999
    _d_in_fldit_dx=999
    _d_dit_fl=999
    _d_dit_bs=999
    _d_bs_dx=999
    _d_dit_wid=999
    _d_fs_dy=999
    _d_fs_dx=999
    _d_fslope=999
    _d_med_el=999
    _d_med_slp=999
    _s_med_type="999"
    _s_hp_message="n/a"
    _d_okay_slope = 1
}

if (median width > 1000) and (_s_side = "left") or
   (median width > 1000) and (_s_side = "right") then
  {
   draw skip to xpgl ypgl
   mark x80 y80
   draw skip trace in off=0 for dx=1000
   draw skip dx=1 dy=0 to chain _s_chain
   draw skip dx=0 dy=50
   draw skip dx=0 dy=-1 to y80
   mark x81 y81
   _d_chain_offset = (x80-x81)
   draw skip to x80 y80
  }
else 
  {
   draw skip to xpgl ypgl
   mark x80 y80
   draw skip trace in off=0 for dx=1000
   draw skip dx=1 dy=0 to chain _s_chain
   draw skip dx=0 dy=50
   draw skip dx=0 dy=-1 to y80
   mark x81 y81
   _d_chain_offset = (x80-x81)
   draw skip to x80 y80
  }


/*********************************** Divided Criteria **************************************/

if (_s_section_type = "divided") then
{

   draw skip to xpgl ypgl
     
  /* determine station and chain values */
  _s_sta=cvt_d_sta(station)
    
  /* mark proposed subgrade centerline elevation */
   draw skip dx=0 dy=_d_10ft
     if (material below = "subgrade") then
       {
        draw skip dx=0 dy=-1 to xs "subgrade"
        _s_clcondition = ^SGCLE^
       }
     else
       {
        draw skip dx=0 dy=-1 to xs "milling line"
        _s_clcondition = ^EXCLE^
       }
   mark _mp_cle
   _s_chain_label = _s_chain + " " + _s_clcondition
  
  /* mark existing ground at centerline elevation location */
  draw skip dx=0 dy=_d_30ft
  draw skip dx=0 dy=-1 to existing ground
  mark _mp_exgrdcle
  draw skip to _mp_cle
  
  /* Compute variables at centerline */
  _D_CLE=_mp_cle.elev
  _D_CLE_DY=(_mp_cle.elev-_mp_exgrdcle.elev)
  
  /* Compute variables at edge of proposed subgrade */
  draw skip dx=0 dy=_d_10ft
    if (material below = "subgrade") then
     {
      draw skip dx=0 dy=-1 to xs "subgrade"
     }
    else
     {
       while material below = "milling line"
        {
         draw skip dx=_d_1ft dy=0
        }
       draw skip dx=0 dy=-1 to xs "subgrade"
     }
  draw skip to x20 y20
mark _mp_end_subgrade
mark x355 y355
  _D_HPDY=(_mp_end_subgrade.elev-_mp_cle.elev)
  _D_HPDX=(abs(_mp_end_subgrade.off-_mp_cle.off))

  /* Determine if section is in cut, fill, cut with no back slope or sheared */
  if (median width > 1000) then
    {
      draw skip to x30 y30
      mark _mp_tie_point
      draw skip trace "finished grade" in off=0 for dx=_d_1ft
      mark _mp_test
      mark x40 y40
        if (abs(x30 -x40) < 2 * tolerance) then  /* Sheared Section  */        
          {
           _S_TIE_TYPE="S"
           draw skip to _mp_end_subgrade
           _d_okay_slope = 0
           _s_hp_message = "Note, Sheared Section, See Cross Sections"
          }
/*   R1 else if (_mp_test.elev > _mp_tie_point.elev) then */      /* Fill Section */
        else if (_mp_test.elev - _mp_tie_point.elev> tolerance) then /* Fill Section */
          {
           _S_TIE_TYPE="F"
           call sub ireg_foreslope_test
           draw skip to _mp_end_subgrade
          }
        else if _mp_test.elev < (_mp_tie_point.elev - 2*tolerance) then  /* Cut Section with Back Slope */
          {
            _S_TIE_TYPE="C"
           call sub ireg_foreslope_test
           call sub ireg_backslope_test
           draw skip to x99 y99
           mark _mp_in_fldit
           mark x3 y3
           draw skip trace "finished grade" out off=0 for dx = tolerance
           draw skip trace "finished grade" out off=0 to endpoint
           
           
/*  Added lines to check for multiple points on ditch bottoms because of OpenRoads  */ 
/*  Tom Sawyer 10/14/2014  */ 
/*  Added loopfail to keep the loop from failing - Tom Sawyer 12-04-2015  */

           mark _mp_test2
           _d_loopfail = 0
           while (_mp_test2.elev - y3 < 2 * tolerance) and _d_loopfail < 50 
              {
                draw skip trace "finished grade" out off=0 for dx = tolerance
                draw skip trace "finished grade" out off=0 to endpoint
                mark _mp_test2
                _d_loopfail = _d_loopfail + 1
              }
           draw skip trace "finished grade" in off=0 for dx = tolerance
           draw skip trace "finished grade" in off=0 to endpoint

/*  End Added lines to check for multiple points on ditch bottoms because of OpenRoads  */                  
           
           
           mark _mp_out_fldit
           mark x98 y98
             if ((abs(y3-y98)) > 2* tolerance) then /* "V" Ditch Exists need to reset _mp_in_fldit to same as _mp_out_fldit */
              {
               draw skip to x99 y99
               mark _mp_out_fldit
               mark x3 y3
               _s_ditchtype = ^v^
              }
            else
              {
                _s_ditchtype = ^fbd^
              }
           draw skip to _mp_end_subgrade
          }       
       else  /* This is a cut section with no back slope */
          {
           _S_TIE_TYPE="CNBS"
           call sub ireg_foreslope_test
           draw skip to _mp_tie_point
           mark _mp_out_fldit
           draw skip trace "finished grade" in off=0 for dx=tolerance
           draw skip trace "finished grade" in off=0 to endpoint
           mark _mp_in_fldit
           mark x3 y3
           draw skip to _mp_end_subgrade
          
          }
      
    }
    else /* Median Condition */
    {
       call subroutine median_type
    }
   /* Determine number and location of hinge points */
  
   if (_S_TIE_TYPE="F") and (median width > 1000) then
    {
      if (_d_okay_slope = 1) then
       {
         call subroutine fill_hinge_points
       }
      draw skip to _mp_tie_point
      _d_elev = _mp_tie_point.elev
       
         if (_s_plot="yes") then
          { 
           call subroutine draw_ditches (plan view = _s_planview)
          }
         else
          {
           draw dx=0 dy=0
          }     
    
    }
   else if (_S_TIE_TYPE="S") then
    {
     draw skip to _mp_tie_point
     _d_elev = _mp_tie_point.elev
       
       if (_s_plot="yes") then
        { 
         call subroutine draw_ditches (plan view = _s_planview)
        }
       else
        {
         draw dx=0 dy=0
        }     
    }  
   else if (_s_tie_type="c") and (median width > 1000) then
    {
      if (_d_okay_slope = 1) then
        { 
         call subroutine cut_hinge_points
        }
      _d_elev = _mp_in_fldit.elev
      draw skip to _mp_tie_point
    
        if (_s_plot="yes") then
          { 
           call subroutine draw_ditches (plan view = _s_planview)
          }
        else
          {
           draw dx=0 dy=0
          }
    } 
    else if (_s_tie_type="cnbs") and (median width > 1000) then
    {
     if (_d_okay_slope = 1) then
        { 
         call subroutine cut_hinge_points
        }
     _d_elev = _mp_in_fldit.elev
     draw skip to _mp_tie_point
    
      if (_s_plot="yes") then
        { 
         call subroutine draw_ditches (plan view = _s_planview)
        }
       else
        {
         draw dx=0 dy=0
        }
    } 
    else
    {
    call subroutine median_hinge_points
    }
/*********************************** Output Data to ACSII File ****************************************/
  
  
  if (_d_okay_slope = 1) then
    {
      ascii write file = _s_filename
      format =^%s,%s,%.3f,%.3f,%.3f,%.3f,%.3f,%.3f,%s,%.3f,%.3f,%.3f,%.3f,%.3f,%.3f,%.3f,%.3f,%.3f,%s,%.3f\n^
      var = _s_chain_label,_s_sta,_d_cle,_d_cle_dy,_d_hpdy,_d_hpdx,_d_hp1dy,_d_hp1dx,_s_tie_type,_d_in_fldit_dy,_d_in_fldit_dx,_d_dit_fl,_d_dit_bs,_d_bs_dx,_d_dit_wid,_d_fs_dy,_d_fs_dx,_d_fslope,_s_med_type,_d_chain_offset
    }
  
  else /* Irregular section */
    {
      ascii write file = _s_filename
      format =^%s,%s,%s\n^
      var = _s_chain_label,_s_sta,_s_hp_message
    }

}

/*==xxx=================================================================================================================*/
/*=================================    Annotate Cross sections    ===================================================*/
/*===================================================================================================================*/

if (_s_XSAnnotate = "Yes") and (_d_okay_slope = 1) then
  {
    
/*     LABEL PGL     */

    if px1 < px2 then
      {
        _d_pglel = ypgl
        _s_pglel = cvt_d_s2(_d_pglel)
        draw skip to xpgl ypgl
        draw skip dx=0 dy=_d_txoff
        draw text value = _s_pglel
          "~pgl elev text symbology"
      }  
 
    draw skip trace in off=0 for dx=1000
    draw skip dx=1 dy=0 to chain _s_chain
    mark x998 y998
    
/*     LABEL END OF SUBGRADE     */    
    
    draw skip to _mp_end_subgrade
    call sub offset_elevation

/*     LABEL TURF SHOULDER POINT (COMPUTED)     */

    mark x345 y345
    mark x503 y503
    draw skip trace "finished grade" in off=0 for dx = 2 * tolerance
    draw skip trace "finished grade" in off=0 for dx = 1000
    mark x500 y500
    draw skip to x345 y345
    draw skip trace "finished grade" in off=0 for dx = 2 * tolerance
    draw skip trace "finished grade" in off=0 to endpoint
    mark x501 y501
    draw skip trace "finished grade" in off=0 for dx = 2 * tolerance
    draw skip trace "finished grade" in off=0 to endpoint
    mark x502 y502
    _d_looptest = 1
    _d_back_slope = 1
    _d_ahead_slope = 1
    while abs(_d_back_slope - _d_ahead_slope) < (10 * tolerance) and _d_looptest < 50
      {
        
        _d_back_slope= 1/(abs((y501-y345)/(x501-x345)))
        _d_ahead_slope=1/(abs((y501-y502)/(x501-x502))) 
        if abs(_d_back_slope - _d_ahead_slope)> 10*tolerance then
          {
            draw skip to x501 y501
            mark x503 y503
            _d_looptest = 50
          }
        mark x501 y501
        draw skip trace "finished grade" in off=0 for dx = 2 * tolerance
        draw skip trace "finished grade" in off=0 to endpoint
        mark x502 y502
        if abs(x500 - x501) < tolerance then
          {
            _d_looptest = 50
          }
        _d_looptest = _d_looptest + 1
      }  
    /*  End While  */
    
    
    if abs(x503 - x345) > tolerance then         /*  turf shoulder found  */
      {
        draw skip to x503 y503
        mark _mp_turf_shldr
        call sub offset_elevation                                  
        draw skip to _mp_end_subgrade
      }
    else                                 /*  more than one vertex found   */
      {
        draw text char = ^Shoulder not drawn correctly^ "~warning text symbology"
      }  
    
                                  

/* ============================================================================ */
/* ============================================================================ */
/* ========================  LABEL FILL SECTION  ============================== */
/* ============================================================================ */
/* ============================================================================ */

/*     LABEL FILL LOC    */
    
    if _s_tie_type = ^f^ then     /*  if in fill  */
      {
        draw skip to _mp_fill_tie
        call sub offset_elevation
        mark x356 y356
      
/*     LABEL HINGE POINT     */           
                
        draw skip to _mp_hp1
        mark x347 y347
            
        if abs(x347 - x1) > 2 * tolerance then    /*  HINGE POINT EXISTS  */
          {
            mark x345 y345
            call sub offset_elevation
            _s_HPTest = ^yes^
          }
            

/*     LABEL FORESLOPES     */
            
        draw skip to _mp_turf_shldr
        mark x348 y348
        
        if abs(x347 - x1) > 2 * tolerance then
          {
            draw slope text between X356 Y356 and X345 Y345
                   "~slope text symbology"      
            draw slope text between x345 y345 and X348 Y348
                   "~slope text symbology"     
          }
        else
          {
            draw slope text between X356 Y356 and X348 Y348
                   "~slope text symbology"
          }                  
        
/*     LABEL FILL LOC     */        
        
        draw skip to _mp_fill_tie 
        mark x345 y345
        call sub offset_elevation  
        
      }

/* ============================================================================ */
/* ============================================================================ */
/* ========================  LABEL CUT SECTION  =============================== */
/* ============================================================================ */
/* ============================================================================ */

    if _s_tie_type = ^c^ or _s_tie_type = ^cnbs^ then   /*  in cut  */
      { 
        
/*     LABEL CUT LOC     */        
        
        draw skip to _mp_tie_point 
        mark x353 y353                      
        mark x345 y345
        call sub offset_elevation
          
/*     LABEL OUTSIDE DITCH     */          
          
            draw skip to _mp_out_fldit
            mark x352 y352
            call sub offset_elevation            
            
/*     LABEL INSIDE DITCH     */            
            
            draw skip to _mp_in_fldit
            mark x351 y351
            call sub offset_2
            
/*     LABEL DITCH FLOW LINE     */            
            
            draw skip dx=abs(x351-x352)/2 dy=0
            draw elevation text
                  "~elevation text symbology"
            
/*     LABEL BACKSLOPE     */            
            
            if abs(x352 - x353) > 1 then
              {
                 draw slope text between x353 y353 and x352 y352
                    "~slope text symbology"
              }      
/*     LABEL HINGE POINT     */           
                
            draw skip to _mp_hp1
            mark x347 y347
            if abs(x347 - x1) > 2 * tolerance then    /*  HINGE POINT EXISTS  */
              {
                mark x345 y345
                call sub offset_elevation
                _s_HPTest = ^yes^
              }
            

/*     LABEL FORESLOPES     */
            
            draw skip to _mp_turf_shldr
            mark x348 y348
            
            if abs(x347 - x1) > 2 * tolerance then   /*  HINGE POINT EXISTS  */
              {
                draw slope text between X351 Y351 and X345 Y345
                       "~slope text symbology"      
                draw slope text between x345 y345 and X348 Y348
                       "~slope text symbology"     
              }
            else
              {
                draw slope text between X351 Y351 and X348 Y348
                       "~slope text symbology"
              }    
            
/*     LABEL EXISTING GROUND INTERSECT POINT (COMPUTED)     */           
                
            if abs(x347 - x1) > 2 * tolerance then   /*  HINGE POINT EXISTS  */
              {
               draw skip to _mp_hp1
               mark x347 y347
               _d_run = abs(x351 - x347)
               _d_rise = y351 - y347
               draw skip dx=_d_run dy=_d_rise to existing ground
               call sub offset_2
              }
            else
              {
                draw skip to _mp_turf_shldr                     
                mark x348 y348
                _d_run = abs(x351 - x348)
                _d_rise = y351 - y348
                draw skip dx=_d_run dy=_d_rise to existing ground
                call sub offset_2                                       
              }  
      }  
      
      

/* ============================================================================ */
/* ============================================================================ */
/* ========================  LABEL MEDIAN SECTION  ============================ */
/* ============================================================================ */
/* ============================================================================ */

    if _s_tie_type = ^M^ and _s_med_type = ^SSTOFBD^ then   /*  CASE 5 median and single slope to flat bottom ditch  */
      {
        if _s_side = ^right^ then
          {
            draw skip to x200 y200
            call sub offset_elevation
            draw skip to x201 y201
            call sub offset_elevation
            draw skip dx = abs((x201-x202)/2) dy = (y201 - y202)/2
            draw elevation text
                  "~elevation text symbology"   
          }
        else
          {
            draw skip to x201 y201
            call sub offset_elevation
          }             
        draw slope text between x200 y200 and x201 y201
             "~slope text symbology"
      }
    else if _s_tie_type = ^M^ and _s_med_type = ^SSTOGRD^ then   /*  CASE 1 median and single slope to existing ground  */
      {   
        draw skip to x200 y200
        call sub offset_elevation
        draw skip to x202 y202
        call sub offset_elevation
        draw slope text between x200 y200 and x202 y202
             "~slope text symbology"
      }      
      
        
  }

/*======================================================================================*/
/*======================================================================================*/
/*=======================  SUBROUTINES  ================================================*/
/*======================================================================================*/
/*======================================================================================*/

subroutine ireg_foreslope_test  /* Checks for irregular foreslope section */
{
  if (1=1) then 
  {
   _d_count_points = 0  
   _d_okay_slope = 1
    if _s_tie_type = "F" then /* Fill Section */
      {
        draw skip to x30 y30
        mark x99 y99 /* mark low point */
      }
     else /* cut section - establish low point of ditch and mark low point x99 y99 */
      {
       draw skip to x20 y20
       mark x99 y99
       mark x98 y98
         while (abs(x98 - x30) > 2*tolerance) 
         {
           draw skip trace "finished grade" out off=0 for dx=2*tolerance
           draw skip trace "finished grade" out off=0 to endpoint
           mark x98 y98
            if ((y99 - y98) > 2* tolerance) then /* Ahead Point is lower */
              {
                mark x99 y99
              }
          }
      }
   draw skip to x20 y20
   draw skip trace "finished grade" out off=0 for dx=2*tolerance
   draw skip trace "finished grade" out off=0 to endpoint
   mark x77 y77
   draw skip trace "finished grade" out off=0 for dx=2*tolerance
   draw skip trace "finished grade" out off=0 to endpoint
   mark x78 y78
   
    if ((abs(y78 - y99)) < 2* tolerance) then /* Slope is okay continue */
      {
       _d_okay_slope = 1
      }
    else /* Check for irregular foreslope slope */
    {
     draw skip to x20 y20 /* intialize pointer to subgrade tie point */
     mark x76 y76 /* Back Point */
     mark x77 y77 /* Current Point */
     mark x78 y78 /* Ahead Point */
     /* When 77 = 78 then no ahead slope can be calculated, either false HP or irr. section was found */ 
     while y77 > y99 and _d_okay_slope = 1 /* determine how many broken back points */
      {
       draw skip trace "finished grade" out off=0 for dx=2*tolerance
       draw skip trace "finished grade" out off=0 to endpoint
       mark x77 y77
       draw skip trace "finished grade" out off=0 for dx=2*tolerance
       draw skip trace "finished grade" out off=0 to endpoint
       mark x78 y78
       if (abs(x78-x77) > 2 * tolerance) or ((y77-y78)> 2* tolerance) then /* Continue...The points are not the same */ 
        {
           _d_bs = (abs(y76-y77)/abs(x76-x77))
           _d_as = (abs(y77-y78)/abs(x77-x78))
             if (abs(_d_bs-_d_as) < (6* tolerance)) then /* False Hinge Point - Reset all points to 77 */
               {
                 draw skip to x77 y77
                 mark x76 y76
                 mark x78 y78
               }
             else /* Broken Back Hinge Point Found */
               {
                 draw skip to x77 y77
                 mark x76 y76
                 mark x78 y78
                 mark _mp_true_hp1
                _d_count_points = _d_count_points + 1
                
                if abs(y77 - y99) < 2*tolerance then
                  {
                    _d_count_points = _d_count_points - 1
                  }
               }
             if _d_count_points <= 1 then /* Okay, have not exceeded acceptable number of slopes */
               {
                _d_okay_slope = 1
               } 
             else /* Exceeded allowable number of foreslopes */
               {
                 _d_okay_slope = 0
                   if _s_tie_type = "F" then
                    {
                     _s_hp_message = "Note, Maximum Number Of Fill Hinge Points Exceeded"
                     draw text char = ^Maximum Number Of Fill Hinge Points Exceeded^ 
                          "~warning text symbology"
                    }
                   else
                    {
                     _s_hp_message = "Note, Maximum Number Of Foreslope Hinge Points Exceeded"
                     draw text char = ^Maximum Number Of Foreslope Hinge Points Exceeded^ 
                          "~warning text symbology"
                    } 
               }
        } /* end if */
       else /* Exit while loop */
        {
          draw skip to x99 y99
          mark x77 y77
        } 
      } /* end while */  
       
    } /* else */
  } /* fill slope check */
} /* sub end */
end sub

subroutine ireg_backslope_test  /* Checks for irregular backslope section */
{
  if (_d_okay_slope = 1) then 
  {
   _d_count_points = 0  
   _d_okay_slope = 1
   /* establish low point of ditch and mark low point x99 y99 */
   draw skip to x30 y30 /* Moves pointer to tie point at x30 y30 */
   draw skip trace "finished grade" in off = 0 for dx = 2*tolerance
   draw skip trace "finished grade" in off = 0 to endpoint
   mark x98 y98
     while ((y98 - y99) > 2*tolerance) /* The two points are different */ 
       {
         draw skip trace "finished grade" in off = 0 for dx = 2*tolerance
         draw skip trace "finished grade" in off = 0 to endpoint
         mark x98 y98
          if ((y99 - y98) > 2* tolerance) then /* Ahead Point is lower */
            {
              mark x99 y99
            }
        }
 
     draw skip to x30 y30
     mark x76 y76
     draw skip trace "finished grade" in off=0 for dx=2*tolerance
     draw skip trace "finished grade" in off=0 to endpoint
     mark x77 y77
     draw skip trace "finished grade" in off=0 for dx=2*tolerance
     draw skip trace "finished grade" in off=0 to endpoint
     mark x78 y78
       
     
    if ((abs(y77 - y99)) < 2* tolerance) then /* Slope is okay continue */
      {
       _d_okay_slope = 1
      }
    else /* Check for irregular back slope */
    {
     while (y77 > (y99 + 2 * tolerance)) and _d_okay_slope = 1 /* determine how many broken back points */
      {
       _d_bs = (abs(y76-y77)/abs(x76-x77))*100
       _d_as = (abs(y77-y78)/abs(x77-x78))*100

       draw skip trace "finished grade" in off=0 for dx=2*tolerance
       draw skip trace "finished grade" in off=0 to endpoint
       mark x77 y77
       draw skip trace "finished grade" in off=0 for dx=2*tolerance
       draw skip trace "finished grade" in off=0 to endpoint
       mark x78 y78
              
       if (abs(_d_bs-_d_as) < 2 * tolerance) then /* false hinge point found */ 
        {
          _d_okay_slope = 1
        } /* end if */

       else /* Invalid Broken Back Slope Found---Exit while loop */
        {
          _d_okay_slope = 0
          _s_hp_message = "Note, Non-Standard Backslope Hinge Point Found"
        } 
      } /* end while */  
       
    } /* else */
  } /* backslope check */
} /* sub end */
end sub

subroutine fill_hinge_points
 {
   mark _mp_prev
   draw skip trace "finished grade" out off=0 for dx=2*tol
   draw skip trace "finished grade" out off=0 to endpoint
   mark _mp_current
   draw skip trace "finished grade" out off=0 for dx=2*tol
   draw skip trace "finished grade" out off=0 to endpoint
   mark _mp_ahead
   
                
        if (abs(_mp_current.off - _mp_ahead.off) < 2*tolerance) then /* no hinge and ties to ground */
          {
            mark _mp_fill_tie
            _d_fs_dy=(_mp_end_subgrade.elev-_mp_fill_tie.elev)
            _d_fs_dx=(abs(_mp_end_subgrade.off-_mp_fill_tie.off))
            _d_fslope=(abs((_mp_end_subgrade.off-_mp_fill_tie.off)/(_mp_end_subgrade.elev-_mp_fill_tie.elev)))
          }
        else   
        /* additional hinge points may exist */
       
         {
          /* check for false hinge point */
           _d_back_slope=1
           _d_ahead_slope=1
           _d_stop_now=0
             while (abs(_d_back_slope-_d_ahead_slope) < 10*tolerance) and (abs(_mp_ahead.elev-_mp_current.elev) > 2*tolerance) and (_d_stop_now=0)
               {          
                 _d_back_slope= 1/(abs((_mp_current.elev-_mp_prev.elev)/(_mp_current.off-_mp_prev.off + tolerance)))
                 _d_ahead_slope=1/(abs((_mp_current.elev-_mp_ahead.elev)/(_mp_current.off-_mp_ahead.off + tolerance)))
                     if ((abs(abs(_d_back_slope)-abs(_d_ahead_slope))) > 6*tolerance) then  /* test slope */
                      /* Defined hinge Point */
                      {
                       draw skip to _mp_current
                       mark _mp_hp1
                       draw skip to _mp_ahead
                       mark x2 y2
                       _d_stop_now = 1
                      }
                     else /* False Hinge Point at _mp_current */
                      {
                      _mp_prev = _mp_current
                      _mp_current = _mp_ahead
                      draw skip to _mp_current
                      draw skip trace "finished grade" out off=0 for dx = 2* tolerance
                      draw skip trace "finished grade" out off=0 to endpoint
                      mark _mp_ahead
                      mark x2 y2
                      }
                    
               }  /* End While */      
                  if (elev diff at x2 y2 < 2* tolerance) and (abs(abs(_d_back_slope)-abs(_d_ahead_slope)) < 2*tolerance) then
                      /* at existing ground with only one fill slope */
                      {
                        mark _mp_fill_tie
                        _d_fs_dy=(_mp_end_subgrade.elev-_mp_fill_tie.elev)
                        _d_fs_dx=(abs(_mp_end_subgrade.off-_mp_fill_tie.off))
                        _d_fslope=(abs((_mp_end_subgrade.off-_mp_fill_tie.off)/(_mp_end_subgrade.elev-_mp_fill_tie.elev)))
                      } 
                
                
                  else /* two different fill slopes with intermediate hinge point */
                     {
                       _d_hp1dy=(_mp_end_subgrade.elev-_mp_hp1.elev)
                       _d_hp1dx=(abs((_mp_end_subgrade.off-_mp_hp1.off)))
                       draw skip trace "finished grade" out off=0 for dx=1000
                       mark _mp_fill_tie
                        _d_fs_dy=(_mp_hp1.elev-_mp_fill_tie.elev)
                        _d_fs_dx=(abs(_mp_hp1.off-_mp_fill_tie.off))
                        _d_fslope=(abs((_mp_hp1.off-_mp_fill_tie.off)/(_mp_hp1.elev-_mp_fill_tie.elev + tolerance)))
                    } 
        
        }
}  
end sub
 
subroutine cut_hinge_points
 {
   mark _mp_prev
   draw skip trace "finished grade" out off=0 to endpoint
   mark _mp_current
   mark _mp_ahead
     if(abs(_mp_in_fldit.elev-_mp_ahead.elev) > 2* tolerance) then
        {
        draw skip trace "finished grade" out off=0 to endpoint
        mark _mp_ahead
        }
      else
        {
        draw dx=0 dy=0
        } 
                
        if ((_mp_current.elev-_mp_ahead.elev) < 2*tolerance) then /* no hinge and stops at flowline of ditch */
          {
            mark _mp_in_fldit
            _d_in_fldit_dy=(_mp_end_subgrade.elev-_mp_in_fldit.elev)
            _d_in_fldit_dx=(abs(_mp_end_subgrade.off-_mp_in_fldit.off))
            _d_dit_fl=_mp_in_fldit.elev
              if (_s_tie_type="c") then  /* Back Slope Exists */
               {
                _d_dit_bs=(abs((_mp_out_fldit.off-_mp_tie_point.off)/(_mp_out_fldit.elev-_mp_tie_point.elev)))
                _d_bs_dx=(abs(_mp_out_fldit.off-_mp_tie_point.off))
                _d_dit_wid=(abs(_mp_out_fldit.off-_mp_in_fldit.off))
               }
               else /* No Back Slope! */
               {
               _d_dit_wid=(abs(_mp_out_fldit.off-_mp_in_fldit.off))
               }         
          }
        else   
        /* additional hinge points may exist */
       
         {
          /* check for false hinge point */
           _d_back_slope=1
           _d_ahead_slope=1
           _d_stop_now=0
             while (abs(_d_back_slope-_d_ahead_slope) < 2*tolerance) and (abs(_mp_ahead.elev-_mp_current.elev) > 2*tolerance) and (_d_stop_now=0)
               {          
                 _d_back_slope= abs((_mp_current.elev-_mp_prev.elev)/(_mp_current.off-_mp_prev.off))
                 _d_ahead_slope=(abs((_mp_current.elev-_mp_ahead.elev)/(_mp_current.off-_mp_ahead.off)))
                     if ((abs(_d_back_slope-_d_ahead_slope)) > 2*tolerance) then
                      /* Defined hinge Point */
                      {
                       draw skip to _mp_current
                       mark _mp_hp1
                      }
                     else if ((_mp_ahead.elev - _mp_out_fldit.elev) > 2* tolerance) then /* False Hinge Point Exist! */
                      {
                      _mp_prev = _mp_current
                      _mp_current = _mp_ahead
                      draw skip to _mp_current
                      draw skip trace "finished grade" out off=0 for dx=2*tolerance
                      draw skip trace "finished grade" out off=0 to endpoint
                      mark _mp_ahead
                      }
                      else
                      {
                      _d_stop_now=1
                      }
                                    
               }        
                  if  (abs(abs(_d_back_slope)-abs(_d_ahead_slope)) < 2*tolerance) then
                      /* at flowline of ditch with only one fill slope and false hinge point */
                      {
                        draw skip to _mp_in_fldit
                        _d_in_fldit_dy=(_mp_end_subgrade.elev-_mp_in_fldit.elev)
                        _d_in_fldit_dx=(abs(_mp_end_subgrade.off-_mp_in_fldit.off))
                        _d_dit_fl=_mp_in_fldit.elev
                           if (_s_tie_type="c") then  /* Back Slope Exists */
                             {                
                              _d_dit_bs=(abs((_mp_out_fldit.off-_mp_tie_point.off)/(_mp_out_fldit.elev-_mp_tie_point.elev)))
                              _d_bs_dx=(abs(_mp_out_fldit.off-_mp_tie_point.off))
                              _d_dit_wid=(abs(_mp_out_fldit.off-_mp_in_fldit.off))
                             }                          
                           else /* No Back Slope Exists! */
                           {
                           _d_dit_wid=(abs(_mp_out_fldit.off-_mp_in_fldit.off))
                           }   
                              
                      } 
                
                
                  else /* two different fill slopes with intermediate hinge point */
                     {
                        _d_hp1dy=(_mp_end_subgrade.elev-_mp_hp1.elev)
                        _d_hp1dx=(abs((_mp_end_subgrade.off-_mp_hp1.off)))
                        _d_in_fldit_dy=(_mp_hp1.elev-_mp_in_fldit.elev)
                        _d_in_fldit_dx=(abs(_mp_hp1.off-_mp_in_fldit.off))
                        _d_dit_fl=_mp_in_fldit.elev
                          if (_s_tie_type="c") then  /* Back Slope Exists */
                            {
                             _d_dit_bs=(abs((_mp_out_fldit.off-_mp_tie_point.off)/(_mp_out_fldit.elev-_mp_tie_point.elev)))
                             _d_bs_dx=(abs(_mp_out_fldit.off-_mp_tie_point.off))
                             _d_dit_wid=(abs(_mp_out_fldit.off-_mp_in_fldit.off))
                            }
                            else /* No Back Slope Exists */
                            {
                            _d_dit_wid=(abs(_mp_out_fldit.off-_mp_in_fldit.off))
                            }                  
                    } 
         }
} 
end sub


subroutine median_type
{
  call subroutine false_point_check
  _d_back_slope = (abs(y201-y200)/abs(x201-x200))
  _d_stop=0
  _s_tie_type="M"
  while _d_stop = 0
   {
     draw skip trace "finished grade" in off=0 for dx=_d_1ft
     draw skip trace "finished grade" out off=0 to endpoint
     draw skip trace "finished grade" out off=0 for dx = 2*tolerance
     draw skip trace "finished grade" out off=0 to endpoint
     
     /*  Added lines to check for multiple points on ditch bottoms because of OpenRoads  */ 
     /*  Tom Sawyer 10/14/2014  */          
      
     
     mark x344 y344
     mark x345 y345
     if abs(elevation difference at x345 y345) > 0.5*tolerance then
       {
         _d_loopfail = 0
         while abs(y345 - y201) < 0.1 * tolerance and _d_loopfail = 0 
           {
             draw skip trace "finished grade" out off=0 for dx = tolerance
             draw skip trace "finished grade" out off=0 to endpoint
             mark x345 y345
             if abs(x345 - x344)< tolerance then
               {
                 _d_loopfail = 1
               }
           }
             draw skip trace "finished grade" in off=0 for dx = tolerance
             draw skip trace "finished grade" in off=0 to endpoint
         }    

/*  End Added lines to check for multiple points on ditch bottoms because of OpenRoads  */     
     
     mark x202 y202
     mark x302 y302
       if (abs(x202-x201) < tolerance) then /* median slope ties to existing ground with only one slope */
        {
          _d_stop=1
          _s_median_type = "case1"
        }
      else if (abs(x202-x201) > tolerance) then /* Proposed Finished Grade Continues */
        {
         _d_ahead_slope = (y202-y201)/abs(x202-x201)
            if (abs(_d_ahead_slope) < tolerance) then /* One slope to flat bottom ditch */
              {
               _d_stop=1
               _s_median_type = "case5"
               _d_in_fldit_dx = abs(x201-x200)
               _d_in_fldit_dy = abs(y200-y201)
               _d_dit_fl = y201
               _d_dit_wid = abs(x202-x201) /* This assumes that bottom of ditch is one line */
              }
            else if (_d_ahead_slope > 0) then /* One slope to a "V" ditch */
             {
               _d_stop=1
               _s_median_type = "case3"
               _d_in_fldit_dx = abs(x201-x200)
               _d_in_fldit_dy = abs(y200-y201)
               _d_dit_fl = y201
             }  
            else /* Broken Back Slope Exists */
             {
               _d_back_slope=_d_ahead_slope
               mark x201 y201
               draw skip trace "finished grade" out off=0 to endpoint
               mark x202 y202
                 if (abs(x202-x201)) < tolerance then /* Broken Back Slope To Existing Ground */
                  {
                    _d_stop = 1
                    _s_median_type = "case2"
                    _d_hp1dx= abs(x301-x200)
                    _d_hp1dy= abs(y200-y301)
                    _d_fs_dy=(abs(y202-y301))
                    _d_fs_dx=(abs(x202-x301))
                    _d_fslope=(abs((x202-x301)/(y202-y301)))
                    
                  }
                 else /* Broken Back To Flat Bottom Or Broken Back To "V" */
                  {
                   _d_ahead_slope = (abs(y202-y201)/abs(x202-x201))
                  }
                    if (_s_median_type = "case2") then
                     {
                      draw skip dx=0 dy=0
                     }
                    
                    else if (_d_ahead_slope = 0) then /* Broken Back To Flat Bottom */
                     {
                       _d_stop = 1
                       _s_median_type = "case6"
                       _d_in_fldit_dx = abs(x302-x301)
                       _d_in_fldit_dy = abs(y301-y302)
                       _d_dit_fl = y302
                       _d_hp1dx= abs(x301-x300)
                       _d_hp1dy= abs(y300-y301)
                       _d_dit_wid = abs(x202-x201)
                    
                     }
                    else /* Broken Back To "V" */
                     {
                       _d_stop = 1
                       _s_median_type = "case4"
                       _d_in_fldit_dx = abs(x302-x301)
                       _d_in_fldit_dy = abs(y301-y302)
                       _d_dit_fl = y302
                       _d_hp1dx= abs(x301-x300)
                       _d_hp1dy= abs(y300-y301)
                     } 
                  
             } 
              
        }
   }
}
end sub

subroutine median_hinge_points
{
  if (_s_median_type = "case1") then
   {
     call subroutine fill_hinge_points
     _s_med_type="SSTOGRD"   
   }
  else if (_s_median_type = "case2") then
   {
     _s_med_type="BBSTOGRD"   
   }
  else if (_s_median_type = "case3") then
   {
     _s_med_type="SSTOV"   
   }
  else if (_s_median_type = "case4") then
   {
     _s_med_type="BBSTOV"   
   }
  else if (_s_median_type = "case5") then
   {
     _s_med_type="SSTOFBD"   
   }
   else 
   {
     _s_med_type="BBSTOFBD"   
   }

}
end sub

subroutine false_point_check
{
  mark x200 y200
  mark x300 y300
  draw skip trace "finished grade" out off = 0 for dx=1.1*tolerance
  draw skip trace "finished grade" out off = 0 to endpoint
  mark x201 y201
  mark x301 y301
  _d_back_slope = (abs(y201-y200)/abs(x201-x200))
  draw skip trace "finished grade" out off = 0 for dx = 2 * tolerance
  draw skip trace "finished grade" out off = 0 to endpoint
  mark x999 y999
   if ((y201-y999)>tolerance) then
    {
     _d_ahead_slope = (abs(y999-y201)/abs(x999-x201))
     while (abs(abs(_d_back_slope)-abs(_d_ahead_slope))) < tolerance and (y999 < y201)
      {
        mark x201 y201
        mark x301 y301
        _d_back_slope = (abs(y201-y200)/abs(x201-x200))
        draw skip trace "finished grade" in off = 0 for dx=_d_1ft
        draw skip trace "finished grade" out off = 0 to endpoint
        draw skip trace "finished grade" out off = 0 to endpoint
        mark x999 y999
            if (abs(x999-x201) > tolerance) then
              {
                _d_ahead_slope = (abs(y999-y201)/abs(x999-x201))
              }
            else
              {
                _d_ahead_slope = 100
              }
      }
     draw skip to x201 y201
    }
   else
    {
     draw skip to x201 y201
    }
}
end sub

subroutine draw_ditches
{
  /********************** Set variables for left or right side *****************************/
   if (_s_side = "left") then
     {
       mark _mp_lt_tie_pnt_curr
       _s_lt_tie_type = _s_tie_type
       
       if (_s_lt_tie_type = "c") then /* Cut section */
         {
           draw skip to _mp_out_fldit
           mark _mp_lt_out_fldit_curr
           draw skip to _mp_in_fldit
           mark _mp_lt_in_fldit_curr
         }
 
        else if (_s_lt_tie_type = "cnbs") then /* Cut section with no backslope */
         {
           draw skip to _mp_lt_tie_pnt_curr
           mark _mp_lt_out_fldit_curr
           draw skip to _mp_in_fldit
           mark _mp_lt_in_fldit_curr
         }
        else /* Fill section */
         {
          mark _mp_lt_out_fldit_curr
          mark _mp_lt_in_fldit_curr            
         } 
 
 /***************************** Plan View Draw Ditch On Left Side ****************************/

if not (_mp_lt_tie_pnt_prev) and (_s_side="left") then  /* First Section! Intialize "Prev" Marked Points */
  {
    _mp_lt_tie_pnt_prev = _mp_lt_tie_pnt_curr
    _mp_lt_out_fldit_prev = _mp_lt_out_fldit_curr
    _mp_lt_in_fldit_prev = _mp_lt_in_fldit_curr
    _d_prev_elev_lt = _d_elev
    draw gg=^Construction Limits^ cell = gpk1 xs=_d_cell_scale ys=_d_cell_scale
/*************************** Determine offset from baseline or designline *************************/    

    if _s_line = "CrossSectionCenterline" then        
      {
        _d_distance=cogo_offsetFromChain(_mp_lt_tie_pnt_curr,_s_chain)
      }
    else
      {
        _d_distance=cogo_offsetFromChain(_mp_lt_tie_pnt_curr,_s_deschain)
      }
/*                                                           */       
    if _S_TIE_TYPE="S" then               /* This next part    */
      {                                   /* puts the word     */
       _s_space = "  Sheared "            /* "Sheared" in the  */ 
      }                                   /* loc text if a     */
    else                                  /* sheared section   */
      {                                   /*                   */
       _s_space = "  "                    /*                   */
      }                                   /*                   */
/*                                                         */
          
    if "plan view scale" < 499 then
       {
        _s_offset_text = _s_space + cvt_d_s0(abs(_d_distance)) + "  "
       }
     else
       {  
        _s_offset_text = _s_space + cvt_d_s1(abs(_d_distance)) + "  "
       }
    
    _d_angle=cogo_tangentanglechain(_mp_lt_tie_pnt_curr,_s_chain) + 90
    draw gg=^Construction Limits^ text value = _s_offset_text 
           "~ltloc text symbology" angle=_d_angle
    
  }
else /* Continue */
  {
    /* Draw Limits of Construction */
    set plot parameters "~loc symbology"
    draw skip to _mp_lt_tie_pnt_curr
    draw gg=^Construction Limits^ cell = gpk1 xs=_d_cell_scale ys=_d_cell_scale
    
    if _s_test_left = "passed" then
      {
       draw skip to _mp_lt_tie_pnt_prev
       draw gg=^Construction Limits^ to _mp_lt_tie_pnt_curr
      }
    else
      {
       draw skip dx=0 dy=0
      }
/***************************** Determine offset from baseline or designline ****************************/

    if _s_line = "CrossSectionCenterline" then
      {
        _d_distance=cogo_offsetFromChain(_mp_lt_tie_pnt_curr,_s_chain)
      }
    else
      {
        _d_distance=cogo_offsetFromChain(_mp_lt_tie_pnt_curr,_s_deschain)
      }    
  /*                                                           */       
    if _S_TIE_TYPE="S" then               /* This next part    */
      {                                   /* puts the word     */
       _s_space = "  Sheared "            /* "Sheared" in the  */ 
      }                                   /* loc text if a     */
    else                                  /* sheared section   */
      {                                   /*                   */
       _s_space = "  "                    /*                   */
      }                                   /*                   */
  /*                                                         */
        
    if "plan view scale" < 499 then
      {
       _s_offset_text = _s_space + cvt_d_s0(abs(_d_distance)) + "  "
      }
    else
      {  
       _s_offset_text = _s_space + cvt_d_s1(abs(_d_distance)) + "  "
      }
    
    _d_angle=cogo_tangentanglechain(_mp_lt_tie_pnt_curr,_s_chain) + 90
    _d_lt_dit_wid_curr = abs(cogo_distance_between_points(_mp_lt_out_fldit_curr,_mp_lt_in_fldit_curr))
    _d_lt_dit_wid_prev = abs(cogo_distance_between_points(_mp_lt_out_fldit_prev,_mp_lt_in_fldit_prev))
    draw gg=^Construction Limits^ text value = _s_offset_text 
             "~ltloc text symbology" angle=_d_angle
    _d_dist = cogo_distance_between_points (_mp_lt_out_fldit_prev, _mp_lt_out_fldit_curr)
    _d_slope = ((_d_elev - _d_prev_elev_lt) / _d_dist) * 100.0
    _s_slope_text = cvt_d_s1(abs(_d_slope)) + "%"
    _d_angle2 = cogo_angle_between_points (_mp_lt_out_fldit_prev, _mp_lt_out_fldit_curr)  
    _d_lt_distance_between_tie_ditch = abs(cogo_distance_between_points(_mp_lt_tie_pnt_prev,_mp_lt_out_fldit_prev)) 
            
      if ((_d_lt_dit_wid_curr > tolerance) or (_d_lt_dit_wid_prev > tolerance) or 
          (_s_ditchtype = ^v^) or (_d_lt_distance_between_tie_ditch > tolerance)) and (_s_test_left = "passed") then /* Ditch Bottom Exists and prev section worked */ 
        {
         set plot parameters "~ditch line symbology"
         draw skip to _mp_lt_out_fldit_prev
         draw gg=^Ditch Lines^ to _mp_lt_out_fldit_curr
         if _s_ditchtype = ^fbd^ or (_d_lt_dit_wid_prev > 0) then /* if current or previous section was a flat bottom ditch */
           {
             draw skip to _mp_lt_in_fldit_prev
             draw gg=^Ditch Lines^ to _mp_lt_in_fldit_curr
           }
         /* Find center of ditch midway between sections */
         draw skip to _mp_lt_out_fldit_prev
         draw skip angle = _d_angle2 for distance = _d_dist/2.0
         draw skip angle = _d_angle2+270 for distance = ((_d_lt_dit_wid_curr+_d_lt_dit_wid_prev)/4)
           if (_d_slope < 0) then /* Water flows back station */
             {
              _d_angle3 = _d_angle2
              _d_angle2 = _d_angle2 - 180
              draw gg=^Ditch Labels^ cell = gpk2 xs=_d_cell_scale ys=_d_cell_scale angle =_d_angle3
              draw skip angle = _d_angle2+90 for distance = ((_d_lt_dit_wid_curr+_d_lt_dit_wid_prev)/2)
              _d_angle=_d_angle-90
              draw gg=^Slope Text^ text value = _s_slope_text 
                       "~slope text symbology" angle=_d_angle
             }
           else if (_d_slope > 0) then
             {
              _d_angle3 = _d_angle2 -180
              draw gg=^Ditch Labels^ cell = gpk2 xs=_d_cell_scale ys=_d_cell_scale angle = _d_angle3
              draw skip angle = _d_angle2+270 for distance = ((_d_lt_dit_wid_curr+_d_lt_dit_wid_prev)/2)
              _d_angle=_d_angle-90
              draw gg=^Slope Text^ text value = _s_slope_text 
                          "~slope text symbology" angle=_d_angle
             }
           else /* Ditch Elevations are equal no flow arrow  */
             {
               draw skip angle = _d_angle2+270 for distance = ((_d_lt_dit_wid_curr+_d_lt_dit_wid_prev)/2)
              _d_angle=_d_angle-90
              draw gg=^Slope Text^ text value = _s_slope_text 
                    "~slope text symbology" angle=_d_angle
             }
        
        
        }
      else   
       {
         draw dx=0 dy=0
       } 
        
    _mp_lt_tie_pnt_prev = _mp_lt_tie_pnt_curr
    _mp_lt_out_fldit_prev = _mp_lt_out_fldit_curr
    _mp_lt_in_fldit_prev = _mp_lt_in_fldit_curr
    _d_prev_elev_lt = _d_elev
    _s_test_left = "passed"
  }

}  
   else /* Right Side */
  /********************** Set variables for left or right side *****************************/
    {
       mark _mp_rt_tie_pnt_curr
       _s_rt_tie_type = _s_tie_type
       
       if (_s_rt_tie_type = "c") then /* Cut section */
         {
           draw skip to _mp_out_fldit
           mark _mp_rt_out_fldit_curr
           draw skip to _mp_in_fldit
           mark _mp_rt_in_fldit_curr
         }
 
        else if (_s_rt_tie_type = "cnbs") then /* Cut section with no backslope */
         {
           draw skip to _mp_rt_tie_pnt_curr
           mark _mp_rt_out_fldit_curr
           draw skip to _mp_in_fldit
           mark _mp_rt_in_fldit_curr
         }
        else /* Fill section */
         {
          mark _mp_rt_out_fldit_curr
          mark _mp_rt_in_fldit_curr            
         } 
 
 /***************************** Plan View Draw Ditch On Right Side ****************************/

if not (_mp_rt_tie_pnt_prev) and (_s_side="right") then  /* First Section! Intialize "Prev" Marked Points */
  {
    _mp_rt_tie_pnt_prev = _mp_rt_tie_pnt_curr
    _mp_rt_out_fldit_prev = _mp_rt_out_fldit_curr
    _mp_rt_in_fldit_prev = _mp_rt_in_fldit_curr
    _d_prev_elev_rt = _d_elev
    draw skip to _mp_rt_tie_pnt_prev
    draw gg=^Construction Limits^ cell = gpk1 xs=_d_cell_scale ys=_d_cell_scale
    
/***************************** Determine offset from baseline or designline ****************************/
    
    if _s_line = "CrossSectionCenterline" then
      {
        _d_distance=cogo_offsetFromChain(_mp_rt_tie_pnt_curr,_s_chain)
      }
    else
      {
        _d_distance=cogo_offsetFromChain(_mp_rt_tie_pnt_curr,_s_deschain)
      }    
/*                                                           */       
    if _S_TIE_TYPE="S" then               /* This next part    */
      {                                   /* puts the word     */
       _s_space = "  Sheared "            /* "Sheared" in the  */ 
      }                                   /* loc text if a     */
    else                                  /* sheared section   */
      {                                   /*                   */
       _s_space = "  "                    /*                   */
      }                                   /*                   */
  /*                                                         */   
  
    if "plan view scale" < 499 then
      {
       _s_offset_text = _s_space + cvt_d_s0(abs(_d_distance)) + "  "
      }
    else
      {  
       _s_offset_text = _s_space + cvt_d_s1(abs(_d_distance)) + "  "
      }
    
    _d_angle=cogo_tangentanglechain(_mp_rt_tie_pnt_curr,_s_chain) + 90
    draw gg=^Construction Limits^ text value = _s_offset_text
       "~rtloc text symbology" angle=_d_angle
    
  }
else /* Continue */
  {
    /* Draw Limits of Construction */
    set plot parameters "~loc symbology"
    draw skip to _mp_rt_tie_pnt_curr
    draw gg=^Construction Limits^ cell = gpk1 xs=_d_cell_scale ys=_d_cell_scale
    
    if _s_test_right = "passed" then
      {
       draw skip to _mp_rt_tie_pnt_prev
       draw gg=^Construction Limits^ to _mp_rt_tie_pnt_curr
      }
    else
      {
       draw skip dx=0 dy=0
      }
    
        
/***************************** Determine offset from baseline or designline ****************************/
    
    if _s_line = "CrossSectionCenterline" then
      {
        _d_distance=cogo_offsetFromChain(_mp_rt_tie_pnt_curr,_s_chain)
      }
    else
      {
        _d_distance=cogo_offsetFromChain(_mp_rt_tie_pnt_curr,_s_deschain)
      }
/*                                                           */       
    if _S_TIE_TYPE="S" then               /* This next part    */
      {                                   /* puts the word     */
       _s_space = "  Sheared "            /* "Sheared" in the  */ 
      }                                   /* loc text if a     */
    else                                  /* sheared section   */
      {                                   /*                   */
       _s_space = "  "                    /*                   */
      }                                   /*                   */
  /*                                                         */   
    
    if "plan view scale" < 499 then
      {
       _s_offset_text = _s_space + cvt_d_s0(abs(_d_distance)) + "  "
      }
    else
      {  
       _s_offset_text = _s_space + cvt_d_s1(abs(_d_distance)) + "  "
      }
    
    _d_angle=cogo_tangentanglechain(_mp_rt_tie_pnt_curr,_s_chain) + 90
    _d_rt_dit_wid_curr = abs(cogo_distance_between_points(_mp_rt_out_fldit_curr,_mp_rt_in_fldit_curr))
    _d_rt_dit_wid_prev = abs(cogo_distance_between_points(_mp_rt_out_fldit_prev,_mp_rt_in_fldit_prev))
    draw gg=^Construction Limits^ text value = _s_offset_text
           "~rtloc text symbology" angle=_d_angle
    _d_dist = cogo_distance_between_points (_mp_rt_out_fldit_prev, _mp_rt_out_fldit_curr)
    _d_slope = ((_d_elev - _d_prev_elev_rt) / _d_dist) * 100.0
    _s_slope_text = cvt_d_s1(abs(_d_slope)) + "%"
    _d_angle2 = cogo_angle_between_points (_mp_rt_out_fldit_prev, _mp_rt_out_fldit_curr)
    _d_rt_distance_between_tie_ditch = abs(cogo_distance_between_points(_mp_rt_tie_pnt_prev,_mp_rt_out_fldit_prev))
     
      if ((_d_rt_dit_wid_curr > tolerance) or (_d_rt_dit_wid_prev > tolerance) or 
          (_s_ditchtype = ^v^) or (_d_rt_distance_between_tie_ditch > tolerance)) and (_s_test_right = "passed") then /* Ditch Bottom Exists and prev section worked */ 
        {
         set plot parameters "~ditch line symbology"
         draw skip to _mp_rt_out_fldit_prev
         draw gg=^Ditch Lines^ to _mp_rt_out_fldit_curr
         if _s_ditchtype = ^fbd^ or (_d_rt_dit_wid_prev > 0) then /* if current or previous section was a flat bottom ditch */
           {
             draw skip to _mp_rt_in_fldit_prev
             draw gg=^Ditch Lines^ to _mp_rt_in_fldit_curr
           }
         /* Find center of ditch midway between sections */
         draw skip to _mp_rt_out_fldit_prev
         draw skip angle = _d_angle2 for distance = _d_dist/2.0
         draw skip angle = _d_angle2+90 for distance = ((_d_rt_dit_wid_curr+_d_rt_dit_wid_prev)/4)
           if (_d_slope < 0) then /* Water flows back station */
             {
              _d_angle3 = _d_angle2
              _d_angle2 = _d_angle2 - 180
              draw gg=^Ditch Labels^ cell = gpk2 xs=_d_cell_scale ys=_d_cell_scale angle =_d_angle3
              draw skip angle = _d_angle2+270 for distance = ((_d_rt_dit_wid_curr+_d_rt_dit_wid_prev)/2)
              _d_angle=_d_angle-90
              draw gg=^Slope Text^ text value = _s_slope_text 
                       "~slope text symbology" angle=_d_angle
             }
           else if (_d_slope > 0) then
             {
              _d_angle3 = _d_angle2 -180
              draw gg=^Ditch Labels^ cell = gpk2 xs=_d_cell_scale ys=_d_cell_scale angle = _d_angle3
              draw skip angle = _d_angle2+90 for distance = ((_d_rt_dit_wid_curr+_d_rt_dit_wid_prev)/2)
              _d_angle=_d_angle-90
              draw gg=^Slope Text^ text value = _s_slope_text
                        "~slope text symbology" angle=_d_angle
             }
          else /* Flow elevations are equal no flow arrow */
            {
              draw skip angle = _d_angle2+90 for distance = ((_d_rt_dit_wid_curr+_d_rt_dit_wid_prev)/2)
              _d_angle=_d_angle-90
              draw gg=^Slope Text^ text value = _s_slope_text
                      "~slope text symbology" angle=_d_angle
            }   
          
        }
      else   
       {
         draw dx=0 dy=0
       } 
        
    _mp_rt_tie_pnt_prev = _mp_rt_tie_pnt_curr
    _mp_rt_out_fldit_prev = _mp_rt_out_fldit_curr
    _mp_rt_in_fldit_prev = _mp_rt_in_fldit_curr
    _d_prev_elev_rt = _d_elev
    _s_test_right = "passed"
  }

}  




}
end sub

}

/*================================================================================================*/
/*================================================================================================*/
/*================================================================================================*/
/*===========  SUBROUTINES USED TO LABEL CROSS SECTIONS  =========================================*/
/*================================================================================================*/
/*================================================================================================*/
/*================================================================================================*/
 
 
 
 
 
 
 
 

/*===============================================================================================*/
/*===========SUBROUTINE - ASSEMBLES THE OFFSET AND ELEVATION LABLE  =============================*/
/*===========  OFFSET IS 2 DEC IMPERIAL, 3 METRIC  ==============================================*/
/*===============================================================================================*/
subroutine offset_elevation     
  {
    mark x345 y345
    _d_off = abs(x345 - x998)
    _d_elev = abs(y345)
    if x345 < x998 then
     {
      _s_side_label = "Lt."
     }
   else
     {
      _s_side_label = "Rt."
     }  
    _s_label = cvt_d_s2(_d_off) + " " + _s_side_label + ", El. " + cvt_d_s2(_d_elev)
    draw skip dx=0 dy = _d_txoff
    draw text value=_s_label
       "~offset text symbology"
    draw skip to x345 y345
  }
end sub

/*===============================================================================================*/
/*===========SUBROUTINE - ASSEMBLES THE OFFSET LABLE ROUNDED TO 2 DEC IF IMPERIAL, 3 IF METRIC  ===================*/
/*===============================================================================================*/
subroutine offset_2            
  {
    mark x345 y345
    _d_off = abs(x345 - x998)
    _d_elev = abs(y345)
    if x345 < x998 then
     {
      _s_side_label = "Lt."
     }
   else
     {
      _s_side_label = "Rt."
     }  
    _s_label = cvt_d_s2(_d_off) + " " + _s_side_label
    draw skip dx=0 dy = _d_txoff
    draw text value=_s_label
       "~offset text symbology"
    draw skip to x345 y345
  }
end sub

/*===============================================================================================*/
/*===========SUBROUTINE - ASSEMBLES THE OFFSET LABLE ROUNDED TO 0 DEC IF IMPERIAL, 1 IF METRIC  =====================*/
/*===============================================================================================*/
subroutine offset_0             
  {
    mark x345 y345
    _d_off = abs(x345 - x998)
    _d_elev = abs(y345)
    if x345 < x998 then
     {
      _s_side_label = "Lt."
     }
   else
     {
      _s_side_label = "Rt."
     }  
    _s_label = cvt_d_s0(_d_off) + " " + _s_side_label
    draw skip dx=0 dy = _d_txoff
    draw text value=_s_label
       "~offset text symbology"
    draw skip to x345 y345
  }
end sub










 
