/*******************************************************************************************************/
/* TEST This criteria file was written for the Nebraska Department of Roads by Chuck Lawson with Geopak     */
/*                                                                                                     */
/*                                                                                                     */
/* The purpose of this criteria file is to create a comma separated ASCII text file which contains     */
/*     detailed slope stake information.  This file will work for undivided roadways only.             */
/*                                                                                                     */
/* The proposed cross sections need to be previously completed in a separate run.                      */
/*                                                                                                     */
/*                                                                                                     */
/* Revised : 5/24/2001 By Chuck Lawson                                                                 */
/*           11/5/2002 Jon Starr                                                                       */              
/*                     fixed bugs, added existing ground check logic                                   */ 
/*           10/14/2014 Tom Sawyer                                                                     */
/*                added logic to handle ditch bottoms that are more than one segment (OpenRoads)       */
/*             04/28/2015 Tom Sawyer                                                                   */
/*                added code to give the user the ability to annotate the cross sections as the        */
/*                slope stake report is being generated. Usually on OpenRoads cross sections           */
/*             R3     06/03/2015 Tom Sawyer                                                            */
/*                Added code to annotate the PGLs                                                      */
/*             R2  10/01/2015 Tom Sawyer                                                               */
/*                added code to annotate the turf shoulder point                                       */
/*                                                                                                     */
/*                                                                                                     */
/*******************************************************************************************************/





define "Plan View Scale" 100
define "XS Annotation Scale" 10




if p1 then
  {
    remove skew effect
  }

if "Plan View Scale" < 499 then             /*  It's Imperial  */
  {
   _d_text_width = "plan view scale" / 10
   _d_text_height = "plan view scale" / 10
   _d_cell_scale = ("plan view scale" / 100) /* Conversion for cell size from plan scale */
   _d_dec = 0
   _d_1ft = 1
   _d_5ft = 5
   _d_50ft = 50
   _d_100ft = 100
   _d_tolerance = 0.01
   _s_ditchtype = ^none^
   _s_units = ^imperial^
   define "~warning text symbology" off=0.000 LvName=XS Text Warning co=3  wt=1 ft=5 th=1.5 tw=1.5 just=lc angle=90
   define "~label text symbology"   off=0.000 LvName=XS Text Msc Label co=73  wt=1 ft=5 th=.5 tw=.5 just=lc angle=90
   define "~debug text symbology"   off=0.000 LvName=XS Text Debug co=3  wt=1 ft=5 th=.5 tw=.5 just=lc angle=90
   
   /*   ADDED DEFINITIONS FOR LABELING OF CROSS SECTIONS  */
   _d_txoff = 0.15 * "XS Annotation Scale"
   define "~offset text symbology"    num of dec place=2 off=0.100*"XS Annotation Scale" LvName = XS Text Offset co=5 wt=1 ft=5 th=.125*"XS Annotation Scale" tw=.125*"XS Annotation Scale" just=lc angle=90
   define "~slope text symbology"     num of dec place=2 off=0.025*"XS Annotation Scale" LvName = XS Text Grading Slope co=4 wt=1 ft=5 th=.125*"XS Annotation Scale" tw=.125*"XS Annotation Scale" just=cb format = run:rise
   define "~elevation text symbology" num of dec place=2 off=-.025*"XS Annotation Scale" LvName = XS Text Elevation co=4 wt=1 ft=5 th=.125*"XS Annotation Scale" tw=.125*"XS Annotation Scale" just=ct
   define "~pgl elev text symbology"  num of dec place=2 off=0.000*"XS Annotation Scale" LvName = XS Text PGL Elevation co=10 wt=1 ft=5 th=.125*"XS Annotation Scale" tw=.125*"XS Annotation Scale" just=lc angle=90

  }
else                                        /*  It's Metric    */
  {
   _d_text_width = "plan view scale" / 400
   _d_text_height = "plan view scale" / 400
   _d_cell_scale = ("plan view scale" / 1000) /* Conversion for cell size from plan scale */
   _d_dec = 1
   _d_1ft = 0.3
   _d_5ft = 1.5
   _d_50ft = 15
   _d_100ft = 30
   _d_tolerance = 0.01
   _s_ditchtype = ^none^
   _s_units = ^metric^
   define "~warning text symbology" off=0.000 LvName=XS Text Warning co=3  wt=1 ft=5 th=0.5 tw=0.5 just=lc angle=90
   define "~label text symbology"   off=0.000 LvName=XS Text Msc Label co=73  wt=1 ft=5 th=.15 tw=.15 just=lc angle=90
   define "~debug text symbology"   off=0.000 LvName=XS Text Debug co=3  wt=1 ft=5 th=.15 tw=.15 just=lc angle=90
  }





if not _mp_open then
    {
      _s_section_type="undivided"
      _s_display_units = _s_units
      _s_chain = chain name
      _s_filename = _s_chain + "_slpstk.csv"
      ascii open file = _s_filename
      ascii write file = _s_filename
      format = ^%s,%s\n^
      var = _s_section_type,_s_display_units
      mark _mp_open
      _s_debug_text = "no"              /*  change this value to yes if you want points marked on xsecs  */
    }
define "~ltloc text symbology" num of dec place=_d_dec off=0.0 LvName=RD Limits of Construction Text co=60 wt=1 ft=5 just=lc th=_d_text_height tw=_d_text_width
define "~rtloc text symbology" num of dec place=_d_dec off=0.0 LvName=RD Limits of Construction Text co=60 wt=1 ft=5 just=rc th=_d_text_height tw=_d_text_width
define "~slope text symbology" num of dec place=_d_dec off=0.0 LvName=RD Ditch Flow Text co=62 wt=1 ft=5 just=cc th=_d_text_height tw=_d_text_width
define "~ditch line symbology" LvName=RD Ditch Flow Lines wt=0 co=16 lc=6
define "~loc symbology"        LvName=RD Limits of Construction wt=1 co=73 lc=0

/******************** Define materials in sections to use for calculations *************************/


define_dgn "finished grade"        dgn = xs.dgn LvName=XS Grading co=4
define_dgn "subgrade"              dgn = xs.dgn LvName=XS Grading co=5
define_dgn "milling line"          dgn = xs.dgn LvName=XS Milling

/******************** Determine if working in side slope left or side slope right *****************/
if (1=1) then
{
  draw skip to xpgl ypgl
  mark x1 y1
  mark x80 y80
  mark x354 y354
  draw skip dx=1 dy=0                                               
  mark x2 y2
    if (x2<x1) then
      {
      _s_side="left"
      draw skip to xpgl ypgl
      }
    else
      {
      _s_side="right"
      draw skip to xpgl ypgl
      }
}

/* =======================================================================================*/
/* =======================================================================================*/
/* =====================         Initial prompts       ===================================*/
/* =======================================================================================*/
/* =======================================================================================*/

if not (_mp_prompt) then
 {
   /* ##################### Criteria Tolerance Check ###########*/

    if (tolerance > 0.01) then
      {
        prompt ^**ERROR** - Cross Section Run Tolerance Too Large, use 0.01^ mode = message
        exit
      }  
  
    /*##########################################################*/
 
 
   _s_test_left = "passed"
   _s_test_right = "passed"
   mark _mp_prompt
   
   
   _s_XSAnnotate = "Yes"
   Prompt ^Annotate Cross Sections?  Yes or No^ variable = _s_XSAnnotate mode = option content = Yes, No
   if (CANCEL) then {EXIT}
          
   _s_plot = "Yes"
   Prompt ^Plot Limits of Construction and Ditch Lines?  Yes or No^ variable = _s_plot mode = option content = Yes, No
   if (CANCEL) then {EXIT}
     if (_s_plot="yes") then
       {
         _s_planview = "Please Select"
         Prompt ^Select Feature File^ variable = _s_planview mode = file select filter = *.dgn
         if (CANCEL) then {EXIT}
         
         while _s_planview = "Please Select"
           {
            Prompt ^You MUST Select a Feature File^ variable = _s_planview mode = file select filter = *.dgn
            if (CANCEL) then {EXIT}
           }
                    
         if "Plan view scale" < 499 then
           {  
            Prompt ^The MAST cell library must be attached!^ mode = message
            if (CANCEL) then {EXIT}
           }
         else
           {
            Prompt ^The MMAST cell library must be attached!^ mode = message
            if (CANCEL) then {EXIT}
           }  
         _s_line = "BaseLine"
         
/********************* Determine if distances are to be from design line or base line **************/         
         
         PROMPT ^Distances computed from BaseLine or DesignLine?^ VARIABLE = _s_line MODE = OPTION CONTENT = BaseLine, DesignLine
         if (CANCEL) then {EXIT}
         if (_s_line="DesignLine") then
           {
             _s_deschain = "Please Enter"
             Prompt ^Name of Chain that distances are computed from^ variable = _s_deschain mode = keyin
             if (CANCEL) then {EXIT}
                                              
             draw skip to x1 y1
           }
                      
       }
     else
     {
       draw dx=0 dy=0
     }
 }

if (1=1) then
  {
   draw skip dx=0 dy=_d_50ft
   mark x1 y1
   _s_subgrade_test = "passed"
  }



/********************* Error checking for presence of completed tie slopes **************/

if (material below = "subgrade") then
{
   _s_clcondition = ^SGCLE^
   draw skip dx=0 dy=-1 to xs "subgrade"
   draw skip trace "subgrade" out off = 0 for dx=1000
   mark x10 y10
   draw skip trace "subgrade" in off=0 for dx=_d_1ft
   mark x11 y11
   draw skip dx=abs(x10 - x11) dy=(y10 - y11) to xs "finished grade"
   mark x20 y20
   if _s_debug_text = "yes" then
     {
       draw text char = ^subgrade intersect^ "~debug text symbology"
     }  
   draw skip trace "finished grade" out off = 0 for dx=1000
   mark x30 y30
   draw skip dx=0 dy=_d_100ft
   mark x346 y346
   draw skip dx=0 dy=-1 to exist ground
   mark x345 y345
   draw skip to x30 y30
}

else if (material below = "milling line") then
{
   _s_clcondition = ^EXCLE^
   while material below = "milling line"
     {
       draw skip dx=_d_1ft dy=0 
     }
   draw skip dx=_d_1ft dy=10
   draw skip dx=0 dy=-1 to xs "subgrade" 
   draw skip trace "subgrade" out off = 0 for dx=1000
   mark x10 y10
   draw skip trace "subgrade" in off=0 for dx=_d_1ft
   mark x11 y11
   draw skip dx=abs(x10 - x11) dy=(y10 - y11) to xs "finished grade"
   mark x20 y20
   if _s_debug_text = "yes" then
     {
      draw text char = ^subgrade intersect^ "~debug text symbology"
     } 
   draw skip trace "finished grade" out off = 0 for dx=1000
   mark x30 y30
   draw skip dx=0 dy=_d_100ft
   mark x346 y346
   draw skip dx=0 dy=-1 to exist ground
   mark x345 y345
   draw skip to x30 y30
}

else /* incomplete section */
{

_s_subgrade_test = "failed"
mark x10 y10
draw skip dx=1 dy=0
mark x11 y11
mark x20 y20
mark x30 y30
draw text char = ^Incomplete Section^ "~warning text symbology"
}

if (abs(x20-x10) > 100* tolerance) then /* Subgrade not close enough to Finished Grade */
{
 
  /* determine station and chain values */
  _s_sta=cvt_d_sta(station)
  _s_chain = chain name
  _s_problem = "Error, Proposed Subgrade Does Not Tie To Finished Grade"
  _s_chain_label = _s_chain + " " + _s_clcondition
  ascii append file = _s_filename
  ascii write file = _s_filename
  format = ^%s,%s,%s\n^
  var = _s_chain_label,_s_sta,_s_problem
  draw skip to x10 y10
  draw text char = ^Gap in Subgrade^  "~warning text symbology"
   
  if _s_side = "left" then
    {
      _s_test_left = "fail"
    }
  else
    {
      _s_test_right = "fail"
    }  

}

else if (_s_subgrade_test = "failed") then /* Could not find subgrade or milling line */
{
 
  /* determine station and chain values */
  _s_sta=cvt_d_sta(station)
  _s_chain = chain name
  _s_problem = "Error, Subgrade line not present"
  _s_chain_label = _s_chain + " " + _s_clcondition
  ascii append file = _s_filename
  ascii write file = _s_filename
  format = ^%s,%s,%s\n^
  var = _s_chain_label,_s_sta,_s_problem
  draw skip to xpgl ypgl  
  draw text char = ^Subgrade line not found^  "~warning text symbology"
   
  if _s_side = "left" then
    {
      _s_test_left = "fail"
    }
  else
    {
      _s_test_right = "fail"
    }  

}

else if (abs(x11-x20) < 2 * tolerance) then /* Incomplete section subgrade does not intersect surface */
{
             /* determine station and chain values */
  _s_sta=cvt_d_sta(station)
  _s_chain = chain name
  _s_problem = "Error, Proposed Subgrade Does Not Tie To Finished Grade"
  _s_chain_label = _s_chain + " " + _s_clcondition
  ascii append file = _s_filename
  ascii write file = _s_filename
  format = ^%s,%s,%s\n^
  var = _s_chain_label,_s_sta,_s_problem
  draw skip to x10 y10
  draw text char = ^Subgrade Does Not Intersect^  "~warning text symbology"
 
 
  if _s_side = "left" then
    {
      _s_test_left = "fail"
    }
  else
    {
      _s_test_right = "fail"
    }   

}
else if abs(y346-y345) < 2*tol then /* incomplete section, existing ground is inside of tie point */
{
   /* determine station and chain values */
  _s_sta=cvt_d_sta(station)
  _s_chain = chain name
  _s_problem = "Error, Finished Grade Does Not Tie To Existing Ground"
  _s_chain_label = _s_chain + " " + _s_clcondition
  ascii append file = _s_filename
  ascii write file = _s_filename
  format = ^%s,%s,%s\n^
  var = _s_chain_label,_s_sta,_s_problem
  draw skip to x30 y30
  draw text char = ^Section Does Not Close^  "~warning text symbology"
 
  if _s_side = "left" then
    {
      _s_test_left = "fail"
    }
  else
    {
      _s_test_right = "fail"
    } 
}
else if (abs(elev diff at x30 y30) > 4* tolerance) then /* Incomplete section surface does not tie to ground */
{
      /* determine station and chain values */
  _s_sta=cvt_d_sta(station)
  _s_chain = chain name
  _s_problem = "Error, Finished Grade Does Not Tie To Existing Ground"
  _s_chain_label = _s_chain + " " + _s_clcondition
  ascii append file = _s_filename
  ascii write file = _s_filename
  format = ^%s,%s,%s\n^
  var = _s_chain_label,_s_sta,_s_problem
  draw skip to x30 y30
  draw text char = ^Section Does Not Close^  "~warning text symbology"
 
  if _s_side = "left" then
    {
      _s_test_left = "fail"
    }
  else
    {
      _s_test_right = "fail"
    } 
   
}

else /* Proposed ties are in place, continue with processing */
{


if (1=1) then
{
/******************* Intialize all out put variables **********************************************/
    _s_chain_offset=999
    _s_chain="n/a"
    _s_sta="n/a"
    _s_hp_message="n/a"
    _d_cle=999
    _d_cle_dy=999
    _d_hpdy=999
    _d_hpdx=999
    _d_hp1dy=999
    _d_hp1dx=999
    _s_tie_type="n/a"
    _d_in_fldit_dy=999
    _d_in_fldit_dx=999
    _d_dit_fl=999
    _d_dit_bs=999
    _d_bs_dx=999
    _d_dit_wid=999
    _d_fs_dy=999
    _d_fs_dx=999
    _d_fslope=999
    _s_med_typ=999
    _s_lt_tie_type="n/a"
    _d_okay_slope = 1
}


/*********************************** Undivided Criteria ************************************/

if (_s_section_type = "undivided") then
{
  draw skip to x1 y1
  /* determine station and chain values */
  _s_sta=cvt_d_sta(station)
  _s_chain = chain name
    
  /* mark proposed subgrade centerline elevation */
    if (material below = "subgrade") then
     {
       draw skip dx=0 dy=-1 to xs "subgrade"
       mark _mp_cle
       _s_clcondition = ^SGCLE^
     }
    else
     {
       draw skip dx=0 dy=-1 to exist ground
       mark _mp_cle
       _s_clcondition = ^EXCLE^
     }
  _s_chain_label = _s_chain + " " + _s_clcondition
  /* mark existing ground at centerline elevation location */
  draw skip dx=0 dy=30
  draw skip dx=0 dy=-1 to existing ground
  mark _mp_exgrdcle
  draw skip to _mp_cle
  
  /* Compute variables at centerline */
  _D_CLE=_mp_cle.elev
  _D_CLE_DY=(_mp_cle.elev-_mp_exgrdcle.elev)
  
  /* Compute variables at edge of proposed subgrade */
   draw skip dx=0 dy=1
     if (material below = "subgrade") then
     {
       draw skip dx=0 dy=-1 to xs "subgrade"
       draw skip trace "subgrade" out off=0 for dx=1000
     }
     else
     {
       while material below = "milling line"
       {
        draw skip dx=_d_1ft dy=0
       }
      draw skip dx=_d_1ft dy=0
      draw skip dx=0 dy=-1 to xs "subgrade"
      draw skip trace "subgrade" out off=0 for dx=1000
     }
  
  draw skip to x20 y20
  mark _mp_end_subgrade    
  mark x355 y355
  _D_HPDY=(_mp_end_subgrade.elev-_mp_cle.elev)
  _D_HPDX=(abs(_mp_end_subgrade.off-_mp_cle.off))

  /* Determine if section is in cut, fill, cut with no back slope, or sheared */
  
  draw skip trace "finished grade" out off = 0 for dx=1000
   
  mark _mp_tie_point
  mark x353 y353
  _s_ele = cvt_d_s4(_mp_tie_point.elev)
  /*          draw text value = _s_ele "~label text symbology"  */    /*   use this line to place elevation at tie point  */ 
  if _s_debug_text = "yes" then
    {
     draw text char = ^Tie^ "~debug text symbology"
    }
  draw skip trace "finished grade" in off=0 to endpoint
  mark _mp_test
  mark x40 y40
  _s_ele = cvt_d_s4(_mp_test.elev)
  if _s_debug_text = "yes" then
    {
      _s_lable = "Test"+" "+_s_ele
      draw text value = _s_lable "~debug text symbology"
    }
        if (abs(x30 -x40) < tolerance) then  /* Sheared Section  */        
          {
           _S_TIE_TYPE="S"
           draw skip to _mp_end_subgrade
           _d_okay_slope = 0
           _s_hp_message = "Note, Sheared Section, See Cross Sections"
          }
        
        else if (_mp_test.elev > _mp_tie_point.elev+tolerance) then /* Fill Section */
          {
           _S_TIE_TYPE="F"
           call sub ireg_foreslope_test
           draw skip to _mp_end_subgrade
          }
        else if _mp_test.elev < (_mp_tie_point.elev - 2*tolerance) then  /* Cut Section with Back Slope */
          {
           _S_TIE_TYPE="C"
           call sub ireg_foreslope_test
           call sub ireg_backslope_test
           draw skip to x99 y99
           mark _mp_in_fldit
           mark x3 y3
           mark x351 y351  /*  Point for labeling ditch bottom elevation  */
           draw skip trace "finished grade" out off=0 for dx = tolerance
           draw skip trace "finished grade" out off=0 to endpoint
           
           
/*  Added lines to check for multiple points on ditch bottoms because of OpenRoads  */ 
/*  Tom Sawyer 10/14/2014  */          

           mark _mp_test2
           while _mp_test2.elev - y3 < 2 * tolerance
              {
                draw skip trace "finished grade" out off=0 for dx = tolerance
                draw skip trace "finished grade" out off=0 to endpoint
                mark _mp_test2
              }
           draw skip trace "finished grade" in off=0 for dx = tolerance
           draw skip trace "finished grade" in off=0 to endpoint

/*  End Added lines to check for multiple points on ditch bottoms because of OpenRoads  */       

           mark _mp_out_fldit
           mark x352 y352  /*  Point for labeling ditch bottom elevation  */
           mark x98 y98
             if ((abs(y3-y98)) > 2* tolerance) then /* "V" Ditch Exists need to reset _mp_in_fldit to same as _mp_out_fldit */
              {
               draw skip to x99 y99
               mark _mp_out_fldit
               mark x352 y352  /*  Point for labeling ditch bottom elevation  */
               mark x3 y3
               _s_ditchtype = ^v^
              }
             else
               {
                 _s_ditchtype = ^fbd^
               }
           draw skip to _mp_end_subgrade
          }       
       else  /* This is a cut section with no back slope */
          {
           _S_TIE_TYPE="CNBS"
           call sub ireg_foreslope_test
           draw skip to _mp_tie_point
           mark _mp_out_fldit
           mark x352 y352  /*  Point for labeling ditch bottom elevation  */

/*   Modified to correct for OpenRoads ditches having extra vertice at ditch midpoint - TLS - 09-08-2016   */
           draw skip to x99 y99    
          
           mark _mp_in_fldit
           mark x3 y3
           mark x351 y351  /*  Point for labeling ditch bottom elevation  */
           draw skip to _mp_end_subgrade
          
          }
      
   /* Determine number and location of hinge points and draw ditches */
   if (_S_TIE_TYPE="F") then
    {
      if (_d_okay_slope = 1) then
       {
         call subroutine fill_hinge_points
       }
    draw skip to _mp_tie_point
    _d_elev = _mp_tie_point.elev
       
       if (_s_plot="yes") then
        { 
         call subroutine draw_ditches (plan view = _s_planview)
        }
       else
        {
         draw dx=0 dy=0
        }     
    }
   else if (_S_TIE_TYPE="S") then
    {
     draw skip to _mp_tie_point
     _d_elev = _mp_tie_point.elev
       
       if (_s_plot="yes") then
        { 
         call subroutine draw_ditches (plan view = _s_planview)
        }
       else
        {
         draw dx=0 dy=0
        }     
    } 
    
   else
    {
       if (_d_okay_slope = 1) then
        { 
         call subroutine cut_hinge_points
        }
      _d_elev = _mp_in_fldit.elev
      draw skip to _mp_tie_point
      
      if (_s_plot="yes") then
        { 
         call subroutine draw_ditches (plan view = _s_planview)
        }
       else
        {
         draw dx=0 dy=0
        }     
    
    } 
    
   
 /*========================================================================*/   
 /*========================================================================*/    
 /*========================================================================*/    
 /*  Annotate Cross Sections  */   
 /*========================================================================*/
 /*========================================================================*/    
 /*========================================================================*/    
 
 if _s_XSAnnotate = "Yes" then    
   {
     
/*  R3  THIS PART ADDED TO PLACE PGL TEXT AT PROPER LOCATION */
    if px1 < px2 then
      {
        _d_pglel = ypgl
        _s_pglel = cvt_d_s2(_d_pglel)
        draw skip to xpgl ypgl
        draw skip dx=0 dy=_d_txoff
        draw text value = _s_pglel
          "~pgl elev text symbology"
      }  
/*  End R3  */   
     
     draw skip trace in off=0 for dx=1000
     draw skip dx=1 dy=0 to chain _s_chain
     mark x998 y998   
     draw skip to _mp_end_subgrade  
     
      
     /*     LABEL TURF SHOULDER POINT (COMPUTED)     */

    mark x345 y345
    mark x503 y503
    draw skip trace "finished grade" in off=0 for dx = 2 * tolerance
    draw skip trace "finished grade" in off=0 for dx = 1000
    mark x500 y500
    draw skip to x345 y345
    draw skip trace "finished grade" in off=0 for dx = 2 * tolerance
    draw skip trace "finished grade" in off=0 to endpoint
    mark x501 y501
    draw skip trace "finished grade" in off=0 for dx = 2 * tolerance
    draw skip trace "finished grade" in off=0 to endpoint
    mark x502 y502
    _d_looptest = 1
    _d_back_slope = 1
    _d_ahead_slope = 1
    while abs(_d_back_slope - _d_ahead_slope) < (10 * tolerance) and _d_looptest < 50
      {
        
        _d_back_slope= 1/(abs((y501-y345)/(x501-x345)))
        _d_ahead_slope=1/(abs((y501-y502)/(x501-x502))) 
        if abs(_d_back_slope - _d_ahead_slope)> 10*tolerance then
          {
            draw skip to x501 y501
            mark x503 y503
            _d_looptest = 50
          }
        mark x501 y501
        draw skip trace "finished grade" in off=0 for dx = 2 * tolerance
        draw skip trace "finished grade" in off=0 to endpoint
        mark x502 y502
        if abs(x500 - x501) < tolerance then
          {
            _d_looptest = 50
          }
        _d_looptest = _d_looptest + 1
      }  
    /*  End While  */
    
    
    if abs(x503 - x345) > tolerance then         /*  turf shoulder found  */
      {
        draw skip to x503 y503
        mark _mp_turf_shldr
        call sub offset_elevation                                  
        draw skip to _mp_end_subgrade
      }
    else                                 /*  more than one vertex found   */
      {
        draw text char = ^Shoulder not drawn correctly^ "~warning text symbology"
      }  
    
        
   if _S_TIE_TYPE="C" or _S_TIE_TYPE="CNBS" then
     {
       Draw skip to x355 y355
       call sub offset_elevation
       Draw skip to x353 y353
       call sub offset_elevation
                       
       draw skip to x351 y351
       call sub offset_elevation
       draw skip dx=abs(x351-x352)/2 dy=0
       draw elevation text
              "~elevation text symbology"
       If y353 - y352 > 0.5 then  /*  Only label if the backslope is taller than 0.5'  */
         {
           draw slope text between x352 y352 and x353 y353
                   "~slope text symbology"
           draw skip to x352 y352
           call sub offset_2                 
         }
       if abs(x354 - x1) > 2*tolerance  then  /*  Hinge point exists  */
         {
           draw skip to x354 y354
           call sub offset_elevation
           draw slope text between x355 y355 and x354 y354
                   "~slope text symbology"     
           draw slope text between x354 y354 and x351 y351
                   "~slope text symbology"          
           if elev diff at x355 y355 > 0 and elev diff at x354 y354 < 0 then
             {
               draw skip to x355 y355
               _d_run =  abs(x355-x354)
               _d_rise = y354 - y355
               draw skip dx=_d_run dy=_d_rise to existing ground
               mark x357 y357
               call sub offset_0
             }
           else if elev diff at x354 y354 > 0 and elev diff at x351 y351 < 0 then
             {
               draw skip to x354 y354
               _d_run =  abs(x354-x351)
               _d_rise = y351 - y354
               draw skip dx=_d_run dy=_d_rise to existing ground
               mark x357 y357
               call sub offset_0
             }
         }
       else
         {
           draw slope text between x355 y355 and x351 y351
                   "~slope text symbology" 
           if elev diff at x355 y355 > 0 and elev diff at x351 y351 < 0 then
             {
               draw skip to x355 y355
               _d_run =  abs(x355-x351)
               _d_rise = y351 - y355
               draw skip dx=_d_run dy=_d_rise to existing ground
               mark x357 y357
               call sub offset_0
             }
         }  
     }                      
   else if _S_TIE_TYPE="S" then
     {
       /*  Do Nothing  */
     }
   else if _S_TIE_TYPE="F" then
     {
       Draw skip to x355 y355
       call sub offset_elevation
       Draw skip to x356 y356
       call sub offset_elevation
              
       if abs(x354 - x1) > 2*tolerance then  /*  Hinge point exists  */
         {
           draw skip to x354 y354
           call sub offset_elevation
           draw slope text between x355 y355 and x354 y354
                   "~slope text symbology"     
           draw slope text between x354 y354 and x356 y356
                   "~slope text symbology"          
         }
       else
         {
           draw slope text between x355 y355 and x356 y356 
                   "~slope text symbology"
         }
     }
   else
     {
       /*  Do Nothing  */
     }
   }
          
/*********************************** Output Data to ACSII File ****************************************/
    
if (_d_okay_slope = 1) then
    {
      ascii write file = _s_filename
      format =^%s,%s,%.3f,%.3f,%.4f,%.4f,%.4f,%.4f,%s,%.4f,%.4f,%.3f,%.3f,%.4f,%.3f,%.4f,%.4f,%.3f,%s,%s\n^
      var = _s_chain_label,_s_sta,_d_cle,_d_cle_dy,_d_hpdy,_d_hpdx,_d_hp1dy,_d_hp1dx,_s_tie_type,_d_in_fldit_dy,_d_in_fldit_dx,_d_dit_fl,_d_dit_bs,_d_bs_dx,_d_dit_wid,_d_fs_dy,_d_fs_dx,_d_fslope,_s_med_typ,_s_chain_offset
    }

else /* Irregular section */
    {
      ascii write file = _s_filename
      format =^%s,%s,%s\n^
      var = _s_chain_label,_s_sta,_s_hp_message
    }
}

subroutine ireg_foreslope_test  /* Checks for irregular foreslope section */
{
  if (1=1) then 
  {
   _d_count_points = 0  
   _d_okay_slope = 1
    if _s_tie_type = "F" then /* Fill Section */
      {
        draw skip to x30 y30
        mark x99 y99 /* mark low point */
        mark x352 y352  /*  Mark point for annotating cross section  */
      }
     else /* cut section - establish low point of ditch and mark low point x99 y99 */
      {
       draw skip to x20 y20
       mark x99 y99
       mark x352 y352  /*  Mark point for annotating cross section  */
       mark x98 y98
         while (abs(x98 - x30) > 2*tolerance) 
         {
           draw skip trace "finished grade" out off=0 for dx=2*tolerance
           draw skip trace "finished grade" out off=0 to endpoint
           mark x98 y98
            if ((y99 - y98) > 2* tolerance) then /* Ahead Point is lower */
              {
                mark x99 y99
                mark x352 y352  /*  Mark point for annotating cross section  */
              }
          }
      }
   draw skip to x20 y20
   draw skip trace "finished grade" out off=0 for dx=2*tolerance
   draw skip trace "finished grade" out off=0 to endpoint
   mark x77 y77
   draw skip trace "finished grade" out off=0 for dx=2*tolerance
   draw skip trace "finished grade" out off=0 to endpoint
   mark x78 y78
   
    if ((abs(y78 - y99)) < 2* tolerance) then /* Slope is okay continue */
      {
       _d_okay_slope = 1
      }
    else /* Check for irregular foreslope slope */
    {
     draw skip to x20 y20 /* intialize pointer to subgrade tie point */
     mark x76 y76 /* Back Point */
     mark x77 y77 /* Current Point */
     mark x78 y78 /* Ahead Point */
     /* When 77 = 78 then no ahead slope can be calculated, either false HP or irr. section was found */ 
     while y77 > y99 and _d_okay_slope = 1 /* determine how many broken back points */
      {
       draw skip trace "finished grade" out off=0 for dx=2*tolerance
       draw skip trace "finished grade" out off=0 to endpoint
       mark x77 y77
       draw skip trace "finished grade" out off=0 for dx=2*tolerance
       draw skip trace "finished grade" out off=0 to endpoint
       mark x78 y78
       if (abs(x78-x77) > 2 * tolerance) or ((y77-y78)> 2* tolerance) then /* Continue...The points are not the same */ 
        {
           _d_bs = (abs(y76-y77)/abs(x76-x77))*100
           _d_as = (abs(y77-y78)/abs(x77-x78))*100  
             if (abs(_d_bs-_d_as) < (2* tolerance)) then /* False Hinge Point - Reset all points to 77 */
               {
                 draw skip to x77 y77
                 mark x76 y76
                 mark x78 y78
               }
             else /* Broken Back Hinge Point Found */
               {
                 draw skip to x77 y77
                 mark x76 y76
                 mark x78 y78
                _d_count_points = _d_count_points + 1
               }
             if _d_count_points <= 1 then /* Okay, have not exceeded acceptable number of slopes */
               {
                _d_okay_slope = 1
               } 
             else /* Exceeded allowable number of foreslopes */
               {
                 _d_okay_slope = 0
                   if _s_tie_type = "F" then
                    {
                     _s_hp_message = "Note, Maximum Number Of Fill Hinge Points Exceeded"
                    }
                   else
                    {
                     _s_hp_message = "Note, Maximum Number Of Foreslope Hinge Points Exceeded"
                    } 
               }
        } /* end if */
       else /* Exit while loop */
        {
          draw skip to x99 y99
          mark x77 y77
        } 
      } /* end while */  
       
    } /* else */
  } /* fill slope check */
} /* sub end */
end sub

subroutine ireg_backslope_test  /* Checks for irregular backslope section */
{
  if (_d_okay_slope = 1) then 
  {
     _d_count_points = 0  
     _d_okay_slope = 1
     draw skip to x30 y30
     mark x76 y76
     draw skip trace "finished grade" in off=0 for dx=2*tolerance
     draw skip trace "finished grade" in off=0 to endpoint
     mark x77 y77
     draw skip trace "finished grade" in off=0 for dx=2*tolerance
     draw skip trace "finished grade" in off=0 to endpoint
     mark x78 y78
       
     
    if ((abs(y77 - y99)) < 2* tolerance) then /* Slope is okay continue */
      {
       _d_okay_slope = 1
      }
    else /* Check for irregular back slope */
    {
     while (y77 > (y99 + 2 * tolerance)) and 
           (y78 >= y99) and
           _d_okay_slope = 1 /* determine how many broken back points */
      {
       _d_bs = (abs(y76-y77)/abs(x76-x77))*100
       _d_as = (abs(y77-y78)/abs(x77-x78))*100

       draw skip to x77 y77
       mark x76 y76
       mark x78 y78
       draw skip trace "finished grade" in off=0 for dx=2*tolerance
       draw skip trace "finished grade" in off=0 to endpoint
       mark x77 y77
       draw skip trace "finished grade" in off=0 for dx=2*tolerance
       draw skip trace "finished grade" in off=0 to endpoint
       mark x78 y78
              
       if (abs(_d_bs-_d_as) < 2 * tolerance) then /* false hinge point found */ 
        {
          _d_okay_slope = 1
        } /* end if */

       else /* Invalid Broken Back Slope Found---Exit while loop */
        {
          _d_okay_slope = 0
          _s_hp_message = "Note, Non-Standard Backslope Hinge Point Found"
        } 
      } /* end while */  
       
    } /* else */
  } /* backslope check */
} /* sub end */
end sub

subroutine fill_hinge_points
 {
   mark _mp_prev
   draw skip trace "finished grade" out off=0 for dx=2*tol
   draw skip trace "finished grade" out off=0 to endpoint
   mark _mp_current
   draw skip trace "finished grade" out off=0 for dx=2*tol
   draw skip trace "finished grade" out off=0 to endpoint
   mark _mp_ahead
   
                
        if (abs(_mp_current.elev-_mp_ahead.elev) < 2*tolerance) then /* no hinge and ties to ground */
          {
            mark _mp_fill_tie  
            mark x356 y356
            _d_fs_dy=(_mp_end_subgrade.elev-_mp_fill_tie.elev)
            _d_fs_dx=(abs(_mp_end_subgrade.off-_mp_fill_tie.off))
            _d_fslope=(abs((_mp_end_subgrade.off-_mp_fill_tie.off)/(_mp_end_subgrade.elev-_mp_fill_tie.elev)))
          }
        else   
        /* additional hinge points may exist */
       
         {
          /* check for false hinge point */
           _d_back_slope=1
           _d_ahead_slope=1
           _d_stop_now=0
             while ((_d_back_slope-_d_ahead_slope) < 2*tolerance) and (abs(_mp_ahead.elev-_mp_current.elev) > 2*tolerance) and (_d_stop_now = 0)
               {          
                 _d_back_slope= (abs((_mp_current.elev-_mp_prev.elev)/(_mp_current.off-_mp_prev.off + tolerance)))
                 _d_ahead_slope=(abs((_mp_current.elev-_mp_ahead.elev)/(_mp_current.off-_mp_ahead.off + tolerance)))
             
                   
                     if ((abs(abs(_d_back_slope)-abs(_d_ahead_slope))) > tolerance) then
                      /* Defined hinge Point */
                      {
                       draw skip to _mp_current
                       mark _mp_hp1
                       mark x354 y354
                       if _s_debug_text = "yes" then
                         {
                           draw text char = ^hp^ "~debug text symbology"
                         }
                       draw skip to _mp_ahead
                       mark x2 y2
                       _d_stop_now = 1
                      }
                     else /* False Hinge Point at _mp_current */
                      {
                      _mp_prev = _mp_current
                      _mp_current = _mp_ahead
                      draw skip to _mp_current
                      draw skip trace "finished grade" out off=0 for dx= 2* tolerance
                      draw skip trace "finished grade" out off=0 to endpoint
                      mark _mp_ahead
                      mark x2 y2
                      }
              
               } /* End While */        
                  if (elev diff at x2 y2 < 2* tolerance) and (abs(abs(_d_back_slope)-abs(_d_ahead_slope)) < 2*tolerance) then
                      /* at existing ground with only one fill slope */
                      {
                        mark _mp_fill_tie  
                        mark x356 y356
                        _d_fs_dy=(_mp_end_subgrade.elev-_mp_fill_tie.elev)
                        _d_fs_dx=(abs(_mp_end_subgrade.off-_mp_fill_tie.off))
                        _d_fslope=(abs((_mp_end_subgrade.off-_mp_fill_tie.off)/(_mp_end_subgrade.elev-_mp_fill_tie.elev)))
                      } 
                
                
                  else /* two different fill slopes with intermediate hinge point */
                     {
                       _d_hp1dy=(_mp_end_subgrade.elev-_mp_hp1.elev)
                       _d_hp1dx=(abs((_mp_end_subgrade.off-_mp_hp1.off)))
                       draw skip trace "finished grade" out off=0 for dx=1000
                       mark _mp_fill_tie    
                       mark x356 y356
                        _d_fs_dy=(_mp_hp1.elev-_mp_fill_tie.elev)
                        _d_fs_dx=(abs(_mp_hp1.off-_mp_fill_tie.off))
                        _d_fslope=(abs((_mp_hp1.off-_mp_fill_tie.off)/(_mp_hp1.elev-_mp_fill_tie.elev)))
                    } 
        
        }
}  
end sub
 
subroutine cut_hinge_points
 {
   mark _mp_prev
   draw skip trace "finished grade" out off=0 to endpoint
   mark _mp_current
   mark _mp_ahead
     if(abs(_mp_in_fldit.elev-_mp_ahead.elev) > 2* tolerance) then
        {
        draw skip trace "finished grade" out off=0 to endpoint
        mark _mp_ahead
        }
      else
        {
        draw skip dx=0 dy=0
        } 
                
        if ((_mp_current.elev-_mp_ahead.elev) < 2*tolerance) then /* no hinge and stops at flowline of ditch */
          {
            mark _mp_in_fldit
            mark x351 y351  /*  Point for labeling ditch bottom elevation  */
            
            if _s_debug_text = "yes" then
              {
                draw text char = ^front of ditch^ "~debug text symbology"
              }
            
            _d_in_fldit_dy=(_mp_end_subgrade.elev-_mp_in_fldit.elev)
            _d_in_fldit_dx=(abs(_mp_end_subgrade.off-_mp_in_fldit.off))
            _d_dit_fl=_mp_in_fldit.elev
              if (_s_tie_type="c") then  /* Back Slope Exists */
               {
                _d_dit_bs=(abs((_mp_out_fldit.off-_mp_tie_point.off)/(_mp_out_fldit.elev-_mp_tie_point.elev)))
                _d_bs_dx=(abs(_mp_out_fldit.off-_mp_tie_point.off))
                _d_dit_wid=(abs(_mp_out_fldit.off-_mp_in_fldit.off))
               }
               else /* No Back Slope! */
               {
               _d_dit_wid=(abs(_mp_out_fldit.off-_mp_in_fldit.off))
               }         
          }
        else   
        /* additional hinge points may exist */
       
         {
          /* check for false hinge point */
           _d_back_slope=1
           _d_ahead_slope=1
           _d_stop_now=0
             while (abs(_d_back_slope-_d_ahead_slope) < 2*tolerance) and (abs(_mp_ahead.elev-_mp_current.elev) > 2*tolerance) and (_d_stop_now=0)
               {          
                 _d_back_slope= abs((_mp_current.elev-_mp_prev.elev)/(_mp_current.off-_mp_prev.off))
                 _d_ahead_slope=(abs((_mp_current.elev-_mp_ahead.elev)/(_mp_current.off-_mp_ahead.off)))
                     if ((abs(_d_back_slope-_d_ahead_slope)) > 2*tolerance) then
                      /* Defined hinge Point */
                      {
                       draw skip to _mp_current
                       mark _mp_hp1   
                       mark x354 y354
                      }
                     else if ((_mp_ahead.elev - _mp_out_fldit.elev) > 2* tolerance) then /* False Hinge Point Exist! */
                      {
                      _mp_prev=_mp_current
                      _mp_current=_mp_ahead
                      draw skip to _mp_current
                      draw skip trace "finished grade" out off=0 for dx=2* tolerance
                      draw skip trace "finished grade" out off=0 to endpoint
                      mark _mp_ahead
                      }
                      else
                      {
                      _d_stop_now=1
                      }
                                    
               }        
                  if  (abs(abs(_d_back_slope)-abs(_d_ahead_slope)) < 2*tolerance) then
                      /* at flowline of ditch with only one fill slope and false hinge point */
                      {
                        draw skip to _mp_in_fldit
                        _d_in_fldit_dy=(_mp_end_subgrade.elev-_mp_in_fldit.elev)
                        _d_in_fldit_dx=(abs(_mp_end_subgrade.off-_mp_in_fldit.off))
                        _d_dit_fl=_mp_in_fldit.elev
                           if (_s_tie_type="c") then  /* Back Slope Exists */
                             {                
                              _d_dit_bs=(abs((_mp_out_fldit.off-_mp_tie_point.off)/(_mp_out_fldit.elev-_mp_tie_point.elev)))
                              _d_bs_dx=(abs(_mp_out_fldit.off-_mp_tie_point.off))
                              _d_dit_wid=(abs(_mp_out_fldit.off-_mp_in_fldit.off))
                             }                          
                           else /* No Back Slope Exists! */
                           {
                           _d_dit_wid=(abs(_mp_out_fldit.off-_mp_in_fldit.off))
                           }   
                              
                      } 
                
                
                  else /* two different fill slopes with intermediate hinge point */
                     {
                        _d_hp1dy=(_mp_end_subgrade.elev-_mp_hp1.elev)
                        _d_hp1dx=(abs((_mp_end_subgrade.off-_mp_hp1.off)))
                        _d_in_fldit_dy=(_mp_hp1.elev-_mp_in_fldit.elev)
                        _d_in_fldit_dx=(abs(_mp_hp1.off-_mp_in_fldit.off))
                        _d_dit_fl=_mp_in_fldit.elev
                          if (_s_tie_type="c") then  /* Back Slope Exists */
                            {
                             _d_dit_bs=(abs((_mp_out_fldit.off-_mp_tie_point.off)/(_mp_out_fldit.elev-_mp_tie_point.elev)))
                             _d_bs_dx=(abs(_mp_out_fldit.off-_mp_tie_point.off))
                             _d_dit_wid=(abs(_mp_out_fldit.off-_mp_in_fldit.off))
                            }
                            else /* No Back Slope Exists */
                            {
                            _d_dit_wid=(abs(_mp_out_fldit.off-_mp_in_fldit.off))
                            }                  
                    } 
         }
} 
end sub

subroutine draw_ditches
{
  /********************** Set variables for left or right side *****************************/
   if (_s_side = "left") then
     {
       mark _mp_lt_tie_pnt_curr
       _s_lt_tie_type = _s_tie_type
       
       if (_s_lt_tie_type = "c") then /* Cut section */
         {
           draw skip to _mp_out_fldit
           mark _mp_lt_out_fldit_curr
           draw skip to _mp_in_fldit
           mark _mp_lt_in_fldit_curr
         }
 
        else if (_s_lt_tie_type = "cnbs") then /* Cut section with no backslope */
         {
           draw skip to _mp_lt_tie_pnt_curr
           mark _mp_lt_out_fldit_curr
           draw skip to _mp_in_fldit
           mark _mp_lt_in_fldit_curr
         }
        else /* Fill section */
         {
          mark _mp_lt_out_fldit_curr
          mark _mp_lt_in_fldit_curr            
         } 
 
 /***************************** Plan View Draw Ditch On Left Side ****************************/

if not (_mp_lt_tie_pnt_prev) and (_s_side="left") then  /* First Section! Intialize "Prev" Marked Points */
  {
    _mp_lt_tie_pnt_prev = _mp_lt_tie_pnt_curr
    _mp_lt_out_fldit_prev = _mp_lt_out_fldit_curr
    _mp_lt_in_fldit_prev = _mp_lt_in_fldit_curr
    _d_prev_elev_lt = _d_elev
    draw gg=^Construction Limits^ cell = gpk1 xs=_d_cell_scale ys=_d_cell_scale
    
/***************************** Determine offset from baseline or designline ****************************/
    
    if _s_line = "baseline" then
      {
        _d_distance=cogo_offsetFromChain(_mp_lt_tie_pnt_curr,_s_chain)
      }
    else
      {
        _d_distance=cogo_offsetFromChain(_mp_lt_tie_pnt_curr,_s_deschain)
      }
       
/*                                                           */       
    if _S_TIE_TYPE="S" then               /* This next part    */
      {                                   /* puts the word     */
       _s_space = "  Sheared "            /* "Sheared" in the  */ 
      }                                   /* loc text if a     */
    else                                  /* sheared section   */
      {                                   /*                   */
       _s_space = "  "                    /*                   */
      }                                   /*                   */
/*                                                         */
            
    if "plan view scale" < 499 then
      {
       _s_offset_text = _s_space + cvt_d_s0(abs(_d_distance)) + "  "
      }
    else
      {  
       _s_offset_text = _s_space + cvt_d_s1(abs(_d_distance)) + "  "
      }
    
    _d_angle=cogo_tangentanglechain(_mp_lt_tie_pnt_curr,_s_chain) + 90
    draw gg=^Construction Limits^ text value = _s_offset_text "~ltloc text symbology" angle=_d_angle
  }
else /* Continue */
  {
    /* Draw Limits of Construction */
    set plot parameters LvName=RD Limits of Construction co=73 wt=2 lc=0
    draw skip to _mp_lt_tie_pnt_curr
    draw gg=^Construction Limits^ cell = gpk1 xs=_d_cell_scale ys=_d_cell_scale
    
    if _s_test_left = "passed" then
      {
        draw skip to _mp_lt_tie_pnt_prev
        draw gg=^Construction Limits^ to _mp_lt_tie_pnt_curr
      }
    else
      {
       draw skip dx=0 dy=0
      }
        
        
/***************************** Determine offset from baseline or designline ****************************/
    
    if _s_line = "baseline" then
      {
        _d_distance=cogo_offsetFromChain(_mp_lt_tie_pnt_curr,_s_chain)
      }
    else
      {
        _d_distance=cogo_offsetFromChain(_mp_lt_tie_pnt_curr,_s_deschain)
      }

  /*                                                           */       
    if _S_TIE_TYPE="S" then               /* This next part    */
      {                                   /* puts the word     */
       _s_space = "  Sheared "            /* "Sheared" in the  */ 
      }                                   /* loc text if a     */
    else                                  /* sheared section   */
      {                                   /*                   */
       _s_space = "  "                    /*                   */
      }                                   /*                   */
  /*                                                         */
     
    if ("plan view scale" < 499) then         /* if english */
      {
       _s_offset_text = _s_space + cvt_d_s0(abs(_d_distance)) + "  "
      }
    else if ("plan view scale" >499) then     /* if metric */
      {  
       _s_offset_text = _s_space + cvt_d_s1(abs(_d_distance)) + "  "
      }
      
    
    _d_angle=cogo_tangentanglechain(_mp_lt_tie_pnt_curr,_s_chain) + 90
    _d_lt_dit_wid_curr = abs(cogo_distance_between_points(_mp_lt_out_fldit_curr,_mp_lt_in_fldit_curr))
    _d_lt_dit_wid_prev = abs(cogo_distance_between_points(_mp_lt_out_fldit_prev,_mp_lt_in_fldit_prev))
    draw gg=^Construction Limits^ text value = _s_offset_text "~ltloc text symbology" angle=_d_angle
    _d_dist = cogo_distance_between_points (_mp_lt_out_fldit_prev, _mp_lt_out_fldit_curr)
    _d_slope = ((_d_elev - _d_prev_elev_lt) / _d_dist) * 100.0
    _s_slope_text = cvt_d_s1(abs(_d_slope)) + "%"
    _d_angle2 = cogo_angle_between_points (_mp_lt_out_fldit_prev, _mp_lt_out_fldit_curr) 
    _d_lt_distance_between_tie_ditch = abs(cogo_distance_between_points(_mp_lt_tie_pnt_prev,_mp_lt_out_fldit_prev)) 
       
       /* if the section is in cut, draw the ditch lines and grades into the plan view */     
      if ((_d_lt_dit_wid_curr > tolerance) or (_d_lt_dit_wid_prev > tolerance) or 
          (_s_ditchtype = ^v^) or (_d_lt_distance_between_tie_ditch > tolerance)) and (_s_test_left = "passed") then /* Ditch Bottom Exists and prev section worked and was not a fill section */ 
        {
         set plot parameters "~ditch line symbology"
         draw skip to _mp_lt_out_fldit_prev
         draw gg=^Ditch Lines^ to _mp_lt_out_fldit_curr
         if _s_ditchtype = ^fbd^ or (_d_lt_dit_wid_prev > 0) then /* if current or previous section was a flat bottom ditch */
           {
             draw skip to _mp_lt_in_fldit_prev
             draw gg=^Ditch Lines^ to _mp_lt_in_fldit_curr
           }
         /* Find center of ditch midway between sections */
         draw skip to _mp_lt_out_fldit_prev
         draw skip angle = _d_angle2 for distance = _d_dist/2.0
         draw skip angle = _d_angle2+270 for distance = ((_d_lt_dit_wid_curr+_d_lt_dit_wid_prev)/4)
           if (_d_slope < 0) then /* Water flows back station */
             {
              _d_angle3 = _d_angle2
              _d_angle2 = _d_angle2 - 180
              draw gg=^Ditch Labels^ cell = gpk2 xs=_d_cell_scale ys=_d_cell_scale angle =_d_angle3
              draw skip angle = _d_angle2+90 for distance = ((_d_lt_dit_wid_curr+_d_lt_dit_wid_prev)/2)
              _d_angle=_d_angle-90
              draw gg=^Slope Text^ text value = _s_slope_text "~slope text symbology" angle=_d_angle
             }
           else if (_d_slope > 0) then
             {
              _d_angle3 = _d_angle2 -180
              draw gg=^Ditch Labels^ cell = gpk2 xs=_d_cell_scale ys=_d_cell_scale angle = _d_angle3
              draw skip angle = _d_angle2+270 for distance = ((_d_lt_dit_wid_curr+_d_lt_dit_wid_prev)/2)
              _d_angle=_d_angle-90
              draw gg=^Slope Text^ text value = _s_slope_text "~slope text symbology" angle=_d_angle
             }
           else /* Ditch Elevations are equal no flow arrow  */
             {
               draw skip angle = _d_angle2+270 for distance = ((_d_lt_dit_wid_curr+_d_lt_dit_wid_prev)/2)
              _d_angle=_d_angle-90
              draw gg=^Slope Text^ text value = _s_slope_text "~slope text symbology" angle=_d_angle
             }
        
        
        }
      else
       {
         draw dx=0 dy=0
       } 
        
    _mp_lt_tie_pnt_prev = _mp_lt_tie_pnt_curr
    _mp_lt_out_fldit_prev = _mp_lt_out_fldit_curr
    _mp_lt_in_fldit_prev = _mp_lt_in_fldit_curr
    _d_prev_elev_lt = _d_elev
    _s_test_left = "passed"
  }

}  
   else /* Right Side */
  /********************** Set variables for left or right side *****************************/
    {
       mark _mp_rt_tie_pnt_curr
       _s_rt_tie_type = _s_tie_type
       
       if (_s_rt_tie_type = "c") then /* Cut section */
         {
           draw skip to _mp_out_fldit
           mark _mp_rt_out_fldit_curr
           draw skip to _mp_in_fldit
           mark _mp_rt_in_fldit_curr
         }
 
        else if (_s_rt_tie_type = "cnbs") then /* Cut section with no backslope */
         {
           draw skip to _mp_rt_tie_pnt_curr
           mark _mp_rt_out_fldit_curr
           draw skip to _mp_in_fldit
           mark _mp_rt_in_fldit_curr
         }
        else /* Fill section */
         {
          mark _mp_rt_out_fldit_curr
          mark _mp_rt_in_fldit_curr            
         } 
 
 /***************************** Plan View Draw Ditch On Right Side ****************************/

if not (_mp_rt_tie_pnt_prev) and (_s_side="right") then  /* First Section! Intialize "Prev" Marked Points */
  {
    _mp_rt_tie_pnt_prev = _mp_rt_tie_pnt_curr
    _mp_rt_out_fldit_prev = _mp_rt_out_fldit_curr
    _mp_rt_in_fldit_prev = _mp_rt_in_fldit_curr
    _d_prev_elev_rt = _d_elev
    draw skip to _mp_rt_tie_pnt_prev
    draw gg=^Construction Limits^ cell = gpk1 xs=_d_cell_scale ys=_d_cell_scale
    
/***************************** Determine offset from baseline or designline ****************************/
    
    if _s_line = "baseline" then
      {
        _d_distance=cogo_offsetFromChain(_mp_rt_tie_pnt_curr,_s_chain)
      }
    else
      {
        _d_distance=cogo_offsetFromChain(_mp_rt_tie_pnt_curr,_s_deschain)
      }
      
/*                                                           */       
    if _S_TIE_TYPE="S" then               /* This next part    */
      {                                   /* puts the word     */
       _s_space = "  Sheared "            /* "Sheared" in the  */ 
      }                                   /* loc text if a     */
    else                                  /* sheared section   */
      {                                   /*                   */
       _s_space = "  "                    /*                   */
      }                                   /*                   */
  /*                                                         */   
   
    if "plan view scale" < 499 then
      {
       _s_offset_text = _s_space + cvt_d_s0(abs(_d_distance)) + "  "
      }
    else
      {  
       _s_offset_text = _s_space + cvt_d_s1(abs(_d_distance)) + "  "
      }
        
    _d_angle=cogo_tangentanglechain(_mp_rt_tie_pnt_curr,_s_chain) + 90
    draw gg=^Construction Limits^ text value = _s_offset_text "~rtloc text symbology" angle=_d_angle
    
  }
else /* Continue */
  {
    /* Draw Limits of Construction */
    set plot parameters LvName=RD Limits of Construction co=73 wt=2 lc=0
    draw skip to _mp_rt_tie_pnt_curr
    draw gg=^Construction Limits^ cell = gpk1 xs=_d_cell_scale ys=_d_cell_scale
    
    if _s_test_right = "passed" then
      {
       draw skip to _mp_rt_tie_pnt_prev
       draw gg=^Construction Limits^ to _mp_rt_tie_pnt_curr
      }
    else
      {
       draw skip dx=0 dy=0
      }
    
/***************************** Determine offset from baseline or designline ****************************/
    
    if _s_line = "baseline" then
      {
        _d_distance=cogo_offsetFromChain(_mp_rt_tie_pnt_curr,_s_chain)
      }
    else
      {
        _d_distance=cogo_offsetFromChain(_mp_rt_tie_pnt_curr,_s_deschain)
      }

/*                                                           */       
    if _S_TIE_TYPE="S" then               /* This next part    */
      {                                   /* puts the word     */
       _s_space = "  Sheared "            /* "Sheared" in the  */ 
      }                                   /* loc text if a     */
    else                                  /* sheared section   */
      {                                   /*                   */
       _s_space = "  "                    /*                   */
      }                                   /*                   */
  /*                                                         */          
       
    if "plan view scale" < 499 then
      {
       _s_offset_text = _s_space + cvt_d_s0(abs(_d_distance)) + "  "
      }
    else
      {  
       _s_offset_text = _s_space + cvt_d_s1(abs(_d_distance)) + "  "
      }
    
    _d_angle=cogo_tangentanglechain(_mp_rt_tie_pnt_curr,_s_chain) + 90
    _d_rt_dit_wid_curr = abs(cogo_distance_between_points(_mp_rt_out_fldit_curr,_mp_rt_in_fldit_curr))
    _d_rt_dit_wid_prev = abs(cogo_distance_between_points(_mp_rt_out_fldit_prev,_mp_rt_in_fldit_prev))
    draw gg=^Construction Limits^ text value = _s_offset_text "~rtloc text symbology" angle=_d_angle
    _d_dist = cogo_distance_between_points (_mp_rt_out_fldit_prev, _mp_rt_out_fldit_curr)
    _d_slope = ((_d_elev - _d_prev_elev_rt) / _d_dist) * 100.0
    _s_slope_text = cvt_d_s1(abs(_d_slope)) + "%"
    _d_angle2 = cogo_angle_between_points (_mp_rt_out_fldit_prev, _mp_rt_out_fldit_curr)
    _d_rt_distance_between_tie_ditch = abs(cogo_distance_between_points(_mp_rt_tie_pnt_prev,_mp_rt_out_fldit_prev))
     
      if ((_d_rt_dit_wid_curr > tolerance) or (_d_rt_dit_wid_prev > tolerance) or 
          (_s_ditchtype = ^v^) or (_d_rt_distance_between_tie_ditch > tolerance))  and (_s_test_right = "passed") then /* Ditch Bottom Exists and prev section worked*/ 
        {
         set plot parameters "~ditch line symbology"
         draw skip to _mp_rt_out_fldit_prev
         draw gg=^Ditch Lines^ to _mp_rt_out_fldit_curr
         if _s_ditchtype = ^fbd^ or (_d_rt_dit_wid_prev > 0) then /* if current or previous section was a flat bottom ditch */
           {
             draw skip to _mp_rt_in_fldit_prev
             draw gg=^Ditch Lines^ to _mp_rt_in_fldit_curr
           }
         /* Find center of ditch midway between sections */
         draw skip to _mp_rt_out_fldit_prev
         draw skip angle = _d_angle2 for distance = _d_dist/2.0
         draw skip angle = _d_angle2+90 for distance = ((_d_rt_dit_wid_curr+_d_rt_dit_wid_prev)/4)
         if (_d_slope < 0) then /* Water flows back station */
             {
              _d_angle3 = _d_angle2
              _d_angle2 = _d_angle2 - 180
              draw gg=^Ditch Labels^ cell = gpk2 xs=_d_cell_scale ys=_d_cell_scale angle =_d_angle3
              draw skip angle = _d_angle2+270 for distance = ((_d_rt_dit_wid_curr+_d_rt_dit_wid_prev)/2)
              _d_angle=_d_angle-90
              draw gg=^Slope Text^ text value = _s_slope_text "~slope text symbology" angle=_d_angle
             }
           else if (_d_slope > 0) then
             {
              _d_angle3 = _d_angle2 -180
              draw gg=^Ditch Labels^ cell = gpk2 xs=_d_cell_scale ys=_d_cell_scale angle = _d_angle3
              draw skip angle = _d_angle2+90 for distance = ((_d_rt_dit_wid_curr+_d_rt_dit_wid_prev)/2)
              _d_angle=_d_angle-90
              draw gg=^Slope Text^ text value = _s_slope_text "~slope text symbology" angle=_d_angle
             }
          else /* Flow elevations are equal no flow arrow */
            {
              draw skip angle = _d_angle2+90 for distance = ((_d_rt_dit_wid_curr+_d_rt_dit_wid_prev)/2)
              _d_angle=_d_angle-90
              draw gg=^Slope Text^ text value = _s_slope_text "~slope text symbology" angle=_d_angle
            }   
          
        }
      else   
       {
         draw dx=0 dy=0
       } 
        
    _mp_rt_tie_pnt_prev = _mp_rt_tie_pnt_curr
    _mp_rt_out_fldit_prev = _mp_rt_out_fldit_curr
    _mp_rt_in_fldit_prev = _mp_rt_in_fldit_curr
    _d_prev_elev_rt = _d_elev
    _s_test_right = "passed"
  }

}  




}
end sub
} 

 
 
/*=XXX===============================================================================================*/
/*================================================================================================*/
/*================================================================================================*/
/*===========  SUBROUTINES USED TO LABEL CROSS SECTIONS  =========================================*/
/*================================================================================================*/
/*================================================================================================*/
/*================================================================================================*/
 
 
 
 
 
 
 
 

/*===============================================================================================*/
/*===========SUBROUTINE - ASSEMBLES THE OFFSET AND ELEVATION LABLE  =============================*/
/*===========  OFFSET IS 2 DEC IMPERIAL, 3 METRIC  ==============================================*/
/*===============================================================================================*/
subroutine offset_elevation     
  {
    mark x345 y345
    _d_off = abs(x345 - x998)
    _d_elev = abs(y345)
    if x345 < x998 then
     {
      _s_side_label = "Lt."
     }
   else
     {
      _s_side_label = "Rt."
     }  
    _s_label = cvt_d_s2(_d_off) + " " + _s_side_label + ", El. " + cvt_d_s2(_d_elev)
    draw skip dx=0 dy = _d_txoff
    draw text value=_s_label
       "~offset text symbology"
    draw skip to x345 y345
  }
end sub

/*===============================================================================================*/
/*===========SUBROUTINE - ASSEMBLES THE OFFSET LABLE ROUNDED TO 2 DEC IF IMPERIAL, 3 IF METRIC  ===================*/
/*===============================================================================================*/
subroutine offset_2            
  {
    mark x345 y345
    _d_off = abs(x345 - x998)
    _d_elev = abs(y345)
    if x345 < x998 then
     {
      _s_side_label = "Lt."
     }
   else
     {
      _s_side_label = "Rt."
     }  
    _s_label = cvt_d_s2(_d_off) + " " + _s_side_label
    draw skip dx=0 dy = _d_txoff
    draw text value=_s_label
       "~offset text symbology"
    draw skip to x345 y345
  }
end sub

/*===============================================================================================*/
/*===========SUBROUTINE - ASSEMBLES THE OFFSET LABLE ROUNDED TO 0 DEC IF IMPERIAL, 1 IF METRIC  =====================*/
/*===============================================================================================*/
subroutine offset_0             
  {
    mark x345 y345
    _d_off = abs(x345 - x998)
    _d_elev = abs(y345)
    if x345 < x998 then
     {
      _s_side_label = "Lt."
     }
   else
     {
      _s_side_label = "Rt."
     }  
    _s_label = cvt_d_s0(_d_off) + " " + _s_side_label
    draw skip dx=0 dy = _d_txoff
    draw text value=_s_label
       "~offset text symbology"
    draw skip to x345 y345
  }
end sub









