/* Locates and annotates the left low point and right low point
on the existing ground xsecs

   Requirements: 1. Run as shapeless criteria
                 2. Run as Side Slope Lt ONLY or run as Side
                    Slope Rt ONLY.
***************************************************************/



/*  DEFINE VARIABLES  */

define_dgn "exground" \
       dgn = *.dgn \
        lvname = Xsec:Existing Ground \
        co = ByLevel \
        wt = ByLevel \
        lc = ByLevel

define "~flag symbology" lvname=Sheet:Notes co=5  lc=ByLevel wt=ByLevel

define "xs scale" 10

              /*  SET UP VARIABLES FOR ANNOTATION  */

if "xs scale" < 99 then              /* ITS IMPERIAL  */
   {
     _d_th = (0.15* "xs scale")
     _d_tw = (0.15* "xs scale")
     _d_mth = (0.005* "xs scale")
     _d_mtw = (0.005* "xs scale")
     _d_voff = 1
     _d_lspace = (0.2 * "xs scale")
     _d_length = (0.5 * "xs scale")
   }
else                                 /* ITS METRIC  */
   {
    _d_th = (0.0045* "xs scale")
    _d_tw = (0.0045* "xs scale")
    _d_mth = (0.0015* "xs scale")
    _d_mtw = (0.0015* "xs scale")
    _d_voff = 0.3
    _d_lspace = (0.006 * "xs scale")
    _d_length = (0.015 * "xs scale")
   }

define "~text" th=_d_th tw=_d_tw num of dec places=2 lvname=Sheet:Notes co=5  lc=ByLevel wt=ByLevel just=lc angle=90
define "~textmicro" th=_d_mth tw=_d_mtw num of dec places=2 lvname=Sheet:Notes co=5  lc=ByLevel wt=ByLevel just=cc angle=90

if p1 then

  {
    mark x80 y80
    draw skip dx=0 dy=100
    if Material Below = "exground" then
      {
       draw skip dx = 0 dy = -1 to xs "exground"
       draw skip trace "exground" out off=0 to endpoint
       mark x1 y1
       mark x20 y20
       draw skip trace "exground" out off=0 to endpoint
       mark x2 y2
       if y2 < y1 then
         {
           mark x20 y20
         }
       while abs(x2 - x1) > tolerance
          {
            mark x1 y1
            draw skip trace "exground" out off=0 to endpoint
            mark x2 y2
            if y2 < y20 then
              {
                mark x20 y20
              }
          }
                 /*  LABEL LOW POINT  */
       draw skip to x20 y20
       if x20 < x80 then        /* ON LEFT  */
          {
            _s_mt = "llp"
          }
       else                     /* ON RIGHT  */
          {
            _s_mt = "rlp"
          }
       draw text value = _s_mt
              "~textmicro"
       draw skip to x20 y20
       set plot param "~flag symbology"
       draw skip dx = 0 dy = _d_voff
       draw dx = 0 dy = _d_length
       draw skip dx = 0 dy = _d_voff
       mark x25 y25
       draw text char = ^LOW POINT^
              "~text"


                /*  CALCULATE AND PLACE OFFSET LABEL  */
       draw skip to x25 y25
       draw skip dx = -(_d_lspace) dy = 0
       _d_off = abs(x20 - x80)
       if x20 < x80 then
          {
            _s_label = cvt_d_s2(_d_off) + " Lt."
          }
       else
          {
            _s_label = cvt_d_s2(_d_off) + " Rt."
          }
            draw text value=_s_label
               "~text"


                /*  CALCULATE AND PLACE ELEVATION LABEL  */
       draw skip to x25 y25
       draw skip dx = _d_lspace dy = 0
       _d_elev = y20
       _s_elev = cvt_d_s2(_d_elev)
       draw text value=_s_elev
               "~text"
      }
  }


