/* Plots Estimated Subgrade on Finals */

/*=========================================================================
REMSURF.BX -- This criteria file is meant to draw the subgrade surface on any
finaled project. All the user should have to do is define the appropriate symbology
for the edges of pavement, as well as the appropriate pavement
thicknesses for his/her project. You can also define the symbology
with which the subbase will be plotted.

Written By: Tom Sawyer

This file should be run from side slope lt only

ASSUMPTIONS:

Assumes that edges of pavement will be found in pairs. If you have an odd
number of edges of pavement, you will get irregular results for that
particular cross section. An error message will be written onto the
cross section if an odd number of pavement edges are found.

=========================================================================*/

/*=========================================================================
DEFINITIONS
=========================================================================*/

define_dgn "final" \
       dgn = *.dgn \
        lv = Xsec:Prop Slope \
        co = ByLevel \
        wt = ByLevel \
        lc = ByLevel

define_dgn "existing edge of pavement"\
       dgn = topog file\
        lvname = Back of Curb \
        co = ByLevel \
        lc = ByLevel \
        wt = ByLevel

define "exist pavement thick" 0.2
define "intersect distance" 25
define "~warning text symbology" off=0 lv=11 co=3 wt=1 ft=5 th=1.25 tw=1.25 just=lc angle=90
define "~ex pavement symbology"       lv=9  co=16 wt=1 lc=2
define "~shoulder undercut symbology" lvname=Default co=69 wt=0


/*=================================================================
This section of the file marks and labels each edge of pavement
and shoulder
================================================================*/

if p1 then
{
_d_eop_intersection = 0
_d_eop_intersection_counter = 0
_d_exshoulder_intersection = 0
_d_exshoulder_intersection_counter = 0
_d_irreg = 0

draw skip trace in off=0 for dx = 300
mark x900 y900

/*  mark  EXISTING EDGES OF PAVEMENT  X1 - X19 */

     if intersect dgn = "existing edge of pavement" then
          {
          _d_eop_intersection = 1
          _d_eop_intersection_counter = 1
          _s_test = ^pass^
          while intersect dgn = "existing edge of pavement" and _s_test = ^pass^
               {
               draw skip dx = 1 dy = 0 to "existing edge of pavement"
               draw skip dx = 0 dy = 50
               mark x200 y200
               draw skip dx = 0 dy = -1 to xs "final"
               mark x201 y201
               if y200 > y201 then            /*  final was found */
                 {
                  mark x[_d_eop_intersection_counter] y[_d_eop_intersection_counter]
                  _d_eop_intersection_counter = _d_eop_intersection_counter + 1
                  draw text angle=90 lv=62 char=^eop^ just=lc th=0.5 tw=0.5 co=0
                  draw skip dx = (2 * tolerance) dy = 0
                 }
               else
                 {
                  _s_test = ^fail^
                  draw skip dx=0 dy=-50
                  draw text char=^Edge of Pavement not on FINAL^
                     "~warning text symbology"
                 }  
               }
          }
     _d_eop_intersection_counter = _d_eop_intersection_counter - 1

}

/*=================================================================================
Check for odd number of edges of pavement and issue error message
=================================================================================*/

_d_temp = _d_eop_intersection_counter / 2
_d_temp_int = INT(_d_temp)

if _d_temp > _d_temp_int then
  {
  draw skip to xpgl ypgl
  draw text char=^Irregular Pavement Found^
     "~warning text symbology"
  _d_irreg = 1
  }
/*=======================================================================================
This while loop loops over each of the edge of pavement pairs and draws the existing
pavement and shoulder subbase
=======================================================================================*/

if _d_irreg = 0 then
   {
   _d_admin_counter = 1
   _d_median = 0
   while (_d_admin_counter < _d_eop_intersection_counter)

      {

      _d_global_counter = _d_admin_counter

/*===========================================================================
This section draws the estimated subgrade template
==========================================================================*/

       if p1 then
         {
         _d_rt_eop = _d_global_counter

         /* Draw Pavement */
         set plot parameters "~ex pavement symbology"
         draw skip to x[_d_rt_eop] y[_d_rt_eop]
         mark x601 y601
         mark x891 y891
         draw dx = 0 dy = -"exist pavement thick"
         set plot parameters "~shoulder undercut symbology"
         draw skip to x[_d_rt_eop] y[_d_rt_eop]
         draw trace "final" out off = -"exist pavement thick" to x[_d_rt_eop+1]
         set plot parameters "~ex pavement symbology"
         draw dx = 0 dy = 1 to xs "final"

         /* save off mark points for subsequent use */
         draw skip to x[_d_rt_eop] y[_d_rt_eop]
         draw skip dx = 0 dy = -"exist pavement thick"
         mark x702 y702
         mark x802 y802

         /* Mark points to use for subgrade slope */
         set plot parameters "~shoulder undercut symbology"
         draw skip to x[_d_rt_eop] y[_d_rt_eop]
         draw skip trace "final" out offset = 0 for dx = 2 * tolerance
         draw skip trace "final" out offset = 0 to endpoint
         draw skip dx = 0 dy = -"exist pavement thick"
         mark x902 y902
         _d_slope = (y902 - y702)/abs(x902 - x702)
         draw skip to x702 y702
         draw skip dx = -1 dy= (-_d_slope) to xs "final"
         mark x999 y999
         if abs(x999 - x702) < tolerance then
           {
            draw text char=^Could not Intersect^
               "~warning text symbology"
           }
         else if abs(x999 - x702) > "intersect distance" then
           {
            draw skip to x702 y702
            draw text char=^Intersect Distance Exceeded^
                "~warning text symbology"
           }
         else
           {
            draw to x702 y702
           }
         draw skip to x[_d_rt_eop] y[_d_rt_eop]


         /* FIND THE BREAK POINT CLOSEST TO THE LEFT EDGES */
         draw skip trace "final" out offset = 0 for dx = 2 * tolerance
         draw skip trace "final" out offset = 0 to endpoint
         mark x70 y70
         while abs(x[_d_rt_eop+1] - x900) - abs(x70 - x900) > tolerance
           {
            mark x69 y69
            draw skip trace "final" out offset = 0 for dx = 2 * tolerance
            draw skip trace "final" out off=0 to endpoint
            mark x70 y70
           }
         draw skip to x69 y69
         draw skip dx = 0 dy = -"exist pavement thick"
         mark x902 y902

         draw skip to x[_d_rt_eop+1] y[_d_rt_eop+1]
         mark x602 y602
         mark x892 y892
         draw skip dx = 0 dy = -"exist pavement thick"
         mark x701 y701
         mark x801 y801


         _d_slope = (y902 - y701)/abs(x902 - x701)
         draw skip to x701 y701
         draw skip dx = 1 dy= (-_d_slope) to xs "final"
         mark x999 y999


         if abs(x999 - x701) < tolerance then
           {
            draw text char=^Could not Intersect^
               "~warning text symbology"
           }
         else if abs(x999 - x701) > "intersect distance" then
           {
            draw skip to x701 y701
            draw text char=^Intersect Distance Exceeded^
                "~warning text symbology"
           }
         else
           {
            draw to x701 y701
           }
         draw skip to x[_d_rt_eop+1] y[_d_rt_eop+1]
         }


/*===============================================================
Reset the counter and go to the next pair of eop's
/*=============================================================*/

      _d_admin_counter = _d_admin_counter + 2
     }
   }

