/***************************************************************************************************/
/* Pave Grades                                                                                     */
/*                                                                                                 */
/* This criteria file was written by Tom Sawyer of NDOR                                            */
/*                                                                                                 */
/*                                                                                                 */
/* The purpose of this criteria file is to create a comma separated ASCII text file which contains */
/*     detailed paving grade information.                                                          */
/*                                                                                                 */
/* The proposed cross sections need to be previously completed in a separate run.                  */
/*                                                                                                 */
/* Written : 9/18/2001 By Tom Sawyer                                                               */
/* Editted : 6/8/04    By Mike Otte ~ Edited Symbology and removed Elevation Truncation            */
/*                                    Line 757 ~ _s_elevation_text = cvt_d_s2(_d_elevation_trunc)  */
/*                                       NOW   = _s_elevation_text = cvt_d_s2(_d_elevation)        */
/***************************************************************************************************/

define "Plan View Scale" 20


/********************* Define materials in sections to use for calculations *************************/

define_dgn "Top of Pavement" dgn = xs.dgn lvname=PX:Prop Pvmnt Top co=Bylayer wt=Bylayer
define_dgn "Subgrade"        dgn = xs.dgn lvname=Default co=69 wt=Bylayer
define_dgn "Top of Curb"     dgn = xs.dgn lvname=PX:Prop Curb co=Bylayer wt=Bylayer
define_dgn "XS Back of Curb" dgn = xs.dgn lvname=PX:Prop Curb Sub co=Bylayer wt=Bylayer
define_dgn "Joint Lines"     dgn = pat.dgn lvname=Joints co=Bylayer wt=Bylayer

define "~grade line symbology" lvname=Sht:Notes wt=0 co=5 lc=0
define "~tic mark symbology"   lvname=Sht:Notes wt=1 co=8 lc=0   

/*==================  Imperial symbology variables  ===========================================*/
define "~warning text symbology" off=0.000 lvname=PX:Warning Label co=3  wt=1 ft=1 th=("Plan View Scale"/30) tw=("Plan View Scale"/30) just=lc angle=90
define "~label text symbology"   off=0.000 lvname=PX:Warning Label co=73  wt=1 ft=1 th=("Plan View Scale"/10) tw=("Plan View Scale"/10) just=lc angle=90
define "~pave debug text symbology"   off=0.000 lvname=PX:Warning Label co=3  wt=1 ft=1 th=1 tw=1 just=lc angle=90
define "~blue debug text symbology"   off=0.000 lvname=PX:Warning Label co=69  wt=1 ft=1 th=1 tw=1 just=rc angle=90
define "~grade text symbology" num of dec place=2 lvname=Sht:Notes co=5 wt=1 ft=2 just=lc th=2.8 tw=2.8

/*==================  Metric symbology variables  =============================================*/
define "~M_warning text symbology" off=0.000 lv=11 co=3  wt=1 ft=5 th=("plan view scale" / 1000) tw=("plan view scale" / 1000) just=lc angle=90
define "~M_label text symbology"   off=0.000 lv=12 co=73  wt=1 ft=5 th=("plan view scale" / 333.3) tw=("plan view scale" / 333.3) just=lc angle=90
define "~M_pave debug text symbology"   off=0.000 lv=62 co=3  wt=1 ft=5 th=0.5 tw=0.5 just=lc angle=90
define "~M_blue debug text symbology"   off=0.000 lv=62 co=69  wt=1 ft=5 th=0.5 tw=0.5 just=rc angle=90
define "~M_grade text symbology" num of dec place=3 lv=24 co=5 wt=1 ft=5 just=lb th=("Plan View Scale"/333.3) tw=("Plan View Scale"/333.3)

/******************** Set up variables for metric or english ***************************************/

if "Plan View Scale" < 199 then             /*  It's Imperial  */
  {
   _d_1ft = 1
   _d_2ft = 2
   _d_4ft = 4
   _d_5ft = 5
   _d_10ft = 10
   _d_50ft = 50
   _d_tolerance = 0.01
   _d_tic_length = ("Plan View Scale"/7.1429)
   _d_grade_line_length = ("Plan View Scale"/2)
   _s_units = ^imperial^
  }
else                                        /*  It's Metric    */
  {
   _d_1ft = 0.3
   _d_2ft = 0.6
   _d_4ft = 1.2
   _d_5ft = 1.5
   _d_10ft = 3
   _d_50ft = 15
   _d_tolerance = 0.01
   _d_tic_length = ("Plan View Scale"/500)
   _d_grade_line_length = ("Plan View Scale"/66.67)
   _s_units = ^metric^
  }
if p1 then
  {   
   _s_EG_test = ^passed^
   _s_test_left = ^passed^
   _s_test_right = ^passed^
   _s_test1 = ^inside^
  }



/********************************************************************************************************/
/***************************     PROMPTS     ************************************************************/
/********************************************************************************************************/   
if not (_mp_prompt) then
 { 
   /***********************   Check Tolerance   *********************************************************/ 
   if 1*tolerance > _d_tolerance then
   {
    Prompt ^The tolerance value is too large, Use 0.01^ mode = message
            if (CANCEL) then {EXIT}
            if (OK) then {EXIT}
   }
   if 1*tolerance < _d_tolerance then
   {
    Prompt ^The tolerance value is too Small, Use 0.01^ mode = message
            if (CANCEL) then {EXIT}
            if (OK) then {EXIT}
   }
   
   mark _mp_prompt

   /********************* PROMPT: Report Type **************************************************************/
   _s_report_type = "Paving_Grades"
   Prompt ^Select Type of Report to Be Created^ variable = _s_report_type mode = option content = Paving_Grades, Blue_Top, Both
   if (CANCEL) then {EXIT}
   if not _s_report_type = "Blue_Top" then
     {
       /********************* PROMPT: Draw Paving Grades to DGN file?  ***********************************/
       _s_plot = ^yes^
       Prompt ^Plot Paving Grades to Plan View File?  Yes or No^ variable = _s_plot mode = option content = Yes, No
       if (CANCEL) then {EXIT}
       if (_s_plot=^yes^) then
       {
         /********************* PROMPT: Name of DGN File?  ***********************************************/
         _s_planview = "Please Select"
         Prompt ^Select DGN File^ variable = _s_planview mode = file select filter = *.dgn
         if (CANCEL) then {EXIT}
         if _s_planview = "Please Select" then
           {
             Prompt ^YOU MUST Select DGN File^ variable = _s_planview mode = file select filter = *.dgn
             if (CANCEL) then {EXIT}
             if _s_planview = "please select" then
               {
                 {EXIT}
               }
           
           }
         _d_grade_line_angle = 45
         Prompt ^Enter Angle for Grade Line (measured from CL)^ variable = _d_grade_line_angle mode = keyin
         if (CANCEL) then {EXIT}
            
       }
     }

   /********************* PROMPT: Draw annotations to cross section file?  ***********************************/
   _s_debug_text = ^yes^
   Prompt ^Annotate Points on Cross Sections? (on Level 62)  Yes or No^ variable = _s_debug_text mode = option content = Yes, No
   if (CANCEL) then {EXIT}



   /********************* PROMPT: distances are to be from design line or base line **************/
   PROMPT ^Distances computed from BaseLine or DesignLine?^ VARIABLE = _s_line MODE = OPTION CONTENT = BaseLine, DesignLine
   if (CANCEL) then {EXIT}
   if (_s_line="DesignLine") then
     {
       /********************* PROMPT: Name of chain to be used for offsets?  ******************************/
       _s_deschain = "Please Enter"
       Prompt ^Name of Chain that distances are computed from^ variable = _s_deschain mode = keyin
       if (CANCEL) then {EXIT}
                                        
       draw skip to x1 y1
     }
                
 }
else
 {
  draw dx=0 dy=0
 }

/********************************************************************************************************/
/***************************     END PROMPTS     ********************************************************/
/********************************************************************************************************/

/********************************************************************************************************/
/***************************     OPEN FILES      ********************************************************/
/********************************************************************************************************/

if not _mp_open then       
  {
    _s_dummytext = ^^
    _s_chain = chain name
    if (_s_report_type = ^paving_grades^) or (_s_report_type = ^both^) then
      {
        _s_heading = ^PAVING GRADES REPORT^
        _s_heading2 = ^ALIGNMENT^
        _s_heading3 = ^STATION^
        _s_heading4 = ^CODE^
        _s_heading5 = ^OFFSET^
        _s_heading6 = ^elevation^
        _s_pavegrade = _s_chain + "_pavegrd.csv"
        _s_filename = _s_pavegrade
        ascii open file = _s_filename
        ascii write file = _s_filename
        format =^%s\n\n^
        var = _s_heading
        ascii write file = _s_filename
        format =^%s,%s,%s,%s,%s\n^
        var = _s_heading2,_s_heading3,_s_heading4,_s_heading5,_s_heading6
      }
    if (_s_report_type = ^blue_top^) or (_s_report_type = ^both^) then
      {
        _s_heading = ^BLUETOP REPORT^
        _s_heading2 = ^ALIGNMENT^
        _s_heading3 = ^STATION^
        _s_heading4 = ^CODE^
        _s_heading5 = ^OFFSET^
        _s_heading6 = ^elevation^
        _s_bluetop = _s_chain + "_bluetop.csv"
        _s_filename = _s_bluetop
        ascii open file = _s_filename
        ascii write file = _s_filename
        format =^%s\n\n^
        var = _s_heading
        ascii write file = _s_filename
        format =^%s,%s,%s,%s,%s\n^
        var = _s_heading2,_s_heading3,_s_heading4,_s_heading5,_s_heading6
      }
    mark _mp_open
    
  }
if p1 then             /*  INITIALIZE VARIABLES  */
  {
    /*  _s_blankline = ^^  */
    _s_BRcheck = ^true^
    _d_slope1 = 0
    _d_slope2 = 0
    _d_elevation_trunc = 0
    _d_counter_low = 0
    _s_PointType = ^EOP^
    _s_EG_test = ^passed^
  }

/********************************************************************************************************/
      /********************* Checking for presence of existing ground **************/

if p1 then
  {
    draw skip dx=0 dy=_d_50ft
    mark x1 y1
    draw skip dx=0 dy=-1 to existing ground
    mark x80 y80
    if abs(y80 - y1) < 2*tolerance then   /*  Did not move, could not find existing ground  */
      {
       _s_EG_test = ^failed^
       draw skip dx=5*tolerance dy=0
       draw skip dx=0 dy=-1 to existing ground
       mark x80 y80
       if abs(y80 - y1) > 2*tolerance then   /*  Moved, found existing ground  */
         {
          _s_EG_test = ^passed^
         }
       
      }
    else
      {
       _s_EG_test = ^passed^
      }
        
    if _s_EG_test = ^passed^ then     /*   Existing ground was found, mark both ends of the section  */
      {
       draw skip trace out offset = 0 for dx=5000
       mark x500 y500                                /*  Left end  */
       draw skip trace in offset = 0 for dx=5000
       mark x501 y501                                /*  Right end  */
       draw skip to x80 y80
      }
    else
      {
       _s_sta=cvt_d_sta(station)
       _s_problem = "Existing ground not found"
       ascii append file = _s_filename
       ascii write file = _s_filename
       format = ^%s,%s,%s\n^
       var = _s_chain,_s_sta,_s_problem
       draw skip to xpgl ypgl
       if _s_units = ^Imperial^ then
         {  
          draw text char = ^Existing ground not found^  "~warning text symbology"
         }
       else
         {
          draw text char = ^Existing ground not found^  "~M_warning text symbology"
         }  
      }  
    
  }
  
  /********************* Checking for presence of top of pavement **************/
  /********************* Createing the Pave Grade Report and Grade Sheets **************/
      
if (_s_EG_test = ^passed^) and not (_s_report_type = "blue_top") then   /* Check for top of pavement starting at left end of section  */
  {
   _s_filename = _s_pavegrade
   draw skip to x80 y80
   draw skip trace out offset = 0 for dx=1000
   draw skip dx=0 dy=50
   mark x100 y100
   While (x501 - x100) > tolerance
     {
      if not (Material Below = "top of pavement") then
        {
          draw skip trace in offset = _d_50ft for dx=_d_10ft
          mark x100 y100
        }
      else
        {
          draw skip dx=-(_d_1ft) dy=0
          draw skip dx=0 dy=-1 to xs "top of pavement"
          draw skip trace "top of pavement" out offset = 0 for dx=_d_50ft
          mark x250 y250    /*   Left EOP   */
          
          /*  Check for shear  */
          draw skip trace "top of pavement" in offset = 0 to endpoint
          mark x345 y345
          draw skip to x250 y250
          if abs(x345 - x250) < tolerance then    /*  Segment is vertical  */
            {
             draw skip dx=-2*tolerance dy=100
             mark x345 y345
             draw skip dx=0 dy=-1 to xs "top of pavement"
             mark x346 y346
             mark x346 y346
             draw skip trace "top of pavement" out offset = 0 to endpoint
             mark x250 y250
            }          
                   
          /*  end check for shear  */
          
          
          draw skip dx=(_d_1ft/2) dy=_d_1ft
          if Material Below = "Top of curb" then
            {
              draw skip to x250 y250
              
              /* detmine slope of last segment. assume that the last 1/2 foot is representitive of pavement slope.    */
              draw skip dx=(-_d_1ft/2) dy = 1
              draw skip dx=0 dy=-1 to xs "top of pavement"
              mark x240 y240
              draw skip to x250 y250
              /* end determine pave slope */
              
              _d_slope=((y250-y240)/abs(x250-x240)*100)
              draw skip slope = _d_slope to xs "xs back of curb"
              mark x240 y240
              if abs(x240 - x250) > 0 and abs(x240 - x250) < _d_4ft then
                {
                 _s_PointType = ^BOC^
                 mark _mp_current
                 call sub write_point
                }
              else
                {
                 _s_PointType = ^ERROR^
                 _s_message = ^Could not find BOC in cross section file^
                 mark _mp_current
                 call sub write_point
                }  
            }
          
          
          draw skip to x250 y250                      /*   Left EOP   */
          if _s_PointType = ^BOC^ then
            {
             _s_PointType = ^FOC^
             mark _mp_current
             call sub write_point
            }
          else
            {
             _s_PointType = ^EOP^
             mark _mp_current
             call sub write_point
            }
                   
          mark x199 y199
          mark x200 y200
          mark x201 y201
          draw skip trace "top of pavement" in offset = 0 for dx = 1000
          mark x251 y251                      /*   Right EOP    */
          
          /*  Check for shear  */
          draw skip trace "top of pavement" out offset = 0 to endpoint
          mark x345 y345
          draw skip to x251 y251
          
          if abs(x345 - x251) < tolerance then    /*  Segment is vertical  */
            {
             draw skip dx=tolerance dy=100
             mark x345 y345
             draw skip dx=0 dy=-1 to xs "top of pavement"
             mark x346 y346
             draw skip trace "top of pavement" in offset = 0 to endpoint
             mark x251 y251
            } 
                            
          /*  end check for shear  */
          
          draw skip to x250 y250
          mark _mp_current
          draw skip trace "top of pavement" in offset = 0 to endpoint
          mark x201 y201
          mark _mp_current
                    
          while ((x201-x200) > tolerance) and ((x201-x251) < tolerance)
            {
              mark x703 y703
              draw skip dx=-2*tolerance dy=0
              while intersect dgn = "Joint Lines" and _s_test1 = ^inside^
                {
                 _s_PointType = ^JL^
                 draw skip dx=1 dy=0 to "Joint Lines"
                 mark x600 y600
                 
                 if abs(x501 - x600) < abs(x501 - x200) then
                   {
                    draw skip dx=0 dy=50
                    mark x600 y600
                    draw skip dx=0 dy=-1 to xs "top of pavement"
                    mark x601 y601
                    if y601 < y600 then
                      {
                       mark _mp_current
                       _d_elevation = y601
                       mark _mp_current
                       call sub write_point
                      }
          
                   }
                 else
                   {
                    _s_test1 = ^outside^
                   }      
                 draw skip dx=2*tolerance dy=0   
                }
              draw skip to x703 y703   
              _s_test1 = ^inside^             
              _s_PointType = ^BR^
              mark _mp_current
              if ((x200 - x250) > tolerance) then     /*  x200 is not the left EOP  */
                {
                  draw skip to x200 y200
                  call sub check_false
                  if _s_BRcheck = ^true^ then
                    { 
                     mark _mp_current
                     call sub write_point
                    } 
                }  
              draw skip to x200 y200
              mark x199 y199
              draw skip to x201 y201
              mark x200 y200
              draw skip trace "top of pavement" in offset = 0 for dx = (2*tolerance)
              draw skip trace "top of pavement" in offset = 0 to endpoint
              mark x201 y201
            }
          
          draw skip to x251 y251
                            
          draw skip dx=-(_d_1ft/2) dy=_d_1ft
          if Material Below = "Top of curb" then
            {
              draw skip to x251 y251
              
              /* detmine slope of last segment. assume that the last 1/2 foot is representitive of pavement slope.    */
              draw skip dx= (_d_1ft/2) dy = 1
              draw skip dx=0 dy=-1 to xs "top of pavement"
              mark x240 y240
              draw skip to x251 y251
              /* end determine pave slope */
                            
              _d_slopex = -abs(x240-x251)
              _d_slopey = -(y240-y251)
              draw skip dx= _d_slopex dy= _d_slopey to xs "XS back of curb"
              mark x240 y240
              draw skip to x251 y251
              _s_PointType = ^FOC^
              mark _mp_current
              call sub write_point
              draw skip to x240 y240
              if abs(x240 - x251) > 0 and abs(x240 - x251) < _d_4ft then
                {
                 _s_PointType = ^BOC^
                 mark _mp_current
                 call sub write_point
                }
              else
                {
                 _s_PointType = ^ERROR^
                 _s_error_message = ^Could not find BOC in cross section file^
                 mark _mp_current
                 call sub write_point
                }  
                    
            } 
          else
            {
             draw skip to x251 y251        /*   Right EOP   */
             _s_PointType = ^EOP^
             mark _mp_current
             call sub write_point
            }
          
          call sub write_blank
          draw skip dx=-1 dy=_d_50ft
          mark x100 y100
                 
        }
     }
   draw skip to x501 y501
  
  }

  
  /********************* Createing the Blue Top Report *********************************/
  
if (_s_EG_test = ^passed^) and not (_s_report_type = "paving_grades") then   /* Check for top of Subgrade starting at left end of section  */
  {
   _s_filename = _s_bluetop
   draw skip to x80 y80
   draw skip trace out offset = 0 for dx=1000
   draw skip dx=0 dy=50
   mark x100 y100
   While abs(x501 - x100) > tolerance
     {
      if not (Material Below = "subgrade") then
        {
          draw skip trace in offset = _d_50ft for dx=_d_5ft
          mark x100 y100
        }
      else
        {
          draw skip dx=-(_d_1ft) dy=0
          draw skip dx=0 dy=-1 to xs "subgrade"
          draw skip trace "subgrade" out offset = 0 for dx=_d_50ft
          mark x250 y250                      /*   Left shoulder point   */
          _s_PointType = ^SHLDR^
          
          /*  Check for shear  */
          draw skip trace "subgrade" in offset = 0 to endpoint
          mark x345 y345
          draw skip to x250 y250
          
          if abs(x345 - x250) < tolerance then    /*  Segment is vertical  */
            {
             draw skip dx=-2*tolerance dy=0
             mark x345 y345
             draw skip dx=0 dy=1 to xs "subgrade"  /* try up  */
             mark x346 y346
             if abs(y346 - y345) < tolerance then  /*  did not move, subgrade must be below  */
               {
                draw skip dx=0 dy=-1 to xs "subgrade"
               }
             mark x346 y346
             draw skip trace "subgrade" out offset = 0 to endpoint
             mark x250 y250
            } 
          
          /*  end check for shear  */
          
          mark _mp_current
          call sub write_point
          mark x199 y199
          mark x200 y200
          mark x201 y201
          draw skip trace "subgrade" in offset = 0 for dx = 1000
          mark x251 y251                          /*   Right shoulder point    */
          
          /*  Check for shear  */
          draw skip trace "subgrade" in offset = 0 to endpoint
          mark x345 y345
          draw skip to x251 y251
          if abs(x345 - x251) < tolerance then    /*  Segment is vertical  */
            {
             draw skip dx=2*tolerance dy=0
             mark x345 y345
             draw skip dx=0 dy=1 to xs "subgrade"  /* try up  */
             mark x346 y346
             if abs(y346 - y345) < tolerance then  /*  did not move, subgrade must be below  */
               {
                draw skip dx=0 dy=-1 to xs "subgrade"
               }
             mark x346 y346
             draw skip trace "subgrade" in offset = 0 to endpoint
             mark x251 y251
            }           
                   
          /*  end check for shear  */
          
          draw skip to x250 y250
          mark _mp_current
          draw skip trace "subgrade" in offset = 0 to endpoint
          mark x201 y201
          mark _mp_current
                    
          while ((x201-x200) > tolerance) and ((x201-x251) < tolerance)
            {
              _s_PointType = ^BR^
              mark _mp_current
              if ((x200 - x250) > tolerance) then     /*  x200 is not the left shoulder point  */
                {
                  draw skip to x200 y200
                  call sub check_false
                  if _s_BRcheck = ^true^ then
                    { 
                     mark _mp_current
                     call sub write_point
                    } 
                }  
              draw skip to x200 y200
              mark x199 y199
              draw skip to x201 y201
              mark x200 y200
              draw skip trace "subgrade" in offset = 0 for dx = (2*tolerance)
              draw skip trace "subgrade" in offset = 0 to endpoint
              mark x201 y201
            }
          
          draw skip to x251 y251
          _s_PointType = ^SHLDR^
          mark _mp_current
          call sub write_point
          call sub write_blank
          draw skip dx=-1 dy=_d_50ft
          mark x100 y100
                 
        }
     }
   
  }  
  
  
/*===========================================================================*/
/*===========================================================================*/
/*======================   SUBROUTINES   ====================================*/
/*===========================================================================*/
/*===========================================================================*/

subroutine check_false
{
  mark x701 y701
  if (x199 < x200) and (x200 < x201) then
    {
     _d_slope1 = ((y200 - y199)/(x200 - x199))*10
     _d_slope2 = ((y201 - y200)/(x201 - x200))*10
     if (_d_slope1 - _d_slope2 < -1*tolerance) or (_d_slope1 - _d_slope2 > tolerance) then
       {
        _s_BRcheck = ^true^
       }
     else
       {
        _s_BRcheck = ^false^
       }  
       
    }
  draw skip to x701 y701   
}
end sub

/*===========================================================================*/
/*======================   SUBROUTINE WRITE POINT  ==========================*/
/*===========================================================================*/

subroutine write_point
{
  mark x702 y702
  mark x345 y345
  if (_s_debug_text = ^yes^) then
    {
      if (_s_filename = _s_pavegrade) then
        {
          _s_message = _s_PointType 
          if _s_units = ^imperial^ then
            {
             draw GG=^debugtext^ text value = _s_message "~pave debug text symbology"
            }
          else
            {
             draw GG=^debugtext^ text value = _s_message "~M_pave debug text symbology"
            } 
        }
      else
        {
          _s_message = _s_PointType 
          if _s_units = ^Imperial^ then
            {
             draw GG=^debugtext^ text value = _s_message "~blue debug text symbology"
            }
          else
            {
             draw GG=^debugtext^ text value = _s_message "~M_blue debug text symbology"
            }   
        }
    }
  if _s_PointType = ^ERROR^ then
    {
      ascii append file = _s_filename
      ascii write file = _s_filename
      format =^%s,%s,%s,%s\n^
      var = _s_chain,_s_sta,_s_PointType,_s_error_message
    }
  else
    {
      _s_sta=cvt_d_sta(station)
      _d_offset = x345 - x80
      _d_elevation = y345
      call sub truncate
      ascii append file = _s_filename
      ascii write file = _s_filename
      format =^%s,%s,%s,%.2f,%.2f\n^
      var = _s_chain,_s_sta,_s_PointType,_d_offset,_d_elevation
      if (_s_plot = ^yes^) and (_s_filename = _s_pavegrade) then
        {
          call sub draw_point (plan view = _s_planview)
        }
    }    
  draw skip to x702 y702
}
end sub

/*===========================================================================*/
/*======================   SUBROUTINE WRITE BLANK LINE   ====================*/
/*===========================================================================*/

subroutine write_blank
{
  _s_blankline = ^^
  ascii write file = _s_filename
  format =^%s\n^
  var = _s_blankline
}
end sub

/*===========================================================================*/
/*======================   SUBROUTINE DRAW POINT  ===========================*/
/*===========================================================================*/

subroutine draw_point
{
  if not _s_PointType = ^FOC^ then    /*  Only draw if EOP, BR, or BOC   */
    {
      draw skip to _mp_current
      _d_angle0=cogo_tangentanglechain(_mp_current,_s_chain) + 0
      _d_angleGL=cogo_tangentanglechain(_mp_current,_s_chain) + _d_grade_line_angle
      _d_angle90=cogo_tangentanglechain(_mp_current,_s_chain) + 90
      _d_angle180=cogo_tangentanglechain(_mp_current,_s_chain) + 180
      _d_angle270=cogo_tangentanglechain(_mp_current,_s_chain) + 270
      _d_angle45=cogo_tangentanglechain(_mp_current,_s_chain) + 45
      _d_angle135=cogo_tangentanglechain(_mp_current,_s_chain) + 135
      _d_angle225=cogo_tangentanglechain(_mp_current,_s_chain) + 225
      _d_angle315=cogo_tangentanglechain(_mp_current,_s_chain) + 315
      set plot parameters "~tic mark symbology"
      draw skip angle=_d_angle225 for distance=(_d_tic_length/2)
      draw gg=^grades^ angle=_d_angle45 for distance=_d_tic_length
      draw skip to _mp_current
      draw skip angle=_d_angle315 for distance=(_d_tic_length/2)
      draw gg=^grades^ angle=_d_angle135 for distance=_d_tic_length
      /*draw skip to _mp_current*/
      /*set plot parameters "~grade line symbology"*/
      /*draw gg=^grades^ angle=_d_angleGL for distance=_d_grade_line_length*/
      draw skip to _mp_current
      draw skip angle=_d_angleGL for distance=("Plan View Scale"/1000)
      draw skip angle=(_d_angleGL + 90) for distance=("Plan View Scale"/2000)
      
      if _s_units = ^imperial^ then
        {
          _s_elevation_text = " " + cvt_d_s2(_d_elevation)
          draw gg=^grades^ text value = _s_elevation_text "~grade text symbology" angle=_d_angleGL
        }
      else 
        {
         _s_elevation_text = cvt_d_s3(_d_elevation_trunc)
         draw gg=^grades^ text value = _s_elevation_text "~M_grade text symbology" angle=_d_angleGL
        }
        
      draw skip to _mp_current
    }
}
end sub

/*===========================================================================*/
/*======================   SUBROUTINE TRUNCATE ELEVATION   ==================*/
/*===========================================================================*/

subroutine truncate
{
  if _d_elevation > 5000 then
    {
     _d_counter_low = 5000
    }
  else if _d_elevation > 3000 then 
    {
     _d_counter_low = 3000
    }
  else if _d_elevation > 2000 then 
    {
     _d_counter_low = 2000
    }
  else if _d_elevation > 1000 then 
    {
     _d_counter_low = 1000
    }
  else
    {
     _d_counter_low = 0
    }
     
  while _d_elevation > _d_counter_low 
    {
      _d_counter_low = _d_counter_low + 100
    }
  _d_elevation_trunc=_d_elevation - (_d_counter_low - 100)
_d_counter_low = 0
}
end sub





 
