/* Make Profile Input File */
/************************************************************************************************/
/*     10-25-2003                                                                               */
/* This criteria file will generate profile input files for a user selected marked point on the */
/* cross section.  The user will be prompted for the left profile input file name, the left     */
/* profile name and marked point on the left side.  They will then be prompted for the same     */
/* information on the right side.  This will give the users the ability to profile any marked   */
/* in the cross section.  This will then generate a profile input file the user can then read   */
/* directly in to COGO.  This criteria file should be included once for side slope left and     */
/* once for side slope right.  The criteria should be included after all of the points have     */
/* been marked.  This file requires GEOPAK 2001 or later.                                       */
/*                                                                                              */
/************************************************************************************************/

if not _mp_prompt5 then    
  {
    mark _mp_prompt5
    _s_answer = ^No^
    prompt ^Create Profile Input File of Marked Point for COGO?^ var = _s_answer mode = option content = No,Yes
    if (CANCEL) then {EXIT}
  }

/* Determine if left or right side slope condition */
if (p1) then
  {
    mark x345 y345
    draw skip dx=1 dy=0
    mark x346 y346
    if (x346 < x345) then
      {
        _s_side = ^Left^
      }
    else
      {
        _s_side = ^Right^
      }
    draw skip to x345 y345
  }


if (_s_answer = ^Yes^) then    
  {
    
    if not _mp_prompt1 and (_s_side = ^Left^) and (median width > 1000) then /* Left outside prompts */
      {
        mark _mp_prompt1
        _s_lt_output_profilename = ^LTDITCH999.ixx^
        prompt ^Keyin Left Profile Input File Name^ var = _s_lt_output_profilename mode = keyin
        if (CANCEL) then {EXIT}
        _s_lt_profile_name = ^Ltditch^
         prompt ^Keyin Left Profile Name^ var = _s_lt_profile_name mode = keyin
        if (CANCEL) then {EXIT}
        _s_lt_mp = ^1^
        prompt ^Left Marked Point Number To Profile for X1 Y1 Use 1^ var = _s_lt_mp mode = keyin
        if (CANCEL) then {EXIT}
        _d_lt_mp = cvt_s_d(_s_lt_mp)
        _d_lt_mp = int(_d_lt_mp)
    
      }
    else if not _mp_prompt2 and (_s_side = ^Right^) and (Median Width > 1000) then /* Right outside prompts */
      {
        mark _mp_prompt2
        _s_rt_output_profilename = ^RTDITCH999.ixx^
        prompt ^Keyin Right Profile Input File Name^ var = _s_rt_output_profilename mode = keyin
        if (CANCEL) then {EXIT}
        _s_rt_profile_name = ^Rtditch^
         prompt ^Keyin Right Profile Name^ var = _s_rt_profile_name mode = keyin
        if (CANCEL) then {EXIT}
        _s_rt_mp = ^1^
        prompt ^Right Marked Point Number To Profile for X1 Y1 Use 1^ var = _s_rt_mp mode = keyin
        if (CANCEL) then {EXIT}
        _d_rt_mp = cvt_s_d(_s_rt_mp)
        _d_rt_mp = int(_d_rt_mp)
      }
      
     else if not _mp_prompt3 and (_s_side = ^Right^) and (Median Width < 1000) then /* Right Median prompts */
      {
        mark _mp_prompt3
        _s_rt_median_output_profilename = ^RTMEDIAN999.ixx^
        prompt ^Keyin Right Median Profile Input File Name^ var = _s_rt_median_output_profilename mode = keyin
        if (CANCEL) then {EXIT}
        _s_rt_median_profile_name = ^RtMedian^
         prompt ^Keyin Right Median Profile Name^ var = _s_rt_median_profile_name mode = keyin
        if (CANCEL) then {EXIT}
        _s_rt_median_mp = ^1^
        prompt ^Right Median Marked Point Number To Profile for X1 Y1 Use 1^ var = _s_rt_median_mp mode = keyin
        if (CANCEL) then {EXIT}
        _d_rt_median_mp = cvt_s_d(_s_rt_median_mp)
        _d_rt_median_mp = int(_d_rt_median_mp)
      }  
     
     else if not _mp_prompt4 and (_s_side = ^Left^) and (Median Width < 1000) then /* Left Median prompts */
      {
        mark _mp_prompt4
        _s_lt_median_output_profilename = ^LTMEDIAN999.ixx^
        prompt ^Keyin Left Median Profile Input File Name^ var = _s_lt_median_output_profilename mode = keyin
        if (CANCEL) then {EXIT}
        _s_lt_median_profile_name = ^LtMedian^
         prompt ^Keyin Left Median Profile Name^ var = _s_lt_median_profile_name mode = keyin
        if (CANCEL) then {EXIT}
        _s_lt_median_mp = ^1^
        prompt ^Left Median Marked Point Number To Profile for X1 Y1 Use 1^ var = _s_lt_median_mp mode = keyin
        if (CANCEL) then {EXIT}
        _d_lt_median_mp = cvt_s_d(_s_lt_median_mp)
        _d_lt_median_mp = int(_d_lt_median_mp)
      }  
    
     if (_s_side = ^Left^) and (median width > 1000)  then 
      {
        /* The next line represents the marked point location that will be profiled */
        draw skip to x[_d_lt_mp] y[_d_lt_mp]
        mark _mp_wanted_point
        _d_elevation = _mp_wanted_point.elev
        _s_elevation = cvt_d_s2(_d_elevation)
        _s_sta=cvt_d_sta(station)
    
        if not _mp_open_lt then /* Used for first point only to create and open the ascii text file */
          {
            mark _mp_open_lt
            _d_point_number_lt = 1
            _s_point_number_lt = cvt_d_s0(_d_point_number_lt)
            _s_first_line = ^Sto Pro ^ + _s_lt_profile_name  /* Name of the profile that would be read into cogo for left side */
            ascii open file = _s_lt_output_profilename
            ascii write file = _s_lt_output_profilename
            format = ^%s\n^
            var = _s_first_line
            _s_second_line = ^VPI ^ + _s_point_number_lt + ^ S ^ + _s_sta + ^ E ^ + _s_elevation
            ascii write file = _s_lt_output_profilename
            format = ^%s\n^
            var = _s_second_line
    
          }
        else
          {
            _d_point_number_lt = _d_point_number_lt + 1
            _s_point_number_lt = cvt_d_s0(_d_point_number_lt)
            _s_second_line = ^VPI ^ + _s_point_number_lt + ^ S ^ + _s_sta + ^ E ^ + _s_elevation
            ascii write file = _s_lt_output_profilename
            format = ^%s\n^
            var = _s_second_line
            /***************** This section can only be ran in Geopak 2001 ***************************/
            /* Used to put the command "end pro" at the bottom of the file --> Comment out in Geopak 2000 and type manually */
            if (downstream xs station > 1000000) then
              {
                _s_text = ^End Pro^
                ascii write file = _s_lt_output_profilename
                format = ^%s\n^
                var = _s_text
                ascii close file = _s_lt_output_profilename
              }
             /*******************The section above can only be ran in Geopak 2001 *********************/
          }
      } /* End Left Outside*/
    
    else if (_s_side = ^Right^) and (median width > 1000) then 
      {
        /* The next line represents the marked point location that will be profiled */
        draw skip to x[_d_rt_mp] y[_d_rt_mp]
        mark _mp_wanted_point
        _d_elevation = _mp_wanted_point.elev
        _s_elevation = cvt_d_s2(_d_elevation)
        _s_sta=cvt_d_sta(station)
    
        if not _mp_open_rt then /* Used for first point only to create and open the ascii text file */
          {
            mark _mp_open_rt
            _d_point_number_rt = 1
            _s_point_number_rt = cvt_d_s0(_d_point_number_rt)
            _s_first_line = ^Sto Pro ^ + _s_rt_profile_name /* Name of the profile that would be read into cogo for left side */
            ascii open file = _s_rt_output_profilename
            ascii write file = _s_rt_output_profilename
            format = ^%s\n^
            var = _s_first_line
            _s_second_line = ^VPI ^ + _s_point_number_rt + ^ S ^ + _s_sta + ^ E ^ + _s_elevation
            ascii write file = _s_rt_output_profilename
            format = ^%s\n^
            var = _s_second_line
    
          }
        else
          {
            _d_point_number_rt = _d_point_number_rt + 1
            _s_point_number_rt = cvt_d_s0(_d_point_number_rt)
            _s_second_line = ^VPI ^ + _s_point_number_rt + ^ S ^ + _s_sta + ^ E ^ + _s_elevation
            ascii write file = _s_rt_output_profilename
            format = ^%s\n^
            var = _s_second_line
            /***************** This section can only be ran in Geopak 2001 ***************************/
            /* Used to put the command "end pro" at the bottom of the file --> Comment out in Geopak 2000 and type manually */
             if (downstream xs station > 1000000) then /* Used to create the end pro command */
              {
                _s_text = ^End Pro^
                ascii write file = _s_rt_output_profilename
                format = ^%s\n^
                var = _s_text
                ascii close file = _s_rt_output_profilename
              }
           /*******************The section above can only be ran in Geopak 2001 *********************/
          }
      } /* End Right Outside */
    
    else if (_s_side = ^Right^) and (median width < 1000) then 
      {
        /* The next line represents the marked point location that will be profiled */
        draw skip to x[_d_rt_median_mp] y[_d_rt_median_mp]
        mark _mp_wanted_point
        _d_elevation = _mp_wanted_point.elev
        _s_elevation = cvt_d_s2(_d_elevation)
        _s_sta=cvt_d_sta(station)
    
        if not _mp_open_median_rt then /* Used for first point only to create and open the ascii text file */
          {
            mark _mp_open_median_rt
            _d_point_number_rt_median = 1
            _s_point_number_rt_median = cvt_d_s0(_d_point_number_rt_median)
            _s_first_line = ^Sto Pro ^ + _s_rt_median_profile_name /* Name of the profile that would be read into cogo for left side */
            ascii open file = _s_rt_median_output_profilename
            ascii write file = _s_rt_median_output_profilename
            format = ^%s\n^
            var = _s_first_line
            _s_second_line = ^VPI ^ + _s_point_number_rt_median + ^ S ^ + _s_sta + ^ E ^ + _s_elevation
            ascii write file = _s_rt_median_output_profilename
            format = ^%s\n^
            var = _s_second_line
    
          }
        else
          {
            _d_point_number_rt_median = _d_point_number_rt_median + 1
            _s_point_number_rt_median = cvt_d_s0(_d_point_number_rt_median)
            _s_second_line = ^VPI ^ + _s_point_number_rt_median + ^ S ^ + _s_sta + ^ E ^ + _s_elevation
            ascii write file = _s_rt_median_output_profilename
            format = ^%s\n^
            var = _s_second_line
            /***************** This section can only be ran in Geopak 2001 ***************************/
            /* Used to put the command "end pro" at the bottom of the file --> Comment out in Geopak 2000 and type manually */
             if (downstream xs station > 1000000) then /* Used to create the end pro command */
              {
                _s_text = ^End Pro^
                ascii write file = _s_rt_median_output_profilename
                format = ^%s\n^
                var = _s_text
                ascii close file = _s_rt_median_output_profilename
              }
           /*******************The section above can only be ran in Geopak 2001 *********************/
          }
      } /* End Right Median */

    else if (_s_side = ^Left^) and (median width < 1000) then 
      {
        /* The next line represents the marked point location that will be profiled */
        draw skip to x[_d_lt_median_mp] y[_d_lt_median_mp]
        mark _mp_wanted_point
        _d_elevation = _mp_wanted_point.elev
        _s_elevation = cvt_d_s2(_d_elevation)
        _s_sta=cvt_d_sta(station)
    
        if not _mp_open_median_lt then /* Used for first point only to create and open the ascii text file */
          {
            mark _mp_open_median_lt
            _d_point_number_lt_median = 1
            _s_point_number_lt_median = cvt_d_s0(_d_point_number_lt_median)
            _s_first_line = ^Sto Pro ^ + _s_lt_median_profile_name /* Name of the profile that would be read into cogo for left side */
            ascii open file = _s_lt_median_output_profilename
            ascii write file = _s_lt_median_output_profilename
            format = ^%s\n^
            var = _s_first_line
            _s_second_line = ^VPI ^ + _s_point_number_lt_median + ^ S ^ + _s_sta + ^ E ^ + _s_elevation
            ascii write file = _s_lt_median_output_profilename
            format = ^%s\n^
            var = _s_second_line
    
          }
        else
          {
            _d_point_number_lt_median = _d_point_number_lt_median + 1
            _s_point_number_lt_median = cvt_d_s0(_d_point_number_lt_median)
            _s_second_line = ^VPI ^ + _s_point_number_lt_median + ^ S ^ + _s_sta + ^ E ^ + _s_elevation
            ascii write file = _s_lt_median_output_profilename
            format = ^%s\n^
            var = _s_second_line
            /***************** This section can only be ran in Geopak 2001 ***************************/
            /* Used to put the command "end pro" at the bottom of the file --> Comment out in Geopak 2000 and type manually */
             if (downstream xs station > 1000000) then /* Used to create the end pro command */
              {
                _s_text = ^End Pro^
                ascii write file = _s_lt_median_output_profilename
                format = ^%s\n^
                var = _s_text
                ascii close file = _s_lt_median_output_profilename
              }
           /*******************The section above can only be ran in Geopak 2001 *********************/
          }
      } /* End Left Median */


  } /* Ends Master Prompt */

