/* Retaining wall from dgn a slope off of a shape or at end of a shape */
/*----------------------------------------------------------------------------+
|                                                                             |
| FILENAME    ret01.e                                                         |
|                                                                             |
| AGENCY      TxDOT                                                           |
|                                                                             |
| SYSTEM      Criteria (TxDOT Design X-Section applications)                  |
|                                                                             |
| LANGUAGE    Ascii                                                           |
|                                                                             |
| DESCRIPTION This criteria file draws a retaining wall based on a defined    |
|             slope off of the shape or at the end of the shape and can also  |
|             tie to an adjoining roadway.  if an adjoining roadway is used,  |
|             it must be placed first. The retaining wall is drawn 0.3 meters |
|             below existing ground.                                          |
|                                                                             |
|                                                                             |
+-----------------------------------------------------------------------------+
|                                                                             |
|      TxDOT Information Systems Division   --   Engineering Development      |
|                                                                             |
|      This product was designed and created explicitly for the needs and     |
|      requirements of the Texas Department of Transportation.  This product  |
|      may be used, reproduced, and modified, provided that there is no       |
|      charge, and that this notice is retained in its entirety in any such   |
|      reproduction or modification.                                          |
|                                                                             |
+-----------------------------------------------------------------------------+
| HISTORY      Date:         Name:               Description:                 |
| created      May 10 1994    JF                 Authors                      |
| last update  June 18 1994   JF                                              |
|              July 27, 1998  cc                 modified for english         |
+-----------------------------------------------------------------------------+

+-----------------------------------------------------------------------------+
| Criteria Files Needed in Conjunction With                                   |
+-----------------------------------------------------------------------------+

      srf02.e 

+-----------------------------------------------------------------------------+
| Defined Variables Required                                                  |
+-----------------------------------------------------------------------------+

      "retwsl"          slope off of shape to top of ret wall ( % )

+-----------------------------------------------------------------------------+
| Intrinsic Variables Used                                                    |
+-----------------------------------------------------------------------------+

      existing ground

+-----------------------------------------------------------------------------+
| DGN Variables Required                                                      |
+-----------------------------------------------------------------------------+

      "retw"            retaining wall drawn in plan view file

+-----------------------------------------------------------------------------+
| Marked Points                                                               |
+-----------------------------------------------------------------------------+

      x6  y6     hinge point at edge of pavement (shape, shoulder, widening)
      x40 y40    top back of retaining wall
      x41 y41    top front of retaining wall
      x42 y42    face of retaining wall at existing ground

+-----------------------------------------------------------------------------+
| Required Points                                                             |
+-----------------------------------------------------------------------------+


+-----------------------------------------------------------------------------+
| Plot Parameters                                                             |
+----------------------------------------------------------------------------*/

   xcode = 1
   
    plot param

      lv = 16
      co = 56
      wt = 3

/*----------------------------------------------------------------------------+
| Define Statements                                                           |
+----------------------------------------------------------------------------*/

    x6 = orig x
    y6 = orig y 

  /* locate top of retaining wall */

   if pavement slope < 100 then
    draw skip to x6 y6 

   if "retwsl" < 0 and intersect dgn = "retw" then
    draw skip slope = "retwsl" to "retw"
    mark x40 y40
    draw text lv = 62 th = .25 tw = .25 char = 40

   /* draw riprap flume (ditch) between top of retaining wall and edge 
      of shape*/

    draw dx = -1.476 dy = -.738
    draw dx = -1 dy = 0
    draw to x6 y6
    
   /* check for retaining wall at edge of shape (x6 y6) */

    else if intersect dgn = "retw" then 
     mark x40 y40     
     draw text lv = 62 th = .25 tw = .25 char = 40

     else 
       draw skip dx = 0 dy = 0

 /*  place width of retaining wall and mark points for face of wall to 
     existing ground */

     

    if intersect dgn = "retw" then

   set plot param

      lv = 17
      co = 56
      wt = 3

     draw skip to x40 y40
     draw dx = 1 dy = 0
     mark x41 y41
     draw text lv = 62 th = .25 tw = .25 char = 41

     draw  dx = 0 dy = -1 to existing ground
     mark x42 y42
     draw text lv = 62 th = .25 tw = .25 char = 42

    set plot param
      lv = 18
      co = 56
      wt = 3

     draw dx = 0 dy = -1
     draw dx = -1 dy = 0
     draw to x40 y40
     draw skip to x6 y6

    else
      draw skip to x6 y6
    
