/* Station and Elevation Labeling */

/* ********************************************************************
File Name: xslabel.ex

Version:  2.29.00

Written August 1, 1997 by Eric Thomas

Revision History:
  September 7, 2000 by Eric Thomas
    - Modified the label locations to ensure that they will fall at the
      desired location when carried to the cross sections sheets.

  February 29, 2000 by Eric Thomas
    - forced the criteria to only place the label once in the event that the
      user included it for both the left and right side slope conditions.
    - Converted the labeling functions to a subroutine.

Description:
  http://www.dot.state.oh.us/prod/geopak/criteria/xslabel.pdf
**********************************************************************/

if (2 > 1) then
{

call subroutine current_side

if (_d_side = 0) then
  {
  mark x900 y900
  draw skip to xpgl ypgl
  mark x901 y901

  /******************************************/
  /* find existing ground at the centerline */
  /******************************************/
  if (el diff < 0) then
    {
    draw skip dx=0 dy=1 to exist ground
    }  
  else
    {
    draw skip dx=0 dy=-1 to exist ground
    }
  mark x902 y902

  /*******************/
  /* draw the labels */
  /*******************/

  /* case where the pgl is above existing ground */
  if (y901 > y902) then
    {
    draw skip to x902 y902
    _d_tmp = y902
    _d_tmp = _d_tmp / 5
    _d_tmp = int(_d_tmp)
    _d_tmp = _d_tmp * 5
    _d_tmp = y902 - _d_tmp
    draw skip dx = 0 dy = -(_d_tmp + 7.5)
    mark x903 y903
    call subroutine place_5xslabel
    
    draw skip to x902 y902
    _d_tmp = y902
    _d_tmp = _d_tmp / 10
    _d_tmp = int(_d_tmp)
    _d_tmp = _d_tmp * 10
    _d_tmp = y902 - _d_tmp
    draw skip dx = 0 dy = -(_d_tmp + 5)
    mark x903 y903
    call subroutine place_10xslabel
    }
  
  /* case where the pgl is equal to or below existing ground */
  else
    {
    draw skip to x901 y901
    _d_tmp = y901
    _d_tmp = _d_tmp / 5
    _d_tmp = int(_d_tmp)
    _d_tmp = _d_tmp * 5
    _d_tmp = y901 - _d_tmp
    draw skip dx = 0 dy = -(_d_tmp + 7.5)
    mark x903 y903
    call subroutine place_5xslabel
    
    draw skip to x901 y901
    _d_tmp = y901
    _d_tmp = _d_tmp / 10
    _d_tmp = int(_d_tmp)
    _d_tmp = _d_tmp * 10
    _d_tmp = y901 - _d_tmp
    draw skip dx = 0 dy = -(_d_tmp + 5)
    mark x903 y903
    call subroutine place_10xslabel
    }
  
  /******************************************/
  /* return to the initial pointer location */
  /******************************************/
  draw skip to x900 y900
  }
}


subroutine place_5xslabel
  {
  /* draw the station text on level 4 for 1:5 */
  draw station text
    number of decimal places = 2
    offset = 0
    lv = 4
    co = 0
    wt = 2
    lc = 0
    ft = 83
    th = 0.94
    tw = 0.94
    just = cc

  /* draw the proposed elevation for 1:5 */
  draw skip to x903 y903
  draw skip dx = 0 dy = 1.56
  draw text value = (y901)
    number of decimal places = 2
    lv = 4
    co = 0
    wt = 1
    lc = 0
    ft = 83
    th = 0.78
    tw = 0.78
    just = cc

  /* draw the existing elevation for 1:5 */
  draw skip to x903 y903
  draw skip dx = 0 dy = -1.56
  draw text value = (y902)
    number of decimal places = 2
    lv = 4
    co = 0
    wt = 1
    lc = 0
    ft = 83
    th = 0.78
    tw = 0.78
    just = cc
}
end subroutine

subroutine place_10xslabel
  {
  /* draw the station text on level 5 for 1:10 */
  draw station text
    number of decimal places = 2
    offset = 0
    lv = 5
    co = 0
    wt = 2
    lc = 0
    ft = 83
    th = 1.88
    tw = 1.88
    just = cc

  /* draw the proposed elevation for 1:10 */
  draw skip to x903 y903
  draw skip dx = 0 dy = 2.5
  draw text value = (y901)
    number of decimal places = 2
    lv = 5
    co = 0
    wt = 1
    lc = 0
    ft = 83
    th = 1.56
    tw = 1.56
    just = cc

  /* draw the existing elevation for 1:10 */
  draw skip to x903 y903
  draw skip dx = 0 dy = -2.5
  draw text value = (y902)
    number of decimal places = 2
    lv = 5
    co = 0
    wt = 1
    lc = 0
    ft = 83
    th = 1.56
    tw = 1.56
    just = cc
}
end subroutine

