<?xml version="1.0" encoding="UTF-8"?>
<xsl:stylesheet version="1.1" xmlns:xsl="http://www.w3.org/1999/XSL/Transform" xmlns:fo="http://www.w3.org/1999/XSL/Format" xmlns:msxsl="urn:schemas-microsoft-com:xslt" xmlns:inr="http://mycompany.com/mynamespace">
    <xsl:include href="../format.xsl"/>
    <xsl:param name="xslRootDirectory" select="inr:xslRootDirectory"/>
    <!-- Plate Girder Elevations Report -->
    <xsl:template match="/">
        <xsl:variable name="gridOut" select="inr:SetGridOut(number(InRoads/@outputGridScaleFactor))"/>
        <html>
            <head>
                <link rel="stylesheet" type="text/css" href="{$xslRootDirectory}/_Themes/engineer/theme.css"/>
                <!-- Title displayed in browser Title Bar -->
                <title lang="en">Plate Girder Elevations Report</title>
            </head>
            <body>
                <xsl:choose>
                    <xsl:when test="$xslShowHelp = 'true'">
                        <xsl:call-template name="StyleSheetHelp"/>
                    </xsl:when>
                    <xsl:otherwise>
                        <xsl:for-each select="InRoads">
                            <center>
                                <!-- Report Title -->
                                <h2 lang="en">Plate Girder Elevations Report</h2>
                                <p lang="en">
                                    Report Created:&#xa0; <xsl:value-of select="inr:date()"/><br />
                                    Time:&#xa0; <xsl:value-of select="inr:time()"/>
                                </p>
                            </center>
                            <!-- Project Data -->
                            <xsl:for-each select="BridgeProject">
                                <table cellpadding="2" class="margin" width="90%">
                                    <tbody>
                                        <tr>
                                            <th align="right" lang="en">Project:&#xa0; </th>
                                            <td align="left" colspan="2"><xsl:value-of select="@name"/></td>
                                        </tr>
                                        <tr>
                                            <th align="right" lang="en">Description:&#xa0; </th>
                                            <td align="left" colspan="2"><xsl:value-of select="@description"/></td>
                                        </tr>
                                        <tr>
                                            <th align="right" lang="en">File Name:&#xa0; </th>
                                            <td align="left" colspan="2"><xsl:value-of select="@file"/></td>
                                        </tr>
                                        <tr>
                                            <th align="right" lang="en">Last Revised:&#xa0; </th>
                                            <td align="left" colspan="2"><xsl:value-of select="concat(@lastRevisedBy, '  ', @lastRevisedDate)"/></td>
                                        </tr>
                                        <tr>
                                            <th align="right" lang="en" style="font-size: 80%">Input Grid Factor:&#xa0; </th>
                                            <td align="left" style="font-size: 80%"><xsl:value-of select="../@inputGridScaleFactor" /></td>
                                            <td align="right" lang="en" style="font-size: 80%">
                                                <strong>Note:&#xa0; </strong>All units in this report are in
                                                <xsl:if test="//@linearUnits = 'Imperial'">feet</xsl:if>
                                                <xsl:if test="//@linearUnits = 'Metric'">meters</xsl:if>
                                                unless specified otherwise.
                                            </td>
                                        </tr>
                                    </tbody>
                                </table>
                                <hr/>
                                <!-- Plate Girder Elevation Data -->
                                <table class="margin" width="95%">
                                    <colgroup>
                                        <col width="6%"/>
                                        <col width="14%"/>
                                        <col width="8%"/>
                                        <col width="8%"/>
                                        <col width="8%"/>
                                        <col width="8%"/>
                                        <col width="8%"/>
                                        <col width="8%"/>
                                        <col width="8%"/>
                                        <col width="8%"/>
                                        <col width="8%"/>
                                        <col width="8%"/>
                                    </colgroup>
                                    <xsl:for-each select="BridgeCenterLine">
                                        <thead style="display:table-header-group">
                                            <tr>
                                                <th class="underline" lang="en" valign="bottom">Point</th>
                                                <th class="underline" lang="en" valign="bottom">Relative Station<br/>(Distance Along)</th>
                                                <th class="underline" lang="en" valign="bottom">Top of Slab</th>
                                                <th class="underline" lang="en" valign="bottom">Top of Web</th>
                                                <th class="underline" lang="en" valign="bottom">Bottom of Girder</th>
                                                <th class="underline" lang="en" valign="bottom">Slab Thickness</th>
                                                <th class="underline" lang="en" valign="bottom">Haunch Thickness</th>
                                                <th class="underline" lang="en" valign="bottom">Top Cover Thickness</th>
                                                <th class="underline" lang="en" valign="bottom">Top Flange Thickness</th>
                                                <th class="underline" lang="en" valign="bottom">Web Depth</th>
                                                <th class="underline" lang="en" valign="bottom">Bottom Flange Thickness</th>
                                                <th class="underline" lang="en" valign="bottom">Bottom Cover Thickness</th>
                                            </tr>
                                        </thead>
                                        <tbody>
                                            <xsl:for-each select="Girders/Girder/PlateGirder">
                                                <tr>
                                                    <th align="left" colspan="12">Girder <xsl:value-of select="position()"/> (<xsl:value-of select="../@name"/>)</th>
                                                </tr>
                                                <xsl:for-each select="GirderElevations/GirderElevation">
                                                    <tr>
                                                        <td align="center"><xsl:value-of select="position()"/></td>
                                                        <td align="right" class="leftrightpad">
                                                            <xsl:value-of select="inr:distanceFormat(number(@distanceAlong), $xslDistancePrecision)"/>
                                                        </td>
                                                        <td align="right">
                                                            <xsl:value-of select="inr:elevationFormat(number(@topOfSlabElevation), $xslElevationPrecision)"/>
                                                        </td>
                                                        <td align="right">
                                                            <xsl:value-of select="inr:elevationFormat(number(@topOfWebElevation), $xslElevationPrecision)"/>
                                                        </td>
                                                        <td align="right">
                                                            <xsl:value-of select="inr:elevationFormat(number(@bottomOfGirderElevation), $xslElevationPrecision)"/>
                                                        </td>
                                                        <td align="right">
                                                            <xsl:value-of select="inr:elevationFormat(number(@slabThickness), $xslElevationPrecision)"/>
                                                        </td>
                                                        <td align="right">
                                                            <xsl:value-of select="inr:elevationFormat(number(@haunchThickness), $xslElevationPrecision)"/>
                                                        </td>
                                                        <td align="right">
                                                            <xsl:value-of select="inr:elevationFormat(number(@topCoverThickness), $xslElevationPrecision)"/>
                                                        </td>
                                                        <td align="right">
                                                            <xsl:value-of select="inr:elevationFormat(number(@topFlangeThickness), $xslElevationPrecision)"/>
                                                        </td>
                                                        <td align="right">
                                                            <xsl:value-of select="inr:elevationFormat(number(@webDepth), $xslElevationPrecision)"/>
                                                        </td>
                                                        <td align="right">
                                                            <xsl:value-of select="inr:elevationFormat(number(@bottomFlangeThickness), $xslElevationPrecision)"/>
                                                        </td>
                                                        <td align="right">
                                                            <xsl:value-of select="inr:elevationFormat(number(@bottomCoverThickness), $xslElevationPrecision)"/>
                                                        </td>
                                                    </tr>
                                                </xsl:for-each>
                                                <tr><td>&#xa0;</td></tr>
                                            </xsl:for-each>
                                        </tbody>
                                    </xsl:for-each>
                                </table>
                            </xsl:for-each>
                        </xsl:for-each>
                    </xsl:otherwise>
                </xsl:choose>
            </body>
        </html>
    </xsl:template>
    <xsl:template name="StyleSheetHelp">
        <div class="section1">
            <h4 lang="en">Notes</h4>
            <p class="normal1" lang="en">
                Your active alignment must be a bridge alignment and you must have created slab fascia, 
                abutments/piers, bearing lines, girders and verticals for the bridge.
            </p>
            <p class="normal1" lang="en">
                You must specify the <em>Bridge Surface</em> on the <em>Main</em> tab of the <em>Bridge 
                &gt; Bridge Reports</em> command.&#xa0; You must also toggle on the <em>Include Girder 
                Elevations</em> option on the <em>Girder Elevations</em> tab to get results from this 
                report.
            </p>
            <p class="normal1" lang="en">This report is only suitable for Plate Girders.</p>
            <p class="small" lang="en">
                <em>&#xa9; 2006 Bentley Systems, Inc</em>
            </p>
        </div>
    </xsl:template>
</xsl:stylesheet>
