<?xml version="1.0" encoding="UTF-8"?>
<xsl:stylesheet version="1.1" xmlns:xsl="http://www.w3.org/1999/XSL/Transform" xmlns:fo="http://www.w3.org/1999/XSL/Format" xmlns:msxsl="urn:schemas-microsoft-com:xslt" xmlns:inr="http://mycompany.com/mynamespace">
    <xsl:include href="../format.xsl"/>

    <xsl:variable name="linearUnit">
        <xsl:choose>
            <xsl:when test="//@linearUnits = 'Imperial'">ft</xsl:when>
            <xsl:otherwise>m</xsl:otherwise>
        </xsl:choose>
    </xsl:variable>
    <xsl:variable name="areaUnit1">
        <xsl:choose>
            <xsl:when test="//@linearUnits = 'Imperial'">sq ft</xsl:when>
            <xsl:otherwise>sq m</xsl:otherwise>
        </xsl:choose>
    </xsl:variable>
    <xsl:variable name="areaUnit2">
        <xsl:choose>
            <xsl:when test="//@linearUnits = 'Imperial'">ac</xsl:when>
            <xsl:otherwise>hec</xsl:otherwise>
        </xsl:choose>
    </xsl:variable>

    <xsl:output method="text" media-type="text/plain" encoding="iso-8859-1"/>
    <xsl:template match="/">
        <xsl:variable name="gridOut" select="inr:SetGridOut(number(InRoads/@outputGridScaleFactor))"/>
        <xsl:choose>
            <xsl:when test="$xslShowHelp = 'true'">
                <xsl:call-template name="StyleSheetHelp"/>
            </xsl:when>
            <xsl:otherwise>
                <xsl:for-each select="InRoads">
                    <xsl:text/>

                    <xsl:text>                        Traverse Report&#xd;</xsl:text>
                    <xsl:text>            Report Created:  </xsl:text>
                    <xsl:value-of select="inr:date()"/>
                    <xsl:text> Time:  </xsl:text>
                    <xsl:value-of select="inr:time()"/>
                    <xsl:text>&#xd;&#xd;</xsl:text>

                    <xsl:for-each select="GeometryProject">
                        <xsl:text>          Project:  </xsl:text><xsl:value-of select="@name"/>
                        <xsl:text>&#xd;      Description:  </xsl:text><xsl:value-of select="@description"/>
                        <xsl:text>&#xd;        File Name:  </xsl:text><xsl:value-of select="@file"/>
                        <xsl:text>&#xd;     Last Revised:  </xsl:text>
                        <xsl:value-of select="@lastRevisedBy"/><xsl:text> </xsl:text>
                        <xsl:value-of select="@lastRevisedDate"/>
                        <xsl:text>  Note:  All units in this report are in</xsl:text>
                        <xsl:choose>
                            <xsl:when test="//@linearUnits = 'Metric'"> meters </xsl:when>
                            <xsl:otherwise> feet </xsl:otherwise>
                        </xsl:choose>
                        <xsl:text>unless specified otherwise.&#xd;</xsl:text>

                        <xsl:for-each select="HorizontalAlignment">
                            <xsl:text>&#xd;       Alignment Name:  </xsl:text>
                            <xsl:value-of select="@name"/>
                            <xsl:text>&#xd;Alignment Description:  </xsl:text>
                            <xsl:value-of select="@description"/>
                            <xsl:text>&#xd;&#xd;</xsl:text>
                            <xsl:text>                                           - - C o o r d i n a t e s - -&#xd;</xsl:text>
                            <xsl:text>Point        Bearing          Distance     Northing           Easting&#xd;</xsl:text>
                            <xsl:text>----------   -------------    --------     -----------        -----------&#xd;</xsl:text>
                            <xsl:apply-templates/>
                            <xsl:if test="@northingClosingError">
                                <xsl:text>   Northing Error:  </xsl:text>
                                <xsl:value-of select="inr:columnDoubleFormat(number(@northingClosingError), $xslDistancePrecision, 12)"/>
                                <xsl:text> </xsl:text>
                                <xsl:value-of select="$linearUnit"/>
                                <xsl:text>        Easting Error:  </xsl:text>
                                <xsl:value-of select="inr:columnDoubleFormat(number(@eastingClosingError), $xslDistancePrecision, 12)"/>
                                <xsl:text> </xsl:text>
                                <xsl:value-of select="$linearUnit"/>
                                <xsl:text>&#xd;Closing Direction:  </xsl:text>
                                <xsl:value-of select="inr:columnFormat(string(inr:directionFormat(number(@closingDirection), $xslDirectionFormat, $xslDirectionPrecision, $xslDirectionModeFormat, $xslAngularMethod)), 15)"/>
                                <xsl:text>     Closing Distance:  </xsl:text>
                                <xsl:value-of select="inr:columnDoubleFormat(number(@closingDistance), $xslDistancePrecision, 12)"/>
                                <xsl:text> </xsl:text>
                                <xsl:value-of select="$linearUnit"/>
                                <xsl:text>&#xd;        Precision:  </xsl:text>
                                <xsl:value-of select="inr:columnDoubleFormat(number(@closingPrecision), $xslDistancePrecision, 12)"/>
                            </xsl:if>
                            <xsl:text>&#xd;</xsl:text>
                        </xsl:for-each>
                    </xsl:for-each>
                </xsl:for-each>
            </xsl:otherwise>
        </xsl:choose>
    </xsl:template>

    <xsl:template match="HorizontalLine">
        <xsl:value-of select="inr:columnFormat(inr:pointType(string(Start/@pointType)), 3)"/>
        <xsl:text> (</xsl:text>
        <xsl:choose>
            <xsl:when test="Start/@name">
                <xsl:value-of select="inr:columnFormat(string(Start/@name), 4)"/>
            </xsl:when>
            <xsl:otherwise><xsl:value-of select="concat('  ', '  ')"/></xsl:otherwise>
        </xsl:choose>
        <xsl:text>)</xsl:text>
        <xsl:value-of select="inr:columnDoubleFormat(number(Start/@northing), $xslNorthingPrecision, 44)"/>
        <xsl:value-of select="inr:columnDoubleFormat(number(Start/@easting), $xslEastingPrecision, 19)"/>
        <xsl:text>&#xd;</xsl:text>
        <xsl:value-of select="inr:columnFormat(string(inr:directionFormat(number(@direction), $xslDirectionFormat, $xslDirectionPrecision, $xslDirectionModeFormat, $xslAngularMethod)), 26)"/>
        <xsl:value-of select="inr:columnDoubleFormat(number(@length), $xslDistancePrecision, 11)"/>
        <xsl:text>&#xd;&#xd;</xsl:text>
        <xsl:if test="position() = last()">
            <xsl:value-of select="inr:columnFormat(inr:pointType(string(End/@pointType)), 3)"/>
            <xsl:text> (</xsl:text>
            <xsl:choose>
                <xsl:when test="End/@name">
                    <xsl:value-of select="inr:columnFormat(string(End/@name), 4)"/>
                </xsl:when>
                <xsl:otherwise><xsl:value-of select="concat('  ', '  ')"/></xsl:otherwise>
            </xsl:choose>
            <xsl:text>)</xsl:text>
            <xsl:value-of select="inr:columnDoubleFormat(number(End/@northing), $xslNorthingPrecision, 44)"/>
            <xsl:value-of select="inr:columnDoubleFormat(number(End/@easting), $xslEastingPrecision, 19)"/>
            <xsl:text>&#xd;&#xd;</xsl:text>
        </xsl:if>
    </xsl:template>

    <xsl:template match="HorizontalCircle">
        <xsl:value-of select="inr:columnFormat(inr:pointType(string(Start/@pointType)), 3)"/>
        <xsl:text> (</xsl:text>
        <xsl:choose>
            <xsl:when test="Start/@name">
                <xsl:value-of select="inr:columnFormat(string(Start/@name), 4)"/>
            </xsl:when>
            <xsl:otherwise><xsl:value-of select="concat('  ', '  ')"/></xsl:otherwise>
        </xsl:choose>
        <xsl:text>)</xsl:text>
        <xsl:value-of select="inr:columnDoubleFormat(number(Start/@northing), $xslNorthingPrecision, 44)"/>
        <xsl:value-of select="inr:columnDoubleFormat(number(Start/@easting), $xslEastingPrecision, 19)"/>
        <xsl:text>&#xd;&#xd;      Tangent Bearing in:</xsl:text>
        <xsl:value-of select="inr:columnFormat(string(inr:directionFormat(number(@tangentialDirectionStart), $xslDirectionFormat, $xslDirectionPrecision, $xslDirectionModeFormat, $xslAngularMethod)), 15)"/>
        <xsl:text>   Radial Bearing:</xsl:text>
        <xsl:value-of select="inr:columnFormat(string(inr:directionFormat(number(@radialDirectionStart), $xslDirectionFormat, $xslDirectionPrecision, $xslDirectionModeFormat, $xslAngularMethod)), 20)"/>
        <xsl:text>&#xd;</xsl:text>
        <xsl:value-of select="inr:columnFormat(inr:pointType(string(Center/@pointType)), 3)"/>
        <xsl:text> (</xsl:text>
        <xsl:choose>
            <xsl:when test="Center/@name">
                <xsl:value-of select="inr:columnFormat(string(Center/@name), 4)"/>
            </xsl:when>
            <xsl:otherwise><xsl:value-of select="concat('  ', '  ')"/></xsl:otherwise>
        </xsl:choose>
        <xsl:text>)</xsl:text>
        <xsl:value-of select="inr:columnDoubleFormat(number(Center/@northing), $xslNorthingPrecision, 44)"/>
        <xsl:value-of select="inr:columnDoubleFormat(number(Center/@easting), $xslEastingPrecision, 19)"/>
        <xsl:text>&#xd; Radius:</xsl:text>
        <xsl:value-of select="inr:columnDoubleFormat(number(@radius), $xslDistancePrecision, 9)"/>
        <xsl:text>  Delta:</xsl:text>
        <xsl:value-of select="inr:columnFormat(string(inr:angularFormat(number(@delta), $xslAngularFormat, $xslAngularPrecision, $xslAngularMethod)), 10)"/>
        <xsl:choose>
            <xsl:when test="@rotationDirection = 'ccw'"><xsl:text>  Left</xsl:text></xsl:when>
            <xsl:otherwise><xsl:text> Right</xsl:text></xsl:otherwise>
        </xsl:choose>
        <xsl:text>  Length:</xsl:text>
        <xsl:value-of select="inr:columnDoubleFormat(number(@length), $xslDistancePrecision, 8)"/>
        <xsl:text>&#xd;Tangent:</xsl:text>
        <xsl:value-of select="inr:columnDoubleFormat(number(@tangentLength), $xslDistancePrecision, 9)"/>
        <xsl:text>  Chord:</xsl:text>
        <xsl:value-of select="inr:columnDoubleFormat(number(@chord), $xslDistancePrecision, 8)"/>
        <xsl:text>&#xd;       Radial Bearing:</xsl:text>
        <xsl:value-of select="inr:columnFormat(string(inr:directionFormat(number(@radialDirectionEnd), $xslDirectionFormat, $xslDirectionPrecision, $xslDirectionModeFormat, $xslAngularMethod)), 18)"/>
        <xsl:text>   Tangent Bearing out:</xsl:text>
        <xsl:value-of select="inr:columnFormat(string(inr:directionFormat(number(@tangentialDirectionEnd), $xslDirectionFormat, $xslDirectionPrecision, $xslDirectionModeFormat, $xslAngularMethod)), 15)"/>
        <xsl:text>&#xd;&#xd;</xsl:text>
        <xsl:if test="position() = last()">
            <xsl:value-of select="inr:columnFormat(inr:pointType(string(End/@pointType)), 3)"/>
            <xsl:text> (</xsl:text>
            <xsl:choose>
                <xsl:when test="End/@name">
                    <xsl:value-of select="inr:columnFormat(string(End/@name), 4)"/>
                </xsl:when>
                <xsl:otherwise><xsl:value-of select="concat('  ', '  ')"/></xsl:otherwise>
            </xsl:choose>
            <xsl:text>)</xsl:text>
            <xsl:value-of select="inr:columnDoubleFormat(number(End/@northing), $xslNorthingPrecision, 44)"/>
            <xsl:value-of select="inr:columnDoubleFormat(number(End/@easting), $xslEastingPrecision, 19)"/>
            <xsl:text>&#xd;&#xd;</xsl:text>
        </xsl:if>
    </xsl:template>

    <xsl:template match="HorizontalSpiral">
        <xsl:value-of select="inr:columnFormat(inr:pointType(string(Start/@pointType)), 3)"/>
        <xsl:text> (</xsl:text>
        <xsl:choose>
            <xsl:when test="Start/@name">
                <xsl:value-of select="inr:columnFormat(string(Start/@name), 4)"/>
            </xsl:when>
            <xsl:otherwise><xsl:value-of select="concat('  ', '  ')"/></xsl:otherwise>
        </xsl:choose>
        <xsl:text>)</xsl:text>
        <xsl:value-of select="inr:columnDoubleFormat(number(Start/@northing), $xslNorthingPrecision, 44)"/>
        <xsl:value-of select="inr:columnDoubleFormat(number(Start/@easting), $xslEastingPrecision, 19)"/>
        <xsl:text>&#xd;&#xd;</xsl:text>
        <xsl:if test="position() = last()">
            <xsl:value-of select="inr:columnFormat(inr:pointType(string(End/@pointType)), 3)"/>
            <xsl:text> (</xsl:text>
            <xsl:choose>
                <xsl:when test="End/@name">
                    <xsl:value-of select="inr:columnFormat(string(End/@name), 4)"/>
                </xsl:when>
                <xsl:otherwise><xsl:value-of select="concat('  ', '  ')"/></xsl:otherwise>
            </xsl:choose>
            <xsl:text>)</xsl:text>
            <xsl:value-of select="inr:columnDoubleFormat(number(End/@northing), $xslNorthingPrecision, 44)"/>
            <xsl:value-of select="inr:columnDoubleFormat(number(End/@easting), $xslEastingPrecision, 19)"/>
            <xsl:text>&#xd;&#xd;</xsl:text>
        </xsl:if>
    </xsl:template>

    <xsl:template name="StyleSheetHelp">
        <xsl:text>Notes&#xd;&#xd;</xsl:text>
         <xsl:text>You must select at least one Civil horizontal element&#xd;</xsl:text>
        <xsl:text>    to get results from this report.&#xd;&#xd;</xsl:text>
        <xsl:text>Copyright 2012 Bentley Systems, Inc&#xd;</xsl:text>
    </xsl:template>

    <msxsl:script implements-prefix="inr" language="JScript">
        <![CDATA[
            // This function sets the format of angular information.
            // n - value from xml
            // format - (1 - "ddd^mm'ss.s", 2 - "ddd.ddd")
            // formatMethod - (1 - Degrees, 2 - Grads, 3 - Radians, 4 - Mils)
            // precision - the number of digits after the decimal point
            function angularFormat(n, format, precision, formatMethod)
            {
                // Checking to see if the number is valid
                if (!isNaN(n))
                {
                    // converts from Radians to Degrees and formats the
                    // value
                    if (formatMethod == 1)
                    {
                        var decdeg = (n * 180) / Math.PI;
                        // format 1 - this converts the number to
                        // "ddd^mm'ss.s"
                        if (format == 1)
                        {
                            // takes only the whole number (ddd)
                            deg = Math.floor(Math.abs(decdeg));
                            
                            // multiplies the decimal portion time 60 to get the minutes.
                            var decmin = (Math.abs(decdeg) - deg) * 60;
                            
                            // takes only the whole part of that number (mm')
                            var min = Math.floor(decmin);
                            
                            // multiplies the decimal portion time 60 to get the seconds.
                            var decsec = (decmin - min) * 60;
                            
                            // this calls the function that gives the number the correct precision
                            var str = formatNumber(decsec, precision);
                            
                            if (  str.substring(0,2) == "60" )
                            {
                                decsec = 0;
                                str = formatNumber(decsec, precision);
                                min = min+1;
                                if ( min == 60 )
                                {
                                    min = 0;
                                    deg = deg + 1;
                                }
                            }
                                
                            if ( min < 10 )
                            {
                                min = "0" + min;
                            }
                            var sec = str;
                            if ( sec < 10 )
                            {
                                sec = "0" + sec;
                            }
                            
                            var msg;
                            if( decdeg >= 0 || decdeg <= -1 )
                            {
                                if( decdeg < 0 )
                                    msg =  "-" + deg + "^" + min + "'" + sec + '"';
                                else
                                    msg =  deg + "^" + min + "'" + sec + '"';
                            }
                            else
                                msg =  "-0" + "^" + min + "'" + sec + '"';
                                
                            return msg;
                        }
                        // format 2 - "ddd.ddd"
                        if (format == 2)
                        {
                            // this calls the function that gives the
                            // number the correct precision
                            var str = formatNumber(decdeg, precision);
                            str = str + "^";
                            return str;
                        }
                    }
                    //converts Radians to Grads
                    if (formatMethod == 2)
                    {
                        var radtograd = (n * 200) / Math.PI;
                        var grad = formatNumber(radtograd, precision);
                        if (useAngSuffix == true)
                        {
                            grad = grad + "g";
                        }
                        return grad;
                    }
                    // value in Radians needs to be formated
                    if (formatMethod == 3)
                    {
                        // this calls the function that gives the number
                        // the correct precision
                        var radian = formatNumber(n, precision);
                        if (useAngSuffix == true)
                        {
                            radian = radian + "r";
                        }
                        return radian;
                    }
                    //converts Radians to Mils
                    if (formatMethod == 4 )
                    {
                         var radtomils = n * (6400.0 / (2.0 * Math.PI));
                         var mils = formatNumber( radtomils, precision );
                         return mils;
                    }
                }
                return 985;
             }
        ]]>
    </msxsl:script>
</xsl:stylesheet>
