<?xml version="1.0" encoding="UTF-8"?>
<xsl:stylesheet version="1.1" xmlns:xsl="http://www.w3.org/1999/XSL/Transform" xmlns:fo="http://www.w3.org/1999/XSL/Format" xmlns:msxsl="urn:schemas-microsoft-com:xslt" xmlns:inr="http://mycompany.com/mynamespace">
    <xsl:include href="../format.xsl"/>
    <xsl:param name="xslRootDirectory" select="inr:xslRootDirectory"/>
    <!-- Cross Section to AGTEK EndArea Format -->
    <xsl:output method="text" media-type="text/plain" encoding="iso-8859-1"/>
    <xsl:template match="/">
        <xsl:choose>
            <xsl:when test="$xslShowHelp = 'true'">
                <xsl:call-template name="StyleSheetHelp"/>
            </xsl:when>
            <xsl:otherwise>
                <xsl:for-each select="InRoads">
                    <xsl:text/>
                    <xsl:text>E</xsl:text>
                    <xsl:choose>
                        <xsl:when test="//@units = 'Metric'"><xsl:text>M</xsl:text></xsl:when>
                        <xsl:otherwise><xsl:text>I</xsl:text></xsl:otherwise>
                    </xsl:choose>
                    <xsl:text>X000 7.035    KC31&#xd;</xsl:text>
                    <xsl:for-each select="CrossSectionSet/CrossSectionStations/CrossSectionStation">
                        <xsl:for-each select="CrossSectionSurfaces/CrossSectionSurface[@type = '0']">
                            <xsl:text>  -1</xsl:text>
                            <xsl:value-of select="inr:columnDoubleFormat(number(../../Station/@internalStation), $xslStationPrecision, 10)"/>
                            <xsl:value-of select="inr:columnDoubleFormat(number(../../Station/@internalStation), $xslStationPrecision, 10)"/>
                            <xsl:value-of select="inr:columnDoubleFormat(number(../../@easting), $xslEastingPrecision, 17)"/>
                            <xsl:value-of select="inr:columnDoubleFormat(number(../../@northing), $xslNorthingPrecision, 17)"/>
                            <xsl:text>&#xd;</xsl:text>
                            <xsl:for-each select="CrossSectionPoints/CrossSectionPoint">
                                <xsl:choose>
                                    <xsl:when test="@offset &lt; 0">
                                        <xsl:text>L1</xsl:text>
                                        <xsl:value-of select="inr:columnDoubleFormat(number(-1 * @offset), $xslDistancePrecision, 12)"/>
                                    </xsl:when>
                                    <xsl:otherwise>
                                        <xsl:text>R1</xsl:text>
                                        <xsl:value-of select="inr:columnDoubleFormat(number(@offset), $xslDistancePrecision, 12)"/>
                                    </xsl:otherwise>
                                </xsl:choose>
                                <xsl:value-of select="inr:columnDoubleFormat(number(@elevation), $xslElevationPrecision, 12)"/>
                                <xsl:text>&#xd;</xsl:text>
                            </xsl:for-each>
                        </xsl:for-each>
                        <xsl:for-each select="CrossSectionBottomOfDesign">
                            <xsl:text>03&#xd;</xsl:text>
                            <xsl:for-each select="CrossSectionPoints/CrossSectionPoint">
                                <xsl:choose>
                                    <xsl:when test="@offset &lt; 0">
                                        <xsl:text>NL</xsl:text>
                                        <xsl:value-of select="inr:columnDoubleFormat(number(-1 * @offset), $xslDistancePrecision, 12)"/>
                                    </xsl:when>
                                    <xsl:otherwise>
                                        <xsl:text>NR</xsl:text>
                                        <xsl:value-of select="inr:columnDoubleFormat(number(@offset), $xslDistancePrecision, 12)"/>
                                    </xsl:otherwise>
                                </xsl:choose>
                                <xsl:value-of select="inr:columnDoubleFormat(number(@elevation), $xslElevationPrecision, 12)"/>
                                <xsl:text>&#xd;</xsl:text>
                            </xsl:for-each>
                        </xsl:for-each>
                        <xsl:text>98&#xd;</xsl:text>
                    </xsl:for-each>
                    <xsl:text>-999&#xd;</xsl:text>
                </xsl:for-each>
            </xsl:otherwise>
        </xsl:choose>
    </xsl:template>
    <xsl:template name="StyleSheetHelp">
        <xsl:text>Notes&#xd;&#xd;</xsl:text>
        <xsl:text>    You must have created cross sections along your&#xd;</xsl:text>
        <xsl:text>    alignment and the cross section set must have the&#xd;</xsl:text>
        <xsl:text>    surfaces and features upon which you wish to report&#xd;</xsl:text>
        <xsl:text>    displayed.&#xd;&#xd;</xsl:text>
        <xsl:text>    You can create the XML data file from the Evaluation &gt;&#xd;</xsl:text>
        <xsl:text>    Cross Section &gt; Cross Section Report command or from&#xd;</xsl:text>
        <xsl:text>    the End-Area Volumes leaf of the Evaluation &gt; Cross&#xd;</xsl:text>
        <xsl:text>    Section &gt; Cross Sections command by toggling on&#xd;</xsl:text>
        <xsl:text>    the Create XML Report option on the General leaf.&#xd;&#xd;</xsl:text>
        <xsl:text>Copyright 2006 Bentley Systems, Inc&#xd;</xsl:text>
    </xsl:template>
</xsl:stylesheet>
