<?xml version="1.0" encoding="UTF-8"?>
<xsl:stylesheet version="1.1" xmlns:xsl="http://www.w3.org/1999/XSL/Transform" xmlns:fo="http://www.w3.org/1999/XSL/Format" xmlns:msxsl="urn:schemas-microsoft-com:xslt" xmlns:inr="http://mycompany.com/mynamespace">
    <xsl:include href="../format.xsl"/>
    <xsl:variable name="pi" select="inr:setPI()"/>
    <!-- Georgia DOT 20-Scale Parcel Report -->
    <xsl:output method="text" media-type="text/plain" encoding="iso-8859-1"/>
    <xsl:template match="/">
        <xsl:variable name="gridOut" select="inr:SetGridOut(number(InRoads/@outputGridScaleFactor))"/>
        <xsl:choose>
            <xsl:when test="$xslShowHelp = 'true'">
                <xsl:call-template name="StyleSheetHelp"/>
            </xsl:when>
            <xsl:otherwise>
                <xsl:for-each select="InRoads/GeometryProject">
                    <xsl:text/>
                    <xsl:text>.LOCK GG ON&#xd;</xsl:text>
                    <xsl:text>.TH=15.0&#xd;</xsl:text>
                    <xsl:text>.TW=10.0&#xd;</xsl:text>
                    <xsl:text>.LS=5.0&#xd;</xsl:text>
                    <xsl:text>.FT=24&#xd;</xsl:text>
                    <xsl:text>.WT=1&#xd;</xsl:text>
                    <xsl:text>.CO=2&#xd;</xsl:text>
                    <xsl:text>.ACTIVE TXJ LT&#xd;</xsl:text>
                    <xsl:text>.ACTIVE TNJ LT&#xd;</xsl:text>
                    <xsl:text>.NEWGG&#xd;&#xd;</xsl:text>
                    <xsl:for-each select="HorizontalAlignment[@style = 'REQD' or @style = 'PESMT' or @style = 'DWESMT' or @style = 'TESMT']">
                        <xsl:text>**************************************************************&#xd;</xsl:text>
                        <xsl:value-of select="inr:columnFormat(string(@description), 11)"/>
                        <xsl:choose>
                            <xsl:when test="@style = 'REQD'">
                                <xsl:text>     REQ'D  R/W   </xsl:text>
                            </xsl:when>
                            <xsl:when test="@style = 'PESMT'">
                                <xsl:text>     REQ'D PERM. EASM'T.   </xsl:text>
                            </xsl:when>
                            <xsl:when test="@style = 'DWESMT'">
                                <xsl:text>     REQ'D DRWY. EASM'T.   </xsl:text>
                            </xsl:when>
                            <xsl:when test="@style = 'TESMT'">
                                <xsl:text>     REQ'D TEMP. EASM'T.   </xsl:text>
                            </xsl:when>
                            <xsl:otherwise/>
                        </xsl:choose>
                        <xsl:value-of select="@name"/>
                        <xsl:text>&#xd;**************************************************************&#xd;</xsl:text>
                        <xsl:text>  PNT       OFFSET/        STATION/         ALIGNMENT&#xd;</xsl:text>
                        <xsl:if test="@style = 'REQD' or @style = 'PESMT'">
                            <xsl:text>              DIST         BEARING&#xd;</xsl:text>
                        </xsl:if>
                        <xsl:text>-------------------------------------------------------------&#xd;</xsl:text>
                        <xsl:if test="@style = 'REQD' or @style = 'PESMT'">
                            <xsl:apply-templates mode="ReqdRWEase"/>
                        </xsl:if>
                        <xsl:if test="@style = 'DWESMT' or @style = 'TESMT'">
                            <xsl:apply-templates mode="ReqdDWTemp"/>
                        </xsl:if>
                        <xsl:choose>
                            <xsl:when test="@style = 'REQD'">
                                <xsl:text>  REQD R/W  =  </xsl:text>
                            </xsl:when>
                            <xsl:when test="@style = 'PESMT'">
                                <xsl:text>REQD EASMT  =  </xsl:text>
                            </xsl:when>
                            <xsl:when test="@style = 'TESMT'">
                                <xsl:text>  REQD EASMT AREA =  </xsl:text>
                            </xsl:when>
                            <xsl:otherwise/>
                        </xsl:choose>
                        <xsl:if test="@style = 'REQD' or @style = 'PESMT' or @style = 'TESMT'">
                            <xsl:value-of select="inr:areaFormat(number(@area), 3)"/>
                            <xsl:choose>
                                <xsl:when test="//@linearUnits = 'Imperial'"><xsl:text>   SF&#xd;</xsl:text></xsl:when>
                                <xsl:otherwise><xsl:text>   M2&#xd;</xsl:text></xsl:otherwise>
                            </xsl:choose>
                        </xsl:if>
                        <xsl:choose>
                            <xsl:when test="@style = 'REQD'">
                                <xsl:text>  REQD R/W  =  </xsl:text>
                            </xsl:when>
                            <xsl:when test="@style = 'PESMT'">
                                <xsl:text>REQD EASMT  =  </xsl:text>
                            </xsl:when>
                            <xsl:otherwise/>
                        </xsl:choose>
                        <xsl:if test="@style = 'REQD' or @style = 'PESMT'">
                            <xsl:choose>
                                <xsl:when test="//@linearUnits = 'Imperial'">
                                    <xsl:value-of select="inr:acreFormat(number(@area div 43560), 3)"/>
                                    <xsl:text>    ACRES&#xd;</xsl:text>
                                    <xsl:if test="@style = 'REQD'">
                                        <xsl:text>REMAINDER   =  +/- __________  ACRES&#xd;</xsl:text>
                                    </xsl:if>
                                </xsl:when>
                                <xsl:otherwise>
                                    <xsl:value-of select="inr:acreFormat(number(@area div 10000), 3)"/>
                                    <xsl:text>     HECT&#xd;</xsl:text>
                                    <xsl:if test="@style = 'REQD'">
                                         <xsl:text>REMAINDER   =  +/- __________  HECT&#xd;</xsl:text>
                                   </xsl:if>
                                </xsl:otherwise>
                            </xsl:choose>
                        </xsl:if>
                        <xsl:if test="position() != last()">
                            <xsl:text>.NEWGG&#xd;</xsl:text>
                        </xsl:if>
                        <xsl:text>&#xd;</xsl:text>
                    </xsl:for-each>
                </xsl:for-each>
            </xsl:otherwise>
        </xsl:choose>
    </xsl:template>
    <!-- Horizontal Line Data -->
    <xsl:template match="HorizontalLine" mode="ReqdRWEase">
        <xsl:value-of select="inr:columnFormat(string(Start/@name), 8)"/>
        <xsl:choose>
            <xsl:when test="Start/legalReference/@offset &lt; 0">
                <xsl:value-of select="inr:columnDoubleFormat(number(-1 * Start/legalReference/@offset), 2, 10)"/>
                <xsl:text>  L</xsl:text>
            </xsl:when>
            <xsl:otherwise>
                <xsl:value-of select="inr:columnDoubleFormat(number(Start/legalReference/@offset), 2, 10)"/>
                <xsl:text>  R</xsl:text>
            </xsl:otherwise>
        </xsl:choose>
        <xsl:value-of select="inr:columnFormat(string(inr:stationFormat(number(Start/legalReference/station/@externalStation), $xslStationFormat, 2, string(Start/legalReference/station/@externalStationName))), 14)"/>
        <xsl:value-of select="concat('    ', '     ')"/>
        <xsl:value-of select="Start/legalReference/@referenceAlignmentDescription"/>
        <xsl:text>&#xd;</xsl:text>
        <xsl:value-of select="inr:columnDoubleFormat(number(@length), 2, 18)"/>
        <xsl:value-of select="inr:columnFormat(string(inr:directionFormat(number(@direction), $xslDirectionFormat, 1, $xslDirectionModeFormat, $xslAngularMethod)), 21)"/>
        <xsl:text>&#xd;</xsl:text>
        <xsl:if test="position() = last()">
            <xsl:value-of select="inr:columnFormat(string(End/@name), 8)"/>
            <xsl:choose>
                <xsl:when test="End/legalReference/@offset &lt; 0">
                    <xsl:value-of select="inr:columnDoubleFormat(number(-1 * End/legalReference/@offset), 2, 10)"/>
                    <xsl:text>  L</xsl:text>
                </xsl:when>
                <xsl:otherwise>
                    <xsl:value-of select="inr:columnDoubleFormat(number(End/legalReference/@offset), 2, 10)"/>
                    <xsl:text>  R</xsl:text>
                </xsl:otherwise>
            </xsl:choose>
            <xsl:value-of select="inr:columnFormat(string(inr:stationFormat(number(End/legalReference/station/@externalStation), $xslStationFormat, 1, string(End/legalReference/station/@externalStationName))), 14)"/>
            <xsl:value-of select="concat('    ', '     ')"/>
            <xsl:value-of select="End/legalReference/@referenceAlignmentDescription"/>
            <xsl:text>&#xd;</xsl:text>
        </xsl:if>
    </xsl:template>
    <xsl:template match="HorizontalLine" mode="ReqdDWTemp">
        <xsl:value-of select="inr:columnFormat(string(Start/@name), 8)"/>
        <xsl:choose>
            <xsl:when test="Start/legalReference/@offset &lt; 0">
                <xsl:value-of select="inr:columnDoubleFormat(number(-1 * Start/legalReference/@offset), 2, 10)"/>
                <xsl:text>  L</xsl:text>
            </xsl:when>
            <xsl:otherwise>
                <xsl:value-of select="inr:columnDoubleFormat(number(Start/legalReference/@offset), 2, 10)"/>
                <xsl:text>  R</xsl:text>
            </xsl:otherwise>
        </xsl:choose>
        <xsl:value-of select="inr:columnFormat(string(inr:stationFormat(number(Start/legalReference/station/@externalStation), $xslStationFormat, 2, string(Start/legalReference/station/@externalStationName))), 14)"/>
        <xsl:value-of select="concat('    ', '     ')"/>
        <xsl:value-of select="Start/legalReference/@referenceAlignmentDescription"/>
        <xsl:text>&#xd;</xsl:text>
        <xsl:if test="position() = last()">
            <xsl:value-of select="inr:columnFormat(string(End/@name), 8)"/>
            <xsl:choose>
                <xsl:when test="End/legalReference/@offset &lt; 0">
                    <xsl:value-of select="inr:columnDoubleFormat(number(-1 * End/legalReference/@offset), 2, 10)"/>
                    <xsl:text>  L</xsl:text>
                </xsl:when>
                <xsl:otherwise>
                    <xsl:value-of select="inr:columnDoubleFormat(number(End/legalReference/@offset), 2, 10)"/>
                    <xsl:text>  R</xsl:text>
                </xsl:otherwise>
            </xsl:choose>
            <xsl:value-of select="inr:columnFormat(string(inr:stationFormat(number(End/legalReference/station/@externalStation), $xslStationFormat, 2, string(End/legalReference/station/@externalStationName))), 14)"/>
            <xsl:value-of select="concat('    ', '     ')"/>
            <xsl:value-of select="End/legalReference/@referenceAlignmentDescription"/>
            <xsl:text>&#xd;</xsl:text>
        </xsl:if>
    </xsl:template>
    <!-- Horizontal Circle Data -->
    <xsl:template match="HorizontalCircle" mode="ReqdRWEase">
        <xsl:value-of select="inr:columnFormat(string(Start/@name), 8)"/>
        <xsl:choose>
            <xsl:when test="Start/legalReference/@offset &lt; 0">
                <xsl:value-of select="inr:columnDoubleFormat(number(-1 * Start/legalReference/@offset), 2, 10)"/>
                <xsl:text>  L</xsl:text>
            </xsl:when>
            <xsl:otherwise>
                <xsl:value-of select="inr:columnDoubleFormat(number(Start/legalReference/@offset), 2, 10)"/>
                <xsl:text>  R</xsl:text>
            </xsl:otherwise>
        </xsl:choose>
        <xsl:value-of select="inr:columnFormat(string(inr:stationFormat(number(Start/legalReference/station/@externalStation), $xslStationFormat, 2, string(Start/legalReference/station/@externalStationName))), 14)"/>
        <xsl:value-of select="concat('    ', '     ')"/>
        <xsl:value-of select="Start/legalReference/@referenceAlignmentDescription"/>
        <xsl:text>&#xd;ARC LENGTH = </xsl:text>
        <xsl:value-of select="inr:distanceFormat(number(@length), 2)"/>
        <xsl:text>&#xd;CHORD BEAR = </xsl:text>
        <xsl:value-of select="inr:directionFormat(number(@chordDirection), $xslDirectionFormat, 1, $xslDirectionModeFormat, $xslAngularMethod)"/>
        <xsl:text>&#xd;LNTH CHORD = </xsl:text>
        <xsl:value-of select="inr:distanceFormat(number(@chord), 2)"/>
        <xsl:text>&#xd;    RADIUS = </xsl:text>
        <xsl:value-of select="inr:distanceFormat(number(@radius), 2)"/>
        <xsl:text>&#xd;    DEGREE = </xsl:text>
        <xsl:value-of select="inr:angularFormat(number(@degreeOfCurve), $xslAngularFormat, 1, $xslAngularMethod)"/>
        <xsl:text>&#xd;</xsl:text>
        <xsl:if test="position() = last()">
            <xsl:value-of select="inr:columnFormat(string(End/@name), 8)"/>
            <xsl:choose>
                <xsl:when test="End/legalReference/@offset &lt; 0">
                    <xsl:value-of select="inr:columnDoubleFormat(number(-1 * End/legalReference/@offset), 2, 10)"/>
                    <xsl:text>  L</xsl:text>
                </xsl:when>
                <xsl:otherwise>
                    <xsl:value-of select="inr:columnDoubleFormat(number(End/legalReference/@offset), 2, 10)"/>
                    <xsl:text>  R</xsl:text>
                </xsl:otherwise>
            </xsl:choose>
            <xsl:value-of select="inr:columnFormat(string(inr:stationFormat(number(End/legalReference/station/@externalStation), $xslStationFormat, 2, string(End/legalReference/station/@externalStationName))), 14)"/>
            <xsl:value-of select="concat('    ', '     ')"/>
            <xsl:value-of select="End/legalReference/@referenceAlignmentDescription"/>
            <xsl:text>&#xd;</xsl:text>
        </xsl:if>
    </xsl:template>
    <xsl:template match="HorizontalCircle" mode="ReqdDWTemp">
        <xsl:value-of select="inr:columnFormat(string(Start/@name), 8)"/>
        <xsl:choose>
            <xsl:when test="Start/legalReference/@offset &lt; 0">
                <xsl:value-of select="inr:columnDoubleFormat(number(-1 * Start/legalReference/@offset), 2, 10)"/>
                <xsl:text>  L</xsl:text>
            </xsl:when>
            <xsl:otherwise>
                <xsl:value-of select="inr:columnDoubleFormat(number(Start/legalReference/@offset), 2, 10)"/>
                <xsl:text>  R</xsl:text>
            </xsl:otherwise>
        </xsl:choose>
        <xsl:value-of select="inr:columnFormat(string(inr:stationFormat(number(Start/legalReference/station/@externalStation), $xslStationFormat, 2, string(Start/legalReference/station/@externalStationName))), 14)"/>
        <xsl:value-of select="concat('    ', '     ')"/>
        <xsl:value-of select="Start/legalReference/@referenceAlignmentDescription"/>
        <xsl:text>&#xd;ARC LENGTH = </xsl:text>
        <xsl:value-of select="inr:distanceFormat(number(@length), 2)"/>
        <xsl:text>&#xd;CHORD BEAR = </xsl:text>
        <xsl:value-of select="inr:directionFormat(number(@chordDirection), $xslDirectionFormat, 1, $xslDirectionModeFormat, $xslAngularMethod)"/>
        <xsl:text>&#xd;LNTH CHORD = </xsl:text>
        <xsl:value-of select="inr:distanceFormat(number(@chord), 2)"/>
        <xsl:text>&#xd;    RADIUS = </xsl:text>
        <xsl:value-of select="inr:distanceFormat(number(@radius), 2)"/>
        <xsl:text>&#xd;    DEGREE = </xsl:text>
        <xsl:value-of select="inr:angularFormat(number(@degreeOfCurve), $xslAngularFormat, 1, $xslAngularMethod)"/>
        <xsl:text>&#xd;</xsl:text>
        <xsl:if test="position() = last()">
            <xsl:value-of select="inr:columnFormat(string(End/@name), 8)"/>
            <xsl:choose>
                <xsl:when test="End/legalReference/@offset &lt; 0">
                    <xsl:value-of select="inr:columnDoubleFormat(number(-1 * End/legalReference/@offset), 2, 10)"/>
                    <xsl:text>  L</xsl:text>
                </xsl:when>
                <xsl:otherwise>
                    <xsl:value-of select="inr:columnDoubleFormat(number(End/legalReference/@offset), 2, 10)"/>
                    <xsl:text>  R</xsl:text>
                </xsl:otherwise>
            </xsl:choose>
            <xsl:value-of select="inr:columnFormat(string(inr:stationFormat(number(End/legalReference/station/@externalStation), $xslStationFormat, 2, string(End/legalReference/station/@externalStationName))), 14)"/>
            <xsl:value-of select="concat('    ', '     ')"/>
            <xsl:value-of select="End/legalReference/@referenceAlignmentDescription"/>
            <xsl:text>&#xd;</xsl:text>
        </xsl:if>
    </xsl:template>
    <xsl:template name="StyleSheetHelp">
        <xsl:text>Notes&#xd;&#xd;</xsl:text>
        <xsl:text>    You must include at least one horizontal alignment in&#xd;</xsl:text>
        <xsl:text>    the Include field on the Tools &gt; XML Reports &gt; Legal&#xd;</xsl:text>
        <xsl:text>    Description command to get results from this report.&#xd;&#xd;</xsl:text>
        <xsl:text>    This report requires at least one reference alignment&#xd;</xsl:text>
        <xsl:text>    to be specified in the Reference Alignments &gt; Include&#xd;</xsl:text>
        <xsl:text>    field on the Tools &gt; XML Reports &gt; Legal Description&#xd;</xsl:text>
        <xsl:text>    command for a complete report.  Reference alignment(s)&#xd;</xsl:text>
        <xsl:text>    must contain descriptions and must have a style of REQD&#xd;</xsl:text>
        <xsl:text>    if they are required right-of-way, PESMT if they are&#xd;</xsl:text>
        <xsl:text>    required permanent easements, TESMT if they are&#xd;</xsl:text>
        <xsl:text>    required temporary easements and DWESMT if they are&#xd;</xsl:text>
        <xsl:text>    required driveway easements.  Alignments with other&#xd;</xsl:text>
        <xsl:text>    styles will not be included in this report.&#xd;&#xd;</xsl:text>
        <xsl:text>Copyright 2007 Bentley Systems, Inc&#xd;</xsl:text>
    </xsl:template>
    <msxsl:script implements-prefix="inr" language="JScript">
        <![CDATA[
            // This function sets the format of angular information.  It is copied here from format.xsl so 
            // that the degrees symbol can be output as "^".
            // n - value from xml
            // format - (1 - "ddd^mm'ss.s", 2 - "ddd.ddd")
            // formatMethod - (1 - Degrees, 2 - Grads, 3 - Radians, 4 - Mils)
            // precision - the number of digits after the decimal point
            function angularFormat(n, format, precision, formatMethod)
            {
                // Checking to see if the number is valid
                if(!isNaN(n))
                {
                    // converts from Radians to Degrees and formats the value
                    if(formatMethod == 1)
                    {
                        var decdeg = (n * 180) / Math.PI;
                        // format 1 - this converts the number to "ddd^mm'ss.s"
                        if(format == 1)
                        {
                            // takes only the whole number (ddd)
                            deg = Math.floor(Math.abs(decdeg));
                            // multiplies the decimal portion time 60 to get the minutes
                            var decmin = (Math.abs(decdeg) - deg) * 60;
                            // takes only the whole part of that number (mm')
                            var min = Math.floor(decmin);
                            // multiplies the decimal portion time 60 to get the seconds.
                            var decsec = (decmin - min) * 60;
                            // this calls the function that gives the number the correct precision
                            var str = formatNumber(decsec, precision);
                            if(str.substring(0, 2) == "60")
                            {
                                decsec = 0;
                                str = formatNumber(decsec, precision);
                                min = min+1;
                                if(min == 60)
                                {
                                    min = 0;
                                    deg = deg + 1;
                                }
                            }
                            if(min < 10)
                            {
                                min = "0" + min;
                            }
                            var sec = str;
                            if(sec < 10)
                            {
                                sec = "0" + sec;
                            }
                            var msg;
                            if(decdeg >= 0 || decdeg <= -1)
                            {
                                if(decdeg < 0)
                                    msg =  "-" + deg + "^" + min + "'" + sec + '"';
                                else
                                    msg =  deg + "^" + min + "'" + sec + '"';
                            }
                            else
                                msg =  "-0" + "^" + min + "'" + sec + '"';
                            return msg;
                        }
                        // format 2 - "ddd.ddd"
                        if(format == 2)
                        {
                            // this calls the function that gives the number the correct precision
                            var str = formatNumber(decdeg, precision);
                            str = str + "^";
                            return str;
                        }
                    }
                    //converts Radians to Grads
                    if(formatMethod == 2)
                    {
                        var radtograd = (n * 200) / Math.PI;
                        var grad = formatNumber(radtograd, precision);
                        if (gradSuffix == true)
                        {
                            grad = grad + "g";
                        }
                        return grad;
                    }
                    // value in Radians needs to be formated
                    if(formatMethod == 3)
                    {
                        // this calls the function that gives the number the correct precision
                        var radian = formatNumber(n, precision);
                        if(radSuffix == true)
                        {
                            radian = radian + "r";
                        }
                        return radian;
                    }
                    //converts Radians to Mils
                    if(formatMethod == 4 )
                    {
                         var radtomils = n * (6400.0 / (2.0 * Math.PI));
                         var mils = formatNumber(radtomils, precision);
                         return mils;
                    }
                }
                return NaN;
             }
            function setPI()
            {
                var strPI = Math.PI;
                return strPI;
            }
        ]]>
    </msxsl:script>
</xsl:stylesheet>
