<?xml version="1.0" encoding="UTF-8"?>
<xsl:stylesheet version="1.1" xmlns:xsl="http://www.w3.org/1999/XSL/Transform" xmlns:fo="http://www.w3.org/1999/XSL/Format" xmlns:msxsl="urn:schemas-microsoft-com:xslt" xmlns:inr="http://mycompany.com/mynamespace">
    <xsl:include href="../format.xsl"/>
    <!-- Horizontal Elements Geodimeter Format -->
    <xsl:output method="text" media-type="text/plain" encoding="iso-8859-1"/>
    <xsl:template match="/">
        <xsl:variable name="gridOut" select="inr:SetGridOut(number(InRoads/@outputGridScaleFactor))" />
        <xsl:choose>
            <xsl:when test="$xslShowHelp = 'true'">
                <xsl:call-template name="StyleSheetHelp"/>
            </xsl:when>
            <xsl:otherwise>
                <xsl:for-each select="//HorizontalAlignment">
                    <xsl:text/>
                    <xsl:text>15=</xsl:text><xsl:value-of select="substring(@name, 1, 6)"/>
                    <xsl:text>#1&#xd;</xsl:text>
                    <xsl:apply-templates/>
                    <xsl:text>&#xd;</xsl:text>
                </xsl:for-each>
            </xsl:otherwise>
        </xsl:choose>
    </xsl:template>
    <!-- Horizontal Alignment Linear Data -->
    <xsl:template match="HorizontalLine">
        <xsl:text>80=</xsl:text>
        <xsl:value-of select="inr:distanceFormat(number(Start/station/@internalStation), $xslDistancePrecision)"/>
        <xsl:text>&#xd;</xsl:text>
        <xsl:text>37=</xsl:text>
        <xsl:value-of select="inr:northingFormat(number(Start/@northing), $xslNorthingPrecision)"/>
        <xsl:text>&#xd;</xsl:text>
        <xsl:text>38=</xsl:text>
        <xsl:value-of select="inr:eastingFormat(number(Start/@easting), $xslEastingPrecision)"/>
        <xsl:text>&#xd;</xsl:text>
        <xsl:if test="position() = last()">
            <xsl:text>80=</xsl:text>
            <xsl:value-of select="inr:distanceFormat(number(End/station/@internalStation), $xslDistancePrecision)"/>
            <xsl:text>&#xd;</xsl:text>
            <xsl:text>37=</xsl:text>
            <xsl:value-of select="inr:northingFormat(number(End/@northing), $xslNorthingPrecision)"/>
            <xsl:text>&#xd;</xsl:text>
            <xsl:text>38=</xsl:text>
            <xsl:value-of select="inr:eastingFormat(number(End/@easting), $xslEastingPrecision)"/>
            <xsl:text>&#xd;</xsl:text>
        </xsl:if>
    </xsl:template>
    <!-- Horizontal Alignment Circular Data -->
    <xsl:template match="HorizontalCircle">
        <xsl:text>80=</xsl:text>
        <xsl:value-of select="inr:distanceFormat(number(Start/station/@internalStation), $xslDistancePrecision)"/>
        <xsl:text>&#xd;</xsl:text>
        <xsl:text>37=</xsl:text>
        <xsl:value-of select="inr:northingFormat(number(Start/@northing), $xslNorthingPrecision)"/>
        <xsl:text>&#xd;</xsl:text>
        <xsl:text>38=</xsl:text>
        <xsl:value-of select="inr:eastingFormat(number(Start/@easting), $xslEastingPrecision)"/>
        <xsl:text>&#xd;</xsl:text>
        <xsl:text>64=</xsl:text>
        <xsl:choose>
            <xsl:when test="@rotationDirection = 'ccw'">
                <xsl:value-of select="inr:distanceFormat(number(-1 * @radius), $xslDistancePrecision)"/>
            </xsl:when>
            <xsl:otherwise>
                <xsl:value-of select="inr:distanceFormat(number(@radius), $xslDistancePrecision)"/>
            </xsl:otherwise>
        </xsl:choose>
        <xsl:text>&#xd;</xsl:text>
        <xsl:if test="position() = last()">
            <xsl:text>80=</xsl:text>
            <xsl:value-of select="inr:distanceFormat(number(End/station/@internalStation), $xslDistancePrecision)"/>
            <xsl:text>&#xd;</xsl:text>
            <xsl:text>37=</xsl:text>
            <xsl:value-of select="inr:northingFormat(number(End/@northing), $xslNorthingPrecision)"/>
            <xsl:text>&#xd;</xsl:text>
            <xsl:text>38=</xsl:text>
            <xsl:value-of select="inr:eastingFormat(number(End/@easting), $xslEastingPrecision)"/>
            <xsl:text>&#xd;</xsl:text>
        </xsl:if>
    </xsl:template>
    <!-- Horizontal Alignment Spiral Data -->
    <xsl:template match="HorizontalSpiral">
        <xsl:text>80=</xsl:text>
        <xsl:value-of select="inr:distanceFormat(number(Start/station/@internalStation), $xslDistancePrecision)"/>
        <xsl:text>&#xd;</xsl:text>
        <xsl:text>37=</xsl:text>
        <xsl:value-of select="inr:northingFormat(number(Start/@northing), $xslNorthingPrecision)"/>
        <xsl:text>&#xd;</xsl:text>
        <xsl:text>38=</xsl:text>
        <xsl:value-of select="inr:eastingFormat(number(Start/@easting), $xslEastingPrecision)"/>
        <xsl:text>&#xd;</xsl:text>
        <xsl:text>81=</xsl:text>
        <xsl:value-of select="inr:distanceFormat(number(@aConstant), $xslDistancePrecision)"/>
        <xsl:text>&#xd;</xsl:text>
        <xsl:if test="position() = last()">
            <xsl:text>80=</xsl:text>
            <xsl:value-of select="inr:distanceFormat(number(End/station/@internalStation), $xslDistancePrecision)"/>
            <xsl:text>&#xd;</xsl:text>
            <xsl:text>37=</xsl:text>
            <xsl:value-of select="inr:northingFormat(number(End/@northing), $xslNorthingPrecision)"/>
            <xsl:text>&#xd;</xsl:text>
            <xsl:text>38=</xsl:text>
            <xsl:value-of select="inr:eastingFormat(number(End/@easting), $xslEastingPrecision)"/>
            <xsl:text>&#xd;</xsl:text>
        </xsl:if>
    </xsl:template>
    <xsl:template name="StyleSheetHelp">
        <xsl:text>Notes&#xd;&#xd;</xsl:text>
        <xsl:text>    You must include at least one horizontal alignment in&#xd;</xsl:text>
        <xsl:text>    the Include field on the Tools &gt; XML Reports &gt; Geometry&#xd;</xsl:text>
        <xsl:text>    command to get results from this report.&#xd;&#xd;</xsl:text>
        <xsl:text>    Most style sheets in the DataCollection directory do&#xd;</xsl:text>
        <xsl:text>    not honor Tools &gt; Format Options with the exception of&#xd;</xsl:text>
        <xsl:text>    precision, where practical.&#xd;&#xd;</xsl:text>
        <xsl:text>Copyright 2006 Bentley Systems, Inc&#xd;</xsl:text>
    </xsl:template>
</xsl:stylesheet>
