<?xml version="1.0" encoding="UTF-8"?>
<xsl:stylesheet version="1.1" xmlns:xsl="http://www.w3.org/1999/XSL/Transform" xmlns:fo="http://www.w3.org/1999/XSL/Format" xmlns:msxsl="urn:schemas-microsoft-com:xslt" xmlns:inr="http://mycompany.com/mynamespace">
    <xsl:include href="../format.xsl"/>
    <!-- Horizontal Off-Alignment Points -->
    <xsl:output method="text" media-type="text/plain" encoding="iso-8859-1"/>
    <xsl:template match="/">
        <xsl:variable name="gridOut" select="inr:SetGridOut(number(InRoads/@outputGridScaleFactor))"/>
        <xsl:choose>
            <xsl:when test="$xslShowHelp = 'true'">
                <xsl:call-template name="StyleSheetHelp"/>
            </xsl:when>
            <xsl:otherwise>
                <xsl:for-each select="InRoads/GeometryProject">
                    <xsl:text/>
                    <xsl:text>* BENTLEY HORIZONTAL OFF-ALIGNMENT POINTS&#xd;</xsl:text>
                    <xsl:text>* &#xd;</xsl:text>
                    <xsl:for-each select="HorizontalAlignment">
                        <xsl:text>* Alignment name: </xsl:text><xsl:value-of select="@name"/><xsl:text>&#xd;</xsl:text>
                        <xsl:text>* Alignment description: </xsl:text><xsl:value-of select="@description"/><xsl:text>&#xd;</xsl:text>
                        <xsl:text>* Alignment style: </xsl:text><xsl:value-of select="@style"/><xsl:text>&#xd;</xsl:text>
                        <xsl:text>* Input Factor: </xsl:text><xsl:value-of select="//@inputGridScaleFactor"/><xsl:text>&#xd;</xsl:text>
                        <xsl:text>* &#xd;</xsl:text>
                        <xsl:text>*</xsl:text>
                        <xsl:value-of select="inr:columnFormat('Point Type', 12)"/>
                        <xsl:value-of select="inr:columnFormat('X Coord', 16)"/>
                        <xsl:value-of select="inr:columnFormat('Y Coord', 16)"/>
                        <xsl:value-of select="inr:columnFormat('Z Coord', 12)"/>
                        <xsl:text>   Style</xsl:text>
                        <xsl:text>&#xd;</xsl:text>
                        <xsl:for-each select="HorizontalElements">
                            <xsl:apply-templates/>
                        </xsl:for-each>
                    </xsl:for-each>
                </xsl:for-each>
            </xsl:otherwise>
        </xsl:choose>
    </xsl:template>
    <xsl:template match="HorizontalCircle/PI | HorizontalSpiral/PI | Center">
        <xsl:value-of select="inr:columnFormat(string(@type), 10)"/>
        <xsl:value-of select="inr:columnDoubleFormat(number(@easting), $xslEastingPrecision, 19)"/>
        <xsl:value-of select="inr:columnDoubleFormat(number(@northing), $xslNorthingPrecision, 16)"/>
        <xsl:value-of select="inr:columnDoubleFormat(number(@elevation), $xslElevationPrecision, 12)"/>
        <xsl:text>&#xa0; &#xa0;</xsl:text>
        <xsl:value-of select="@style"/>
        <xsl:text>&#xd;</xsl:text>
    </xsl:template>
    <xsl:template name="StyleSheetHelp">
        <xsl:text>Notes&#xd;&#xd;</xsl:text>
        <xsl:text>    You must include at least one horizontal alignment in&#xd;</xsl:text>
        <xsl:text>    the Include field on the Tools &gt; XML Reports &gt; Geometry&#xd;</xsl:text>
        <xsl:text>    command to get results from this report.&#xd;&#xd;</xsl:text>
        <xsl:text>    Most style sheets in the DataCollection directory do&#xd;</xsl:text>
        <xsl:text>    not honor Tools &gt; Format Options with the exception of&#xd;</xsl:text>
        <xsl:text>    precision, where practical.&#xd;&#xd;</xsl:text>
        <xsl:text>Copyright 2006 Bentley Systems, Inc&#xd;</xsl:text>
    </xsl:template>
</xsl:stylesheet>
