<?xml version="1.0" encoding="UTF-8"?>
<xsl:stylesheet version="1.1" xmlns:xsl="http://www.w3.org/1999/XSL/Transform" xmlns:fo="http://www.w3.org/1999/XSL/Format" xmlns:msxsl="urn:schemas-microsoft-com:xslt" xmlns:inr="http://mycompany.com/mynamespace">
    <xsl:include href="../format.xsl"/>
    <!-- Name of Feature Table XML file-->
    <xsl:variable name="featureTableList" select="document('FeatureTable.xml')"/>
    <!-- Stakeout SMI Format -->
    <xsl:output method="text" media-type="text/plain" encoding="iso-8859-1"/>
    <xsl:template match="/">
        <xsl:variable name="gridOut" select="inr:SetGridOut(number(InRoads/@outputGridScaleFactor))"/>
        <xsl:choose>
            <xsl:when test="$xslShowHelp = 'true'">
                <xsl:call-template name="StyleSheetHelp"/>
            </xsl:when>
            <xsl:otherwise>
                <xsl:for-each select="InRoads/GeometryProject">
                    <xsl:text/>
                    <xsl:text>*FILE NAME: </xsl:text><xsl:value-of select="@file"/><xsl:text>&#xd;</xsl:text>
                    <xsl:text>*&#xd;</xsl:text>
                    <xsl:text>*DATE: </xsl:text><xsl:value-of select="inr:date()"/><xsl:text>&#xd;</xsl:text>
                    <xsl:text>*&#xd;</xsl:text>
                    <xsl:text>*PROJECT NUMBER: </xsl:text><xsl:value-of select="@name"/><xsl:text>&#xd;</xsl:text>
                    <xsl:text>*&#xd;</xsl:text>
                    <xsl:text>*DESCRIPTION: </xsl:text><xsl:value-of select="@description"/><xsl:text>&#xd;</xsl:text>
                    <xsl:text>*                        </xsl:text><xsl:value-of select="//@inputGridScaleFactor"/><xsl:text>&#xd;</xsl:text>
                    <xsl:text>*UNITS: </xsl:text>
                    <xsl:choose>
                        <xsl:when test="//@linearUnits = 'Imperial'">
                            <xsl:text>ENGLISH    </xsl:text>
                        </xsl:when>
                        <xsl:otherwise>
                            <xsl:text>METRIC     </xsl:text>
                        </xsl:otherwise>
                    </xsl:choose>
                    <xsl:text>G.F.: </xsl:text><xsl:value-of select="//@outputGridScaleFactor"/><xsl:text>&#xd;</xsl:text>
                    <xsl:text>*&#xd;</xsl:text>
                    <xsl:text>*FEATURE CODE # 176 USED TO IDENTIFY MOUNDS OF RUINS/DEBRIS&#xd;</xsl:text>
                    <xsl:text>*&#xd;</xsl:text>
                    <xsl:text>*PT NO.   EAST           NORTH        ELEV.     FEATURE CODE&#xd;</xsl:text>
                    <xsl:for-each select="HorizontalAlignment">
                        <xsl:apply-templates/>
                    </xsl:for-each>
                    <xsl:for-each select="CogoPoints">
                        <xsl:apply-templates/>
                    </xsl:for-each>
                </xsl:for-each>
            </xsl:otherwise>
        </xsl:choose>
    </xsl:template>
    <!-- Point Data -->
    <xsl:template match="HorizontalLine | HorizontalCircle | HorizontalSpiral">
        <xsl:variable name="startStation" select="Start/station/@internalStation"/>
        <xsl:variable name="endStation" select="End/station/@internalStation"/>
        <xsl:apply-templates/>
        <xsl:for-each select="../../HorizontalEventPoints/*/*/GeometryPoint[station/@internalStation &gt; $startStation][station/@internalStation &lt; $endStation]">
            <xsl:variable name="parentStyle" select="ancestor::*/@style"/>
            <xsl:variable name="SMIcode" select="$featureTableList/*/SMI[@featureCode = $parentStyle]/@code"/>
            <xsl:choose>
                <xsl:when test="@name">
                    <xsl:value-of select="inr:columnFormat(string(@name), 5)"/>
                </xsl:when>
                <xsl:otherwise>
                    <xsl:call-template name="pntNumber"/>
                </xsl:otherwise>
            </xsl:choose>
            <xsl:value-of select="inr:columnDoubleFormat(number(@easting), 5, 15)"/>
            <xsl:value-of select="inr:columnDoubleFormat(number(@northing), 5, 16)"/>
            <xsl:value-of select="inr:columnDoubleFormat(number(@elevation), 5, 11)"/>
            <xsl:text> F</xsl:text><xsl:value-of select="$SMIcode"/>
            <xsl:choose>
                <xsl:when test="@description">
                    <xsl:text>S</xsl:text><xsl:value-of select="@description"/>
                </xsl:when>
                <xsl:otherwise/>
            </xsl:choose>
            <xsl:text>C</xsl:text><xsl:call-template name="strNumber"/>
            <xsl:text>&#xd;</xsl:text>
        </xsl:for-each>
        <xsl:if test="position() = last()">
            <xsl:variable name="SMIcode" select="$featureTableList/*/SMI[@featureCode = current()/End/@style]/@code"/>
            <xsl:choose>
                <xsl:when test="End/@name">
                    <xsl:value-of select="inr:columnFormat(string(End/@name), 5)"/>
                </xsl:when>
                <xsl:otherwise>
                    <xsl:call-template name="pntNumber"/>
                </xsl:otherwise>
            </xsl:choose>
            <xsl:value-of select="inr:columnDoubleFormat(number(End/@easting), 5, 15)"/>
            <xsl:value-of select="inr:columnDoubleFormat(number(End/@northing), 5, 16)"/>
            <xsl:value-of select="inr:columnDoubleFormat(number(End/@elevation), 5, 11)"/>
            <xsl:text> F</xsl:text><xsl:value-of select="$SMIcode"/>
            <xsl:choose>
                <xsl:when test="End/@description">
                    <xsl:text>S</xsl:text><xsl:value-of select="End/@description"/>
                </xsl:when>
                <xsl:otherwise/>
            </xsl:choose>
            <xsl:text>C</xsl:text><xsl:call-template name="strNumber"/>
            <xsl:text>&#xd;</xsl:text>
        </xsl:if>
    </xsl:template>
    <xsl:template match="Start | CogoPoints/GeometryPoint">
        <xsl:variable name="SMIcode" select="$featureTableList/*/SMI[@featureCode = current()/@style]/@code"/>
        <xsl:choose>
            <xsl:when test="@name">
                <xsl:value-of select="inr:columnFormat(string(@name), 5)"/>
            </xsl:when>
            <xsl:otherwise>
                <xsl:call-template name="pntNumber"/>
            </xsl:otherwise>
        </xsl:choose>
        <xsl:value-of select="inr:columnDoubleFormat(number(@easting), 5, 15)"/>
        <xsl:value-of select="inr:columnDoubleFormat(number(@northing), 5, 16)"/>
        <xsl:value-of select="inr:columnDoubleFormat(number(@elevation), 5, 11)"/>
        <xsl:text> F</xsl:text><xsl:value-of select="$SMIcode"/>
        <xsl:choose>
            <xsl:when test="@description">
                <xsl:text>S</xsl:text><xsl:value-of select="@description"/>
            </xsl:when>
            <xsl:otherwise/>
        </xsl:choose>
        <xsl:text>C</xsl:text><xsl:call-template name="strNumber"/>
        <xsl:text>&#xd;</xsl:text>
    </xsl:template>
    <xsl:template name="pntNumber">
        <xsl:variable name="pointNumber">
            <xsl:number count="Start[not(@name)] | End[not(@name)] | CogoPoints/GeometryPoint[not(@name)] | HorizontalEventPoint/GeometryPoint[not(@name)]" level="any"/>
        </xsl:variable>
        <xsl:value-of select="inr:columnFormat(string($pointNumber), 5)"/>
    </xsl:template>
    <xsl:template name="strNumber">
        <xsl:variable name="stringNumber">
            <xsl:number count="HorizontalAlignment" level="any"/>
        </xsl:variable>
        <xsl:value-of select="$stringNumber"/>
    </xsl:template>
    <xsl:template name="StyleSheetHelp">
        <xsl:text>Notes&#xd;&#xd;</xsl:text>
        <xsl:text>    You must include at least one horizontal alignment in&#xd;</xsl:text>
        <xsl:text>    the Include field on the Tools &gt; XML Reports &gt;&#xd;</xsl:text>
        <xsl:text>    Geometry command to get results from this report.&#xd;&#xd;</xsl:text>
        <xsl:text>    If a horizontal alignment point does not have a name,&#xd;</xsl:text>
        <xsl:text>    it will be assigned one, based on its position, by this&#xd;</xsl:text>
        <xsl:text>    style sheet.&#xd;&#xd;</xsl:text>
        <xsl:text>    This style sheet uses a "look-up table" to select an&#xd;</xsl:text>
        <xsl:text>    SMI feature code from a separate XML file by finding a&#xd;</xsl:text>
        <xsl:text>    style that matches the style attribute of the&#xd;</xsl:text>
        <xsl:text>    alignment.  An example XML file called FeatureTable.xml&#xd;</xsl:text>
        <xsl:text>    is included in the DataCollection directory.  This file&#xd;</xsl:text>
        <xsl:text>    can be modified to suit your needs, or you can create&#xd;</xsl:text>
        <xsl:text>    your own file.  The file is name is stored in a&#xd;</xsl:text>
        <xsl:text>    variable near the top of the style sheet, and you&#xd;</xsl:text>
        <xsl:text>    should change this value if you create your own file.&#xd;&#xd;</xsl:text>
        <xsl:text>    Most style sheets in the DataCollection directory do&#xd;</xsl:text>
        <xsl:text>    not honor Tools &gt; Format Options with the exception of&#xd;</xsl:text>
        <xsl:text>    precision, where practical.&#xd;&#xd;</xsl:text>
        <xsl:text>Copyright 2006 Bentley Systems, Inc&#xd;</xsl:text>
    </xsl:template>
</xsl:stylesheet>
