<?xml version="1.0" encoding="UTF-8"?>
<xsl:stylesheet version="1.1" xmlns:xsl="http://www.w3.org/1999/XSL/Transform" xmlns:fo="http://www.w3.org/1999/XSL/Format" xmlns:msxsl="urn:schemas-microsoft-com:xslt" xmlns:inr="http://mycompany.com/mynamespace">
    <xsl:include href="../format.xsl"/>
    <!-- Trimble Station Offset DC Format -->
    <xsl:output method="text" media-type="text/plain" encoding="iso-8859-1"/>
    <xsl:template match="/">
        <xsl:variable name="gridOut" select="inr:SetGridOut(number(InRoads/@outputGridScaleFactor))"/>
        <xsl:choose>
            <xsl:when test="$xslShowHelp = 'true'">
                <xsl:call-template name="StyleSheetHelp"/>
            </xsl:when>
            <xsl:otherwise>
                <xsl:for-each select="InRoads/GeometryProject">
                    <xsl:text/>
                    <xsl:text>00NMSC &#xa0; &#xa0; &#xa0; V07 &#xa0; &#xa0;0 &#xa0; </xsl:text>
                    <xsl:value-of select="inr:date()"/>
                    <xsl:text> &#xa0; &#xa0; &#xa0; </xsl:text>
                    <xsl:text> 111121&#xd;</xsl:text>
                    <xsl:text>10NM1 &#xa0; &#xa0; &#xa0; &#xa0; &#xa0; &#xa0; &#xa0; 121111&#xd;</xsl:text>
                    <xsl:text>64KI10.00000000 &#xa0; &#xa0; &#xa0;0.00000000 &#xa0; &#xa0; &#xa0;</xsl:text>
                    <xsl:text>0.0000 &#xa0; &#xa0; &#xa0; &#xa0; &#xa0;0.0000 &#xa0; &#xa0; &#xa0;</xsl:text>
                    <xsl:text> &#xa0; &#xa0;0.0000 &#xa0; &#xa0; &#xa0; &#xa0; &#xa0;0.0000&#xd;</xsl:text>
                    <xsl:text>65KI6378137.0000 &#xa0; &#xa0; 298.2572235630&#xd;</xsl:text>
                    <xsl:text>49KI16378137.0000 &#xa0; &#xa0; 298.2572235630 0.000000</xsl:text>
                    <xsl:text> &#xa0; &#xa0; &#xa0; &#xa0;0.000000 &#xa0; &#xa0; &#xa0; &#xa0;</xsl:text>
                    <xsl:text>0.000000 &#xa0; &#xa0; &#xa0; &#xa0;0.000000&#xd;</xsl:text>
                    <xsl:for-each select="//StationOffsetPoint">
                        <xsl:text>69GE</xsl:text>
                        <xsl:value-of select="inr:columnFormat(string(inr:stationFormat(number(centerLinePoint/point/station/@externalStation), $xslStationFormat, $xslStationPrecision, string(centerLinePoint/point/station/@externalStationName))), 10)"/>
                        <xsl:value-of select="inr:columnDoubleFormat(number(offsetPoint/@easting), 3, 15)"/>
                        <xsl:value-of select="inr:columnDoubleFormat(number(offsetPoint/@northing), 3, 15)"/>
                        <xsl:value-of select="inr:columnDoubleFormat(number(0.0), 3, 15)"/>
                        <xsl:value-of select="inr:columnDoubleFormat(number(@firstOffset), 3, 15)"/>
                        <xsl:text> O/S &#xa0; &#xa0;11&#xd;</xsl:text>
                    </xsl:for-each>
                </xsl:for-each>
            </xsl:otherwise>
        </xsl:choose>
    </xsl:template>
    <xsl:template name="StyleSheetHelp">
        <xsl:text>Notes&#xd;&#xd;</xsl:text>
        <xsl:text>    You must create station offset points for this report&#xd;</xsl:text>
        <xsl:text>    by selecting either Tools &gt; XML Reports &gt; Station Base&#xd;</xsl:text>
        <xsl:text>    or Tools &gt; XML Reports &gt; Station Offset.  You must&#xd;</xsl:text>
        <xsl:text>    include at least one horizontal alignment or one&#xd;</xsl:text>
        <xsl:text>    feature on the General leaf in the From fields.  You&#xd;</xsl:text>
        <xsl:text>    must also include at least one horizontal alignment on&#xd;</xsl:text>
        <xsl:text>    the Horizontal Alignments leaf or one feature on the&#xd;</xsl:text>
        <xsl:text>    Features leaf.  You must choose at least one option on&#xd;</xsl:text>
        <xsl:text>    the Include leaf (Horizontal On-Alignment Points,&#xd;</xsl:text>
        <xsl:text>    Horizontal Event Points, Vertical On-Alignment Points,&#xd;</xsl:text>
        <xsl:text>    Vertical Event Points or Interval.)&#xd;&#xd;</xsl:text>
        <xsl:text>    If you wish to include Vertical Event Points or you&#xd;</xsl:text>
        <xsl:text>    wish to use an Offset, you must use the Tools &gt; XML&#xd;</xsl:text>
        <xsl:text>    Reports &gt; Station Offset command rather than the Tools&#xd;</xsl:text>
        <xsl:text>    &gt; XML Reports &gt; Station Base command.&#xd;&#xd;</xsl:text>
        <xsl:text>    Station Limits only apply to computed data, ie, event&#xd;</xsl:text>
        <xsl:text>    points by interval.&#xd;&#xd;</xsl:text>
        <xsl:text>    Most style sheets in the DataCollection directory do&#xd;</xsl:text>
        <xsl:text>    not honor Tools &gt; Format Options with the exception of&#xd;</xsl:text>
        <xsl:text>    precision, where practical.&#xd;&#xd;</xsl:text>
        <xsl:text>Copyright 2006 Bentley Systems, Inc&#xd;</xsl:text>
    </xsl:template>
</xsl:stylesheet>
