<?xml version="1.0" encoding="UTF-8"?>
<xsl:stylesheet version="1.1" xmlns:xsl="http://www.w3.org/1999/XSL/Transform" xmlns:fo="http://www.w3.org/1999/XSL/Format" xmlns:msxsl="urn:schemas-microsoft-com:xslt" xmlns:inr="http://mycompany.com/mynamespace">
    <xsl:include href="../format.xsl"/>
    <!-- Variable to hold unit string -->
    <xsl:variable name="unit">
        <xsl:choose>
            <xsl:when test="//@linearUnits = 'Imperial'">17</xsl:when>
            <xsl:otherwise>16</xsl:otherwise>
        </xsl:choose>
    </xsl:variable>
    <!-- Vertical Elements - Leica GSI16 Format -->
    <xsl:output method="text" media-type="text/plain" encoding="is0-8859-1"/>
    <xsl:template match="/">
        <xsl:variable name="gridOut" select="inr:SetGridOut(number(InRoads/@outputGridScaleFactor))"/>
        <xsl:choose>
            <xsl:when test="$xslShowHelp = 'true'">
                <xsl:call-template name="StyleSheetHelp"/>
            </xsl:when>
            <xsl:otherwise>
                <!-- Vertical Alignment Data -->
                <xsl:for-each select="//VerticalAlignment">
                    <xsl:text/>
                    <xsl:text>*41....+</xsl:text>
                    <xsl:choose>
                        <xsl:when test="string-length(@name) &gt; 16">
                            <xsl:value-of select="substring(@name, 1, 16)"/>
                        </xsl:when>
                        <xsl:when test="string-length(@name) &lt; 16">
                            <xsl:value-of select="substring('0000000000000000', 1, 16 - string-length(@name))"/>
                            <xsl:value-of select="@name"/>
                        </xsl:when>
                        <xsl:otherwise>
                            <xsl:value-of select="@name"/>
                        </xsl:otherwise>
                    </xsl:choose>
                    <xsl:text> 42....+000000000VALIGNM 43....+00000000STACOORD&#xd;</xsl:text>
                    <xsl:for-each select="VerticalElements">
                        <xsl:apply-templates/>
                    </xsl:for-each>
                </xsl:for-each>
            </xsl:otherwise>
        </xsl:choose>
    </xsl:template>
    <!-- Vertical Alignment Linear Data -->
    <xsl:template match="VerticalLine">
        <!-- Find absolute value -->
        <xsl:variable name="absStartStation">
            <xsl:choose>
                <xsl:when test="VerticalStart/station/@internalStation &lt; 0">
                    <xsl:value-of select="number(-1 * VerticalStart/station/@internalStation)"/>
                </xsl:when>
                <xsl:otherwise>
                    <xsl:value-of select="number(VerticalStart/station/@internalStation)"/>
                </xsl:otherwise>
            </xsl:choose>
        </xsl:variable>
        <xsl:variable name="absStartElevation">
            <xsl:choose>
                <xsl:when test="VerticalStart/@elevation &lt; 0">
                    <xsl:value-of select="number(-1 * VerticalStart/@elevation)"/>
                </xsl:when>
                <xsl:otherwise><xsl:value-of select="number(VerticalStart/@elevation)"/></xsl:otherwise>
            </xsl:choose>
        </xsl:variable>
        <xsl:variable name="absEndStation">
            <xsl:choose>
                <xsl:when test="VerticalEnd/station/@internalStation &lt; 0">
                    <xsl:value-of select="number(-1 * VerticalEnd/station/@internalStation)"/>
                </xsl:when>
                <xsl:otherwise>
                    <xsl:value-of select="number(VerticalEnd/station/@internalStation)"/>
                </xsl:otherwise>
            </xsl:choose>
        </xsl:variable>
        <xsl:variable name="absEndElevation">
            <xsl:choose>
                <xsl:when test="VerticalEnd/@elevation &lt; 0">
                    <xsl:value-of select="number(-1 * VerticalEnd/@elevation)"/>
                </xsl:when>
                <xsl:otherwise><xsl:value-of select="number(VerticalEnd/@elevation)"/></xsl:otherwise>
            </xsl:choose>
        </xsl:variable>
        <!-- Set decimal precision and pad with leading zeros -->
        <xsl:variable name="fmtStartStation" select="inr:zeroDoubleFormat(number($absStartStation), 4, 16)"/>
        <xsl:variable name="fmtStartElevation" select="inr:zeroDoubleFormat(number($absStartElevation), 4, 16)"/>
        <xsl:variable name="fmtEndStation" select="inr:zeroDoubleFormat(number($absEndStation), 4, 16)"/>
        <xsl:variable name="fmtEndElevation" select="inr:zeroDoubleFormat(number($absEndElevation), 4, 16)"/>
        <xsl:text>*11....</xsl:text>
        <xsl:choose>
            <xsl:when test="VerticalStart/station/@internalStation &lt; 0">
                <xsl:text>-</xsl:text>
            </xsl:when>
            <xsl:otherwise>
                <xsl:text>+</xsl:text>
            </xsl:otherwise>
        </xsl:choose>
        <xsl:value-of select="substring($fmtStartStation, 1, 16)"/>
        <xsl:text> 71....+00000000STRAIGHT 72....+0000000000000NON 83..</xsl:text>
        <xsl:value-of select="$unit"/>
        <xsl:choose>
            <xsl:when test="VerticalStart/@elevation &lt; 0"><xsl:text>-</xsl:text></xsl:when>
            <xsl:otherwise><xsl:text>+</xsl:text></xsl:otherwise>
        </xsl:choose>
        <xsl:choose>
            <xsl:when test="string-length($fmtStartElevation) &gt; 16">
                <xsl:value-of select="substring($fmtStartElevation, (string-length($fmtStartElevation) - 15), 16)"/>
            </xsl:when>
            <xsl:otherwise>
                <xsl:value-of select="$fmtStartElevation"/>
            </xsl:otherwise>
        </xsl:choose>
        <xsl:text>&#xd;</xsl:text>
        <xsl:if test="position() = last()">
            <xsl:text>*11....</xsl:text>
            <xsl:choose>
                <xsl:when test="VerticalEnd/station/@internalStation &lt; 0">
                    <xsl:text>-</xsl:text>
                </xsl:when>
                <xsl:otherwise>
                    <xsl:text>+</xsl:text>
                </xsl:otherwise>
            </xsl:choose>
            <xsl:value-of select="substring($fmtEndStation, 1, 16)"/>
            <xsl:text> 71....+0000000000000EOP 72....+0000000000000NON 83..</xsl:text>
            <xsl:value-of select="$unit"/>
            <xsl:choose>
                <xsl:when test="VerticalEnd/@elevation &lt; 0"><xsl:text>-</xsl:text></xsl:when>
                <xsl:otherwise><xsl:text>+</xsl:text></xsl:otherwise>
            </xsl:choose>
            <xsl:choose>
                <xsl:when test="string-length($fmtEndElevation) &gt; 16">
                    <xsl:value-of select="substring($fmtEndElevation, (string-length($fmtEndElevation) - 15), 16)"/>
                </xsl:when>
                <xsl:otherwise>
                    <xsl:value-of select="$fmtEndElevation"/>
                </xsl:otherwise>
            </xsl:choose>
            <xsl:text>&#xd;</xsl:text>
        </xsl:if>
    </xsl:template>
    <!-- Vertical Alignment Symmetrical Parabola Data -->
    <xsl:template match="VerticalSymmetricalParabola">
        <!-- Find absolute value -->
        <xsl:variable name="absStartStation">
            <xsl:choose>
                <xsl:when test="VerticalStart/station/@internalStation &lt; 0">
                    <xsl:value-of select="number(-1 * VerticalStart/station/@internalStation)"/>
                </xsl:when>
                <xsl:otherwise>
                    <xsl:value-of select="number(VerticalStart/station/@internalStation)"/>
                </xsl:otherwise>
            </xsl:choose>
        </xsl:variable>
        <xsl:variable name="absStartElevation">
            <xsl:choose>
                <xsl:when test="VerticalStart/@elevation &lt; 0">
                    <xsl:value-of select="number(-1 * VerticalStart/@elevation)"/>
                </xsl:when>
                <xsl:otherwise><xsl:value-of select="number(VerticalStart/@elevation)"/></xsl:otherwise>
            </xsl:choose>
        </xsl:variable>
        <xsl:variable name="absEndStation">
            <xsl:choose>
                <xsl:when test="VerticalEnd/station/@internalStation &lt; 0">
                    <xsl:value-of select="number(-1 * VerticalEnd/station/@internalStation)"/>
                </xsl:when>
                <xsl:otherwise>
                    <xsl:value-of select="number(VerticalEnd/station/@internalStation)"/>
                </xsl:otherwise>
            </xsl:choose>
        </xsl:variable>
        <xsl:variable name="absEndElevation">
            <xsl:choose>
                <xsl:when test="VerticalEnd/@elevation &lt; 0">
                    <xsl:value-of select="number(-1 * VerticalEnd/@elevation)"/>
                </xsl:when>
                <xsl:otherwise><xsl:value-of select="number(VerticalEnd/@elevation)"/></xsl:otherwise>
            </xsl:choose>
        </xsl:variable>
        <!-- Set decimal precision and pad with leading zeros -->
        <xsl:variable name="fmtStartStation" select="inr:zeroDoubleFormat(number($absStartStation), 4, 16)"/>
        <xsl:variable name="fmtStartElevation" select="inr:zeroDoubleFormat(number($absStartElevation), 4, 16)"/>
        <xsl:variable name="fmtEndStation" select="inr:zeroDoubleFormat(number($absEndStation), 4, 16)"/>
        <xsl:variable name="fmtEndElevation" select="inr:zeroDoubleFormat(number($absEndElevation), 4, 16)"/>
        <xsl:text>*11....</xsl:text>
        <xsl:choose>
            <xsl:when test="VerticalStart/station/@internalStation &lt; 0"><xsl:text>-</xsl:text></xsl:when>
            <xsl:otherwise><xsl:text>+</xsl:text></xsl:otherwise>
        </xsl:choose>
        <xsl:value-of select="substring($fmtStartStation, 1, 16)"/>
        <xsl:text> 71....+00000000PARABOLA 72....</xsl:text>
        <xsl:choose>
            <xsl:when test="@midOrdinate &lt; 0"><xsl:text>-</xsl:text></xsl:when>
            <xsl:otherwise><xsl:text>+</xsl:text></xsl:otherwise>
        </xsl:choose>
        <xsl:value-of select="inr:zeroDoubleFormat(number(@kValue * 100), 4, 16)"/>
        <xsl:text> 83..</xsl:text>
        <xsl:value-of select="$unit"/>
        <xsl:choose>
            <xsl:when test="VerticalStart/@elevation &lt; 0"><xsl:text>-</xsl:text></xsl:when>
            <xsl:otherwise><xsl:text>+</xsl:text>
            </xsl:otherwise>
        </xsl:choose>
        <xsl:choose>
            <xsl:when test="string-length($fmtStartElevation) &gt; 16">
                <xsl:value-of select="substring($fmtStartElevation, (string-length($fmtStartElevation) - 15), 16)"/>
            </xsl:when>
            <xsl:otherwise>
                <xsl:value-of select="$fmtStartElevation"/>
            </xsl:otherwise>
        </xsl:choose>
        <xsl:text>&#xd;</xsl:text>
        <xsl:if test="position() = last()">
            <xsl:text>*11....</xsl:text>
            <xsl:choose>
                <xsl:when test="VerticalEnd/station/@internalStation &lt; 0">
                    <xsl:text>-</xsl:text>
                </xsl:when>
                <xsl:otherwise>
                    <xsl:text>+</xsl:text>
                </xsl:otherwise>
            </xsl:choose>
            <xsl:value-of select="substring($fmtEndStation, 1, 16)"/>
            <xsl:text> 71....+0000000000000EOP 72....+0000000000000NON 83..</xsl:text>
            <xsl:value-of select="$unit"/>
            <xsl:choose>
                <xsl:when test="VerticalEnd/@elevation &lt; 0"><xsl:text>-</xsl:text></xsl:when>
                <xsl:otherwise><xsl:text>+</xsl:text></xsl:otherwise>
            </xsl:choose>
            <xsl:choose>
                <xsl:when test="string-length($fmtEndElevation) &gt; 16">
                    <xsl:value-of select="substring($fmtEndElevation, (string-length($fmtEndElevation) - 15), 16)"/>
                </xsl:when>
                <xsl:otherwise>
                    <xsl:value-of select="$fmtEndElevation"/>
                </xsl:otherwise>
            </xsl:choose>
            <xsl:text>&#xd;</xsl:text>
        </xsl:if>
    </xsl:template>
    <!-- Vertical Alignment Unsymmetrical Parabola Data -->
    <xsl:template match="VerticalUnsymmetricalParabola">
        <!-- Find absolute value -->
        <xsl:variable name="absStartStation">
            <xsl:choose>
                <xsl:when test="VerticalStart/station/@internalStation &lt; 0">
                    <xsl:value-of select="number(-1 * VerticalStart/station/@internalStation)"/>
                </xsl:when>
                <xsl:otherwise>
                    <xsl:value-of select="number(VerticalStart/station/@internalStation)"/>
                </xsl:otherwise>
            </xsl:choose>
        </xsl:variable>
        <xsl:variable name="absStartElevation">
            <xsl:choose>
                <xsl:when test="VerticalStart/@elevation &lt; 0">
                    <xsl:value-of select="number(-1 * VerticalStart/@elevation)"/>
                </xsl:when>
                <xsl:otherwise><xsl:value-of select="number(VerticalStart/@elevation)"/></xsl:otherwise>
            </xsl:choose>
        </xsl:variable>
        <xsl:variable name="absPVCCStation">
            <xsl:choose>
                <xsl:when test="PVCC/station/@internalStation &lt; 0">
                    <xsl:value-of select="number(-1 * PVCC/station/@internalStation)"/>
                </xsl:when>
                <xsl:otherwise>
                    <xsl:value-of select="number(PVCC/station/@internalStation)"/>
                </xsl:otherwise>
            </xsl:choose>
        </xsl:variable>
        <xsl:variable name="absPVCCElevation">
            <xsl:choose>
                <xsl:when test="PVCC/@elevation &lt; 0">
                    <xsl:value-of select="number(-1 * PVCC/@elevation)"/>
                </xsl:when>
                <xsl:otherwise><xsl:value-of select="number(PVCC/@elevation)"/></xsl:otherwise>
            </xsl:choose>
        </xsl:variable>
        <xsl:variable name="absEndStation">
            <xsl:choose>
                <xsl:when test="VerticalEnd/station/@internalStation &lt; 0">
                    <xsl:value-of select="number(-1 * VerticalEnd/station/@internalStation)"/>
                </xsl:when>
                <xsl:otherwise>
                    <xsl:value-of select="number(VerticalEnd/station/@internalStation)"/>
                </xsl:otherwise>
            </xsl:choose>
        </xsl:variable>
        <xsl:variable name="absEndElevation">
            <xsl:choose>
                <xsl:when test="VerticalEnd/@elevation &lt; 0">
                    <xsl:value-of select="number(-1 * VerticalEnd/@elevation)"/>
                </xsl:when>
                <xsl:otherwise><xsl:value-of select="number(VerticalEnd/@elevation)"/></xsl:otherwise>
            </xsl:choose>
        </xsl:variable>
        <!-- Set decimal precision and pad with leading zeros -->
        <xsl:variable name="fmtStartStation" select="inr:zeroDoubleFormat(number($absStartStation), 4, 16)"/>
        <xsl:variable name="fmtStartElevation" select="inr:zeroDoubleFormat(number($absStartElevation), 4, 16)"/>
        <xsl:variable name="fmtPVCCStation" select="inr:zeroDoubleFormat(number($absPVCCStation), 4, 16)"/>
        <xsl:variable name="fmtPVCCElevation" select="inr:zeroDoubleFormat(number($absPVCCElevation), 4, 16)"/>
        <xsl:variable name="fmtEndStation" select="inr:zeroDoubleFormat(number($absEndStation), 4, 16)"/>
        <xsl:variable name="fmtEndElevation" select="inr:zeroDoubleFormat(number($absEndElevation), 4, 16)"/>
        <xsl:text>*11....</xsl:text>
        <xsl:choose>
            <xsl:when test="VerticalStart/station/@internalStation &lt; 0"><xsl:text>-</xsl:text></xsl:when>
            <xsl:otherwise><xsl:text>+</xsl:text></xsl:otherwise>
        </xsl:choose>
        <xsl:value-of select="substring($fmtStartStation, 1, 16)"/>
        <xsl:text> 71....+00000000PARABOLA 72....</xsl:text>
        <xsl:choose>
            <xsl:when test="@midOrdinate &lt; 0"><xsl:text>-</xsl:text></xsl:when>
            <xsl:otherwise><xsl:text>+</xsl:text></xsl:otherwise>
        </xsl:choose>
        <xsl:value-of select="inr:zeroDoubleFormat(number(@startKValue * 100), 4, 16)"/>
        <xsl:text> 83..</xsl:text>
        <xsl:value-of select="$unit"/>
        <xsl:choose>
            <xsl:when test="VerticalStart/@elevation &lt; 0"><xsl:text>-</xsl:text></xsl:when>
            <xsl:otherwise><xsl:text>+</xsl:text>
            </xsl:otherwise>
        </xsl:choose>
        <xsl:choose>
            <xsl:when test="string-length($fmtStartElevation) &gt; 16">
                <xsl:value-of select="substring($fmtStartElevation, (string-length($fmtStartElevation) - 15), 16)"/>
            </xsl:when>
            <xsl:otherwise>
                <xsl:value-of select="$fmtStartElevation"/>
            </xsl:otherwise>
        </xsl:choose>
        <xsl:text>&#xd;</xsl:text>
        <xsl:text>*11....</xsl:text>
        <xsl:choose>
            <xsl:when test="PVCC/station/@internalStation &lt; 0"><xsl:text>-</xsl:text></xsl:when>
            <xsl:otherwise><xsl:text>+</xsl:text></xsl:otherwise>
        </xsl:choose>
        <xsl:value-of select="substring($fmtPVCCStation, 1, 16)"/>
        <xsl:text> 71....+00000000PARABOLA 72....</xsl:text>
        <xsl:choose>
            <xsl:when test="@midOrdinate &lt; 0"><xsl:text>-</xsl:text></xsl:when>
            <xsl:otherwise><xsl:text>+</xsl:text></xsl:otherwise>
        </xsl:choose>
        <xsl:value-of select="inr:zeroDoubleFormat(number(@endKValue * 100), 4, 16)"/>
        <xsl:text> 83..</xsl:text>
        <xsl:value-of select="$unit"/>
        <xsl:choose>
            <xsl:when test="PVCC/@elevation &lt; 0"><xsl:text>-</xsl:text></xsl:when>
            <xsl:otherwise><xsl:text>+</xsl:text>
            </xsl:otherwise>
        </xsl:choose>
        <xsl:value-of select="substring($fmtPVCCElevation, 1, 16)"/>
        <xsl:text>&#xd;</xsl:text>
        <xsl:if test="position() = last()">
            <xsl:text>*11....</xsl:text>
            <xsl:choose>
                <xsl:when test="VerticalEnd/station/@internalStation &lt; 0">
                    <xsl:text>-</xsl:text>
                </xsl:when>
                <xsl:otherwise>
                    <xsl:text>+</xsl:text>
                </xsl:otherwise>
            </xsl:choose>
            <xsl:value-of select="substring($fmtEndStation, 1, 16)"/>
            <xsl:text> 71....+0000000000000EOP 72....+0000000000000NON 83..</xsl:text>
            <xsl:value-of select="$unit"/>
            <xsl:choose>
                <xsl:when test="VerticalEnd/@elevation &lt; 0"><xsl:text>-</xsl:text></xsl:when>
                <xsl:otherwise><xsl:text>+</xsl:text></xsl:otherwise>
            </xsl:choose>
            <xsl:choose>
                <xsl:when test="string-length($fmtEndElevation) &gt; 16">
                    <xsl:value-of select="substring($fmtEndElevation, (string-length($fmtEndElevation) - 15), 16)"/>
                </xsl:when>
                <xsl:otherwise>
                    <xsl:value-of select="$fmtEndElevation"/>
                </xsl:otherwise>
            </xsl:choose>
            <xsl:text>&#xd;</xsl:text>
        </xsl:if>
    </xsl:template>
    <!-- Vertical Alignment Circular Data -->
    <xsl:template match="VerticalCircle">
        <!-- Find absolute value -->
        <xsl:variable name="absStartStation">
            <xsl:choose>
                <xsl:when test="VerticalStart/station/@internalStation &lt; 0">
                    <xsl:value-of select="number(-1 * VerticalStart/station/@internalStation)"/>
                </xsl:when>
                <xsl:otherwise>
                    <xsl:value-of select="number(VerticalStart/station/@internalStation)"/>
                </xsl:otherwise>
            </xsl:choose>
        </xsl:variable>
        <xsl:variable name="absStartElevation">
            <xsl:choose>
                <xsl:when test="VerticalStart/@elevation &lt; 0">
                    <xsl:value-of select="number(-1 * VerticalStart/@elevation)"/>
                </xsl:when>
                <xsl:otherwise><xsl:value-of select="number(VerticalStart/@elevation)"/></xsl:otherwise>
            </xsl:choose>
        </xsl:variable>
        <xsl:variable name="absEndStation">
            <xsl:choose>
                <xsl:when test="VerticalEnd/station/@internalStation &lt; 0">
                    <xsl:value-of select="number(-1 * VerticalEnd/station/@internalStation)"/>
                </xsl:when>
                <xsl:otherwise>
                    <xsl:value-of select="number(VerticalEnd/station/@internalStation)"/>
                </xsl:otherwise>
            </xsl:choose>
        </xsl:variable>
        <xsl:variable name="absEndElevation">
            <xsl:choose>
                <xsl:when test="VerticalEnd/@elevation &lt; 0">
                    <xsl:value-of select="number(-1 * VerticalEnd/@elevation)"/>
                </xsl:when>
                <xsl:otherwise><xsl:value-of select="number(VerticalEnd/@elevation)"/></xsl:otherwise>
            </xsl:choose>
        </xsl:variable>
        <xsl:variable name="absRadius">
            <xsl:choose>
                <xsl:when test="@radius &lt; 0"><xsl:value-of select="number(-1 * @radius)"/></xsl:when>
                <xsl:otherwise><xsl:value-of select="number(@radius)"/></xsl:otherwise>
            </xsl:choose>
        </xsl:variable>
        <!-- Set decimal precision and pad with leading zeros -->
        <xsl:variable name="fmtStartStation" select="inr:zeroDoubleFormat(number($absStartStation), 4, 16)"/>
        <xsl:variable name="fmtStartElevation" select="inr:zeroDoubleFormat(number($absStartElevation), 4, 16)"/>
        <xsl:variable name="fmtEndStation" select="inr:zeroDoubleFormat(number($absEndStation), 4, 16)"/>
        <xsl:variable name="fmtEndElevation" select="inr:zeroDoubleFormat(number($absEndElevation), 4, 16)"/>
        <xsl:variable name="fmtRadius" select="inr:zeroDoubleFormat(number($absRadius), 4, 16)"/>
        <xsl:text>*11....</xsl:text>
        <xsl:choose>
            <xsl:when test="VerticalStart/station/@internalStation &lt; 0">
                <xsl:text>-</xsl:text>
            </xsl:when>
            <xsl:otherwise>
                <xsl:text>+</xsl:text>
            </xsl:otherwise>
        </xsl:choose>
        <xsl:value-of select="substring($fmtStartStation, 1, 16)"/>
        <xsl:text> 71....+00000000000CURVE 72....</xsl:text>
        <!-- RoadPlus uses positive for sag curves and negative for crest curves, which is opposite of -->
        <!-- how InRoads stores it, so swap the sign -->
        <xsl:choose>
            <xsl:when test="@radius &gt; 0">
                <xsl:text>-</xsl:text>
            </xsl:when>
            <xsl:otherwise>
                <xsl:text>+</xsl:text>
            </xsl:otherwise>
        </xsl:choose>
        <xsl:value-of select="substring($fmtRadius, 1, 16)"/>
        <xsl:text> 83..</xsl:text>
        <xsl:value-of select="$unit"/>
        <xsl:choose>
            <xsl:when test="VerticalStart/@elevation &lt; 0"><xsl:text>-</xsl:text></xsl:when>
            <xsl:otherwise><xsl:text>+</xsl:text></xsl:otherwise>
        </xsl:choose>
        <xsl:choose>
            <xsl:when test="string-length($fmtStartElevation) &gt; 16">
                <xsl:value-of select="substring($fmtStartElevation, (string-length($fmtStartElevation) - 15), 16)"/>
            </xsl:when>
            <xsl:otherwise>
                <xsl:value-of select="$fmtStartElevation"/>
            </xsl:otherwise>
        </xsl:choose>
        <xsl:text>&#xd;</xsl:text>
        <xsl:if test="position() = last()">
            <xsl:text>*11....</xsl:text>
            <xsl:choose>
                <xsl:when test="VerticalEnd/station/@internalStation &lt; 0">
                    <xsl:text>-</xsl:text>
                </xsl:when>
                <xsl:otherwise>
                    <xsl:text>+</xsl:text>
                </xsl:otherwise>
            </xsl:choose>
            <xsl:value-of select="substring($fmtEndStation, 1, 16)"/>
            <xsl:text> 71....+0000000000000EOP 72....+0000000000000NON 83..</xsl:text>
            <xsl:value-of select="$unit"/>
            <xsl:choose>
                <xsl:when test="VerticalEnd/@elevation &lt; 0"><xsl:text>-</xsl:text></xsl:when>
                <xsl:otherwise><xsl:text>+</xsl:text></xsl:otherwise>
            </xsl:choose>
            <xsl:choose>
                <xsl:when test="string-length($fmtEndElevation) &gt; 16">
                    <xsl:value-of select="substring($fmtEndElevation, (string-length($fmtEndElevation) - 15), 16)"/>
                </xsl:when>
                <xsl:otherwise>
                    <xsl:value-of select="$fmtEndElevation"/>
                </xsl:otherwise>
            </xsl:choose>
            <xsl:text>&#xd;</xsl:text>
        </xsl:if>
    </xsl:template>
    <xsl:template name="StyleSheetHelp">
        <xsl:text>Notes&#xd;&#xd;</xsl:text>
        <xsl:text>    You must include at least one horizontal alignment in&#xd;</xsl:text>
        <xsl:text>    the Include field on the Tools &gt; XML Reports &gt;&#xd;</xsl:text>
        <xsl:text>    Geometry command to get results from this report.&#xd;&#xd;</xsl:text>
        <xsl:text>    You must toggle on the Include Vertical Alignments&#xd;</xsl:text>
        <xsl:text>    option and select either All or Active.&#xd;&#xd;</xsl:text>
        <xsl:text>    This style sheet reports coordinates and distances to&#xd;</xsl:text>
        <xsl:text>    the nearest 1/10000th foot or the nearest 1/10000th&#xd;</xsl:text>
        <xsl:text>    meter, depending on the units stored in the XML data&#xd;</xsl:text>
        <xsl:text>    file.  If the resulting coordinate is too long to fit&#xd;</xsl:text>
        <xsl:text>    in the field, only the last 16 digits (including the&#xd;</xsl:text>
        <xsl:text>    decimal portion) will be retained.  However, stations,&#xd;</xsl:text>
        <xsl:text>    distances, radii, etc will retain the first 16 digits&#xd;</xsl:text>
        <xsl:text>    (truncating the decimal portion.)&#xd;&#xd;</xsl:text>
        <xsl:text>    If you wish to use a different precision, you must&#xd;</xsl:text>
        <xsl:text>    change the "unit" variable near the top of the style&#xd;</xsl:text>
        <xsl:text>    sheet as well as the precision value wherever the&#xd;</xsl:text>
        <xsl:text>    "zeroDoubleFormat" function is called.&#xd;&#xd;</xsl:text>
        <xsl:text>    Most style sheets in the DataCollection directory do&#xd;</xsl:text>
        <xsl:text>    not honor Tools &gt; Format Options with the exception of&#xd;</xsl:text>
        <xsl:text>    precision, where practical.&#xd;&#xd;</xsl:text>
        <xsl:text>Copyright 2006 Bentley Systems, Inc&#xd;</xsl:text>
    </xsl:template>
    <msxsl:script implements-prefix="inr" language="JScript">
        <![CDATA[
            // This Function formats a string with a length, padding with leading zeros
            // strString - String to get formated
            // nLength - Length of returned string
            function zeroFormat( strString, nLength )
            {
                var nBlanks = nLength - strString.length;
                for( var i = 0; i < nBlanks; i++ )
                    strString = "0" + strString;
                return strString;
            }
            // This function converts a double to string and sets precision and length, padding with leading zeros
            // dNum - Double to be converted to String
            // nPrecision - the number of digits after the decimal point
            // nLength - Length of returned string
            function zeroDoubleFormat( dNum, nPrecision, nLength )
            {
                var nRoundTo = Math.pow( 10, nPrecision );
                var strResult = ( Math.round( nRoundTo * dNum ) ).toString();
                var nCount = strResult.length - strResult.indexOf( "." ) - 1;
                for( var j = 0; j < (nPrecision - nCount); j++ )
                    strResult += "0";
                var nBlanks = nLength - strResult.length;
                for( var i = 0; i < nBlanks; i++ )
                    strResult = "0" + strResult;
                return strResult;
            }
        ]]>
    </msxsl:script>
</xsl:stylesheet>
