<?xml version="1.0" encoding="UTF-8"?>
<xsl:stylesheet version="1.1" xmlns:xsl="http://www.w3.org/1999/XSL/Transform" xmlns:fo="http://www.w3.org/1999/XSL/Format" xmlns:msxsl="urn:schemas-microsoft-com:xslt" xmlns:inr="http://mycompany.com/mynamespace">
    <xsl:include href="../format.xsl"/>
    <xsl:param name="xslRootDirectory" select="inr:xslRootDirectory"/>
    <xsl:variable name="uniqueSurfaceName" select="//CrossSectionSurfaces/CrossSectionSurface[not (@name = preceding::CrossSectionSurface/@name)]/@name"/>
    <xsl:variable name="pointsPerLine" select="2"/>

    <xsl:template match="/">
        <xsl:variable name="gridOut" select="inr:SetGridOut(number(InRoads/@outputGridScaleFactor))"/>
        <html>
            <head>
                <link rel="stylesheet" type="text/css" href="{$xslRootDirectory}/_Themes/engineer/theme.css"/>
                <title lang="en">Cross Section Simple Cross Slope Report</title>
            </head>
            <body>
                <xsl:choose>
                    <xsl:when test="$xslShowHelp = 'true'">
                        <xsl:call-template name="StyleSheetHelp"/>
                    </xsl:when>
                    <xsl:otherwise>
                        <xsl:for-each select="InRoads">
                            <center>
                                <h2 lang="en">Cross Section Simple Cross Slope Report</h2>
                                <p lang="en">
                                    Report Created:&#xa0; <xsl:value-of select="inr:date()"/><br />
                                    Time:&#xa0; <xsl:value-of select="inr:time()"/>
                                </p>
                            </center>

                            <xsl:for-each select="CrossSectionSet">
                                <table class="margin" cellpadding="2" width="90%">
                                    <tbody>
                                        <tr>
                                            <th align="right" lang="en">Set Name:&#xa0; </th>
                                            <td align="left" colspan="2">
                                                <xsl:value-of select="@setName"/>
                                            </td>
                                        </tr>
                                        <tr>
                                            <th align="right" lang="en">Alignment Name:&#xa0; </th>
                                            <td align="left" colspan="2">
                                                <xsl:value-of select="@alignmentName"/>
                                            </td>
                                        </tr>
                                        <tr>
                                            <th align="right" lang="en" style="font-size: 80%">Input Grid Factor:&#xa0; </th>
                                            <td align="left" style="font-size: 80%">
                                                <xsl:value-of select="../@inputGridScaleFactor" />
                                            </td>
                                            <td align="right" lang="en" style="font-size: 80%">
                                                <strong>Note:&#xa0; </strong>All units in this report are in
                                                <xsl:if test="//@linearUnits = 'Imperial'">feet</xsl:if>
                                                <xsl:if test="//@linearUnits = 'Metric'">meters</xsl:if>
                                                unless specified otherwise.
                                            </td>
                                        </tr>
                                    </tbody>
                                </table>
                                <hr/>

                                <table width="80%">
                                    <xsl:for-each select="$uniqueSurfaceName">
                                        <tr>
                                            <th align="left" lang="en">Surface:&#xa0; </th>
                                            <td align="left" colspan="2">
                                                <xsl:value-of select="."/>
                                            </td>
                                        </tr>
                                        <tr>
                                            <th class="underline" lang="en">Station</th>
                                            <th class="underline" lang="en">
                                                Ground<br/>Elevation
                                            </th>
                                            <th class="underline" lang="en">
                                                Design<br/>Elevation
                                            </th>
                                            <th class="underline" lang="en">Northing</th>
                                            <th class="underline" lang="en">Easting</th>
                                            <th class="underline" lang="en">Gradient</th>

                                            <xsl:if test="$pointsPerLine = '2'">
                                                <th class="underline" lang="en">
                                                    Left<br/>Cross Slope
                                                </th>
                                                <th class="underline" lang="en">
                                                    Right<br/>Cross Slope
                                                </th>
                                            </xsl:if>
                                            <xsl:if test="$pointsPerLine != '2'">
                                                <xsl:call-template name="colHead">
                                                    <xsl:with-param name="count" select="$pointsPerLine"/>
                                                </xsl:call-template>
                                            </xsl:if>
                                        </tr>
                                        <xsl:for-each select="//CrossSectionSurface[@name = current()]">
                                            <tr>
                                                <td align="right" nowrap="nowrap">
                                                    <xsl:value-of select="inr:stationFormat(number(../../Station/@externalStation), $xslStationFormat,$xslStationPrecision, string(../../Station/@externalStationName))"/>
                                                </td>

                                                <xsl:variable name="smallWidth" select="0.0001"/>
                                                <xsl:variable name="smallNegative" select="-0.00001"/>
                                                <xsl:variable name="smallPositive" select="0.00001"/>

                                                <xsl:for-each select="CrossSectionPoints/CrossSectionPoint">
                                                    <xsl:if test="following-sibling::*[1]/@offset - @offset &gt; $smallWidth">
                                                        <xsl:if test="@offset &gt; $smallNegative">
                                                            <xsl:if test="@offset &lt; $smallPositive">
                                                                <td align="right" nowrap="nowrap">
                                                                    <xsl:value-of select="inr:elevationFormat(number(@elevation - @cutFillHeight), $xslElevationPrecision)"/>
                                                                </td>
                                                            </xsl:if>
                                                        </xsl:if>
                                                    </xsl:if>
                                                </xsl:for-each>

                                                <td align="right" nowrap="nowrap">
                                                    <xsl:value-of select="inr:elevationFormat(number(../../@elevation), $xslElevationPrecision)"/>
                                                </td>
                                                <td align="right" nowrap="nowrap">
                                                    <xsl:value-of select="inr:northingFormat(number(../../@northing), $xslNorthingPrecision)"/>
                                                </td>
                                                <td align="right" nowrap="nowrap">
                                                    <xsl:value-of select="inr:eastingFormat(number(../../@easting), $xslEastingPrecision)"/>
                                                </td>
                                                <td align="right" nowrap="nowrap">
                                                    <xsl:value-of select="inr:gradeFormat(number(../../@longitudinalGrade), $xslGradeFormat, $xslGradePrecision)"/>
                                                </td>

                                                <xsl:for-each select="CrossSectionFeatures/CrossSectionFeature">
                                                    <xsl:if test="position() != last()">
                                                        <xsl:variable name="vertical" select="CrossSectionFeaturePoints/CrossSectionFeaturePoint/@elevation - following-sibling::*[1]/CrossSectionFeaturePoints/CrossSectionFeaturePoint/@elevation"/>
                                                        <xsl:variable name="horizontal" select="CrossSectionFeaturePoints/CrossSectionFeaturePoint/@offset - following-sibling::*[1]/CrossSectionFeaturePoints/CrossSectionFeaturePoint/@offset"/>
                                                        <xsl:variable name="crossSlope" select="$vertical div $horizontal"/>
                                                        <xsl:variable name="zero" select="0.0"/>
                                                        
                                                        <td align="right" nowrap="nowrap">
                                                            <xsl:choose>
                                                                <xsl:when test="@offset &lt; $zero">
                                                                    <xsl:value-of select="inr:gradeFormat( -1 * $crossSlope, $xslGradeFormat, $xslGradePrecision)"/>
                                                                </xsl:when>
                                                                <xsl:otherwise>
                                                                    <xsl:value-of select="inr:gradeFormat(      $crossSlope, $xslGradeFormat, $xslGradePrecision)"/>
                                                                </xsl:otherwise>
                                                            </xsl:choose>
                                                        </td>
                                                    </xsl:if>
                                                </xsl:for-each>
                                            </tr>
                                        </xsl:for-each>
                                        <tr>
                                            <td colspan="3">&#xa0;</td>
                                        </tr>
                                    </xsl:for-each>
                                </table>
                            </xsl:for-each>
                        </xsl:for-each>
                    </xsl:otherwise>
                </xsl:choose>
            </body>
        </html>
    </xsl:template>

    <xsl:template name="colHead">
        <xsl:param name="count"/>
        <xsl:if test="$count != 0">
            <th class="underline" lang="en">Cross Slope</th>
            <xsl:call-template name="colHead">
                <xsl:with-param name="count" select="$count - 1"/>
            </xsl:call-template>
        </xsl:if>
    </xsl:template>

    <xsl:template name="StyleSheetHelp">
        <div class="section1">
            <h4 lang="en">Notes</h4>
            <p class="normal1" lang="en">
                You must use Cross Section Report and include the left and right edge of pavement and centerline features.
            </p>
            <p class="small" lang="en">
                <em>&#xa9; 2013 Bentley Systems, Inc</em>
            </p>
        </div>
    </xsl:template>
</xsl:stylesheet>
