<?xml version="1.0" encoding="UTF-8"?>
<xsl:stylesheet version="1.1" xmlns:xsl="http://www.w3.org/1999/XSL/Transform" xmlns:fo="http://www.w3.org/1999/XSL/Format" xmlns:msxsl="urn:schemas-microsoft-com:xslt" xmlns:inr="http://mycompany.com/mynamespace">
    <xsl:include href="../format.xsl"/>
    <xsl:param name="xslRootDirectory" select="inr:xslRootDirectory"/>
    <!-- Horizontal and Vertical Alignment Review Report -->
    <xsl:template match="/">
        <xsl:variable name="gridOut" select="inr:SetGridOut(number(InRoads/@outputGridScaleFactor))"/>
        <html>
            <head>
                <link rel="stylesheet" type="text/css" href="{$xslRootDirectory}/_Themes/engineer/theme.css"/>
                <!-- Title displayed in browser Title Bar -->
                <title lang="en">Horizontal and Vertical Alignment Review Report</title>
            </head>
            <body>
                <xsl:choose>
                    <xsl:when test="$xslShowHelp = 'true'">
                        <xsl:call-template name="StyleSheetHelp"/>
                    </xsl:when>
                    <xsl:otherwise>
                        <xsl:for-each select="InRoads">
                            <center>
                                <!-- Report Title -->
                                <h2 lang="en">Horizontal and Vertical Alignment Review Report</h2>
                                <p lang="en">
                                    Report Created:&#xa0; <xsl:value-of select="inr:date()"/><br/>
                                    Time:&#xa0; <xsl:value-of select="inr:time()"/>
                                </p>
                            </center>
                            <!-- Project Data -->
                            <xsl:for-each select="GeometryProject">
                                <table class="margin" cellpadding="2" width="90%">
                                    <tbody>
                                        <tr>
                                            <th align="right" lang="en">Project:&#xa0; </th>
                                            <td align="left" colspan="2"><xsl:value-of select="@name"/></td>
                                        </tr>
                                        <tr>
                                            <th align="right" lang="en">Description:&#xa0; </th>
                                            <td align="left" colspan="2"><xsl:value-of select="@description"/></td>
                                        </tr>
                                        <tr>
                                            <th align="right" lang="en">File Name:&#xa0; </th>
                                            <td align="left" colspan="2"><xsl:value-of select="@file"/></td>
                                        </tr>
                                        <tr>
                                            <th align="right" lang="en">Last Revised:&#xa0; </th>
                                            <td align="left" colspan="2"><xsl:value-of select="concat(@lastRevisedBy, '  ', @lastRevisedDate)"/></td>
                                        </tr>
                                        <tr>
                                            <th align="right" lang="en" style="font-size: 80%">Input Grid Factor:&#xa0; </th>
                                            <td align="left" style="font-size: 80%"><xsl:value-of select="../@inputGridScaleFactor" /></td>
                                            <td align="right" lang="en" style="font-size: 80%">
                                                <strong>Note:&#xa0; </strong>All units in this report are in
                                                <xsl:if test="//@linearUnits = 'Imperial'">feet</xsl:if>
                                                <xsl:if test="//@linearUnits = 'Metric'">meters</xsl:if>
                                                unless specified otherwise.
                                            </td>
                                        </tr>
                                    </tbody>
                                </table>
                                <hr/>
                                <!-- Horizontal Alignment Data -->
                                <table class="margin" cellpadding="2" width="80%">
                                    <colgroup span="5">
                                        <col width="18%"/>
                                        <col width="13%"/>
                                        <col width="25%"/>
                                        <col width="22%"/>
                                        <col width="22%"/>
                                    </colgroup>
                                    <xsl:for-each select="HorizontalAlignment">
                                        <tbody>
                                            <tr>
                                                <th align="right" colspan="2" lang="en"><br/>Horizontal Alignment:&#xa0;</th>
                                                <td align="left" colspan="3" valign="bottom"><xsl:value-of select="@name"/></td>
                                            </tr>
                                            <tr>
                                                <th align="right" colspan="2" lang="en">Horizontal Description:&#xa0;</th>
                                                <td align="left" colspan="3"><xsl:value-of select="@description"/></td>
                                            </tr>
                                            <tr>
                                                <th align="right" colspan="2" lang="en">Horizontal Style:&#xa0;</th>
                                                <td align="left" colspan="3"><xsl:value-of select="@style"/></td>
                                            </tr>
                                            <tr>
                                                <th colspan="2"/>
                                                <th class="underline" align="right" lang="en">Station</th>
                                                <th class="underline" align="right" lang="en">Northing</th>
                                                <th class="underline" align="right" lang="en">Easting</th>
                                            </tr>
                                            <xsl:apply-templates mode="horizontal"/>
                                            <!-- Vertical Alignment Data -->
                                            <xsl:for-each select="VerticalAlignment">
                                                <tr>
                                                    <th align="right" colspan="2" lang="en"><br/>Vertical Alignment:&#xa0;</th>
                                                    <td align="left" colspan="3" valign="bottom"><xsl:value-of select="@name"/></td>
                                                </tr>
                                                <tr>
                                                    <th align="right" colspan="2" lang="en">Vertical Description:&#xa0;</th>
                                                    <td align="left" colspan="3"><xsl:value-of select="@description"/></td>
                                                </tr>
                                                <tr>
                                                    <th align="right" colspan="2" lang="en">Vertical Style:&#xa0;</th>
                                                    <td align="left" colspan="3"><xsl:value-of select="@style"/></td>
                                                </tr>
                                                <tr>
                                                    <th colspan="2"/>
                                                    <th class="underline" align="right" lang="en">Station</th>
                                                    <th class="underline" align="right" lang="en">Elevation</th>
                                                    <th/>
                                                </tr>
                                                <xsl:apply-templates mode="vertical"/>
                                            </xsl:for-each>
                                        </tbody>
                                    </xsl:for-each>
                                </table>
                            </xsl:for-each>
                        </xsl:for-each>
                    </xsl:otherwise>
                </xsl:choose>
            </body>
        </html>
    </xsl:template>
    <!-- Horizontal Alignment Linear Data -->
    <xsl:template match="HorizontalLine" mode="horizontal">
        <tr>
            <td align="left" colspan="5" lang="en"><br/>Element: Linear</td>
        </tr>
        <tr>
            <td align="right"><xsl:value-of select="Start/@type"/></td>
            <td align="right">( <xsl:value-of select="Start/@name"/> )</td>
            <td align="right">
                <xsl:value-of select="inr:stationFormat(number(Start/station/@externalStation), $xslStationFormat,$xslStationPrecision, string(Start/station/@externalStationName))"/>
            </td>
            <td align="right">
                <xsl:value-of select="inr:northingFormat(number(Start/@northing), $xslNorthingPrecision)"/>
            </td>
            <td align="right">
                <xsl:value-of select="inr:eastingFormat(number(Start/@easting), $xslEastingPrecision)"/>
            </td>
        </tr>
        <xsl:if test="StationEquation">
            <xsl:for-each select="StationEquation">
                <tr>
                    <td align="right" colspan="2" lang="en">EQNBK</td>
                    <td align="right">
                        <xsl:value-of select="inr:stationFormat(number(@backStation), $xslStationFormat, $xslStationPrecision, string(StationEquation/@backEquation))"/>
                    </td>
                    <td align="right">
                        <xsl:value-of select="inr:northingFormat(number(GeometryPoint/@northing), $xslNorthingPrecision)"/>
                    </td>
                    <td align="right">
                        <xsl:value-of select="inr:eastingFormat(number(GeometryPoint/@easting), $xslEastingPrecision)"/>
                    </td>
                </tr>
                <tr>
                    <td align="right" colspan="2" lang="en">EQNAHD</td>
                    <td align="right">
                        <xsl:value-of select="inr:stationFormat(number(@aheadStation), $xslStationFormat, $xslStationPrecision, string(StationEquation/@aheadEquation))"/>
                    </td>
                    <td align="right">
                        <xsl:value-of select="inr:northingFormat(number(GeometryPoint/@northing), $xslNorthingPrecision)"/>
                    </td>
                    <td align="right">
                        <xsl:value-of select="inr:eastingFormat(number(GeometryPoint/@easting), $xslEastingPrecision)"/>
                    </td>
                </tr>
            </xsl:for-each>
        </xsl:if>
        <tr>
            <td align="right"><xsl:value-of select="End/@type"/></td>
            <td align="right">( <xsl:value-of select="End/@name"/> )</td>
            <td align="right">
                <xsl:value-of select="inr:stationFormat(number(End/station/@externalStation), $xslStationFormat, $xslStationPrecision, string(End/station/@externalStationName))"/>
            </td>
            <td align="right">
                <xsl:value-of select="inr:northingFormat(number(End/@northing), $xslNorthingPrecision)"/>
            </td>
            <td align="right">
                <xsl:value-of select="inr:eastingFormat(number(End/@easting), $xslEastingPrecision)"/>
            </td>
        </tr>
        <tr>
            <td align="right" colspan="2" lang="en">Tangential Direction:</td>
            <td align="right">
                <xsl:value-of select="inr:directionFormat(number(@direction), $xslDirectionFormat,  $xslDirectionPrecision, $xslDirectionModeFormat, $xslAngularMethod)"/>
            </td>
        </tr>
        <tr>
            <td align="right" colspan="2" lang="en">Tangential Length:</td>
            <td align="right">
                <xsl:value-of select="inr:distanceFormat(number(@length), $xslDistancePrecision)"/>
            </td>
        </tr>
    </xsl:template>
    <!-- Horizontal Alignment Circular Data -->
    <xsl:template match="HorizontalCircle" mode="horizontal">
        <tr>
            <td align="left" colspan="5" lang="en"><br/>Element: Circular</td>
        </tr>
        <tr>
            <td align="right"><xsl:value-of select="Start/@type"/></td>
            <td align="right">( <xsl:value-of select="Start/@name"/> )</td>
            <td align="right">
                <xsl:value-of select="inr:stationFormat( number(Start/station/@externalStation), $xslStationFormat, $xslStationPrecision, string(Start/station/@externalStationName))"/>
            </td>
            <td align="right">
                <xsl:value-of select="inr:northingFormat(number(Start/@northing), $xslNorthingPrecision)"/>
            </td>
            <td align="right">
                <xsl:value-of select="inr:eastingFormat(number(Start/@easting), $xslEastingPrecision)"/>
            </td>
        </tr>
        <xsl:if test="PI">
            <tr>
                <td align="right"><xsl:value-of select="PI/@type"/></td>
                <td align="right">( <xsl:value-of select="PI/@name"/> )</td>
                <td align="right">
                    <xsl:value-of select="inr:stationFormat( number(PI/station/@externalStation), $xslStationFormat, $xslStationPrecision, string(PI/station/@externalStationName))"/>
                </td>
                <td align="right">
                    <xsl:value-of select="inr:northingFormat(number(PI/@northing), $xslNorthingPrecision)"/>
                </td>
                <td align="right">
                    <xsl:value-of select="inr:eastingFormat(number(PI/@easting), $xslEastingPrecision)"/>
                </td>
            </tr>
        </xsl:if>
        <tr>
            <td align="right"><xsl:value-of select="Center/@type"/></td>
            <td align="right">( <xsl:value-of select="Center/@name"/> )</td>
            <td/>
            <td align="right">
                <xsl:value-of select="inr:northingFormat(number(Center/@northing), $xslNorthingPrecision)"/>
            </td>
            <td align="right">
                <xsl:value-of select="inr:eastingFormat(number(Center/@easting), $xslEastingPrecision)"/>
            </td>
        </tr>
        <xsl:if test="StationEquation">
            <xsl:for-each select="StationEquation">
                <tr>
                    <td align="right" colspan="2" lang="en">EQNBK</td>
                    <td align="right">
                        <xsl:value-of select="inr:stationFormat(number(@backStation), $xslStationFormat, $xslStationPrecision, string(@backEquation))"/>
                    </td>
                    <td align="right">
                        <xsl:value-of select="inr:northingFormat(number(GeometryPoint/@northing), $xslNorthingPrecision)"/>
                    </td>
                    <td align="right">
                        <xsl:value-of select="inr:eastingFormat(number(GeometryPoint/@easting), $xslEastingPrecision)"/>
                    </td>
                </tr>
                <tr>
                    <td align="right" colspan="2" lang="en">EQNAHD</td>
                    <td align="right">
                        <xsl:value-of select="inr:stationFormat(number(@aheadStation), $xslStationFormat, $xslStationPrecision, string(@aheadEquation))"/>
                    </td>
                    <td align="right">
                        <xsl:value-of select="inr:northingFormat(number(GeometryPoint/@northing), $xslNorthingPrecision)"/>
                    </td>
                    <td align="right">
                        <xsl:value-of select="inr:eastingFormat(number(GeometryPoint/@easting), $xslEastingPrecision)"/>
                    </td>
                </tr>
            </xsl:for-each>
        </xsl:if>
        <tr>
            <td align="right"><xsl:value-of select="End/@type"/></td>
            <td align="right">( <xsl:value-of select="End/@name"/> )</td>
            <td align="right">
                <xsl:value-of select="inr:stationFormat( number(End/station/@externalStation), $xslStationFormat, $xslStationPrecision, string(End/station/@externalStationName))"/>
            </td>
            <td align="right">
                <xsl:value-of select="inr:northingFormat(number(End/@northing), $xslNorthingPrecision)"/>
            </td>
            <td align="right">
                <xsl:value-of select="inr:eastingFormat(number(End/@easting), $xslEastingPrecision)"/>
            </td>
        </tr>
        <tr>
            <td align="right" colspan="2" lang="en">Radius:</td>
            <td align="right">
                <xsl:value-of select="inr:distanceFormat(number(@radius), $xslDistancePrecision)"/>
            </td>
        </tr>
        <tr>
            <td align="right" colspan="2" lang="en">Delta:</td>
            <td align="right">
                <xsl:value-of select="inr:angularFormat(number(@delta), $xslAngularFormat, $xslAngularPrecision, $xslAngularMethod)"/>
            </td>
            <td lang="en">
                <xsl:if test="@rotationDirection='cw'">Right</xsl:if>
                <xsl:if test="@rotationDirection = 'ccw'">Left</xsl:if>
            </td>
        </tr>
        <tr>
            <td align="right" colspan="2" lang="en">
                <xsl:if test="../../@curvatureDefinition = 'arc'">
                    Degree of Curvature (Arc):
                </xsl:if>
                <xsl:if test="../../@curvatureDefinition = 'chord'">
                    Degree of Curvature (Chord):
                </xsl:if>
            </td>
            <td align="right">
                <xsl:value-of select="inr:angularFormat(number(@degreeOfCurve), $xslAngularFormat, $xslAngularPrecision, $xslAngularMethod)"/>
            </td>
        </tr>
        <tr>
            <td align="right" colspan="2" lang="en">Length:</td>
            <td align="right">
                <xsl:value-of select="inr:distanceFormat(number(@length), $xslDistancePrecision)"/>
            </td>
        </tr>
        <tr>
            <td align="right" colspan="2" lang="en">Tangent:</td>
            <td align="right">
                <xsl:value-of select="inr:distanceFormat(number(@tangentLength), $xslDistancePrecision)"/>
            </td>
        </tr>
        <tr>
            <td align="right" colspan="2" lang="en">Chord:</td>
            <td align="right">
                <xsl:value-of select="inr:distanceFormat(number(@chord), $xslDistancePrecision)"/>
            </td>
        </tr>
        <tr>
            <td align="right" colspan="2" lang="en">Middle Ordinate:</td>
            <td align="right">
                <xsl:value-of select="inr:distanceFormat(number(@middleOrdinate), $xslDistancePrecision)"/>
            </td>
        </tr>
        <tr>
            <td align="right" colspan="2" lang="en">External:</td>
            <td align="right">
                <xsl:value-of select="inr:distanceFormat(number(@externalDistance), $xslDistancePrecision)"/>
            </td>
        </tr>
        <tr>
            <td align="right" colspan="2" lang="en">Tangent Direction:</td>
            <td align="right">
                <xsl:value-of select="inr:directionFormat(number(@tangentialDirectionStart), $xslDirectionFormat, $xslDirectionPrecision, $xslDirectionModeFormat, $xslAngularMethod)"/>
            </td>
        </tr>
        <tr>
            <td align="right" colspan="2" lang="en">Radial Direction:</td>
            <td align="right">
                <xsl:value-of select="inr:directionFormat(number(@radialDirectionStart), $xslDirectionFormat, $xslDirectionPrecision, $xslDirectionModeFormat, $xslAngularMethod)"/>
            </td>
        </tr>
        <tr>
            <td align="right" colspan="2" lang="en">Chord Direction:</td>
            <td align="right">
                <xsl:value-of select="inr:directionFormat(number(@chordDirection), $xslDirectionFormat, $xslDirectionPrecision, $xslDirectionModeFormat, $xslAngularMethod)"/>
            </td>
        </tr>
        <tr>
            <td align="right" colspan="2" lang="en">Radial Direction:</td>
            <td align="right">
                <xsl:value-of select="inr:directionFormat(number(@radialDirectionEnd), $xslDirectionFormat, $xslDirectionPrecision, $xslDirectionModeFormat, $xslAngularMethod)"/>
            </td>
        </tr>
        <tr>
            <td align="right" colspan="2" lang="en">Tangent Direction:</td>
            <td align="right">
                <xsl:value-of select="inr:directionFormat(number(@tangentialDirectionEnd), $xslDirectionFormat, $xslDirectionPrecision, $xslDirectionModeFormat, $xslAngularMethod)"/>
            </td>
        </tr>
    </xsl:template>
    <!-- Horizontal Alignment Spiral Data -->
    <xsl:template match="HorizontalSpiral" mode="horizontal">
        <tr>
            <td align="left" colspan="5" lang="en"><br/><xsl:text>Element: </xsl:text>
                <xsl:choose>
                    <xsl:when test="@compound = 'false'">
                        <xsl:value-of select="@type"/>
                    </xsl:when>
                    <xsl:otherwise>
                        <xsl:text> Compound </xsl:text>
                        <xsl:value-of select="@type"/>
                    </xsl:otherwise>
                </xsl:choose>
            </td>
        </tr>
        <tr>
            <td align="right"><xsl:value-of select="Start/@type"/></td>
            <td align="right">( <xsl:value-of select="Start/@name"/> )</td>
            <td align="right">
                <xsl:value-of select="inr:stationFormat( number(Start/station/@externalStation), $xslStationFormat, $xslStationPrecision, string(Start/station/@externalStationName))"/>
            </td>
            <td align="right">
                <xsl:value-of select="inr:northingFormat(number(Start/@northing), $xslNorthingPrecision)"/>
            </td>
            <td align="right">
                <xsl:value-of select="inr:eastingFormat(number(Start/@easting), $xslEastingPrecision)"/>
            </td>
        </tr>
        <tr>
            <td align="right"><xsl:value-of select="PI/@type"/></td>
            <td align="right">( <xsl:value-of select="PI/@name"/> )</td>
            <td align="right">
                <xsl:value-of select="inr:stationFormat( number(PI/station/@externalStation), $xslStationFormat, $xslStationPrecision, string(PI/station/@externalStationName))"/>
            </td>
            <td align="right">
                <xsl:value-of select="inr:northingFormat(number(PI/@northing), $xslNorthingPrecision)"/>
            </td>
            <td align="right">
                <xsl:value-of select="inr:eastingFormat(number(PI/@easting), $xslEastingPrecision)"/>
            </td>
        </tr>
        <xsl:if test="StationEquation">
            <xsl:for-each select="StationEquation">
                <tr>
                    <td align="right" colspan="2" lang="en">EQNBK</td>
                    <td align="right">
                        <xsl:value-of select="inr:stationFormat(number(@backStation), $xslStationFormat, $xslStationPrecision, string(@backEquation))"/>
                    </td>
                    <td align="right">
                        <xsl:value-of select="inr:northingFormat(number(GeometryPoint/@northing), $xslNorthingPrecision)"/>
                    </td>
                    <td align="right">
                        <xsl:value-of select="inr:eastingFormat(number(GeometryPoint/@easting), $xslEastingPrecision)"/>
                    </td>
                </tr>
                <tr>
                    <td align="right" colspan="2" lang="en">EQNAHD</td>
                    <td align="right">
                        <xsl:value-of select="inr:stationFormat(number(@aheadStation), $xslStationFormat, $xslStationPrecision, string(@aheadEquation))"/>
                    </td>
                    <td align="right">
                        <xsl:value-of select="inr:northingFormat(number(GeometryPoint/@northing), $xslNorthingPrecision)"/>
                    </td>
                    <td align="right">
                        <xsl:value-of select="inr:eastingFormat(number(GeometryPoint/@easting), $xslEastingPrecision)"/>
                    </td>
                </tr>
            </xsl:for-each>
        </xsl:if>
        <tr>
            <td align="right"><xsl:value-of select="End/@type"/></td>
            <td align="right">( <xsl:value-of select="End/@name"/> )</td>
            <td align="right">
                <xsl:value-of select="inr:stationFormat(number(End/station/@externalStation), $xslStationFormat, $xslStationPrecision, string(End/station/@externalStationName))"/>
            </td>
            <td align="right">
                <xsl:value-of select="inr:northingFormat(number(End/@northing), $xslNorthingPrecision)"/>
            </td>
            <td align="right">
                <xsl:value-of select="inr:eastingFormat(number(End/@easting), $xslEastingPrecision)"/>
            </td>
        </tr>
        <tr>
            <td align="right" colspan="2" lang="en">Entrance Radius:</td>
            <td align="right">
                <xsl:value-of select="inr:distanceFormat(number(@startRadius), $xslDistancePrecision)"/>
            </td>
        </tr>
        <tr>
            <td align="right" colspan="2" lang="en">Exit Radius:</td>
            <td align="right">
                <xsl:value-of select="inr:distanceFormat(number(@endRadius), $xslDistancePrecision)"/>
            </td>
        </tr>
        <tr>
            <td align="right" colspan="2" lang="en">Length:</td>
            <td align="right">
                <xsl:value-of select="inr:distanceFormat(number(@length), $xslDistancePrecision)"/>
            </td>
        </tr>
        <tr>
            <td align="right" colspan="2" lang="en">Angle:</td>
            <td align="right">
                <xsl:value-of select="inr:angularFormat(number(@thetaAngle), $xslAngularFormat, $xslAngularPrecision, $xslAngularMethod)"/>
            </td>
            <td>
                <xsl:if test="@rotationDirection='cw'">Right</xsl:if>
                <xsl:if test="@rotationDirection = 'ccw'">Left</xsl:if>
            </td>
        </tr>
        <tr>
            <td align="right" colspan="2" lang="en">Constant:</td>
            <td align="right">
                <xsl:value-of select="inr:distanceFormat(number(@aConstant), $xslDistancePrecision)"/>
            </td>
        </tr>
        <tr>
            <td align="right" colspan="2" lang="en">Long Tangent:</td>
            <td align="right">
                <xsl:value-of select="inr:distanceFormat(number(@longTangent), $xslDistancePrecision)"/>
            </td>
        </tr>
        <tr>
            <td align="right" colspan="2" lang="en">Short Tangent:</td>
            <td align="right">
                <xsl:value-of select="inr:distanceFormat(number(@shortTangent), $xslDistancePrecision)"/>
            </td>
        </tr>
        <tr>
            <td align="right" colspan="2" lang="en">Long Chord:</td>
            <td align="right">
                <xsl:value-of select="inr:distanceFormat(number(@longChord), $xslDistancePrecision)"/>
            </td>
        </tr>
        <tr>
            <td align="right" colspan="2" lang="en">Xs:</td>
            <td align="right">
                <xsl:value-of select="inr:distanceFormat(number(@xs), $xslDistancePrecision)"/>
            </td>
        </tr>
        <tr>
            <td align="right" colspan="2" lang="en">Ys:</td>
            <td align="right">
                <xsl:value-of select="inr:distanceFormat(number(@ys), $xslDistancePrecision)"/>
            </td>
        </tr>
        <tr>
            <td align="right" colspan="2" lang="en">P:</td>
            <td align="right">
                <xsl:value-of select="inr:distanceFormat(number(@p), $xslDistancePrecision)"/>
            </td>
        </tr>
        <tr>
            <td align="right" colspan="2" lang="en">K:</td>
            <td align="right">
                <xsl:value-of select="inr:distanceFormat(number(@ks), $xslDistancePrecision)"/>
            </td>
        </tr>
        <tr>
            <td align="right" colspan="2" lang="en">Tangent Direction:</td>
            <td align="right">
                <xsl:value-of select="inr:directionFormat(number(@tangentialDirectionStart), $xslDirectionFormat, $xslDirectionPrecision, $xslDirectionModeFormat, $xslAngularMethod)"/>
            </td>
        </tr>
        <tr>
            <td align="right" colspan="2" lang="en">Radial Direction:</td>
            <td align="right">
                <xsl:value-of select="inr:directionFormat(number(@radialDirectionStart), $xslDirectionFormat, $xslDirectionPrecision, $xslDirectionModeFormat, $xslAngularMethod)"/>
            </td>
        </tr>
        <tr>
            <td align="right" colspan="2" lang="en">Chord Direction:</td>
            <td align="right">
                <xsl:value-of select="inr:directionFormat(number(@chordDirection), $xslDirectionFormat, $xslDirectionPrecision, $xslDirectionModeFormat, $xslAngularMethod)"/>
            </td>
        </tr>
        <tr>
            <td align="right" colspan="2" lang="en">Radial Direction:</td>
            <td align="right">
                <xsl:value-of select="inr:directionFormat(number(@radialDirectionEnd), $xslDirectionFormat, $xslDirectionPrecision, $xslDirectionModeFormat, $xslAngularMethod)"/>
            </td>
        </tr>
        <tr>
            <td align="right" colspan="2" lang="en">Tangent Direction:</td>
            <td align="right">
                <xsl:value-of select="inr:directionFormat(number(@tangentialDirectionEnd), $xslDirectionFormat, $xslDirectionPrecision, $xslDirectionModeFormat, $xslAngularMethod)"/>
            </td>
        </tr>
    </xsl:template>
    <!-- Vertical Alignment Linear Data -->
    <xsl:template match="VerticalLine" mode="vertical">
        <tr>
            <td align="left" colspan="5" lang="en"><br/>Element: Linear</td>
        </tr>
        <tr>
            <td align="right" colspan="2"><xsl:value-of select="VerticalStart/@type"/></td>
            <td align="right">
                <xsl:value-of select="inr:stationFormat(number(VerticalStart/station/@externalStation), $xslStationFormat, $xslStationPrecision, string(VerticalStart/station/@externalStationName))"/>
            </td>
            <td align="right">
                <xsl:value-of select="inr:elevationFormat(number(VerticalStart/@elevation), $xslElevationPrecision)"/>
            </td>
        </tr>
        <xsl:if test="StationEquation">
            <xsl:for-each select="StationEquation">
                <tr>
                    <td align="right" colspan="2" lang="en">EQNBK</td>
                    <td align="right">
                        <xsl:value-of select="inr:stationFormat(number(@backStation), $xslStationFormat, $xslStationPrecision, string(StationEquation/@backEquation))"/>
                    </td>
                    <td align="right">
                        <xsl:value-of select="inr:elevationFormat(number(GeometryPoint/@elevation), $xslElevationPrecision)"/>
                    </td>
                </tr>
                <tr>
                    <td align="right" colspan="2" lang="en">EQNAHD</td>
                    <td align="right">
                        <xsl:value-of select="inr:stationFormat(number(@aheadStation), $xslStationFormat, $xslStationPrecision, string(StationEquation/@aheadEquation))"/>
                    </td>
                    <td align="right">
                        <xsl:value-of select="inr:elevationFormat(number(GeometryPoint/@elevation), $xslElevationPrecision)"/>
                    </td>
                </tr>
            </xsl:for-each>
        </xsl:if>
        <tr>
            <td align="right" colspan="2"><xsl:value-of select="VerticalEnd/@type"/></td>
            <td align="right">
                <xsl:value-of select="inr:stationFormat(number(VerticalEnd/station/@externalStation), $xslStationFormat, $xslStationPrecision, string(VerticalEnd/station/@externalStationName))"/>
            </td>
            <td align="right">
                <xsl:value-of select="inr:elevationFormat(number(VerticalEnd/@elevation), $xslElevationPrecision)"/>
            </td>
         </tr>
         <tr>
            <td align="right" colspan="2" lang="en">Tangent Grade:</td>
            <td align="right">
                <xsl:value-of select="inr:gradeFormat(number(@grade), $xslGradeFormat, $xslGradePrecision)"/>
            </td>
         </tr>
         <tr>
            <td align="right" colspan="2" lang="en">Tangent Length:</td>
            <td align="right">
                <xsl:value-of select="inr:distanceFormat(number(@length), $xslDistancePrecision)"/>
            </td>
         </tr>
    </xsl:template>
    <!-- Vertical Alignment Symmetrical Parabola Data -->
    <xsl:template match="VerticalSymmetricalParabola" mode="vertical">
        <tr>
            <td align="left" colspan="5" lang="en"><br/>Element: Symmetrical Parabola</td>
        </tr>
        <tr>
            <td align="right" colspan="2"><xsl:value-of select="VerticalStart/@type"/></td>
            <td align="right">
                <xsl:value-of select="inr:stationFormat(number(VerticalStart/station/@externalStation), $xslStationFormat, $xslStationPrecision, string(VerticalStart/station/@externalStationName))"/>
            </td>
            <td align="right">
                <xsl:value-of select="inr:elevationFormat(number(VerticalStart/@elevation), $xslElevationPrecision)"/>
            </td>
        </tr>
        <tr>
            <td align="right" colspan="2"><xsl:value-of select="PVI/@type"/></td>
            <td align="right">
                <xsl:value-of select="inr:stationFormat(number(PVI/station/@externalStation), $xslStationFormat, $xslStationPrecision, string(PVI/station/@externalStationName))"/>
            </td>
            <td align="right">
                <xsl:value-of select="inr:elevationFormat(number(PVI/@elevation), $xslElevationPrecision)"/>
            </td>
        </tr>
        <xsl:if test="StationEquation">
            <xsl:for-each select="StationEquation">
                <tr>
                    <td align="right" colspan="2" lang="en">EQNBK</td>
                    <td align="right">
                        <xsl:value-of select="inr:stationFormat(number(@backStation), $xslStationFormat, $xslStationPrecision, string(StationEquation/@backEquation))"/>
                    </td>
                    <td align="right">
                        <xsl:value-of select="inr:elevationFormat(number(GeometryPoint/@elevation), $xslElevationPrecision)"/>
                    </td>
                </tr>
                <tr>
                    <td align="right" colspan="2" lang="en">EQNAHD</td>
                    <td align="right">
                        <xsl:value-of select="inr:stationFormat(number(@aheadStation), $xslStationFormat, $xslStationPrecision, string(StationEquation/@aheadEquation))"/>
                    </td>
                    <td align="right">
                        <xsl:value-of select="inr:elevationFormat(number(GeometryPoint/@elevation), $xslElevationPrecision)"/>
                    </td>
                </tr>
            </xsl:for-each>
        </xsl:if>
        <tr>
            <td align="right" colspan="2"><xsl:value-of select="VerticalEnd/@type"/></td>
            <td align="right">
                <xsl:value-of select="inr:stationFormat(number(VerticalEnd/station/@externalStation), $xslStationFormat, $xslStationPrecision, string(VerticalEnd/station/@externalStationName))"/>
            </td>
            <td align="right">
                <xsl:value-of select="inr:elevationFormat(number(VerticalEnd/@elevation), $xslElevationPrecision)"/>
            </td>
        </tr>
        <xsl:if test="TurningPoint">
            <tr>
                <td align="right" colspan="2"><xsl:value-of select="TurningPoint/@type"/></td>
                <td align="right">
                    <xsl:value-of select="inr:stationFormat(number(TurningPoint/station/@externalStation), $xslStationFormat, $xslStationPrecision, string(TurningPoint/station/@externalStationName))"/>
                </td>
                <td align="right">
                    <xsl:value-of select="inr:elevationFormat(number(TurningPoint/@elevation), $xslElevationPrecision)"/>
                </td>
            </tr>
        </xsl:if>
        <tr>
            <td align="right" colspan="2" lang="en">Length:</td>
            <td align="right">
                <xsl:value-of select="inr:distanceFormat(number(@verticalCurveLength), $xslDistancePrecision)"/>
            </td>
        </tr>
        <tr>
            <td align="right" colspan="2" lang="en">Entrance Grade:</td>
           <td align="right">
                <xsl:value-of select="inr:gradeFormat(number(@startGrade), $xslGradeFormat, $xslGradePrecision)"/>
           </td>
        </tr>
        <tr>
            <td align="right" colspan="2" lang="en">Exit Grade:</td>
            <td align="right">
                <xsl:value-of select="inr:gradeFormat(number(@endGrade), $xslGradeFormat, $xslGradePrecision)"/>
            </td>
        </tr>
        <tr>
            <td align="right" colspan="2" lang="en">r = (g2 - g1) / L:</td>
            <td align="right">
                <xsl:value-of select="inr:distanceFormat(number(@rateOfChange), $xslDistancePrecision)"/>
            </td>
        </tr>
        <tr>
            <td align="right" colspan="2" lang="en">K = l / (g2 - g1):</td>
            <td align="right">
                <xsl:value-of select="inr:distanceFormat(number(@kValue), $xslDistancePrecision)"/>
            </td>
        </tr>
        <tr>
            <td align="right" colspan="2" lang="en">Middle Ordinate:</td>
            <td align="right">
                <xsl:value-of select="inr:distanceFormat(number(@midOrdinate), $xslDistancePrecision)"/>
            </td>
        </tr>
    </xsl:template>
    <!-- Vertical Alignment Unsymmetrical Parabola Data -->
    <xsl:template match="VerticalUnsymmetricalParabola" mode="vertical">
        <tr>
            <td align="left" colspan="5" lang="en"><br/>Element: Unsymmetrical Parabola</td>
        </tr>
        <tr>
            <td align="right" colspan="2"><xsl:value-of select="VerticalStart/@type"/></td>
            <td align="right">
                <xsl:value-of select="inr:stationFormat(number(VerticalStart/station/@externalStation), $xslStationFormat, $xslStationPrecision, string(VerticalStart/station/@externalStationName))"/>
            </td>
            <td align="right">
                <xsl:value-of select="inr:elevationFormat(number(VerticalStart/@elevation), $xslElevationPrecision)"/>
            </td>
        </tr>
        <tr>
            <td align="right" colspan="2"><xsl:value-of select="PVI/@type"/></td>
            <td align="right">
                <xsl:value-of select="inr:stationFormat(number(PVI/station/@externalStation), $xslStationFormat, $xslStationPrecision, string(PVI/station/@externalStationName))"/>
            </td>
            <td align="right">
                <xsl:value-of select="inr:elevationFormat(number(PVI/@elevation), $xslElevationPrecision)"/>
            </td>
        </tr>
        <tr>
            <td align="right" colspan="2"><xsl:value-of select="PVCC/@type"/></td>
            <td align="right">
                <xsl:value-of select="inr:stationFormat(number(PVCC/station/@externalStation), $xslStationFormat, $xslStationPrecision, string(PVCC/station/@externalStationName))"/>
            </td>
            <td align="right">
                <xsl:value-of select="inr:elevationFormat(number(PVCC/@elevation), $xslElevationPrecision)"/>
            </td>
        </tr>
        <xsl:if test="StationEquation">
            <xsl:for-each select="StationEquation">
                <tr>
                    <td align="right" colspan="2" lang="en">EQNBK</td>
                    <td align="right">
                        <xsl:value-of select="inr:stationFormat(number(@backStation), $xslStationFormat, $xslStationPrecision, string(StationEquation/@backEquation))"/>
                    </td>
                    <td align="right">
                        <xsl:value-of select="inr:elevationFormat(number(GeometryPoint/@elevation), $xslElevationPrecision)"/>
                    </td>
                </tr>
                <tr>
                    <td align="right" colspan="2" lang="en">EQNAHD</td>
                    <td align="right">
                        <xsl:value-of select="inr:stationFormat(number(@aheadStation), $xslStationFormat, $xslStationPrecision, string(StationEquation/@aheadEquation))"/>
                    </td>
                    <td align="right">
                        <xsl:value-of select="inr:elevationFormat(number(GeometryPoint/@elevation), $xslElevationPrecision)"/>
                    </td>
                </tr>
            </xsl:for-each>
        </xsl:if>
        <tr>
            <td align="right" colspan="2"><xsl:value-of select="VerticalEnd/@type"/></td>
            <td align="right">
                <xsl:value-of select="inr:stationFormat(number(VerticalEnd/station/@externalStation), $xslStationFormat, $xslStationPrecision, string(VerticalEnd/station/@externalStationName))"/>
            </td>
            <td align="right">
                <xsl:value-of select="inr:elevationFormat(number(VerticalEnd/@elevation), $xslElevationPrecision)"/>
            </td>
        </tr>
        <xsl:if test="TurningPoint">
            <tr>
                <td align="right" colspan="2"><xsl:value-of select="TurningPoint/@type"/></td>
                <td align="right">
                    <xsl:value-of select="inr:stationFormat(number(TurningPoint/station/@externalStation), $xslStationFormat, $xslStationPrecision, string(TurningPoint/station/@externalStationName))"/>
                </td>
                <td align="right">
                    <xsl:value-of select="inr:elevationFormat(number(TurningPoint/@elevation), $xslElevationPrecision)"/>
                </td>
            </tr>
        </xsl:if>
        <tr>
            <td align="right" colspan="2" lang="en">Entrance Length:</td>
            <td align="right">
                <xsl:value-of select="inr:distanceFormat(number(@startVerticalCurveLength), $xslDistancePrecision)"/>
            </td>
        </tr>
        <tr>
            <td align="right" colspan="2" lang="en">Exit Length:</td>
            <td align="right">
                <xsl:value-of select="inr:distanceFormat(number(@endVerticalCurveLength), $xslDistancePrecision)"/>
            </td>
        </tr>
        <tr>
            <td align="right" colspan="2" lang="en">Entrance Grade:</td>
            <td align="right">
                <xsl:value-of select="inr:gradeFormat(number(@startGrade), $xslGradeFormat, $xslGradePrecision)"/>
            </td>
        </tr>
        <tr>
            <td align="right" colspan="2" lang="en">Exit Grade:</td>
            <td align="right">
                <xsl:value-of select="inr:gradeFormat(number(@endGrade), $xslGradeFormat, $xslGradePrecision)"/>
            </td>
        </tr>
        <tr>
            <td align="right" colspan="2" lang="en">r = (g2 - g1) / L:</td>
            <td align="right">
                Entrance: &#xa0;<xsl:value-of select="inr:distanceFormat(number(@startRateOfChange), $xslDistancePrecision)"/>
            </td>
            <td align="right">
                Exit: &#xa0;<xsl:value-of select="inr:distanceFormat(number(@endRateOfChange), $xslDistancePrecision)"/>
            </td>
         </tr>
         <tr>
             <td align="right" colspan="2" lang="en">K = l / (g2 - g1):</td>
             <td align="right">
                 Entrance: &#xa0;<xsl:value-of select="inr:distanceFormat(number(@startKValue), $xslDistancePrecision)"/>
             </td>
             <td align="right">
                 Exit: &#xa0;<xsl:value-of select="inr:distanceFormat(number(@endKValue), $xslDistancePrecision)"/>
             </td>
         </tr>
         <tr>
             <td align="right" colspan="2" lang="en">Middle Ordinate:</td>
             <td align="right">
                 <xsl:value-of select="inr:distanceFormat(number(@midOrdinate), $xslDistancePrecision)"/>
             </td>
         </tr>
    </xsl:template>
    <!-- Vertical Alignment Circle Data -->
    <xsl:template match="VerticalCircle" mode="vertical">
        <tr>
            <td align="left" colspan="5" lang="en"><br/>Element: Circular</td>
        </tr>
        <tr>
            <td align="right" colspan="2"><xsl:value-of select="VerticalStart/@type"/></td>
            <td align="right">
                <xsl:value-of select="inr:stationFormat(number(VerticalStart/station/@externalStation), $xslStationFormat, $xslStationPrecision, string(VerticalStart/station/@externalStationName))"/>
            </td>
            <td align="right">
                <xsl:value-of select="inr:elevationFormat(number(VerticalStart/@elevation), $xslElevationPrecision)"/>
            </td>
        </tr>
        <tr>
            <td align="right" colspan="2"><xsl:value-of select="PVI/@type"/></td>
            <td align="right">
                <xsl:value-of select="inr:stationFormat(number(PVI/station/@externalStation), $xslStationFormat, $xslStationPrecision, string(PVI/station/@externalStationName))"/>
            </td>
            <td align="right">
                <xsl:value-of select="inr:elevationFormat(number(PVI/@elevation), $xslElevationPrecision)"/>
            </td>
        </tr>
        <tr>
            <td align="right" colspan="2"><xsl:value-of select="VerticalCenter/@type"/></td>
            <td align="right">
                <xsl:value-of select="inr:stationFormat(number(VerticalCenter/station/@externalStation), $xslStationFormat, $xslStationPrecision, string(VerticalCenter/station/@externalStationName))"/>
            </td>
            <td align="right">
                <xsl:value-of select="inr:elevationFormat(number(VerticalCenter/@elevation), $xslElevationPrecision)"/>
            </td>
        </tr>
        <xsl:if test="StationEquation">
            <xsl:for-each select="StationEquation">
                <tr>
                    <td align="right" colspan="2" lang="en">EQNBK</td>
                    <td align="right">
                        <xsl:value-of select="inr:stationFormat(number(@backStation), $xslStationFormat, $xslStationPrecision, string(StationEquation/@backEquation))"/>
                    </td>
                    <td align="right">
                        <xsl:value-of select="inr:elevationFormat(number(GeometryPoint/@elevation), $xslElevationPrecision)"/>
                    </td>
                </tr>
                <tr>
                    <td align="right" colspan="2" lang="en">EQNAHD</td>
                    <td align="right">
                        <xsl:value-of select="inr:stationFormat(number(@aheadStation), $xslStationFormat, $xslStationPrecision, string(StationEquation/@aheadEquation))"/>
                    </td>
                    <td align="right">
                        <xsl:value-of select="inr:elevationFormat(number(GeometryPoint/@elevation), $xslElevationPrecision)"/>
                    </td>
                </tr>
            </xsl:for-each>
        </xsl:if>
        <tr>
            <td align="right" colspan="2"><xsl:value-of select="VerticalEnd/@type"/></td>
            <td align="right">
                <xsl:value-of select="inr:stationFormat(number(VerticalEnd/station/@externalStation), $xslStationFormat, $xslStationPrecision, string(VerticalEnd/station/@externalStationName))"/>
            </td>
            <td align="right">
                <xsl:value-of select="inr:elevationFormat(number(VerticalEnd/@elevation), $xslElevationPrecision)"/>
            </td>
        </tr>
        <xsl:if test="TurningPoint">
            <tr>
                <td align="right" colspan="2"><xsl:value-of select="TurningPoint/@type"/></td>
                <td align="right">
                    <xsl:value-of select="inr:stationFormat(number(TurningPoint/station/@externalStation), $xslStationFormat, $xslStationPrecision, string(TurningPoint/station/@externalStationName))"/>
                </td>
                <td align="right">
                    <xsl:value-of select="inr:elevationFormat(number(TurningPoint/@elevation), $xslElevationPrecision)"/>
                </td>
            </tr>
        </xsl:if>
        <tr>
            <td align="right" colspan="2" lang="en">Radius:</td>
            <td align="right">
                <xsl:value-of select="inr:distanceFormat(number(@radius), $xslDistancePrecision)"/>
            </td>
        </tr>
        <tr>
            <td align="right" colspan="2" lang="en">Length:</td>
            <td align="right">
                <xsl:value-of select="inr:distanceFormat(number(@length), $xslDistancePrecision)"/>
            </td>
        </tr>
        <tr>
            <td align="right" colspan="2" lang="en">Entrance Grade:</td>
            <td align="right">
                <xsl:value-of select="inr:gradeFormat(number(@startGrade), $xslGradeFormat, $xslGradePrecision)"/>
            </td>
         </tr>
         <tr>
            <td align="right" colspan="2" lang="en">Exit Grade:</td>
            <td align="right">
                <xsl:value-of select="inr:gradeFormat(number(@endGrade), $xslGradeFormat, $xslGradePrecision)"/>
            </td>
        </tr>
    </xsl:template>
    <!-- Vertical Alignment Clothoid Data -->
    <xsl:template match="VerticalClothoid" mode="vertical">
        <tr>
            <td align="left" colspan="5" lang="en"><br/>Element: Clothoid</td>
        </tr>
        <tr>
            <td align="right" colspan="2"><xsl:value-of select="VerticalStart/@type"/></td>
            <td align="right">
                <xsl:value-of select="inr:stationFormat(number(VerticalStart/station/@externalStation), $xslStationFormat, $xslStationPrecision, string(VerticalStart/station/@externalStationName))"/>
            </td>
            <td align="right">
                <xsl:value-of select="inr:elevationFormat(number(VerticalStart/@elevation), $xslElevationPrecision)"/>
            </td>
        </tr>
        <tr>
            <td align="right" colspan="2"><xsl:value-of select="PVI/@type"/></td>
            <td align="right">
                <xsl:value-of select="inr:stationFormat(number(PVI/station/@externalStation), $xslStationFormat, $xslStationPrecision, string(PVI/station/@externalStationName))"/>
            </td>
            <td align="right">
                <xsl:value-of select="inr:elevationFormat(number(PVI/@elevation), $xslElevationPrecision)"/>
            </td>
        </tr>
        <xsl:if test="StationEquation">
            <xsl:for-each select="StationEquation">
                <tr>
                    <td align="right" colspan="2" lang="en">EQNBK</td>
                    <td align="right">
                        <xsl:value-of select="inr:stationFormat(number(@backStation), $xslStationFormat, $xslStationPrecision, string(StationEquation/@backEquation))"/>
                    </td>
                </tr>
                <tr>
                    <td align="right" colspan="2" lang="en">EQNAHD</td>
                    <td align="right">
                        <xsl:value-of select="inr:stationFormat(number(@aheadStation), $xslStationFormat, $xslStationPrecision, string(StationEquation/@aheadEquation))"/>
                    </td>
                </tr>
            </xsl:for-each>
        </xsl:if>
        <tr>
            <td align="right" colspan="2"><xsl:value-of select="VerticalEnd/@type"/></td>
            <td align="right">
                <xsl:value-of select="inr:stationFormat(number(VerticalEnd/station/@externalStation), $xslStationFormat, $xslStationPrecision, string(VerticalEnd/station/@externalStationName))"/>
            </td>
            <td align="right">
                <xsl:value-of select="inr:elevationFormat(number(VerticalEnd/@elevation), $xslElevationPrecision)"/>
            </td>
        </tr>
        <xsl:if test="TurningPoint">
            <tr>
                <td align="right" colspan="2"><xsl:value-of select="TurningPoint/@type"/></td>
                <td align="right">
                    <xsl:value-of select="inr:stationFormat(number(TurningPoint/station/@externalStation), $xslStationFormat, $xslStationPrecision, string(TurningPoint/station/@externalStationName))"/>
                </td>
                <td align="right">
                    <xsl:value-of select="inr:elevationFormat(number(TurningPoint/@elevation), $xslElevationPrecision)"/>
                </td>
            </tr>
        </xsl:if>
        <tr>
            <td align="right" colspan="2" lang="en">Entrance Radius:</td>
            <td align="right">
                <xsl:value-of select="inr:distanceFormat(number(@startRadius), $xslDistancePrecision)"/>
            </td>
        </tr>
        <tr>
            <td align="right" colspan="2" lang="en">Exit Radius:</td>
            <td align="right">
                <xsl:value-of select="inr:distanceFormat(number(@endRadius), $xslDistancePrecision)"/>
            </td>
        </tr>
        <tr>
            <td align="right" colspan="2" lang="en">Length:</td>
            <td align="right">
                <xsl:value-of select="inr:distanceFormat(number(@length), $xslDistancePrecision)"/>
            </td>
        </tr>
        <tr>
            <td align="right" colspan="2" lang="en">Angle:</td>
            <td align="right">
                <xsl:value-of select="inr:angularFormat(number(@thetaAngle), $xslAngularFormat, $xslAngularPrecision, $xslAngularMethod)"/>
            </td>
            <td>
                <xsl:if test="@rotationDirection='cw'">Right</xsl:if>
                <xsl:if test="@rotationDirection = 'ccw'">Left</xsl:if>
            </td>
        </tr>
        <tr>
            <td align="right" colspan="2" lang="en">Long Tangent:</td>
            <td align="right">
                <xsl:value-of select="inr:distanceFormat(number(@longTangent), $xslDistancePrecision)"/>
            </td>
        </tr>
        <tr>
            <td align="right" colspan="2" lang="en">Short Tangent:</td>
            <td align="right">
                <xsl:value-of select="inr:distanceFormat(number(@shortTangent), $xslDistancePrecision)"/>
            </td>
        </tr>
        <tr>
            <td align="right" colspan="2" lang="en">Long Chord:</td>
            <td align="right">
                <xsl:value-of select="inr:distanceFormat(number(@longChord), $xslDistancePrecision)"/>
            </td>
        </tr>
        <tr>
            <td align="right" colspan="2" lang="en">Xs:</td>
            <td align="right">
                <xsl:value-of select="inr:distanceFormat(number(@xs), $xslDistancePrecision)"/>
            </td>
        </tr>
        <tr>
            <td align="right" colspan="2" lang="en">Ys:</td>
            <td align="right">
                <xsl:value-of select="inr:distanceFormat(number(@ys), $xslDistancePrecision)"/>
            </td>
        </tr>
        <tr>
            <td align="right" colspan="2" lang="en">P:</td>
            <td align="right">
                <xsl:value-of select="inr:distanceFormat(number(@p), $xslDistancePrecision)"/>
            </td>
        </tr>
        <tr>
            <td align="right" colspan="2" lang="en">K:</td>
            <td align="right">
                <xsl:value-of select="inr:distanceFormat(number(@ks), $xslDistancePrecision)"/>
            </td>
        </tr>
        <tr>
            <td align="right" colspan="2" lang="en">Entrance Grade:</td>
            <td align="right">
                <xsl:value-of select="inr:gradeFormat(number(@startGrade), $xslGradeFormat, $xslGradePrecision)"/>
            </td>
        </tr>
        <tr>
            <td align="right" colspan="2" lang="en">Exit Grade:</td>
            <td align="right">
                <xsl:value-of select="inr:gradeFormat(number(@endGrade), $xslGradeFormat, $xslGradePrecision)"/>
            </td>
        </tr>
    </xsl:template>
    <xsl:template name="StyleSheetHelp">
        <div class="section1">
            <h4 lang="en">Notes</h4>
            <p class="normal1" lang="en">
                You must include at least one horizontal alignment in the <em>Include</em> field on the 
                <em>Tools &gt; XML Reports &gt; Geometry</em> command to get results from this report.
            </p>
            <p class="normal1" lang="en">
                You must toggle on the <em>Include Vertical Alignments</em> option and select either 
                <em>All</em> or <em>Active</em> for a complete report.
            </p>
            <p class="small" lang="en">
                <em>&#xa9; 2006 Bentley Systems, Inc</em>
            </p>
        </div>
    </xsl:template>
</xsl:stylesheet>
