<?xml version="1.0" encoding="UTF-8"?>
<xsl:stylesheet version="1.1" xmlns:xsl="http://www.w3.org/1999/XSL/Transform" xmlns:fo="http://www.w3.org/1999/XSL/Format" xmlns:msxsl="urn:schemas-microsoft-com:xslt" xmlns:inr="http://mycompany.com/mynamespace">
    <xsl:include href="../format.xsl"/>
    <xsl:param name="xslRootDirectory" select="inr:xslRootDirectory"/>
    <!-- Variable to hold unit string -->
    <xsl:variable name="unit">
        <xsl:choose>
            <xsl:when test="//@linearUnits = 'Imperial'">ft</xsl:when>
            <xsl:otherwise>m</xsl:otherwise>
        </xsl:choose>
    </xsl:variable>
    <!-- Setting Out Table -->
    <xsl:template match="/">
        <xsl:variable name="gridOut" select="inr:SetGridOut(number(InRoads/@outputGridScaleFactor))"/>
        <html>
            <head>
                <link rel="stylesheet" type="text/css" href="{$xslRootDirectory}/_Themes/engineer/theme.css"/>
                <!-- Title displayed in browser Title Bar -->
                <title lang="en">Setting Out Table</title>
            </head>
            <body>
                <xsl:choose>
                    <xsl:when test="$xslShowHelp = 'true'">
                        <xsl:call-template name="StyleSheetHelp"/>
                    </xsl:when>
                    <xsl:otherwise>
                        <xsl:for-each select="InRoads/GeometryProject/HorizontalAlignment">
                            <p lang="en"><u>PRINCIPLE SETTING OUT LINE FOR <xsl:value-of select="@name"/></u></p>
                            <table border="1" cellpadding="2" cellspacing="0" width="100%">
                                <thead>
                                    <tr>
                                        <th rowspan="2" valign="middle">POINT</th>
                                        <th rowspan="2" valign="middle">CHAINAGE (<xsl:value-of select="$unit"/>)</th>
                                        <th rowspan="2" valign="middle">NORTHING (<xsl:value-of select="$unit"/>)</th>
                                        <th rowspan="2" valign="middle">EASTING (<xsl:value-of select="$unit"/>)</th>
                                        <th rowspan="2" valign="middle">ELEMENT</th>
                                        <th rowspan="2" valign="middle">LENGTH (<xsl:value-of select="$unit"/>)</th>
                                        <th rowspan="2" valign="middle">WCB (0°00'00")<br/><span style="font-size: 75%">(STRAIGHT)</span></th>
                                        <th colspan="2" valign="middle">WCB (0°00'00")</th>
                                    </tr>
                                    <tr>
                                        <th style="font-size: 75%" valign="middle">(R=STARTING ANGLE)</th>
                                        <th style="font-size: 75%" valign="middle">(R=END ANGLE)</th>
                                    </tr>
                                </thead>
                                <tbody>
                                    <xsl:for-each select="HorizontalElements">
                                        <xsl:apply-templates/>
                                    </xsl:for-each>
                                </tbody>
                            </table>
                        </xsl:for-each>
                    </xsl:otherwise>
                </xsl:choose>
            </body>
        </html>
    </xsl:template>
    <!-- Horizontal Linear Data -->
    <xsl:template match="HorizontalLine">
        <tr style="font-size: 75%">
            <td class="sidepad" align="center"><xsl:value-of select="Start/@type"/></td>
            <td class="sidepad" align="right" nowrap="nowrap">
                <xsl:value-of select="inr:stationFormat(number(Start/station/@externalStation), $xslStationFormat, $xslStationPrecision, string(Start/station/@externalStationName))"/>
            </td>
            <td class="sidepad" align="right">
                <xsl:value-of select="inr:northingFormat(number(Start/@northing), $xslNorthingPrecision)"/>
            </td>
            <td class="sidepad" align="right">
                <xsl:value-of select="inr:eastingFormat(number(Start/@easting), $xslEastingPrecision)"/>
            </td>
            <td>&#xa0;</td>
            <td>&#xa0;</td>
            <td>&#xa0;</td>
            <td>&#xa0;</td>
            <td>&#xa0;</td>
        </tr>
        <tr style="font-size: 75%">
            <td>&#xa0;</td>
            <td>&#xa0;</td>
            <td>&#xa0;</td>
            <td>&#xa0;</td>
            <td class="sidepad" align="center">STRAIGHT</td>
            <td class="sidepad" align="right">
                <xsl:value-of select="inr:distanceFormat(number(@length), $xslDistancePrecision)"/>
            </td>
            <td class="sidepad" align="right" nowrap="nowrap">
                <xsl:value-of select="inr:directionFormat(number(@direction), $xslDirectionFormat, $xslDirectionPrecision, $xslDirectionModeFormat, $xslAngularMethod)"/>
            </td>
            <td>&#xa0;</td>
            <td>&#xa0;</td>
        </tr>
        <xsl:if test="End[@pointType = 'POE']">
            <tr style="font-size: 75%">
                <td class="sidepad" align="center"><xsl:value-of select="End/@type"/></td>
                <td class="sidepad" align="right" nowrap="nowrap">
                    <xsl:value-of select="inr:stationFormat(number(End/station/@externalStation), $xslStationFormat, $xslStationPrecision, string(End/station/@externalStationName))"/>
                </td>
                <td class="sidepad" align="right">
                    <xsl:value-of select="inr:northingFormat(number(End/@northing), $xslNorthingPrecision)"/>
                </td>
                <td class="sidepad" align="right">
                    <xsl:value-of select="inr:eastingFormat(number(End/@easting), $xslEastingPrecision)"/>
                </td>
                <td>&#xa0;</td>
                <td>&#xa0;</td>
                <td>&#xa0;</td>
                <td>&#xa0;</td>
                <td>&#xa0;</td>
            </tr>
        </xsl:if>
    </xsl:template>
    <!-- Horizontal Circular Data -->
    <xsl:template match="HorizontalCircle">
        <tr style="font-size: 75%">
            <td class="sidepad" align="center"><xsl:value-of select="Start/@type"/></td>
            <td class="sidepad" align="right" nowrap="nowrap">
                <xsl:value-of select="inr:stationFormat(number(Start/station/@externalStation), $xslStationFormat, $xslStationPrecision, string(Start/station/@externalStationName))"/>
            </td>
            <td class="sidepad" align="right">
                <xsl:value-of select="inr:northingFormat(number(Start/@northing), $xslNorthingPrecision)"/>
            </td>
            <td class="sidepad" align="right">
                <xsl:value-of select="inr:eastingFormat(number(Start/@easting), $xslEastingPrecision)"/>
            </td>
            <td>&#xa0;</td>
            <td>&#xa0;</td>
            <td>&#xa0;</td>
            <td>&#xa0;</td>
            <td>&#xa0;</td>
        </tr>
        <tr style="font-size: 75%">
            <td>&#xa0;</td>
            <td>&#xa0;</td>
            <td>&#xa0;</td>
            <td>&#xa0;</td>
            <xsl:choose>
                <xsl:when test="@rotationDirection = 'ccw'">
                    <td align="center">
                        R = -<xsl:value-of select="inr:distanceFormat(number(@radius), $xslDistancePrecision)"/>
                    </td>
                </xsl:when>
                <xsl:otherwise>
                    <td align="center">
                        R = +<xsl:value-of select="inr:distanceFormat(number(@radius), $xslDistancePrecision)"/>
                    </td>
                </xsl:otherwise>
            </xsl:choose>
            <td class="sidepad" align="right">
                <xsl:value-of select="inr:distanceFormat(number(@length), $xslDistancePrecision)"/>
            </td>
            <td>&#xa0;</td>
            <td class="sidepad" align="right" nowrap="nowrap">
                <xsl:value-of select="inr:directionFormat(number(@tangentialDirectionStart), $xslDirectionFormat, $xslDirectionPrecision, $xslDirectionModeFormat, $xslAngularMethod)"/>
            </td>
            <td class="sidepad" align="right" nowrap="nowrap">
                <xsl:value-of select="inr:directionFormat(number(@tangentialDirectionEnd), $xslDirectionFormat, $xslDirectionPrecision, $xslDirectionModeFormat, $xslAngularMethod)"/>
            </td>
        </tr>
        <xsl:if test="position() = last()">
            <tr style="font-size: 75%">
                <td class="sidepad" align="center"><xsl:value-of select="End/@type"/></td>
                <td class="sidepad" align="right" nowrap="nowrap">
                    <xsl:value-of select="inr:stationFormat(number(End/station/@externalStation), $xslStationFormat, $xslStationPrecision, string(End/station/@externalStationName))"/>
                </td>
                <td class="sidepad" align="right">
                    <xsl:value-of select="inr:northingFormat(number(End/@northing), $xslNorthingPrecision)"/>
                </td>
                <td class="sidepad" align="right">
                    <xsl:value-of select="inr:eastingFormat(number(End/@easting), $xslEastingPrecision)"/>
                </td>
                <td>&#xa0;</td>
                <td>&#xa0;</td>
                <td>&#xa0;</td>
                <td>&#xa0;</td>
                <td>&#xa0;</td>
            </tr>
        </xsl:if>
    </xsl:template>
    <!-- Horizontal Spiral Data -->
    <xsl:template match="HorizontalSpiral">
        <tr style="font-size: 75%">
            <td class="sidepad" align="center"><xsl:value-of select="Start/@type"/></td>
            <td class="sidepad" align="right" nowrap="nowrap">
                <xsl:value-of select="inr:stationFormat(number(Start/station/@externalStation), $xslStationFormat, $xslStationPrecision, string(Start/station/@externalStationName))"/>
            </td>
            <td class="sidepad" align="right">
                <xsl:value-of select="inr:northingFormat(number(Start/@northing), $xslNorthingPrecision)"/>
            </td>
            <td class="sidepad" align="right">
                <xsl:value-of select="inr:eastingFormat(number(Start/@easting), $xslEastingPrecision)"/>
            </td>
            <td>&#xa0;</td>
            <td>&#xa0;</td>
            <td>&#xa0;</td>
            <td>&#xa0;</td>
            <td>&#xa0;</td>
        </tr>
        <tr style="font-size: 75%">
            <td>&#xa0;</td>
            <td>&#xa0;</td>
            <td>&#xa0;</td>
            <td>&#xa0;</td>
            <td class="sidepad" align="center">SPIRAL</td>
            <td class="sidepad" align="right">
                <xsl:value-of select="inr:distanceFormat(number(@length), $xslDistancePrecision)"/>
            </td>
            <td>&#xa0;</td>
            <td class="sidepad" align="right" nowrap="nowrap">
                <xsl:value-of select="inr:directionFormat(number(@tangentialDirectionStart), $xslDirectionFormat, $xslDirectionPrecision, $xslDirectionModeFormat, $xslAngularMethod)"/>
            </td>
            <td class="sidepad" align="right" nowrap="nowrap">
                <xsl:value-of select="inr:directionFormat(number(@tangentialDirectionEnd), $xslDirectionFormat, $xslDirectionPrecision, $xslDirectionModeFormat, $xslAngularMethod)"/>
            </td>
        </tr>
        <xsl:if test="position() = last()">
            <tr style="font-size: 75%">
                <td class="sidepad" align="center"><xsl:value-of select="End/@type"/></td>
                <td class="sidepad" align="right" nowrap="nowrap">
                    <xsl:value-of select="inr:stationFormat(number(End/station/@externalStation), $xslStationFormat, $xslStationPrecision, string(End/station/@externalStationName))"/>
                </td>
                <td class="sidepad" align="right">
                    <xsl:value-of select="inr:northingFormat(number(End/@northing), $xslNorthingPrecision)"/>
                </td>
                <td class="sidepad" align="right">
                    <xsl:value-of select="inr:eastingFormat(number(End/@easting), $xslEastingPrecision)"/>
                </td>
                <td>&#xa0;</td>
                <td>&#xa0;</td>
                <td>&#xa0;</td>
                <td>&#xa0;</td>
                <td>&#xa0;</td>
            </tr>
        </xsl:if>
    </xsl:template>
    <xsl:template name="StyleSheetHelp">
        <div class="section1">
            <h4 lang="en">Notes</h4>
            <p class="normal1" lang="en">
                You must include at least one horizontal alignment in the <em>Include</em> field on the 
                <em>Tools &gt; XML Reports &gt; Geometry</em> command to get results from this report.
            </p>
            <p class="small" lang="en">
                <em>&#xa9; 2006 Bentley Systems, Inc</em>
            </p>
        </div>
    </xsl:template>
</xsl:stylesheet>
