<?xml version="1.0" encoding="UTF-8"?>
<xsl:stylesheet version="1.1" xmlns:xsl="http://www.w3.org/1999/XSL/Transform" xmlns:fo="http://www.w3.org/1999/XSL/Format" xmlns:msxsl="urn:schemas-microsoft-com:xslt" xmlns:inr="http://mycompany.com/mynamespace">
    <xsl:include href="../format.xsl"/>
    <!-- Vertical Alignment Review ASCII Report -->
    <xsl:output method="text" media-type="text/plain" encoding="iso-8859-1"/>
    <xsl:template match="/">
        <xsl:variable name="gridOut" select="inr:SetGridOut(number(InRoads/@outputGridScaleFactor))"/>
        <xsl:choose>
            <xsl:when test="$xslShowHelp = 'true'">
                <xsl:call-template name="StyleSheetHelp"/>
            </xsl:when>
            <xsl:otherwise>
                <xsl:for-each select="InRoads/GeometryProject">
                    <xsl:text/>
                    <xsl:text>* BENTLEY VERTICAL ALIGNMENT REVIEW&#xd;</xsl:text>
                    <xsl:text>* &#xd;</xsl:text>
                    <xsl:for-each select="HorizontalAlignment/VerticalAlignment">
                        <xsl:text>* Alignment name: </xsl:text><xsl:value-of select="@name"/><xsl:text>&#xd;</xsl:text>
                        <xsl:text>* Alignment description: </xsl:text><xsl:value-of select="@description"/><xsl:text>&#xd;</xsl:text>
                        <xsl:text>* Alignment style: </xsl:text><xsl:value-of select="@style"/><xsl:text>&#xd;</xsl:text>
                        <xsl:text>* Input Factor: </xsl:text><xsl:value-of select="//@inputGridScaleFactor"/><xsl:text>&#xd;</xsl:text>
                        <xsl:text>* &#xd;</xsl:text>
                        <xsl:value-of select="inr:columnFormat('STATION',70)"/>
                        <xsl:value-of select="inr:columnFormat('ELEVATION',20)"/>
                        <xsl:for-each select="VerticalElements">
                            <xsl:text>&#xd;</xsl:text>
                            <xsl:apply-templates/>
                        </xsl:for-each>
                    </xsl:for-each>
                </xsl:for-each>
            </xsl:otherwise>
        </xsl:choose>
    </xsl:template>
    <!-- Vertical Alignment Linear Data -->
    <xsl:template match="VerticalLine">
        <xsl:text>Element: Linear</xsl:text>
        <xsl:text>&#xd;</xsl:text>
        <xsl:value-of select="inr:columnFormat(string(VerticalStart/@type),50)"/>
        <xsl:value-of select="inr:columnFormat(inr:stationFormat(number(VerticalStart/station/@externalStation), $xslStationFormat, $xslStationPrecision, string(VerticalStart/station/@externalStationName)),20)"/>
        <xsl:value-of select="inr:columnFormat(inr:elevationFormat(number(VerticalStart/@elevation), $xslElevationPrecision),20)"/>
        <xsl:text>&#xd;</xsl:text>
        <xsl:if test="StationEquation">
            <xsl:value-of select="inr:columnFormat('EQNBK',50)"/>
            <xsl:value-of select="inr:columnFormat(inr:stationFormat(number(StationEquation/@backStation), $xslStationFormat, $xslStationPrecision, string(StationEquation/@backEquation)),20)"/>
            <xsl:text>&#xd;</xsl:text>
            <xsl:value-of select="inr:columnFormat('EQNAHD',50)"/>
            <xsl:value-of select="inr:columnFormat(inr:stationFormat(number(StationEquation/@aheadStation), $xslStationFormat, $xslStationPrecision, string(StationEquation/@aheadEquation)),20)"/>
            <xsl:text>&#xd;</xsl:text>
        </xsl:if>
        <xsl:value-of select="inr:columnFormat(string(VerticalEnd/@type),50)"/>
        <xsl:value-of select="inr:columnFormat(inr:stationFormat(number(VerticalEnd/station/@externalStation), $xslStationFormat, $xslStationPrecision, string(VerticalEnd/station/@externalStationName)),20)"/>
        <xsl:value-of select="inr:columnFormat(inr:elevationFormat(number(VerticalEnd/@elevation), $xslElevationPrecision),20)"/>
        <xsl:text>&#xd;</xsl:text>
        <xsl:value-of select="inr:columnFormat('Tangent Grade:',50)"/>
        <xsl:value-of select="inr:columnFormat(inr:gradeFormat(number(@grade), $xslGradeFormat, $xslGradePrecision),20)"/>
        <xsl:text>&#xd;</xsl:text>
        <xsl:value-of select="inr:columnFormat('Tangent Length:',50)"/>
        <xsl:value-of select="inr:columnFormat(inr:distanceFormat(number(@length), $xslDistancePrecision),20)"/>
        <xsl:text>&#xd;</xsl:text>
    </xsl:template>
    <!-- Vertical Alignment Symmetrical Parabola Data -->
    <xsl:template match="VerticalSymmetricalParabola">
        <xsl:text>Element: Symmetrical Parabola</xsl:text>
        <xsl:text>&#xd;</xsl:text>
        <xsl:value-of select="inr:columnFormat(string(VerticalStart/@type),50)"/>
        <xsl:value-of select="inr:columnFormat(inr:stationFormat(number(VerticalStart/station/@externalStation), $xslStationFormat, $xslStationPrecision, string(VerticalStart/station/@externalStationName)),20)"/>
        <xsl:value-of select="inr:columnFormat(inr:elevationFormat(number(VerticalStart/@elevation), $xslElevationPrecision),20)"/>
        <xsl:text>&#xd;</xsl:text>
        <xsl:value-of select="inr:columnFormat(string(PVI/@type),50)"/>
        <xsl:value-of select="inr:columnFormat(inr:stationFormat(number(PVI/station/@externalStation), $xslStationFormat, $xslStationPrecision, string(PVI/station/@externalStationName)),20)"/>
        <xsl:value-of select="inr:columnFormat(inr:elevationFormat(number(PVI/@elevation), $xslElevationPrecision),20)"/>
        <xsl:text>&#xd;</xsl:text>
        <xsl:if test="StationEquation">
            <xsl:value-of select="inr:columnFormat('EQNBK',50)"/>
            <xsl:value-of select="inr:columnFormat(inr:stationFormat(number(StationEquation/@backStation), $xslStationFormat, $xslStationPrecision, string(StationEquation/@backEquation)),20)"/>
            <xsl:text>&#xd;</xsl:text>
            <xsl:value-of select="inr:columnFormat('EQNAHD',50)"/>
            <xsl:value-of select="inr:columnFormat(inr:stationFormat(number(StationEquation/@aheadStation), $xslStationFormat, $xslStationPrecision, string(StationEquation/@aheadEquation)),20)"/>
        </xsl:if>
        <xsl:value-of select="inr:columnFormat(string(VerticalEnd/@type),50)"/>
        <xsl:value-of select="inr:columnFormat(inr:stationFormat(number(VerticalEnd/station/@externalStation), $xslStationFormat, $xslStationPrecision, string(VerticalEnd/station/@externalStationName)),20)"/>
        <xsl:value-of select="inr:columnFormat(inr:elevationFormat(number(VerticalEnd/@elevation), $xslElevationPrecision),20)"/>
        <xsl:text>&#xd;</xsl:text>
        <xsl:if test="TurningPoint">
            <xsl:value-of select="inr:columnFormat(string(TurningPoint/@type),50)"/>
            <xsl:value-of select="inr:columnFormat(inr:stationFormat(number(TurningPoint/station/@externalStation), $xslStationFormat, $xslStationPrecision, string(TurningPoint/station/@externalStationName)),20)"/>
            <xsl:value-of select="inr:columnFormat(inr:elevationFormat(number(TurningPoint/@elevation), $xslElevationPrecision),20)"/>
        </xsl:if>
        <xsl:text>&#xd;</xsl:text>
        <xsl:value-of select="inr:columnFormat('Length:',50)"/>
        <xsl:value-of select="inr:columnFormat(inr:distanceFormat(number(@verticalCurveLength), $xslDistancePrecision),20)"/>
        <xsl:text>&#xd;</xsl:text>
        <xsl:value-of select="inr:columnFormat('Entrance Grade:',50)"/>
        <xsl:value-of select="inr:columnFormat(inr:gradeFormat(number(@startGrade), $xslGradeFormat, $xslGradePrecision),20)"/>
        <xsl:text>&#xd;</xsl:text>
        <xsl:value-of select="inr:columnFormat('Exit Grade:',50)"/>
        <xsl:value-of select="inr:columnFormat(inr:gradeFormat(number(@endGrade), $xslGradeFormat, $xslGradePrecision),20)"/>
        <xsl:text>&#xd;</xsl:text>
        <xsl:value-of select="inr:columnFormat('r = (g2 - g1) / L:',50)"/>
        <xsl:value-of select="inr:columnFormat(inr:distanceFormat(number(@rateOfChange), $xslDistancePrecision),20)"/>
        <xsl:text>&#xd;</xsl:text>
        <xsl:value-of select="inr:columnFormat('K = l / (g2 - g1):',50)"/>
        <xsl:value-of select="inr:columnFormat(inr:distanceFormat(number(@kValue), $xslDistancePrecision),20)"/>
        <xsl:text>&#xd;</xsl:text>
        <xsl:value-of select="inr:columnFormat('Middle Ordinate:',50)"/>
        <xsl:value-of select="inr:columnFormat(inr:distanceFormat(number(@midOrdinate), $xslDistancePrecision),20)"/>
        <xsl:text>&#xd;</xsl:text>
    </xsl:template>
    <!-- Vertical Alignment Unsymmetrical Parabola Data -->
    <xsl:template match="VerticalUnsymmetricalParabola">
        <xsl:text>Element: Unsymmetrical Parabola</xsl:text>
        <xsl:text>&#xd;</xsl:text>
        <xsl:value-of select="inr:columnFormat(string(VerticalStart/@type),50)"/>
        <xsl:value-of select="inr:columnFormat(inr:stationFormat(number(VerticalStart/station/@externalStation), $xslStationFormat, $xslStationPrecision, string(VerticalStart/station/@externalStationName)),20)"/>
        <xsl:value-of select="inr:columnFormat(inr:elevationFormat(number(VerticalStart/@elevation), $xslElevationPrecision),20)"/>
        <xsl:text>&#xd;</xsl:text>
        <xsl:value-of select="inr:columnFormat(string(PVI/@type),50)"/>
        <xsl:value-of select="inr:columnFormat(inr:stationFormat(number(PVI/station/@externalStation), $xslStationFormat, $xslStationPrecision, string(PVI/station/@externalStationName)),20)"/>
        <xsl:value-of select="inr:columnFormat(inr:elevationFormat(number(PVI/@elevation), $xslElevationPrecision),20)"/>
        <xsl:text>&#xd;</xsl:text>
        <xsl:value-of select="inr:columnFormat(string(PVCC/@type),50)"/>
        <xsl:value-of select="inr:columnFormat(inr:stationFormat(number(PVCC/station/@externalStation), $xslStationFormat, $xslStationPrecision, string(PVCC/station/@externalStationName)),20)"/>
        <xsl:value-of select="inr:columnFormat(inr:elevationFormat(number(PVCC/@elevation), $xslElevationPrecision),20)"/>
        <xsl:text>&#xd;</xsl:text>
        <xsl:if test="StationEquation">
            <xsl:value-of select="inr:columnFormat('EQNBK',50)"/>
            <xsl:value-of select="inr:columnFormat(inr:stationFormat(number(StationEquation/@backStation), $xslStationFormat, $xslStationPrecision, string(StationEquation/@backEquation)),20)"/>
            <xsl:text>&#xd;</xsl:text>
            <xsl:value-of select="inr:columnFormat('EQNAHD',50)"/>
            <xsl:value-of select="inr:columnFormat(inr:stationFormat(number(StationEquation/@aheadStation), $xslStationFormat, $xslStationPrecision, string(StationEquation/@aheadEquation)),20)"/>
            <xsl:text>&#xd;</xsl:text>
        </xsl:if>
        <xsl:value-of select="inr:columnFormat(string(VerticalEnd/@type),50)"/>
        <xsl:value-of select="inr:columnFormat(inr:stationFormat(number(VerticalEnd/station/@externalStation), $xslStationFormat, $xslStationPrecision, string(VerticalEnd/station/@externalStationName)),20)"/>
        <xsl:value-of select="inr:columnFormat(inr:elevationFormat(number(VerticalEnd/@elevation), $xslElevationPrecision),20)"/>
        <xsl:text>&#xd;</xsl:text>
        <xsl:if test="TurningPoint">
            <xsl:value-of select="inr:columnFormat(string(TurningPoint/@type),50)"/>
            <xsl:value-of select="inr:columnFormat(inr:stationFormat(number(TurningPoint/station/@externalStation), $xslStationFormat, $xslStationPrecision, string(TurningPoint/station/@externalStationName)),20)"/>
            <xsl:value-of select="inr:columnFormat(inr:elevationFormat(number(TurningPoint/@elevation), $xslElevationPrecision),20)"/>
            <xsl:text>&#xd;</xsl:text>
        </xsl:if>
        <xsl:value-of select="inr:columnFormat('Entrance Length:',50)"/>
        <xsl:value-of select="inr:columnFormat(inr:distanceFormat(number(@startVerticalCurveLength), $xslDistancePrecision),20)"/>
        <xsl:text>&#xd;</xsl:text>
        <xsl:value-of select="inr:columnFormat('Exit Length:',50)"/>
        <xsl:value-of select="inr:columnFormat(inr:distanceFormat(number(@endVerticalCurveLength), $xslDistancePrecision),20)"/>
        <xsl:text>&#xd;</xsl:text>
        <xsl:value-of select="inr:columnFormat('Entrance Grade:',50)"/>
        <xsl:value-of select="inr:columnFormat(inr:gradeFormat(number(@startGrade), $xslGradeFormat, $xslGradePrecision),20)"/>
        <xsl:text>&#xd;</xsl:text>
        <xsl:value-of select="inr:columnFormat('Exit Grade:',50)"/>
        <xsl:value-of select="inr:columnFormat(inr:gradeFormat(number(@endGrade), $xslGradeFormat, $xslGradePrecision),20)"/>
        <xsl:text>&#xd;</xsl:text>
        <xsl:value-of select="inr:columnFormat('r = (g2 - g1) / L:',50)"/>
        <xsl:variable name="startRateOfChange">
            <xsl:text>Entrance:&#xa0;</xsl:text>
            <xsl:value-of select="inr:distanceFormat(number(@startRateOfChange), $xslDistancePrecision)"/>
        </xsl:variable>
        <xsl:variable name="endRateOfChange">
            <xsl:text>Exit:&#xa0;</xsl:text>
            <xsl:value-of select="inr:distanceFormat(number(@endRateOfChange), $xslDistancePrecision)"/>
        </xsl:variable>
        <xsl:value-of select="inr:columnFormat(string($startRateOfChange),20)"/>
        <xsl:value-of select="inr:columnFormat(string($endRateOfChange),20)"/>
        <xsl:text>&#xd;</xsl:text>
        <xsl:variable name="startKValue">
            <xsl:text>Entrance:&#xa0;</xsl:text>
            <xsl:value-of select="inr:distanceFormat(number(@startKValue), $xslDistancePrecision)"/>
        </xsl:variable>
        <xsl:variable name="endKValue">
            <xsl:text>Exit:&#xa0;</xsl:text>
            <xsl:value-of select="inr:distanceFormat(number(@endKValue), $xslDistancePrecision)"/>
        </xsl:variable>
        <xsl:value-of select="inr:columnFormat('K = l / (g2 - g1):',50)"/>
        <xsl:value-of select="inr:columnFormat(string($startKValue),20)"/>
        <xsl:value-of select="inr:columnFormat(string($endKValue),20)"/>
        <xsl:text>&#xd;</xsl:text>
        <xsl:value-of select="inr:columnFormat('Middle Ordinate:',50)"/>
        <xsl:value-of select="inr:columnFormat(inr:distanceFormat(number(@midOrdinate), $xslDistancePrecision),20)"/>
       <xsl:text>&#xd;</xsl:text>
    </xsl:template>
    <!-- Vertical Alignment Circle Data -->
    <xsl:template match="VerticalCircle">
        <xsl:text>Element: Circular</xsl:text>
        <xsl:text>&#xd;</xsl:text>
        <xsl:value-of select="inr:columnFormat(string(VerticalStart/@type),50)"/>
        <xsl:value-of select="inr:columnFormat(inr:stationFormat(number(VerticalStart/station/@externalStation), $xslStationFormat, $xslStationPrecision, string(VerticalStart/station/@externalStationName)),20)"/>
        <xsl:value-of select="inr:columnFormat(inr:elevationFormat(number(VerticalStart/@elevation), $xslElevationPrecision),20)"/>
        <xsl:text>&#xd;</xsl:text>
        <xsl:value-of select="inr:columnFormat(string(PVI/@type),50)"/>
        <xsl:value-of select="inr:columnFormat(inr:stationFormat(number(PVI/station/@externalStation), $xslStationFormat, $xslStationPrecision, string(PVI/station/@externalStationName)),20)"/>
        <xsl:value-of select="inr:columnFormat(inr:elevationFormat(number(PVI/@elevation), $xslElevationPrecision),20)"/>
        <xsl:text>&#xd;</xsl:text>
        <xsl:value-of select="inr:columnFormat(string(VerticalCenter/@type),50)"/>
        <xsl:value-of select="inr:columnFormat(inr:stationFormat(number(VerticalCenter/station/@externalStation), $xslStationFormat, $xslStationPrecision, string(VerticalCenter/station/@externalStationName)),20)"/>
        <xsl:value-of select="inr:columnFormat(inr:elevationFormat(number(VerticalCenter/@elevation), $xslElevationPrecision),20)"/>
        <xsl:text>&#xd;</xsl:text>
        <xsl:if test="StationEquation">
            <xsl:value-of select="inr:columnFormat('EQNBK',50)"/>
            <xsl:value-of select="inr:columnFormat(inr:stationFormat(number(StationEquation/@backStation), $xslStationFormat, $xslStationPrecision, string(StationEquation/@backEquation)),20)"/>
            <xsl:text>&#xd;</xsl:text>
            <xsl:value-of select="inr:columnFormat('EQNAHD',50)"/>
            <xsl:value-of select="inr:columnFormat(inr:stationFormat(number(StationEquation/@aheadStation), $xslStationFormat, $xslStationPrecision, string(StationEquation/@aheadEquation)),20)"/>
            <xsl:text>&#xd;</xsl:text>
        </xsl:if>
        <xsl:value-of select="inr:columnFormat(string(VerticalEnd/@type),50)"/>
        <xsl:value-of select="inr:columnFormat(inr:stationFormat(number(VerticalEnd/station/@externalStation), $xslStationFormat, $xslStationPrecision, string(VerticalEnd/station/@externalStationName)),20)"/>
        <xsl:value-of select="inr:columnFormat(inr:elevationFormat(number(VerticalEnd/@elevation), $xslElevationPrecision),20)"/>
        <xsl:text>&#xd;</xsl:text>
        <xsl:if test="TurningPoint">
            <xsl:value-of select="inr:columnFormat(string(TurningPoint/@type),50)"/>
            <xsl:value-of select="inr:columnFormat(inr:stationFormat(number(TurningPoint/station/@externalStation), $xslStationFormat, $xslStationPrecision, string(TurningPoint/station/@externalStationName)),20)"/>
            <xsl:value-of select="inr:columnFormat(inr:elevationFormat(number(TurningPoint/@elevation), $xslElevationPrecision),20)"/>
            <xsl:text>&#xd;</xsl:text>
        </xsl:if>
        <xsl:value-of select="inr:columnFormat('Radius:',50)"/>
        <xsl:value-of select="inr:columnFormat(inr:distanceFormat(number(@radius), $xslDistancePrecision),20)"/>
        <xsl:text>&#xd;</xsl:text>
        <xsl:value-of select="inr:columnFormat('Length:',50)"/>
        <xsl:value-of select="inr:columnFormat(inr:distanceFormat(number(@length), $xslDistancePrecision),20)"/>
        <xsl:text>&#xd;</xsl:text>
        <xsl:value-of select="inr:columnFormat('Entrance Grade:',50)"/>
        <xsl:value-of select="inr:columnFormat(inr:gradeFormat(number(@startGrade), $xslGradeFormat, $xslGradePrecision),20)"/>
         <xsl:text>&#xd;</xsl:text>
        <xsl:value-of select="inr:columnFormat('Exit Grade:',50)"/>
        <xsl:value-of select="inr:columnFormat(inr:gradeFormat(number(@endGrade), $xslGradeFormat, $xslGradePrecision),20)"/>
        <xsl:text>&#xd;</xsl:text>
    </xsl:template>
    <!-- Vertical Alignment Clothoid Data -->
    <xsl:template match="VerticalClothoid">
        <xsl:text>Element: Clothoid</xsl:text>
        <xsl:text>&#xd;</xsl:text>
        <xsl:value-of select="inr:columnFormat(string(VerticalStart/@type),50)"/>
        <xsl:value-of select="inr:columnFormat(inr:stationFormat(number(VerticalStart/station/@externalStation), $xslStationFormat, $xslStationPrecision, string(VerticalStart/station/@externalStationName)),20)"/>
        <xsl:value-of select="inr:columnFormat(inr:elevationFormat(number(VerticalStart/@elevation), $xslElevationPrecision),20)"/>
        <xsl:text>&#xd;</xsl:text>
        <xsl:value-of select="inr:columnFormat(string(PVI/@type),50)"/>
        <xsl:value-of select="inr:columnFormat(inr:stationFormat(number(PVI/station/@externalStation), $xslStationFormat, $xslStationPrecision, string(PVI/station/@externalStationName)),20)"/>
        <xsl:value-of select="inr:columnFormat(inr:elevationFormat(number(PVI/@elevation), $xslElevationPrecision),20)"/>
        <xsl:text>&#xd;</xsl:text>
        <xsl:if test="StationEquation">
            <xsl:value-of select="inr:columnFormat('EQNBK',50)"/>
            <xsl:value-of select="inr:columnFormat(inr:stationFormat(number(StationEquation/@backStation), $xslStationFormat, $xslStationPrecision, string(StationEquation/@backEquation)),20)"/>
            <xsl:text>&#xd;</xsl:text>
            <xsl:value-of select="inr:columnFormat('EQNAHD',50)"/>
            <xsl:value-of select="inr:columnFormat(inr:stationFormat(number(StationEquation/@aheadStation), $xslStationFormat, $xslStationPrecision, string(StationEquation/@aheadEquation)),20)"/>
            <xsl:text>&#xd;</xsl:text>
        </xsl:if>
        <xsl:value-of select="inr:columnFormat(string(VerticalEnd/@type),50)"/>
        <xsl:value-of select="inr:columnFormat(inr:stationFormat(number(VerticalEnd/station/@externalStation), $xslStationFormat, $xslStationPrecision, string(VerticalEnd/station/@externalStationName)),20)"/>
        <xsl:value-of select="inr:columnFormat(inr:elevationFormat(number(VerticalEnd/@elevation), $xslElevationPrecision),20)"/>
        <xsl:text>&#xd;</xsl:text>
        <xsl:if test="TurningPoint">
            <xsl:value-of select="inr:columnFormat(TurningPoint/@type),50)"/>
            <xsl:value-of select="inr:columnFormat(inr:stationFormat(number(TurningPoint/station/@externalStation), $xslStationFormat, $xslStationPrecision, string(TurningPoint/station/@externalStationName)),20)"/>
            <xsl:value-of select="inr:columnFormat(inr:elevationFormat(number(TurningPoint/@elevation), $xslElevationPrecision),20)"/>
            <xsl:text>&#xd;</xsl:text>
        </xsl:if>
        <xsl:value-of select="inr:columnFormat('Entrance Radius:',50)"/>
        <xsl:value-of select="inr:columnFormat(inr:distanceFormat(number(@startRadius), $xslDistancePrecision),20)"/>
        <xsl:text>&#xd;</xsl:text>
        <xsl:value-of select="inr:columnFormat('Exit Radius:',50)"/>
        <xsl:value-of select="inr:columnFormat(inr:distanceFormat(number(@endRadius), $xslDistancePrecision),20)"/>
        <xsl:text>&#xd;</xsl:text>
        <xsl:value-of select="inr:columnFormat('Length:',50)"/>
        <xsl:value-of select="inr:columnFormat(inr:distanceFormat(number(@length), $xslDistancePrecision),20)"/>
        <xsl:text>&#xd;</xsl:text>
        <xsl:value-of select="inr:columnFormat('Angle:',50)"/>
        <xsl:value-of select="inr:columnFormat(inr:angularFormat(number(@thetaAngle), $xslAngularFormat, $xslAngularPrecision, $xslAngularMethod),20)"/>
            <xsl:if test="@rotationDirection='cw'"><xsl:text> Right</xsl:text></xsl:if>
            <xsl:if test="@rotationDirection = 'ccw'"><xsl:text> Left</xsl:text></xsl:if>
        <xsl:text>&#xd;</xsl:text>
        <xsl:value-of select="inr:columnFormat('Long Tangent:',50)"/>
        <xsl:value-of select="inr:columnFormat(inr:distanceFormat(number(@longTangent), $xslDistancePrecision),20)"/>
        <xsl:text>&#xd;</xsl:text>
        <xsl:value-of select="inr:columnFormat('Short Tangent:',50)"/>
        <xsl:value-of select="inr:columnFormat(inr:distanceFormat(number(@shortTangent), $xslDistancePrecision),20)"/>
        <xsl:text>&#xd;</xsl:text>
        <xsl:value-of select="inr:columnFormat('Long Chord:',50)"/>
        <xsl:value-of select="inr:columnFormat(inr:distanceFormat(number(@longChord), $xslDistancePrecision),20)"/>
        <xsl:text>&#xd;</xsl:text>
        <xsl:value-of select="inr:columnFormat('Xs:',50)"/>
        <xsl:value-of select="inr:columnFormat(inr:distanceFormat(number(@xs), $xslDistancePrecision),20)"/>
        <xsl:text>&#xd;</xsl:text>
        <xsl:value-of select="inr:columnFormat('Ys:',50)"/>
        <xsl:value-of select="inr:columnFormat(inr:distanceFormat(number(@ys), $xslDistancePrecision),20)"/>
        <xsl:text>&#xd;</xsl:text>
        <xsl:value-of select="inr:columnFormat('P:',50)"/>
        <xsl:value-of select="inr:columnFormat(inr:distanceFormat(number(@p), $xslDistancePrecision),20)"/>
        <xsl:text>&#xd;</xsl:text>
        <xsl:value-of select="inr:columnFormat('K:',50)"/>
        <xsl:value-of select="inr:columnFormat(inr:distanceFormat(number(@ks), $xslDistancePrecision),20)"/>
        <xsl:text>&#xd;</xsl:text>
        <xsl:value-of select="inr:columnFormat('Entrance Grade:',50)"/>
        <xsl:value-of select="inr:columnFormat(inr:gradeFormat(number(@startGrade), $xslGradeFormat, $xslGradePrecision),20)"/>
        <xsl:text>&#xd;</xsl:text>
        <xsl:value-of select="inr:columnFormat('Exit Grade:',50)"/>
        <xsl:value-of select="inr:columnFormat(inr:gradeFormat(number(@endGrade), $xslGradeFormat, $xslGradePrecision),20)"/>
        <xsl:text>&#xd;</xsl:text>
    </xsl:template>
    <xsl:template name="StyleSheetHelp">
        <xsl:text>Notes&#xd;&#xd;</xsl:text>
        <xsl:text>    You must include at least one horizontal alignment in&#xd;</xsl:text>
        <xsl:text>    the Include field on the Tools &gt; XML Reports &gt;&#xd;</xsl:text>
        <xsl:text>    Geometry command to get results from this report.&#xd;&#xd;</xsl:text>
        <xsl:text>    You must also toggle on the Include Vertical Alignments&#xd;</xsl:text>
        <xsl:text>    option and select either All or Active.&#xd;&#xd;</xsl:text>
        <xsl:text>Copyright 2006 Bentley Systems, Inc&#xd;</xsl:text>
    </xsl:template>
</xsl:stylesheet>

