<?xml version="1.0" encoding="UTF-8"?>
<xsl:stylesheet version="1.1" xmlns:xsl="http://www.w3.org/1999/XSL/Transform" xmlns:fo="http://www.w3.org/1999/XSL/Format" xmlns:msxsl="urn:schemas-microsoft-com:xslt" xmlns:inr="http://mycompany.com/mynamespace">
    <xsl:include href="../format.xsl"/>
    <xsl:param name="xslRootDirectory" select="inr:xslRootDirectory"/>
    <!-- Variables to hold the minimum and maximum slew values -->
    <xsl:variable name="slewDiagramMax">
        <xsl:for-each select="//VerticalEventPoint[@eventType = 'regressionPoint']">
            <xsl:sort select="@verticalOffset" data-type="number"/>
            <xsl:if test="position() = last()">
                <xsl:value-of select="@verticalOffset"/>
            </xsl:if>
        </xsl:for-each>
    </xsl:variable>
    <xsl:variable name="slewDiagramMin">
        <xsl:for-each select="//VerticalEventPoint[@eventType = 'regressionPoint']">
            <xsl:sort select="@verticalOffset" data-type="number"/>
            <xsl:if test="position() = 1">
                <xsl:value-of select="@verticalOffset"/>
            </xsl:if>
        </xsl:for-each>
    </xsl:variable>
    <!-- Find greater of absolute values of minimum and maximum slew values -->
    <xsl:variable name="slewRange">
        <xsl:choose>
            <xsl:when test="$slewDiagramMax &gt;= (-1 * $slewDiagramMin)">
                <xsl:value-of select="$slewDiagramMax"/>
            </xsl:when>
            <xsl:otherwise>
                <xsl:value-of select="-1 * $slewDiagramMin"/>
            </xsl:otherwise>
        </xsl:choose>
    </xsl:variable>
    <!-- Vertical Slew Diagram Report -->
    <xsl:template match="/">
        <xsl:variable name="gridOut" select="inr:SetGridOut(number(InRoads/@outputGridScaleFactor))"/>
        <html>
            <head>
                <link rel="stylesheet" type="text/css" href="{$xslRootDirectory}/_Themes/engineer/theme.css"/>
                <!-- Title displayed in browser Title Bar -->
                <title lang="en">Vertical Slew Diagram</title>
            </head>
            <body>
                <xsl:choose>
                    <xsl:when test="$xslShowHelp = 'true'">
                        <xsl:call-template name="StyleSheetHelp"/>
                    </xsl:when>
                    <xsl:otherwise>
                        <xsl:for-each select="InRoads">
                            <center>
                                <!-- Report Title -->
                                <h2 lang="en">Vertical Slew Diagram</h2>
                                <p lang="en">
                                    Report Created:&#xa0; <xsl:value-of select="inr:date()"/><br/>
                                    Time:&#xa0; <xsl:value-of select="inr:time()"/>
                                </p>
                            </center>
                            <!-- Project Data -->
                            <xsl:for-each select="GeometryProject">
                                <table class="margin" cellpadding="2" width="90%">
                                    <tbody>
                                        <tr>
                                            <th align="right" lang="en">Project:&#xa0; </th>
                                            <td align="left" colspan="2"><xsl:value-of select="@name"/></td>
                                        </tr>
                                        <tr>
                                            <th align="right" lang="en">Description:&#xa0; </th>
                                            <td align="left" colspan="2"><xsl:value-of select="@description"/></td>
                                        </tr>
                                        <tr>
                                            <th align="right" lang="en">File Name:&#xa0; </th>
                                            <td align="left" colspan="2"><xsl:value-of select="@file"/></td>
                                        </tr>
                                        <tr>
                                            <th align="right" lang="en">Last Revised:&#xa0; </th>
                                            <td align="left" colspan="2">
                                                <xsl:value-of select="concat(@lastRevisedBy, '  ', @lastRevisedDate)"/>
                                            </td>
                                        </tr>
                                        <tr>
                                            <th align="right" lang="en" style="font-size: 80%">Input Grid Factor:&#xa0; </th>
                                            <td align="left" style="font-size: 80%">
                                                <xsl:value-of select="../@inputGridScaleFactor" />
                                            </td>
                                            <td align="right" lang="en" style="font-size: 80%">
                                                <strong>Note:&#xa0; </strong>All units in this report are in
                                                <xsl:if test="//@linearUnits = 'Imperial'">feet</xsl:if>
                                                <xsl:if test="//@linearUnits = 'Metric'">meters</xsl:if>
                                                unless specified otherwise.
                                            </td>
                                        </tr>
                                    </tbody>
                                </table>
                                <hr/>
                                <!-- Horizontal Alignment Data -->
                                <xsl:for-each select="HorizontalAlignment">
                                    <table class="margin" width="90%">
                                        <thead>
                                            <tr>
                                                <th align="right" lang="en" width="30%">Alignment Name:&#xa0; </th>
                                                <td align="left" width="70%"><xsl:value-of select="@name"/></td>
                                            </tr>
                                            <tr>
                                                <th align="right" lang="en">Alignment Description:&#xa0; </th>
                                                <td align="left"><xsl:value-of select="@description"/></td>
                                            </tr>
                                        </thead>
                                        <tbody>
                                            <xsl:for-each select="VerticalAlignment">
                                                <tr>
                                                    <th align="right" lang="en">Alignment Name:&#xa0; </th>
                                                    <td align="left"><xsl:value-of select="@name"/></td>
                                                </tr>
                                                <tr>
                                                    <th align="right" lang="en">Alignment Description:&#xa0; </th>
                                                    <td align="left"><xsl:value-of select="@description"/></td>
                                                </tr>
                                                <tr><td colspan="2">&#xa0;</td></tr>
                                                <xsl:apply-templates/>
                                            </xsl:for-each>
                                        </tbody>
                                    </table>
                                </xsl:for-each>
                            </xsl:for-each>
                        </xsl:for-each>
                    </xsl:otherwise>
                </xsl:choose>
            </body>
        </html>
    </xsl:template>
    <!-- Vertical Line Data -->
    <xsl:template match="VerticalLine">
        <tr>
            <td colspan="2">
                <table width="60%">
                    <colgroup span="3">
                        <col width="30%"/>
                        <col width="35%"/>
                        <col width="35%"/>
                    </colgroup>
                    <tr>
                        <th/>
                        <th align="right" class="underline" lang="en">Station</th>
                        <th align="right" class="underline" lang="en">Elevation</th>
                    </tr>
                    <tr>
                        <td align="left" colspan="3" lang="en">Type:&#xa0; Linear</td>
                    </tr>
                    <tr>
                        <td align="right"><xsl:value-of select="VerticalStart/@type"/></td>
                        <td align="right">
                            <xsl:value-of select="inr:stationFormat(number(VerticalStart/station/@externalStation), $xslStationFormat, $xslStationPrecision, string(VerticalStart/station/@externalStationName))"/>
                        </td>
                        <td align="right">
                            <xsl:value-of select="inr:elevationFormat(number(VerticalStart/@elevation), $xslElevationPrecision)"/>
                        </td>
                    </tr>
                    <xsl:if test="StationEquation">
                        <tr>
                            <td align="right" lang="en">EQNBK</td>
                            <td align="right">
                                <xsl:value-of select="inr:stationFormat(number(StationEquation/@backStation), $xslStationFormat, $xslStationPrecision, string(StationEquation/@backEquation))"/>
                            </td>
                        </tr>
                        <tr>
                            <td align="right" lang="en">EQNAHD</td>
                            <td align="right">
                                <xsl:value-of select="inr:stationFormat(number(StationEquation/@aheadStation), $xslStationFormat, $xslStationPrecision, string(StationEquation/@aheadEquation))"/>
                            </td>
                        </tr>
                    </xsl:if>
                    <tr>
                        <td align="right"><xsl:value-of select="VerticalEnd/@type"/></td>
                        <td align="right">
                            <xsl:value-of select="inr:stationFormat(number(VerticalEnd/station/@externalStation), $xslStationFormat, $xslStationPrecision, string(VerticalEnd/station/@externalStationName))"/>
                        </td>
                        <td align="right">
                            <xsl:value-of select="inr:elevationFormat(number(VerticalEnd/@elevation), $xslElevationPrecision)"/>
                        </td>
                    </tr>
                    <tr>
                        <td align="right" lang="en">Tangent Grade:</td>
                        <td align="right">
                            <xsl:value-of select="inr:gradeFormat(number(@grade), $xslGradeFormat, $xslGradePrecision)"/>
                        </td>
                    </tr>
                    <tr>
                        <td align="right" lang="en">Tangent Length:</td>
                        <td align="right">
                            <xsl:value-of select="inr:distanceFormat(number(@length), $xslDistancePrecision)"/>
                        </td>
                    </tr>
                </table>
            </td>
        </tr>
        <tr><td colspan="2"><hr/></td></tr>
        <xsl:call-template name="Data"/>
    </xsl:template>
    <!-- Vertical Alignment Symmetrical Parabola Data -->
    <xsl:template match="VerticalSymmetricalParabola">
        <tr>
            <td colspan="2">
                <table width="60%">
                    <colgroup span="3">
                        <col width="30%"/>
                        <col width="35%"/>
                        <col width="35%"/>
                    </colgroup>
                    <tr>
                        <th/>
                        <th align="right" class="underline" lang="en">Station</th>
                        <th align="right" class="underline" lang="en">Elevation</th>
                    </tr>
                     <tr>
                        <td align="left" colspan="3" lang="en">Type:&#xa0; Symmetrical Parabola</td>
                    </tr>
                    <tr>
                        <td align="right"><xsl:value-of select="VerticalStart/@type"/></td>
                        <td align="right">
                            <xsl:value-of select="inr:stationFormat(number(VerticalStart/station/@externalStation), $xslStationFormat, $xslStationPrecision, string(VerticalStart/station/@externalStationName))"/>
                        </td>
                        <td align="right">
                            <xsl:value-of select="inr:elevationFormat(number(VerticalStart/@elevation), $xslElevationPrecision)"/>
                        </td>
                    </tr>
                    <tr>
                        <td align="right"><xsl:value-of select="PVI/@type"/></td>
                        <td align="right">
                            <xsl:value-of select="inr:stationFormat(number(PVI/station/@externalStation), $xslStationFormat, $xslStationPrecision, string(PVI/station/@externalStationName))"/>
                        </td>
                        <td align="right">
                            <xsl:value-of select="inr:elevationFormat(number(PVI/@elevation), $xslElevationPrecision)"/>
                        </td>
                    </tr>
                    <xsl:if test="StationEquation">
                        <tr>
                            <td align="right" lang="en">EQNBK</td>
                            <td align="right">
                                <xsl:value-of select="inr:stationFormat(number(StationEquation/@backStation), $xslStationFormat, $xslStationPrecision, string(StationEquation/@backEquation))"/>
                            </td>
                        </tr>
                        <tr>
                            <td align="right" lang="en">EQNAHD</td>
                            <td align="right">
                                <xsl:value-of select="inr:stationFormat(number(StationEquation/@aheadStation), $xslStationFormat, $xslStationPrecision, string(StationEquation/@aheadEquation))"/>
                            </td>
                        </tr>
                    </xsl:if>
                    <tr>
                        <td align="right"><xsl:value-of select="VerticalEnd/@type"/></td>
                        <td align="right">
                            <xsl:value-of select="inr:stationFormat(number(VerticalEnd/station/@externalStation), $xslStationFormat, $xslStationPrecision, string(VerticalEnd/station/@externalStationName))"/>
                        </td>
                        <td align="right">
                            <xsl:value-of select="inr:elevationFormat(number(VerticalEnd/@elevation), $xslElevationPrecision)"/>
                        </td>
                    </tr>
                    <xsl:if test="TurningPoint">
                        <tr>
                            <td align="right"><xsl:value-of select="TurningPoint/@type"/></td>
                            <td align="right">
                                <xsl:value-of select="inr:stationFormat(number(TurningPoint/station/@externalStation), $xslStationFormat, $xslStationPrecision, string(TurningPoint/station/@externalStationName))"/>
                            </td>
                            <td align="right">
                                <xsl:value-of select="inr:elevationFormat(number(TurningPoint/@elevation), $xslElevationPrecision)"/>
                            </td>
                        </tr>
                    </xsl:if>
                    <tr>
                        <td align="right" lang="en">Length:</td>
                        <td align="right">
                            <xsl:value-of select="inr:distanceFormat(number(@verticalCurveLength), $xslDistancePrecision)"/>
                        </td>
                    </tr>
                    <tr>
                        <td align="right" lang="en">Entrance Grade:</td>
                       <td align="right">
                            <xsl:value-of select="inr:gradeFormat(number(@startGrade), $xslGradeFormat, $xslGradePrecision)"/>
                       </td>
                    </tr>
                    <tr>
                        <td align="right" lang="en">Exit Grade:</td>
                        <td align="right">
                            <xsl:value-of select="inr:gradeFormat(number(@endGrade), $xslGradeFormat, $xslGradePrecision)"/>
                        </td>
                    </tr>
                    <tr>
                        <td align="right" lang="en">r = (g2 - g1) / L:</td>
                        <td align="right">
                            <xsl:value-of select="inr:distanceFormat(number(@rateOfChange), $xslDistancePrecision)"/>
                        </td>
                    </tr>
                    <tr>
                        <td align="right" lang="en">K = l / (g2 - g1):</td>
                        <td align="right">
                            <xsl:value-of select="inr:distanceFormat(number(@kValue), $xslDistancePrecision)"/>
                        </td>
                    </tr>
                    <tr>
                        <td align="right" lang="en">Middle Ordinate:</td>
                        <td align="right">
                            <xsl:value-of select="inr:distanceFormat(number(@midOrdinate), $xslDistancePrecision)"/>
                        </td>
                    </tr>
               </table>
            </td>
        </tr>
        <tr><td colspan="2"><hr/></td></tr>
        <xsl:call-template name="Data"/>
    </xsl:template>
    <!-- Vertical Alignment Unsymmetrical Parabola Data -->
    <xsl:template match="VerticalUnsymmetricalParabola">
        <tr>
            <td colspan="2">
                <table width="60%">
                    <colgroup span="3">
                        <col width="30%"/>
                        <col width="35%"/>
                        <col width="35%"/>
                    </colgroup>
                    <tr>
                        <th/>
                        <th align="right" class="underline" lang="en">Station</th>
                        <th align="right" class="underline" lang="en">Elevation</th>
                    </tr>
                    <tr>
                        <td align="left" colspan="3" lang="en">Type:&#xa0; Unsymmetrical Parabola</td>
                    </tr>
                    <tr>
                        <td align="right"><xsl:value-of select="VerticalStart/@type"/></td>
                        <td align="right">
                            <xsl:value-of select="inr:stationFormat(number(VerticalStart/station/@externalStation), $xslStationFormat, $xslStationPrecision, string(VerticalStart/station/@externalStationName))"/>
                        </td>
                        <td align="right">
                            <xsl:value-of select="inr:elevationFormat(number(VerticalStart/@elevation), $xslElevationPrecision)"/>
                        </td>
                    </tr>
                    <tr>
                        <td align="right"><xsl:value-of select="PVI/@type"/></td>
                        <td align="right">
                            <xsl:value-of select="inr:stationFormat(number(PVI/station/@externalStation), $xslStationFormat, $xslStationPrecision, string(PVI/station/@externalStationName))"/>
                        </td>
                        <td align="right">
                            <xsl:value-of select="inr:elevationFormat(number(PVI/@elevation), $xslElevationPrecision)"/>
                        </td>
                    </tr>
                    <tr>
                        <td align="right"><xsl:value-of select="PVCC/@type"/></td>
                        <td align="right">
                            <xsl:value-of select="inr:stationFormat(number(PVCC/station/@externalStation), $xslStationFormat, $xslStationPrecision, string(PVCC/station/@externalStationName))"/>
                        </td>
                        <td align="right">
                            <xsl:value-of select="inr:elevationFormat(number(PVCC/@elevation), $xslElevationPrecision)"/>
                        </td>
                    </tr>
                    <xsl:if test="StationEquation">
                        <tr>
                            <td align="right" lang="en">EQNBK</td>
                            <td align="right">
                                <xsl:value-of select="inr:stationFormat(number(StationEquation/@backStation), $xslStationFormat, $xslStationPrecision, string(StationEquation/@backEquation))"/>
                            </td>
                        </tr>
                        <tr>
                            <td align="right" lang="en">EQNAHD</td>
                            <td align="right">
                                <xsl:value-of select="inr:stationFormat(number(StationEquation/@aheadStation), $xslStationFormat, $xslStationPrecision, string(StationEquation/@aheadEquation))"/>
                            </td>
                        </tr>
                    </xsl:if>
                    <tr>
                        <td align="right"><xsl:value-of select="VerticalEnd/@type"/></td>
                        <td align="right">
                            <xsl:value-of select="inr:stationFormat(number(VerticalEnd/station/@externalStation), $xslStationFormat, $xslStationPrecision, string(VerticalEnd/station/@externalStationName))"/>
                        </td>
                        <td align="right">
                            <xsl:value-of select="inr:elevationFormat(number(VerticalEnd/@elevation), $xslElevationPrecision)"/>
                        </td>
                    </tr>
                    <xsl:if test="TurningPoint">
                        <tr>
                            <td align="right"><xsl:value-of select="TurningPoint/@type"/></td>
                            <td align="right">
                                <xsl:value-of select="inr:stationFormat(number(TurningPoint/station/@externalStation), $xslStationFormat, $xslStationPrecision, string(TurningPoint/station/@externalStationName))"/>
                            </td>
                            <td align="right">
                                <xsl:value-of select="inr:elevationFormat(number(TurningPoint/@elevation), $xslElevationPrecision)"/>
                            </td>
                        </tr>
                    </xsl:if>
                    <tr>
                        <td align="right" lang="en">Entrance Length:</td>
                        <td align="right">
                            <xsl:value-of select="inr:distanceFormat(number(@startVerticalCurveLength), $xslDistancePrecision)"/>
                        </td>
                    </tr>
                    <tr>
                        <td align="right" lang="en">Exit Length:</td>
                        <td align="right">
                            <xsl:value-of select="inr:distanceFormat(number(@endVerticalCurveLength), $xslDistancePrecision)"/>
                        </td>
                    </tr>
                    <tr>
                        <td align="right" lang="en">Entrance Grade:</td>
                        <td align="right">
                            <xsl:value-of select="inr:gradeFormat(number(@startGrade), $xslGradeFormat, $xslGradePrecision)"/>
                        </td>
                    </tr>
                    <tr>
                        <td align="right" lang="en">Exit Grade:</td>
                        <td align="right">
                            <xsl:value-of select="inr:gradeFormat(number(@endGrade), $xslGradeFormat, $xslGradePrecision)"/>
                        </td>
                    </tr>
                    <tr>
                        <td align="right" lang="en">r = (g2 - g1) / L:</td>
                        <td align="right">
                            Entrance: &#xa0;<xsl:value-of select="inr:distanceFormat(number(@startRateOfChange), $xslDistancePrecision)"/>
                        </td>
                        <td align="right">
                            Exit: &#xa0;<xsl:value-of select="inr:distanceFormat(number(@endRateOfChange), $xslDistancePrecision)"/>
                        </td>
                    </tr>
                    <tr>
                        <td align="right" lang="en">K = l / (g2 - g1):</td>
                        <td align="right">
                            Entrance: &#xa0;<xsl:value-of select="inr:distanceFormat(number(@startKValue), $xslDistancePrecision)"/>
                        </td>
                        <td align="right">
                            Exit: &#xa0;<xsl:value-of select="inr:distanceFormat(number(@endKValue), $xslDistancePrecision)"/>
                       </td>
                    </tr>
                    <tr>
                       <td align="right" lang="en">Middle Ordinate:</td>
                       <td align="right">
                           <xsl:value-of select="inr:distanceFormat(number(@midOrdinate), $xslDistancePrecision)"/>
                       </td>
                   </tr>
                </table>
            </td>
        </tr>
        <tr><td colspan="2"><hr/></td></tr>
        <xsl:call-template name="Data"/>
    </xsl:template>
    <!-- Vertical Alignment Circle Data -->
    <xsl:template match="VerticalCircle">
        <tr>
            <td colspan="2">
                <table width="60%">
                    <colgroup span="3">
                        <col width="30%"/>
                        <col width="35%"/>
                        <col width="35%"/>
                    </colgroup>
                    <tr>
                        <th/>
                        <th align="right" class="underline" lang="en">Station</th>
                        <th align="right" class="underline" lang="en">Elevation</th>
                    </tr>
                    <tr>
                        <td align="left" colspan="3" lang="en">Type:&#xa0; Circular</td>
                    </tr>
                    <tr>
                        <td align="right"><xsl:value-of select="VerticalStart/@type"/></td>
                        <td align="right">
                            <xsl:value-of select="inr:stationFormat(number(VerticalStart/station/@externalStation), $xslStationFormat, $xslStationPrecision, string(VerticalStart/station/@externalStationName))"/>
                        </td>
                        <td align="right">
                            <xsl:value-of select="inr:elevationFormat(number(VerticalStart/@elevation), $xslElevationPrecision)"/>
                        </td>
                    </tr>
                    <tr>
                        <td align="right"><xsl:value-of select="PVI/@type"/></td>
                        <td align="right">
                            <xsl:value-of select="inr:stationFormat(number(PVI/station/@externalStation), $xslStationFormat, $xslStationPrecision, string(PVI/station/@externalStationName))"/>
                        </td>
                        <td align="right">
                            <xsl:value-of select="inr:elevationFormat(number(PVI/@elevation), $xslElevationPrecision)"/>
                        </td>
                    </tr>
                    <tr>
                        <td align="right"><xsl:value-of select="VerticalCenter/@type"/></td>
                        <td align="right">
                            <xsl:value-of select="inr:stationFormat(number(VerticalCenter/station/@externalStation), $xslStationFormat, $xslStationPrecision, string(VerticalCenter/station/@externalStationName))"/>
                        </td>
                        <td align="right">
                            <xsl:value-of select="inr:elevationFormat(number(VerticalCenter/@elevation), $xslElevationPrecision)"/>
                        </td>
                    </tr>
                    <xsl:if test="StationEquation">
                        <tr>
                            <td align="right" lang="en">EQNBK</td>
                            <td align="right">
                                <xsl:value-of select="inr:stationFormat(number(StationEquation/@backStation), $xslStationFormat, $xslStationPrecision, string(StationEquation/@backEquation))"/>
                            </td>
                        </tr>
                        <tr>
                            <td align="right" lang="en">EQNAHD</td>
                            <td align="right">
                                <xsl:value-of select="inr:stationFormat(number(StationEquation/@aheadStation), $xslStationFormat, $xslStationPrecision, string(StationEquation/@aheadEquation))"/>
                            </td>
                        </tr>
                    </xsl:if>
                    <tr>
                        <td align="right"><xsl:value-of select="VerticalEnd/@type"/></td>
                        <td align="right">
                            <xsl:value-of select="inr:stationFormat(number(VerticalEnd/station/@externalStation), $xslStationFormat, $xslStationPrecision, string(VerticalEnd/station/@externalStationName))"/>
                        </td>
                        <td align="right">
                            <xsl:value-of select="inr:elevationFormat(number(VerticalEnd/@elevation), $xslElevationPrecision)"/>
                        </td>
                    </tr>
                    <xsl:if test="TurningPoint">
                        <tr>
                            <td align="right"><xsl:value-of select="TurningPoint/@type"/></td>
                            <td align="right">
                                <xsl:value-of select="inr:stationFormat(number(TurningPoint/station/@externalStation), $xslStationFormat, $xslStationPrecision, string(TurningPoint/station/@externalStationName))"/>
                            </td>
                            <td align="right">
                                <xsl:value-of select="inr:elevationFormat(number(TurningPoint/@elevation), $xslElevationPrecision)"/>
                            </td>
                        </tr>
                    </xsl:if>
                    <tr>
                        <td align="right" lang="en">Radius:</td>
                        <td align="right">
                            <xsl:value-of select="inr:distanceFormat(number(@radius), $xslDistancePrecision)"/>
                        </td>
                    </tr>
                    <tr>
                        <td align="right" lang="en">Length:</td>
                        <td align="right">
                            <xsl:value-of select="inr:distanceFormat(number(@length), $xslDistancePrecision)"/>
                        </td>
                    </tr>
                    <tr>
                        <td align="right" lang="en">Entrance Grade:</td>
                        <td align="right">
                            <xsl:value-of select="inr:gradeFormat(number(@startGrade), $xslGradeFormat, $xslGradePrecision)"/>
                        </td>
                    </tr>
                    <tr>
                        <td align="right" lang="en">Exit Grade:</td>
                        <td align="right">
                            <xsl:value-of select="inr:gradeFormat(number(@endGrade), $xslGradeFormat, $xslGradePrecision)"/>
                        </td>
                    </tr>
                </table>
            </td>
        </tr>
        <tr><td colspan="2"><hr/></td></tr>
        <xsl:call-template name="Data"/>
    </xsl:template>
    <!-- Vertical Alignment Clothoid Data -->
    <xsl:template match="VerticalClothoid">
        <tr>
            <td colspan="2">
                <table width="505">
                    <colgroup span="3">
                        <col width="30%"/>
                        <col width="35%"/>
                        <col width="35%"/>
                    </colgroup>
                    <tr>
                        <th/>
                        <th align="right" class="underline" lang="en">Station</th>
                        <th align="right" class="underline" lang="en">Elevation</th>
                    </tr>
                    <tr>
                        <td align="left" colspan="3" lang="en">Type:&#xa0; Clothoid</td>
                    </tr>
                    <tr>
                        <td align="right"><xsl:value-of select="VerticalStart/@type"/></td>
                        <td align="right">
                            <xsl:value-of select="inr:stationFormat(number(VerticalStart/station/@externalStation), $xslStationFormat, $xslStationPrecision, string(VerticalStart/station/@externalStationName))"/>
                        </td>
                        <td align="right">
                            <xsl:value-of select="inr:elevationFormat(number(VerticalStart/@elevation), $xslElevationPrecision)"/>
                        </td>
                    </tr>
                    <tr>
                        <td align="right"><xsl:value-of select="PVI/@type"/></td>
                        <td align="right">
                            <xsl:value-of select="inr:stationFormat(number(PVI/station/@externalStation), $xslStationFormat, $xslStationPrecision, string(PVI/station/@externalStationName))"/>
                        </td>
                        <td align="right">
                            <xsl:value-of select="inr:elevationFormat(number(PVI/@elevation), $xslElevationPrecision)"/>
                        </td>
                    </tr>
                    <xsl:if test="StationEquation">
                        <tr>
                            <td align="right" lang="en">EQNBK</td>
                            <td align="right">
                                <xsl:value-of select="inr:stationFormat(number(StationEquation/@backStation), $xslStationFormat, $xslStationPrecision, string(StationEquation/@backEquation))"/>
                            </td>
                        </tr>
                        <tr>
                            <td align="right" lang="en">EQNAHD</td>
                            <td align="right">
                                <xsl:value-of select="inr:stationFormat(number(StationEquation/@aheadStation), $xslStationFormat, $xslStationPrecision, string(StationEquation/@aheadEquation))"/>
                            </td>
                        </tr>
                    </xsl:if>
                    <tr>
                        <td align="right"><xsl:value-of select="VerticalEnd/@type"/></td>
                        <td align="right">
                            <xsl:value-of select="inr:stationFormat(number(VerticalEnd/station/@externalStation), $xslStationFormat, $xslStationPrecision, string(VerticalEnd/station/@externalStationName))"/>
                        </td>
                        <td align="right">
                            <xsl:value-of select="inr:elevationFormat(number(VerticalEnd/@elevation), $xslElevationPrecision)"/>
                        </td>
                    </tr>
                    <xsl:if test="TurningPoint">
                        <tr>
                            <td align="right"><xsl:value-of select="TurningPoint/@type"/></td>
                            <td align="right">
                                <xsl:value-of select="inr:stationFormat(number(TurningPoint/station/@externalStation), $xslStationFormat, $xslStationPrecision, string(TurningPoint/station/@externalStationName))"/>
                            </td>
                            <td align="right">
                                <xsl:value-of select="inr:elevationFormat(number(TurningPoint/@elevation), $xslElevationPrecision)"/>
                            </td>
                        </tr>
                    </xsl:if>
                    <tr>
                        <td align="right" lang="en">Entrance Radius:</td>
                        <td align="right">
                            <xsl:value-of select="inr:distanceFormat(number(@startRadius), $xslDistancePrecision)"/>
                        </td>
                    </tr>
                    <tr>
                        <td align="right" lang="en">Exit Radius:</td>
                        <td align="right">
                            <xsl:value-of select="inr:distanceFormat(number(@endRadius), $xslDistancePrecision)"/>
                        </td>
                    </tr>
                    <tr>
                        <td align="right" lang="en">Length:</td>
                        <td align="right">
                            <xsl:value-of select="inr:distanceFormat(number(@length), $xslDistancePrecision)"/>
                        </td>
                    </tr>
                    <tr>
                        <td align="right" lang="en">Angle:</td>
                        <td align="right">
                            <xsl:value-of select="inr:angularFormat(number(@thetaAngle), $xslAngularFormat, $xslAngularPrecision, $xslAngularMethod)"/>
                        </td>
                        <td>
                            <xsl:if test="@rotationDirection='cw'">Right</xsl:if>
                            <xsl:if test="@rotationDirection = 'ccw'">Left</xsl:if>
                        </td>
                    </tr>
                    <tr>
                        <td align="right" lang="en">Long Tangent:</td>
                        <td align="right">
                            <xsl:value-of select="inr:distanceFormat(number(@longTangent), $xslDistancePrecision)"/>
                        </td>
                    </tr>
                    <tr>
                        <td align="right" lang="en">Short Tangent:</td>
                        <td align="right">
                            <xsl:value-of select="inr:distanceFormat(number(@shortTangent), $xslDistancePrecision)"/>
                        </td>
                    </tr>
                    <tr>
                        <td align="right" lang="en">Long Chord:</td>
                        <td align="right">
                            <xsl:value-of select="inr:distanceFormat(number(@longChord), $xslDistancePrecision)"/>
                        </td>
                    </tr>
                    <tr>
                        <td align="right" lang="en">Xs:</td>
                        <td align="right">
                            <xsl:value-of select="inr:distanceFormat(number(@xs), $xslDistancePrecision)"/>
                        </td>
                    </tr>
                    <tr>
                        <td align="right" lang="en">Ys:</td>
                        <td align="right">
                            <xsl:value-of select="inr:distanceFormat(number(@ys), $xslDistancePrecision)"/>
                        </td>
                    </tr>
                    <tr>
                        <td align="right" lang="en">P:</td>
                        <td align="right">
                            <xsl:value-of select="inr:distanceFormat(number(@p), $xslDistancePrecision)"/>
                        </td>
                    </tr>
                    <tr>
                        <td align="right" lang="en">K:</td>
                        <td align="right">
                            <xsl:value-of select="inr:distanceFormat(number(@ks), $xslDistancePrecision)"/>
                        </td>
                    </tr>
                    <tr>
                        <td align="right" lang="en">Entrance Grade:</td>
                        <td align="right">
                            <xsl:value-of select="inr:gradeFormat(number(@startGrade), $xslGradeFormat, $xslGradePrecision)"/>
                        </td>
                    </tr>
                    <tr>
                        <td align="right" lang="en">Exit Grade:</td>
                        <td align="right">
                            <xsl:value-of select="inr:gradeFormat(number(@endGrade), $xslGradeFormat, $xslGradePrecision)"/>
                        </td>
                    </tr>
                </table>
            </td>
        </tr>
        <tr><td colspan="2"><hr/></td></tr>
        <xsl:call-template name="Data"/>
    </xsl:template>
    <!-- Heading template for Slew Diagram columns -->
    <xsl:template name="Headings">
        <tr>
            <th class="underline" lang="en">Element <br/>Station</th>
            <th class="underline" lang="en">Alignment <br/>Station</th>
            <th class="underline" lang="en">Point Name</th>
            <th class="underline" lang="en">Vertical<br/>Offset</th>
            <th class="underline" lang="en">Fixity</th>
            <th class="underline" align="right" lang="en">Down</th>
            <th class="underline" lang="en">&#124;</th>
            <th class="underline" align="left" lang="en">Up</th>
        </tr>
    </xsl:template>
    <!-- Slew Diagram Data -->
    <xsl:template name="Data">
        <xsl:variable name="startStation" select="VerticalStart/station/@internalStation"/>
        <xsl:variable name="endStation" select="VerticalEnd/station/@internalStation"/>
        <tr>
            <td colspan="2">
                <table width="100%">
                    <colgroup span="8">
                        <col width="14%"/>
                        <col width="14%"/>
                        <col width="13%"/>
                        <col width="9%"/>
                        <col width="9"/>
                        <col width="19%"/>
                        <col width="1%"/>
                        <col width="19%"/>
                    </colgroup>
                    <xsl:call-template name="Headings"/>
                    <xsl:for-each select="ancestor::*/VerticalEventPoints/VerticalRegressionPoints/VerticalRegressionPoint/VerticalEventPoint/GeometryPoint">
                        <xsl:if test="station/@internalStation &gt;= $startStation and station/@internalStation &lt;= $endStation">
                            <tr>
                                <td align="right" style="white-space:nowrap;">
                                    <xsl:value-of select="inr:stationFormat(number(station/@externalStation - $startStation), $xslStationFormat, $xslStationPrecision, string(station/@externalStationName))"/>
                                </td>
                                <td align="right" style="white-space:nowrap;">
                                    <xsl:value-of select="inr:stationFormat(number(station/@externalStation), $xslStationFormat, $xslStationPrecision, string(station/@externalStationName))"/>
                                </td>
                                <td align="center">
                                    <xsl:value-of select="(@name)"/>
                                </td>
                                <td align="right">
                                    <xsl:value-of select="inr:distanceFormat(number(../@verticalOffset), $xslDistancePrecision)"/>
                                </td>
                                <td align="center">
                                    <xsl:value-of select="../../../VerticalRegressionPoint/@statusFixFree"/>
                                </td>
                                <!-- Slew Diagram Column-->
                                <td align="right">
                                    <xsl:if test="(../@verticalOffset &lt; 0.0)">
                                        <xsl:call-template name="Diagram"/>
                                    </xsl:if>
                                </td>
                                <td align="center">
                                    <xsl:if test="../@verticalOffset = 0.0">=</xsl:if>
                                    <xsl:if test="not(../@verticalOffset = 0.0)">&#124;</xsl:if>
                                </td>
                                <td align="left">
                                    <xsl:if test="(../@verticalOffset &gt; 0.0)">
                                        <xsl:call-template name="Diagram"/>
                                    </xsl:if>
                                </td>
                            </tr>
                        </xsl:if>
                    </xsl:for-each>
                </table>
            </td>
        </tr>
        <tr><td colspan="2"><hr/></td></tr>
        <tr><td colspan="2">&#xa0;</td></tr>
    </xsl:template>
    <!-- Slew Diagram -->
    <xsl:template name="Diagram">
        <xsl:if test="../@verticalOffset &lt; 0.0">
            <xsl:call-template name="LessThan0">
                <xsl:with-param name="valuePerSpace" select="number($slewRange div 9)"/>
            </xsl:call-template>
        </xsl:if>
        <xsl:if test="(../@verticalOffset &gt; 0.0)">
            <xsl:call-template name="GreaterThan0">
                <xsl:with-param name="valuePerSpace" select="number($slewRange div 9)"/>
            </xsl:call-template>
        </xsl:if>
    </xsl:template>
    <!-- Positive Offset -->
    <xsl:template name="GreaterThan0">
        <xsl:param name="valuePerSpace"/>
        <xsl:choose>
            <xsl:when test="(number(../@verticalOffset) &gt; 0.0) and (number(../@verticalOffset) &lt;= $valuePerSpace)">
                <xsl:value-of select="inr:leadingFormat('>', 3)"/>
            </xsl:when>
            <xsl:when test="(number(../@verticalOffset) &gt; $valuePerSpace) and (number(../@verticalOffset) &lt;= (2 * $valuePerSpace))">
                <xsl:value-of select="inr:leadingFormat('>', 6)"/>
            </xsl:when>
            <xsl:when test="(number(../@verticalOffset) &gt; (2 * $valuePerSpace)) and (number(../@verticalOffset) &lt;= (3 * $valuePerSpace))">
                <xsl:value-of select="inr:leadingFormat('>', 9)"/>
            </xsl:when>
            <xsl:when test="(number(../@verticalOffset) &gt; (3 * $valuePerSpace)) and (number(../@verticalOffset) &lt;= (4 * $valuePerSpace))">
                <xsl:value-of select="inr:leadingFormat('>', 12)"/>
            </xsl:when>
            <xsl:when test="(number(../@verticalOffset) &gt; (4 * $valuePerSpace)) and (number(../@verticalOffset) &lt;= (5 * $valuePerSpace))">
                <xsl:value-of select="inr:leadingFormat('>', 15)"/>
            </xsl:when>
            <xsl:when test="(number(../@verticalOffset) &gt; (5 * $valuePerSpace)) and (number(../@verticalOffset) &lt;= (6 * $valuePerSpace))">
                <xsl:value-of select="inr:leadingFormat('>', 18)"/>
            </xsl:when>
            <xsl:when test="(number(../@verticalOffset) &gt; (6 * $valuePerSpace)) and (number(../@verticalOffset) &lt;= (7 * $valuePerSpace))">
                <xsl:value-of select="inr:leadingFormat('>', 21)"/>
            </xsl:when>
            <xsl:when test="(number(../@verticalOffset) &gt; (7 * $valuePerSpace)) and (number(../@verticalOffset) &lt;= (8 * $valuePerSpace))">
                <xsl:value-of select="inr:leadingFormat('>', 24)"/>
            </xsl:when>
            <xsl:when test="(number(../@verticalOffset) &gt; (8 * $valuePerSpace)) and (number(../@verticalOffset) &lt;= (9 * $valuePerSpace))">
                <xsl:value-of select="inr:leadingFormat('>', 27)"/>
            </xsl:when>
            <xsl:when test="(number(../@verticalOffset) &gt; (9 * $valuePerSpace)) and (number(../@verticalOffset) &lt;= (slewDiagramMax))">
                <xsl:value-of select="inr:leadingFormat('>', 30)"/>
            </xsl:when>
        </xsl:choose>
    </xsl:template>
    <!-- Negative Offset -->
    <xsl:template name="LessThan0">
        <xsl:param name="valuePerSpace"/>
        <xsl:choose>
            <xsl:when test="(number(../@verticalOffset) &lt; 0.0) and (number(../@verticalOffset) &gt;= (-1 * $valuePerSpace))">
                <xsl:value-of select="inr:trailingFormat('&lt;', 3)"/>
            </xsl:when>
            <xsl:when test="(number(../@verticalOffset) &lt; (-1 * $valuePerSpace)) and (number(../@verticalOffset) &gt;= (-2 * $valuePerSpace))">
                <xsl:value-of select="inr:trailingFormat('&lt;', 6)"/>
            </xsl:when>
            <xsl:when test="(number(../@verticalOffset) &lt; (-2 * $valuePerSpace)) and (number(../@verticalOffset) &gt;= (-3 * $valuePerSpace))">
                <xsl:value-of select="inr:trailingFormat('&lt;', 9)"/>
            </xsl:when>
            <xsl:when test="(number(../@verticalOffset) &lt; (-3 * $valuePerSpace)) and (number(../@verticalOffset) &gt;= (-4 * $valuePerSpace))">
                <xsl:value-of select="inr:trailingFormat('&lt;', 12)"/>
            </xsl:when>
            <xsl:when test="(number(../@verticalOffset) &lt; (-4 * $valuePerSpace)) and (number(../@verticalOffset) &gt;= (-5 * $valuePerSpace))">
                <xsl:value-of select="inr:trailingFormat('&lt;', 15)"/>
            </xsl:when>
            <xsl:when test="(number(../@verticalOffset) &lt; (-5 * $valuePerSpace)) and (number(../@verticalOffset) &gt;= (-6 * $valuePerSpace))">
                <xsl:value-of select="inr:trailingFormat('&lt;', 18)"/>
            </xsl:when>
            <xsl:when test="(number(../@verticalOffset) &lt; (-6 * $valuePerSpace)) and (number(../@verticalOffset) &gt;= (-7 * $valuePerSpace))">
                <xsl:value-of select="inr:trailingFormat('&lt;', 21)"/>
            </xsl:when>
            <xsl:when test="(number(../@verticalOffset) &lt; (-7 * $valuePerSpace)) and (number(../@verticalOffset) &gt;= (-8 * $valuePerSpace))">
                <xsl:value-of select="inr:trailingFormat('&lt;', 24)"/>
            </xsl:when>
            <xsl:when test="(number(../@verticalOffset) &lt; (-8 * $valuePerSpace)) and (number(../@verticalOffset) &gt;= (-9 * $valuePerSpace))">
                <xsl:value-of select="inr:trailingFormat('&lt;', 27)"/>
            </xsl:when>
            <xsl:when test="(number(../@verticalOffset) &lt; (-9 * $valuePerSpace)) and (number(../@verticalOffset) &gt;= (slewDiagramMin))">
                <xsl:value-of select="inr:trailingFormat('&lt;', 30)"/>
            </xsl:when>
        </xsl:choose>
    </xsl:template>
    <xsl:template name="StyleSheetHelp">
        <div class="section1">
            <h4 lang="en">Notes</h4>
            <p class="normal1" lang="en">
                You must include at least one horizontal alignment in the <em>Include</em> field on the 
                <em>Tools &gt; XML Reports &gt; Geometry</em> command to get results from this report.
            </p>
            <p class="normal1" lang="en">
                You must also toggle on the <em>Include Vertical Alignments</em> option and 
                select either <em>All</em> or <em>Active</em>.
            </p>
            <p class="normal1" lang="en">
                This report requires vertical regression points for a complete report and you must toggle 
                on the <em>Include Vertical Event Points</em> option.
            </p>
            <p class="small" lang="en">
                <em>&#xa9; 2006 Bentley Systems, Inc</em>
            </p>
        </div>
    </xsl:template>
    <msxsl:script implements-prefix="inr" language="JScript">
        <![CDATA[
            // This Function formats a string with a length, padding with leading spaces
            // strString - String to get formated
            // nLength - Length of returned string
            function leadingFormat( strString, nLength )
            {
                var i = 0;
                var nBlanks = nLength - strString.length;
                for( i = 0; i < nBlanks; i++ )
                    strString = unescape("%a0") + strString;
                return strString;
            }
            // This Function formats a string with a length, padding with trailing spaces
            // strString - String to get formated
            // nLength - Length of returned string
            function trailingFormat( strString, nLength )
            {
                var nBlanks = nLength - strString.length;
                for( var i = 0; i < nBlanks; i++ )
                    strString = strString + unescape("%a0");
                return strString;
            }
        ]]>
    </msxsl:script>
</xsl:stylesheet>
