<?xml version="1.0" encoding="UTF-8"?>
<xsl:stylesheet version="1.1" xmlns:xsl="http://www.w3.org/1999/XSL/Transform" xmlns:fo="http://www.w3.org/1999/XSL/Format" xmlns:msxsl="urn:schemas-microsoft-com:xslt" xmlns:inr="http://mycompany.com/mynamespace">
    <xsl:include href="../format.xsl"/>
    <xsl:param name="xslRootDirectory" select="inr:xslRootDirectory"/>
    <!-- Locate Direction Report -->
    <xsl:output method="text" media-type="text/plain" encoding="iso-8859-1"/>
    <xsl:template match="/">
        <xsl:variable name="gridOut" select="inr:SetGridOut(number(InRoads/@outputGridScaleFactor))"/>
        <xsl:choose>
            <xsl:when test="$xslShowHelp = 'true'">
                <xsl:call-template name="StyleSheetHelp"/>
            </xsl:when>
            <xsl:otherwise>
                <xsl:for-each select="InRoads/GeometryProject">
                    <xsl:text/>
                    <xsl:text>SET SEQUENCE NE&#xd;</xsl:text>
                    <xsl:text>SET PARAMETER 1&#xd;</xsl:text>
                    <xsl:text>SET REFERENCE z&#xd;</xsl:text>
                    <xsl:text>SET TOLERANCE 0.0001&#xd;</xsl:text>
                    <xsl:text>COMBINED GRID FACTOR 1. 1.&#xd;</xsl:text>
                    <xsl:text>SET PROTECTION 0&#xd;</xsl:text>
                    <xsl:for-each select="HorizontalAlignment[HorizontalElements/*]">
                        <xsl:for-each select="HorizontalElements">
                            <xsl:text>STORE </xsl:text>
                            <xsl:value-of select="inr:columnFormat(string(*[position() = 1]/Start/@name), 6)"/>
                            <xsl:text> </xsl:text>
                            <xsl:value-of select="inr:columnDoubleFormat(number(*[position() = 1]/Start/@northing), 5, 13)"/>
                            <xsl:text> </xsl:text>
                            <xsl:value-of select="inr:columnDoubleFormat(number(*[position() = 1]/Start/@easting), 5, 13)"/>
                            <xsl:text> </xsl:text>
                            <xsl:value-of select="inr:columnDoubleFormat(number(*[position() = 1]/Start/@elevation), 5, 10)"/>
                            <xsl:text> ! </xsl:text>
                            <xsl:value-of select="*[position() = 1]/Start/@style"/>
                            <xsl:text> * </xsl:text>
                            <xsl:value-of select="*[position() = 1]/Start/@description"/>
                            <xsl:text>&#xd;</xsl:text>
                            <xsl:apply-templates mode="direction"/>
                        </xsl:for-each>
                        <xsl:text>DELETE FIGURE [ </xsl:text><xsl:value-of select="@name"/><xsl:text> ]&#xd;</xsl:text>
                        <xsl:text>STORE FIGURE </xsl:text>
                        <xsl:value-of select="@name"/>
                        <xsl:for-each select="HorizontalElements">
                            <xsl:variable name="fmtStartStation" select="inr:stationFormat(number(*[position() = 1]/Start/station/@externalStation), $xslStationFormat, 6, string(*[position() = 1]/Start/station/@externalStationName))"/>
                            <xsl:apply-templates mode="figure"/>
                            <xsl:value-of select="*[position() = 1]/Start/@name"/>
                            <xsl:text> </xsl:text>
                            <xsl:value-of select="inr:columnFormat(string($fmtStartStation), 16)"/>
                            <xsl:text>&#xd;</xsl:text>
        		              <xsl:text>FIGURE DESCRIPTION [ </xsl:text><xsl:value-of select="../@name"/><xsl:text> ] * </xsl:text><xsl:value-of select="../@description"/><xsl:text>&#xd;</xsl:text>
        		              <xsl:text>SET ALIGNMENT </xsl:text><xsl:value-of select="../@name"/>
                            <xsl:text>&#xd;</xsl:text>
                            <xsl:for-each select="*/StationEquation">
                                <xsl:variable name="fmtBackStation" select="inr:stationFormat(number(@backStation), $xslStationFormat, 6, string(@backEquation))"/>
                                <xsl:variable name="fmtAheadStation" select="inr:stationFormat(number(@aheadStation), $xslStationFormat, 6, string(@aheadEquation))"/>
                                <xsl:text>STATION EQUATION </xsl:text>
                                <xsl:value-of select="inr:columnFormat(string($fmtBackStation), 16)"/>
                                <xsl:value-of select="inr:columnFormat(string($fmtAheadStation), 16)"/>
                                <xsl:text>&#xd;</xsl:text>
                            </xsl:for-each>
                            <xsl:text>&#xd;</xsl:text>
                        </xsl:for-each>
                    </xsl:for-each>
                    <xsl:text>SET PROTECTION 1&#xd;</xsl:text>
                </xsl:for-each>
            </xsl:otherwise>
        </xsl:choose>
    </xsl:template>
    <!-- Horizontal Line Data -->
    <xsl:template match="HorizontalLine" mode="direction">
        <xsl:variable name="fmtDirection" select="inr:icsDirectionFormat(number(@direction), $xslDirectionPrecision, $xslAngularMethod)"/>
        <xsl:text>LOCATE DIRECTION </xsl:text>
        <xsl:value-of select="inr:columnFormat(string(Start/@name), 6)"/>
        <xsl:text> </xsl:text>
        <xsl:value-of select="inr:columnFormat(string(End/@name), 6)"/>
        <xsl:text> </xsl:text>
        <xsl:value-of select="inr:columnFormat(string($fmtDirection), 16)"/>
        <xsl:text> </xsl:text>
        <xsl:value-of select="inr:columnDoubleFormat(number(@length), 5, 11)"/>
        <xsl:text> ! </xsl:text>
        <xsl:value-of select="*[position() = 1]/End/@style"/>
        <xsl:text> * </xsl:text>
        <xsl:value-of select="*[position() = 1]/End/@description"/>
        <xsl:text>&#xd;</xsl:text>
    </xsl:template>
    <xsl:template match="HorizontalLine" mode="figure">
        <xsl:if test="position() = 1">
            <xsl:text> ( </xsl:text>
        </xsl:if>
        <xsl:value-of select="Start/@name"/>
        <xsl:choose>
            <xsl:when test="position() mod 8 = 0">
                <xsl:text>&#xd; </xsl:text>
            </xsl:when>
            <xsl:otherwise>
                <xsl:text> </xsl:text>
            </xsl:otherwise>
        </xsl:choose>
        <xsl:if test="position() = last()">
            <xsl:value-of select="End/@name"/>
            <xsl:text> ) </xsl:text>
        </xsl:if>
    </xsl:template>
    <!-- Horizontal Circle Data -->
    <xsl:template match="HorizontalCircle" mode="direction">
        <xsl:variable name="fmtDirectionStart">
            <xsl:choose>
                <xsl:when test="@rotationDirection = 'ccw'">
                    <xsl:value-of select="inr:icsDirectionFormat(number(@radialDirectionStart + 3.14159), $xslDirectionPrecision, $xslAngularMethod)"/>
                </xsl:when>
                <xsl:otherwise>
                    <xsl:value-of select="inr:icsDirectionFormat(number(@radialDirectionStart), $xslDirectionPrecision, $xslAngularMethod)"/>
                </xsl:otherwise>
            </xsl:choose>
        </xsl:variable>
        <xsl:variable name="fmtDirectionEnd">
            <xsl:choose>
                <xsl:when test="@rotationDirection = 'ccw'">
                    <xsl:value-of select="inr:icsDirectionFormat(number(@radialDirectionEnd), $xslDirectionPrecision, $xslAngularMethod)"/>
                </xsl:when>
                <xsl:otherwise>
                    <xsl:value-of select="inr:icsDirectionFormat(number(@radialDirectionEnd + 3.14159), $xslDirectionPrecision, $xslAngularMethod)"/>
                </xsl:otherwise>
            </xsl:choose>
        </xsl:variable>
        <xsl:text>LOCATE DIRECTION </xsl:text>
        <xsl:value-of select="inr:columnFormat(string(Start/@name), 6)"/>
        <xsl:text> </xsl:text>
        <xsl:value-of select="inr:columnFormat(string(Center/@name), 6)"/>
        <xsl:text> </xsl:text>
        <xsl:value-of select="inr:columnFormat(string($fmtDirectionStart), 16)"/>
        <xsl:text> </xsl:text>
        <xsl:value-of select="inr:columnDoubleFormat(number(@radius), 5, 11)"/>
        <xsl:text> ! </xsl:text>
        <xsl:value-of select="*[position() = 1]/Center/@style"/>
        <xsl:text> * </xsl:text>
        <xsl:value-of select="*[position() = 1]/Center/@description"/>
        <xsl:text>&#xd;</xsl:text>
        <xsl:text>LOCATE DIRECTION </xsl:text>
        <xsl:value-of select="inr:columnFormat(string(Center/@name), 6)"/>
        <xsl:text> </xsl:text>
        <xsl:value-of select="inr:columnFormat(string(End/@name), 6)"/>
        <xsl:text> </xsl:text>
        <xsl:value-of select="inr:columnFormat(string($fmtDirectionEnd), 16)"/>
        <xsl:text> </xsl:text>
        <xsl:value-of select="inr:columnDoubleFormat(number(@radius), 5, 11)"/>
        <xsl:text> ! </xsl:text>
        <xsl:value-of select="*[position() = 1]/End/@style"/>
        <xsl:text> * </xsl:text>
        <xsl:value-of select="*[position() = 1]/End/@description"/>
        <xsl:text>&#xd;</xsl:text>
    </xsl:template>
    <xsl:template match="HorizontalCircle" mode="figure">
        <xsl:if test="position() = 1">
            <xsl:text> ( </xsl:text>
        </xsl:if>
        <xsl:value-of select="Start/@name"/>
        <xsl:text> C</xsl:text>
        <xsl:value-of select="Center/@name"/>
        <xsl:choose>
            <xsl:when test="@rotationDirection = 'ccw'">L</xsl:when>
            <xsl:otherwise>R</xsl:otherwise>
        </xsl:choose>
        <xsl:choose>
            <xsl:when test="position() mod 8 = 0">
                <xsl:text>&#xd; </xsl:text>
            </xsl:when>
            <xsl:otherwise>
                <xsl:text> </xsl:text>
            </xsl:otherwise>
        </xsl:choose>
        <xsl:if test="position() = last()">
            <xsl:value-of select="End/@name"/>
            <xsl:text> ) </xsl:text>
        </xsl:if>
    </xsl:template>
    <!-- Horizontal Spiral Data -->
    <xsl:template match="HorizontalSpiral" mode="direction">
        <xsl:variable name="fmtDirectionStart" select="inr:icsDirectionFormat(number(@tangentialDirectionStart), $xslDirectionPrecision, $xslAngularMethod)"/>
        <xsl:variable name="fmtDirectionEnd" select="inr:icsDirectionFormat(number(@tangentialDirectionEnd), $xslDirectionPrecision, $xslAngularMethod)"/>
        <xsl:text>LOCATE DIRECTION </xsl:text>
        <xsl:value-of select="inr:columnFormat(string(Start/@name), 6)"/>
        <xsl:text> </xsl:text>
        <xsl:value-of select="inr:columnFormat(string(PI/@name), 6)"/>
        <xsl:text> </xsl:text>
        <xsl:value-of select="inr:columnFormat(string($fmtDirectionStart), 16)"/>
        <xsl:text> </xsl:text>
        <xsl:choose>
            <xsl:when test="(@startRadius &gt; @endRadius or @startRadius = 0) and not(@endRadius = 0)">
                <xsl:value-of select="inr:columnDoubleFormat(number(@longTangent), 5, 11)"/>
            </xsl:when>
            <xsl:otherwise>
                <xsl:value-of select="inr:columnDoubleFormat(number(@shortTangent), 5, 11)"/>
            </xsl:otherwise>
        </xsl:choose>
        <xsl:text> ! </xsl:text>
        <xsl:value-of select="*[position() = 1]/PI/@style"/>
        <xsl:text> * </xsl:text>
        <xsl:value-of select="*[position() = 1]/PI/@description"/>
        <xsl:text>&#xd;</xsl:text>
        <xsl:text>LOCATE DIRECTION </xsl:text>
        <xsl:value-of select="inr:columnFormat(string(PI/@name), 6)"/>
        <xsl:text> </xsl:text>
        <xsl:value-of select="inr:columnFormat(string(End/@name), 6)"/>
        <xsl:text> </xsl:text>
        <xsl:value-of select="inr:columnFormat(string($fmtDirectionEnd), 16)"/>
        <xsl:text> </xsl:text>
        <xsl:choose>
            <xsl:when test="(@startRadius &gt; @endRadius or @startRadius = 0) and not(@endRadius = 0)">
                <xsl:value-of select="inr:columnDoubleFormat(number(@shortTangent), 5, 11)"/>
            </xsl:when>
            <xsl:otherwise>
                <xsl:value-of select="inr:columnDoubleFormat(number(@longTangent), 5, 11)"/>
            </xsl:otherwise>
        </xsl:choose>
        <xsl:text> ! </xsl:text>
        <xsl:value-of select="*[position() = 1]/End/@style"/>
        <xsl:text> * </xsl:text>
        <xsl:value-of select="*[position() = 1]/End/@description"/>
        <xsl:text>&#xd;</xsl:text>
    </xsl:template>
    <xsl:template match="HorizontalSpiral" mode="figure">
        <xsl:if test="position() = 1">
            <xsl:text> ( </xsl:text>
        </xsl:if>
        <xsl:value-of select="Start/@name"/>
        <xsl:text> S</xsl:text>
        <xsl:value-of select="PI/@name"/>
        <xsl:choose>
            <xsl:when test="position() mod 8 = 0">
                <xsl:text>&#xd; </xsl:text>
            </xsl:when>
            <xsl:otherwise>
                <xsl:text> </xsl:text>
            </xsl:otherwise>
        </xsl:choose>
        <xsl:if test="position() = last()">
            <xsl:value-of select="End/@name"/>
            <xsl:text> ) </xsl:text>
        </xsl:if>
    </xsl:template>
    <xsl:template name="StyleSheetHelp">
        <xsl:text>Notes&#xd;&#xd;</xsl:text>
        <xsl:text>    You must include at least one horizontal alignment in&#xd;</xsl:text>
        <xsl:text>    the Include field on the Tools &gt; XML Reports &gt;&#xd;</xsl:text>
        <xsl:text>    Geometry command to get results from this report.&#xd;&#xd;</xsl:text>
        <xsl:text>    If your alignment points do not have names, this report&#xd;</xsl:text>
        <xsl:text>    will produce incomplete results.&#xd;&#xd;</xsl:text>
        <xsl:text>    Cogo point names and alignment point names must follow&#xd;</xsl:text>
        <xsl:text>    the strict ICS naming conventions for this report to be&#xd;</xsl:text>
        <xsl:text>    usable as an ICS input file.&#xd;&#xd;</xsl:text>
        <xsl:text>Copyright 2006 Bentley Systems, Inc&#xd;</xsl:text>
    </xsl:template>
    <msxsl:script implements-prefix="inr" language="JScript">
        <![CDATA[
            // This function sets the direction to ICS format
            // n - value from XML
            // precision - the number of digits after the decimal point
            function icsDirectionFormat(n, precision, method)
            {
                // Make sure we have a valid number
                if (!isNaN(n))
                {   
                    // this adds 360 to a negative number until it becomes positive
                    while (n < 0)
                    {
                        n += (2 * Math.PI);
                    }
                    // this subtracts 360 if the number is greater than 360
                    while (n >= (2 * Math.PI))
                    {
                        n -= (2 * Math.PI);
                    }
                    var decdeg = (n * 180) / Math.PI;
                    //identifies the quadrant
                    if (decdeg <= 90)
                    {
                        var strAngle = icsAngularFormat(n, precision, method);
                        return "N " + strAngle + " E";
                    }
                    //identifies the quadrant
                    if (90 < decdeg && decdeg <= 180)
                    {
                        n = Math.PI - n;
                        var strAngle = icsAngularFormat(n, precision, method);
                        return "S " + strAngle + " E";
                    }
                    //identifies the quadrant 
                    if (180 < decdeg && decdeg < 270)
                    {
                        n -= Math.PI;
                        var strAngle = icsAngularFormat(n, precision, method);
                        return "S " + strAngle + " W";
                    }
                    //identifies the quadrant
                    if (270 <= decdeg && decdeg < 360)
                    {
                        n = (2.0 * Math.PI) - n;
                        var strAngle = icsAngularFormat(n, precision, method);
                        return "N " + strAngle + " W";
                    }
                }
                return "";
             }
            // This function sets the angle to ICS format
            // n - value from xml
            // formatMethod - 1) Degrees, 2) Grads, 3) Radians
            // precision - the number of digits after the decimal point
            function icsAngularFormat(n, precision, formatMethod)
            {
                // Checking to see if the number is valid
                if (!isNaN(n))
                {
                    // converts from Radians to Degrees and formats the value
                    if (formatMethod == 1)
                    {
                        var decdeg = (n * 180) / Math.PI;
                        // takes only the whole number (ddd)
                        deg = Math.floor(Math.abs(decdeg));
                        // multiplies the decimal portion times 60 to get the minutes
                        var decmin = (Math.abs(decdeg) - deg) * 60;
                        // takes only the whole part of that number (mm')
                        var min = Math.floor(decmin);
                        // multiplies the decimal portion times 60 to get the seconds
                        var decsec = (decmin - min) * 60;
                        // call the function to set the correct precision
                        var str = formatNumber(decsec, precision);
                        if (str.substring(0, 2) == "60")
                        {
                            decsec = 0;
                            str = formatNumber(decsec, precision);
                            min = min + 1;
                            if (min == 60)
                            {
                                min = 0;
                                deg = deg + 1;
                            }
                        }
                        if (deg < 10)
                        {
                            deg = "0" + deg;
                        }
                        if (min < 10)
                        {
                            min = "0" + min;
                        }
                        var sec = str;
                        if (sec < 10)
                        {
                            sec = "0" + sec;
                        }
                        var msg =  deg + " " + min + " " + sec ;
                        return msg;
                    }
                    //converts Radians to Grads
                    if (formatMethod == 2)
                    {
                        var radtograd = (n * 200) / Math.PI;
                        var grad = formatNumber(radtograd, precision);
                        return grad;
                    }
                    // value in Radians needs to be formated
                    if (formatMethod == 3)
                    {
                        // call the function to set the correct precision
                        var radian = formatNumber(n, precision);
                        return radian;
                    }
                }
                return "";
             }
        ]]>
    </msxsl:script>
</xsl:stylesheet>
