<?xml version="1.0" encoding="UTF-8"?>
<xsl:stylesheet version="1.1" xmlns:xsl="http://www.w3.org/1999/XSL/Transform" xmlns:fo="http://www.w3.org/1999/XSL/Format" xmlns:msxsl="urn:schemas-microsoft-com:xslt" xmlns:inr="http://mycompany.com/mynamespace">
    <xsl:include href="../format.xsl"/>
    <!-- LandXML Vertical Alignment Review ASCII Format -->
    <xsl:output method="text" media-type="text/plain" encoding="iso-8859-1"/>
    <xsl:template match="/">
        <xsl:variable name="gridOut" select="inr:SetGridOut(number(InRoads/@outputGridScaleFactor))"/>
        <xsl:choose>
            <xsl:when test="$xslShowHelp = 'true'">
                <xsl:call-template name="StyleSheetHelp"/>
            </xsl:when>
            <xsl:otherwise>
                <xsl:for-each select="LandXML">
                    <xsl:text/>
                    <xsl:text>* BENTLEY LANDXML VERTICAL ALIGNMENT REVIEW&#xd;</xsl:text>
                    <xsl:text>* &#xd;</xsl:text>
                    <!-- Horizontal Alignment Data -->
                    <xsl:for-each select="Alignments/Alignment/Profile/ProfAlign">
                        <xsl:text>* Alignment name: </xsl:text><xsl:value-of select="@name"/><xsl:text>&#xd;</xsl:text>
                        <xsl:text>* Alignment description: </xsl:text><xsl:value-of select="@desc"/><xsl:text>&#xd;</xsl:text>
                        <xsl:text>* Alignment style: </xsl:text><xsl:value-of select="Feature/Property[@label = 'style']/@value"/><xsl:text>&#xd;</xsl:text>
                        <xsl:text>* Input Factor: </xsl:text><xsl:value-of select="//Project/Feature/Property[@label = 'GridScaleFactor']/@value"/><xsl:text>&#xd;</xsl:text>
                        <xsl:text>* &#xd;</xsl:text>
                        <xsl:value-of select="inr:columnFormat('STATION', 45)"/>
                        <xsl:value-of select="inr:columnFormat('ELEVATION', 20)"/>
                        <xsl:text>&#xd;</xsl:text>
                        <xsl:apply-templates/>
                    </xsl:for-each>
                </xsl:for-each>
            </xsl:otherwise>
        </xsl:choose>
    </xsl:template>
    <!-- Vertical Alignment Linear Data -->
    <xsl:template match="PVI">
        <xsl:text>Element: Linear</xsl:text>
        <xsl:text>&#xd;</xsl:text>
        <xsl:value-of select="inr:columnFormat('PVI', 25)"/>
        <xsl:call-template name="outputStation">
            <xsl:with-param name="list" select="."/>
        </xsl:call-template>
        <xsl:text>&#xd;</xsl:text>
        <xsl:text>&#xd;</xsl:text>
    </xsl:template>
    <!-- Vertical Alignment Symmetrical Parabola Data -->
    <xsl:template match="ParaCurve">
        <xsl:text>Element: Symmetrical Parabola</xsl:text>
        <xsl:text>&#xd;</xsl:text>
        <xsl:value-of select="inr:columnFormat('PVI', 25)"/>
        <xsl:call-template name="outputStation">
            <xsl:with-param name="list" select="."/>
        </xsl:call-template>
        <xsl:text>&#xd;</xsl:text>
        <xsl:value-of select="inr:columnFormat('Length:', 25)"/>
        <xsl:value-of select="inr:columnFormat(inr:distanceFormat(number(@length), $xslDistancePrecision), 20)"/>
        <xsl:text>&#xd;</xsl:text>
        <xsl:text>&#xd;</xsl:text>
    </xsl:template>
    <!-- Vertical Alignment Unsymmetrical Parabola Data -->
    <xsl:template match="UnsymParaCurve">
        <xsl:text>Element: Unsymmetrical Parabola</xsl:text>
        <xsl:text>&#xd;</xsl:text>
        <xsl:value-of select="inr:columnFormat('PVI', 25)"/>
        <xsl:call-template name="outputStation">
            <xsl:with-param name="list" select="."/>
        </xsl:call-template>
        <xsl:text>&#xd;</xsl:text>
        <xsl:value-of select="inr:columnFormat('Entrance Length:', 25)"/>
        <xsl:value-of select="inr:columnFormat(inr:distanceFormat(number(@lengthIn), $xslDistancePrecision), 20)"/>
        <xsl:text>&#xd;</xsl:text>
        <xsl:value-of select="inr:columnFormat('Exit Length:', 25)"/>
        <xsl:value-of select="inr:columnFormat(inr:distanceFormat(number(@lengthOut), $xslDistancePrecision), 20)"/>
        <xsl:text>&#xd;</xsl:text>
        <xsl:text>&#xd;</xsl:text>
    </xsl:template>
    <!-- Vertical Alignment Circle Data -->
    <xsl:template match="CircCurve">
        <xsl:text>Element: Circular</xsl:text>
        <xsl:text>&#xd;</xsl:text>
        <xsl:value-of select="inr:columnFormat('PVI', 25)"/>
        <xsl:call-template name="outputStation">
            <xsl:with-param name="list" select="."/>
        </xsl:call-template>
        <xsl:text>&#xd;</xsl:text>
        <xsl:value-of select="inr:columnFormat('Radius:', 25)"/>
        <xsl:value-of select="inr:columnFormat(inr:distanceFormat(number(@radius), $xslDistancePrecision), 20)"/>
        <xsl:text>&#xd;</xsl:text>
        <xsl:value-of select="inr:columnFormat('Length:', 25)"/>
        <xsl:value-of select="inr:columnFormat(inr:distanceFormat(number(@length), $xslDistancePrecision), 20)"/>
        <xsl:text>&#xd;</xsl:text>
        <xsl:text>&#xd;</xsl:text>
    </xsl:template>
    <!-- Coordinates -->
    <xsl:template name="outputStation">
        <xsl:param name="list"/>
        <xsl:variable name="nList" select="concat(normalize-space($list), ' ')"/>
        <xsl:variable name="first" select="substring-before($nList, ' ')"/>
        <xsl:variable name="rest" select="substring-after($nList, ' ')"/>
        <xsl:value-of select="inr:columnFormat(inr:stationFormat(number($first), $xslStationFormat, $xslStationPrecision, ''), 20)"/>
        <xsl:if test="$rest">
            <xsl:call-template name="outputZCoord">
                <xsl:with-param name="list" select="$rest"/>
            </xsl:call-template>
        </xsl:if>
    </xsl:template>
    <xsl:template name="outputZCoord">
        <xsl:param name="list"/>
        <xsl:variable name="nList" select="concat(normalize-space($list), ' ')"/>
        <xsl:variable name="first" select="substring-before($nList, ' ')"/>
        <xsl:value-of select="inr:columnFormat(inr:elevationFormat(number($first), $xslElevationPrecision), 20)"/>
    </xsl:template>
    <xsl:template name="StyleSheetHelp">
        <xsl:text>Notes&#xd;&#xd;</xsl:text>
        <xsl:text>    You must include at least one horizontal alignment with a child&#xd;</xsl:text>
        <xsl:text>    vertical alignment in the Include field on the Export Alignment&#xd;</xsl:text>
        <xsl:text>    tab of the File &gt; Translators &gt; LandXML Translator command&#xd;</xsl:text>
        <xsl:text>    to get results from this report.&#xd;&#xd;</xsl:text>
        <xsl:text>    You must also edit the file produced by the LandXML Translator&#xd;</xsl:text>
        <xsl:text>    command to remove the following attributes from the LandXML&#xd;</xsl:text>
        <xsl:text>    element at the top:&#xd;&#xd;</xsl:text>
        <xsl:text>       xmlns="http://www.landxml.org/schema/LandXML-1.1"&#xd;&#xd;</xsl:text>
        <xsl:text>       xmlns:xsi="http://www.w3.org/2001/XMLSchema-instance"&#xd;&#xd;</xsl:text>
        <xsl:text>       xsi:schemaLocation="http://www.landxml.org/schema/LandXML-1.1&#xd;</xsl:text>
        <xsl:text>         http://www.landxml.org/schema/landxml-1.1/LandXML-1.1.xsd"&#xd;&#xd;</xsl:text>
        <xsl:text>    The LandXML element should now resemble the following, where the&#xd;</xsl:text>
        <xsl:text>    version, date and time are replaced with your actual values:&#xd;&#xd;</xsl:text>
        <xsl:text>       &lt;LandXML version="1.1" date="2009-11-16" time="12:29:43"&gt;&#xd;&#xd;</xsl:text>
        <xsl:text>Copyright 2009 Bentley Systems, Inc&#xd;</xsl:text>
    </xsl:template>
</xsl:stylesheet>
