<?xml version="1.0" encoding="UTF-8"?>
<xsl:stylesheet version="1.1" xmlns:xsl="http://www.w3.org/1999/XSL/Transform" xmlns:fo="http://www.w3.org/1999/XSL/Format" xmlns:msxsl="urn:schemas-microsoft-com:xslt" xmlns:inr="http://mycompany.com/mynamespace">
    <xsl:include href="../format.xsl"/>
    <xsl:param name="xslRootDirectory" select="inr:xslRootDirectory"/>
    <!-- InRoads Station Base Report plus LandXML Geometry Export to IHSDM LandXML Format Report -->
    <!-- Variable to hold matching LandXML Geometry File.  This file must be placed in the same -->
    <!-- directory as this style sheet or the full short path must be provided. -->
    <xsl:variable name="geometryFile" select="document(concat($xslRootDirectory, '\StationOffset\MyGeom.xml'))"/>
    <!-- Variables to hold the feature names of the key features defining the zones.  These names need -->
    <!-- to be customized to match your data.  Do not change the name="" portion, only the portion -->
    <!-- between the angle brackets. -->
    <xsl:variable name="leftForeSlope">Ditch_L</xsl:variable>
    <xsl:variable name="leftShoulder">Shoulder_L</xsl:variable>
    <xsl:variable name="leftEOP">Edge_Driving_Top_L</xsl:variable>
    <xsl:variable name="center">CL_Asphalt_Top</xsl:variable>
    <xsl:variable name="rightEOP">Edge_Driving_Top_R</xsl:variable>
    <xsl:variable name="rightShoulder">Shoulder_R</xsl:variable>
    <xsl:variable name="rightForeSlope">Ditch_R</xsl:variable>
    <!-- Variable to hold the terrain type.  Please enter your choice of flat, rolling or mountainous. -->
    <xsl:variable name="terrainType">rolling</xsl:variable>
    <!-- Variable to hold the classification.  Please enter your choice of arterial, collector or -->
    <!-- local. -->
    <xsl:variable name="classification">local</xsl:variable>
    <xsl:output method="xml" encoding="iso-8859-1" indent="yes"/>
    <xsl:template match="/">
        <xsl:variable name="gridOut" select="inr:SetGridOut(number(InRoads/@outputGridScaleFactor))"/>
        <xsl:choose>
            <xsl:when test="$xslShowHelp = 'true'">
                <xsl:call-template name="StyleSheetHelp"/>
            </xsl:when>
            <xsl:otherwise>
                <xsl:apply-templates/>
            </xsl:otherwise>
        </xsl:choose>
    </xsl:template>
    <xsl:template match="InRoads" xmlns="http://www.landxml.org/schema/LandXML-1.0" xmlns:xsi="http://www.w3.org/2001/XMLSchema-instance" xsi:schemaLocation="http://www.landxml.org/schema/LandXML-1.0 http://www.landxml.org/schema/landxml-1.0/LandXML-1.0.xsd">
        <xsl:element name="LandXML" namespace="http://www.landxml.org/schema/LandXML-1.0">
            <xsl:attribute name="version">1.0</xsl:attribute>
            <xsl:attribute name="date"><xsl:value-of select="inr:dateLXML()"/></xsl:attribute>
            <xsl:attribute name="time"><xsl:value-of select="inr:timeLXML()"/></xsl:attribute>
            <xsl:copy-of select="$geometryFile/*/node()"/>
            <xsl:for-each select="GeometryProject/HorizontalAlignment">
                <xsl:element name="Roadways">
                    <xsl:element name="Roadway">
                        <xsl:attribute name="name"><xsl:value-of select="@name"/></xsl:attribute>
                        <xsl:attribute name="alignmentRefs"><xsl:value-of select="@name"/></xsl:attribute>
                        <xsl:attribute name="gradeModelRefs">
                            <xsl:value-of select="StationOffsetPoints/StationOffsetPoint/@surfaceName"/>
                        </xsl:attribute>
                        <xsl:attribute name="staStart">
                            <xsl:value-of select="HorizontalElements/*[1]/Start/station/@internalStation"/>
                        </xsl:attribute>
                        <xsl:attribute name="staEnd">
                            <xsl:value-of select="HorizontalElements/*[position() = last()]/End/station/@internalStation"/>
                        </xsl:attribute>
                        <xsl:attribute name="roadTerrain"><xsl:value-of select="$terrainType"/></xsl:attribute>
                        <xsl:attribute name="state">proposed</xsl:attribute>
                        <xsl:element name="Classification">
                            <xsl:attribute name="staStart">
                                <xsl:value-of select="HorizontalElements/*[1]/Start/station/@internalStation"/>
                            </xsl:attribute>
                            <xsl:attribute name="staEnd">
                                <xsl:value-of select="HorizontalElements/*[position() = last()]/End/station/@internalStation"/>
                            </xsl:attribute>
                            <xsl:attribute name="functionalClass"><xsl:value-of select="$classification"/></xsl:attribute>
                        </xsl:element>
                        <xsl:element name="Lanes">
                            <xsl:element name="ThruLane">
                                <xsl:attribute name="staStart">
                                    <xsl:value-of select="HorizontalElements/*[1]/Start/station/@internalStation"/>
                                </xsl:attribute>
                                <xsl:attribute name="staEnd">
                                    <xsl:value-of select="HorizontalElements/*[position() = last()]/End/station/@internalStation"/>
                                </xsl:attribute>
                                <xsl:attribute name="width">
                                    <xsl:value-of select="format-number(-1 * StationOffsetPoints/StationOffsetPoint[@offsetAlignmentName = $leftEOP]/@firstOffset, '#####0.000000')"/>
                                </xsl:attribute>
                                <xsl:attribute name="sideofRoad">left</xsl:attribute>
                            </xsl:element>
                            <xsl:element name="ThruLane">
                                <xsl:attribute name="staStart">
                                    <xsl:value-of select="HorizontalElements/*[1]/Start/station/@internalStation"/>
                                </xsl:attribute>
                                <xsl:attribute name="staEnd">
                                    <xsl:value-of select="HorizontalElements/*[position() = last()]/End/station/@internalStation"/>
                                </xsl:attribute>
                                <xsl:attribute name="width">
                                    <xsl:value-of select="format-number(StationOffsetPoints/StationOffsetPoint[@offsetAlignmentName = $rightEOP]/@firstOffset, '#####0.000000')"/>
                                </xsl:attribute>
                                <xsl:attribute name="sideofRoad">right</xsl:attribute>
                            </xsl:element>
                        </xsl:element>
                    </xsl:element>
                </xsl:element>
                <xsl:apply-templates/>
            </xsl:for-each>
        </xsl:element>
    </xsl:template>
    <xsl:template match="StationOffsetPoints">
        <xsl:element name="GradeModel">
            <xsl:attribute name="name"><xsl:value-of select="StationOffsetPoint/@surfaceName"/></xsl:attribute>
            <xsl:element name="GradeSurface">
                <xsl:attribute name="alignmentRef"><xsl:value-of select="../@name"/></xsl:attribute>
                <xsl:attribute name="surfaceType">finalSurface</xsl:attribute>
                <xsl:attribute name="name"><xsl:value-of select="StationOffsetPoint/@surfaceName"/></xsl:attribute>
                <xsl:element name="Zones">
                    <xsl:apply-templates mode="left"/>
                </xsl:element>
                <xsl:element name="Zones">
                    <xsl:apply-templates mode="right"/>
                </xsl:element>
            </xsl:element>
        </xsl:element>
    </xsl:template>
    <xsl:template match="StationOffsetPoint" mode="left">
        <xsl:attribute name="side">left</xsl:attribute>
        <xsl:if test="following-sibling::*[1]/@offsetAlignmentName = @offsetAlignmentName">
            <xsl:choose>
                <xsl:when test="@offsetAlignmentName = $leftForeSlope">
                    <xsl:element name="Zone">
                        <xsl:attribute name="priority">3</xsl:attribute>
                        <xsl:attribute name="category">road foreSlope</xsl:attribute>
                        <xsl:attribute name="staStart">
                            <xsl:value-of select="centerLinePoint/point/station/@internalStation"/>
                        </xsl:attribute>
                        <xsl:attribute name="staEnd">
                            <xsl:value-of select="following-sibling::*[1]/centerLinePoint/point/station/@internalStation"/>
                        </xsl:attribute>
                        <xsl:attribute name="startWidth"><xsl:value-of select="format-number(../StationOffsetPoint[centerLinePoint/point/station/@internalStation = current()/centerLinePoint/point/station/@internalStation][@offsetAlignmentName = $leftShoulder]/@firstOffset - @firstOffset, '#####0.000000')"/></xsl:attribute>
                        <xsl:attribute name="startVertValue">
                            <xsl:value-of select="format-number(((../StationOffsetPoint[centerLinePoint/point/station/@internalStation = current()/centerLinePoint/point/station/@internalStation][@offsetAlignmentName = $leftShoulder]/offsetPoint/@elevation - offsetPoint/@elevation) div @firstOffset) * 100, '#####0.000000')"/>
                        </xsl:attribute>
                        <xsl:attribute name="startVertType">slope</xsl:attribute>
                        <xsl:attribute name="endWidth"><xsl:value-of select="format-number(../StationOffsetPoint[centerLinePoint/point/station/@internalStation = current()/following-sibling::*[1]/centerLinePoint/point/station/@internalStation][@offsetAlignmentName = $leftShoulder]/@firstOffset - following-sibling::*[1]/@firstOffset, '#####0.000000')"/></xsl:attribute>
                        <xsl:attribute name="endVertValue">
                            <xsl:value-of select="format-number(((../StationOffsetPoint[centerLinePoint/point/station/@internalStation = current()/following-sibling::*[1]/centerLinePoint/point/station/@internalStation][@offsetAlignmentName = $leftShoulder]/offsetPoint/@elevation - following-sibling::*[1]/offsetPoint/@elevation) div following-sibling::*[1]/@firstOffset) * 100, '#####0.000000')"/>
                        </xsl:attribute>
                        <xsl:attribute name="endVertType">slope</xsl:attribute>
                    </xsl:element>
                </xsl:when>
                <xsl:when test="@offsetAlignmentName = $leftShoulder">
                    <xsl:element name="Zone">
                        <xsl:attribute name="priority">2</xsl:attribute>
                        <xsl:attribute name="category">road shoulder</xsl:attribute>
                        <xsl:attribute name="staStart">
                            <xsl:value-of select="centerLinePoint/point/station/@internalStation"/>
                        </xsl:attribute>
                        <xsl:attribute name="staEnd">
                            <xsl:value-of select="following-sibling::*[1]/centerLinePoint/point/station/@internalStation"/>
                        </xsl:attribute>
                        <xsl:attribute name="startWidth"><xsl:value-of select="format-number(../StationOffsetPoint[centerLinePoint/point/station/@internalStation = current()/centerLinePoint/point/station/@internalStation][@offsetAlignmentName = $leftEOP]/@firstOffset -  @firstOffset, '#####0.000000')"/></xsl:attribute>
                        <xsl:attribute name="startVertValue">
                            <xsl:value-of select="format-number(((../StationOffsetPoint[centerLinePoint/point/station/@internalStation = current()/centerLinePoint/point/station/@internalStation][@offsetAlignmentName = $leftEOP]/offsetPoint/@elevation - offsetPoint/@elevation) div (@firstOffset - ../StationOffsetPoint[centerLinePoint/point/station/@internalStation = current()/centerLinePoint/point/station/@internalStation][@offsetAlignmentName = $leftEOP]/@firstOffset)) * 100, '#####0.000000')"/>
                        </xsl:attribute>
                        <xsl:attribute name="startVertType">slope</xsl:attribute>
                        <xsl:attribute name="endWidth"><xsl:value-of select="format-number(../StationOffsetPoint[centerLinePoint/point/station/@internalStation = current()/following-sibling::*[1]/centerLinePoint/point/station/@internalStation][@offsetAlignmentName = $leftEOP]/@firstOffset - following-sibling::*[1]/@firstOffset, '#####0.000000')"/></xsl:attribute>
                        <xsl:attribute name="endVertValue">
                            <xsl:value-of select="format-number(((../StationOffsetPoint[centerLinePoint/point/station/@internalStation = current()/following-sibling::*[1]/centerLinePoint/point/station/@internalStation][@offsetAlignmentName = $leftEOP]/offsetPoint/@elevation - following-sibling::*[1]/offsetPoint/@elevation) div (following-sibling::*[1]/@firstOffset - ../StationOffsetPoint[centerLinePoint/point/station/@internalStation = current()/following-sibling::*[1]/centerLinePoint/point/station/@internalStation][@offsetAlignmentName = $leftEOP]/@firstOffset)) * 100, '#####0.000000')"/>
                        </xsl:attribute>
                        <xsl:attribute name="endVertType">slope</xsl:attribute>
                    </xsl:element>
                </xsl:when>
                <xsl:when test="@offsetAlignmentName = $leftEOP">
                    <xsl:element name="Zone">
                        <xsl:attribute name="priority">1</xsl:attribute>
                        <xsl:attribute name="category">road surface</xsl:attribute>
                        <xsl:attribute name="staStart">
                            <xsl:value-of select="centerLinePoint/point/station/@internalStation"/>
                        </xsl:attribute>
                        <xsl:attribute name="staEnd">
                            <xsl:value-of select="following-sibling::*[1]/centerLinePoint/point/station/@internalStation"/>
                        </xsl:attribute>
                        <xsl:attribute name="startWidth"><xsl:value-of select="format-number(-1 * @firstOffset, '#####0.000000')"/></xsl:attribute>
                        <xsl:attribute name="startVertValue">
                            <xsl:value-of select="format-number(((../StationOffsetPoint[centerLinePoint/point/station/@internalStation = current()/centerLinePoint/point/station/@internalStation][@offsetAlignmentName = $center]/offsetPoint/@elevation - offsetPoint/@elevation) div (@firstOffset - ../StationOffsetPoint[centerLinePoint/point/station/@internalStation = current()/centerLinePoint/point/station/@internalStation][@offsetAlignmentName = $center]/@firstOffset)) * 100, '#####0.000000')"/>
                        </xsl:attribute>
                        <xsl:attribute name="startVertType">slope</xsl:attribute>
                        <xsl:attribute name="endWidth"><xsl:value-of select="format-number(-1 * following-sibling::*[1]/@firstOffset, '#####0.000000')"/></xsl:attribute>
                        <xsl:attribute name="endVertValue">
                            <xsl:value-of select="format-number(((../StationOffsetPoint[centerLinePoint/point/station/@internalStation = current()/following-sibling::*[1]/centerLinePoint/point/station/@internalStation][@offsetAlignmentName = $center]/offsetPoint/@elevation - following-sibling::*[1]/offsetPoint/@elevation) div (following-sibling::*[1]/@firstOffset - ../StationOffsetPoint[centerLinePoint/point/station/@internalStation = current()/following-sibling::*[1]/centerLinePoint/point/station/@internalStation][@offsetAlignmentName = $center]/@firstOffset)) * 100, '#####0.000000')"/>
                        </xsl:attribute>
                        <xsl:attribute name="endVertType">slope</xsl:attribute>
                    </xsl:element>
                </xsl:when>
                <xsl:otherwise/>
            </xsl:choose>
        </xsl:if>
    </xsl:template>
    <xsl:template match="StationOffsetPoint" mode="right">
        <xsl:attribute name="side">right</xsl:attribute>
        <xsl:if test="following-sibling::*[1]/@offsetAlignmentName = @offsetAlignmentName">
            <xsl:choose>
                <xsl:when test="@offsetAlignmentName = $rightEOP">
                    <xsl:element name="Zone">
                        <xsl:attribute name="priority">1</xsl:attribute>
                        <xsl:attribute name="category">road surface</xsl:attribute>
                        <xsl:attribute name="staStart">
                            <xsl:value-of select="centerLinePoint/point/station/@internalStation"/>
                        </xsl:attribute>
                        <xsl:attribute name="staEnd">
                            <xsl:value-of select="following-sibling::*[1]/centerLinePoint/point/station/@internalStation"/>
                        </xsl:attribute>
                        <xsl:attribute name="startWidth"><xsl:value-of select="format-number(@firstOffset, '#####0.000000')"/></xsl:attribute>
                        <xsl:attribute name="startVertValue">
                            <xsl:value-of select="format-number(((offsetPoint/@elevation - ../StationOffsetPoint[centerLinePoint/point/station/@internalStation = current()/centerLinePoint/point/station/@internalStation][@offsetAlignmentName = $center]/offsetPoint/@elevation) div (@firstOffset - ../StationOffsetPoint[centerLinePoint/point/station/@internalStation = current()/centerLinePoint/point/station/@internalStation][@offsetAlignmentName = $center]/@firstOffset)) * 100, '#####0.000000')"/>
                        </xsl:attribute>
                        <xsl:attribute name="startVertType">slope</xsl:attribute>
                        <xsl:attribute name="endWidth"><xsl:value-of select="format-number(following-sibling::*[1]/@firstOffset, '#####0.000000')"/></xsl:attribute>
                        <xsl:attribute name="endVertValue">
                            <xsl:value-of select="format-number(((following-sibling::*[1]/offsetPoint/@elevation - ../StationOffsetPoint[centerLinePoint/point/station/@internalStation = current()/following-sibling::*[1]/centerLinePoint/point/station/@internalStation][@offsetAlignmentName = $center]/offsetPoint/@elevation) div (following-sibling::*[1]/@firstOffset - ../StationOffsetPoint[centerLinePoint/point/station/@internalStation = current()/following-sibling::*[1]/centerLinePoint/point/station/@internalStation][@offsetAlignmentName = $center]/@firstOffset)) * 100, '#####0.000000')"/>
                        </xsl:attribute>
                        <xsl:attribute name="endVertType">slope</xsl:attribute>
                    </xsl:element>
                </xsl:when>
                <xsl:when test="@offsetAlignmentName = $rightShoulder">
                    <xsl:element name="Zone">
                        <xsl:attribute name="priority">2</xsl:attribute>
                        <xsl:attribute name="category">road shoulder</xsl:attribute>
                        <xsl:attribute name="staStart">
                            <xsl:value-of select="centerLinePoint/point/station/@internalStation"/>
                        </xsl:attribute>
                        <xsl:attribute name="staEnd">
                            <xsl:value-of select="following-sibling::*[1]/centerLinePoint/point/station/@internalStation"/>
                        </xsl:attribute>
                        <xsl:attribute name="startWidth"><xsl:value-of select="@firstOffset - ../StationOffsetPoint[centerLinePoint/point/station/@internalStation = current()/centerLinePoint/point/station/@internalStation][@offsetAlignmentName = $rightEOP]/@firstOffset"/></xsl:attribute>
                        <xsl:attribute name="startVertValue">
                            <xsl:value-of select="format-number(((offsetPoint/@elevation - ../StationOffsetPoint[centerLinePoint/point/station/@internalStation = current()/centerLinePoint/point/station/@internalStation][@offsetAlignmentName = $rightEOP]/offsetPoint/@elevation) div (@firstOffset - ../StationOffsetPoint[centerLinePoint/point/station/@internalStation = current()/centerLinePoint/point/station/@internalStation][@offsetAlignmentName = $rightEOP]/@firstOffset)) * 100, '#####0.000000')"/>
                        </xsl:attribute>
                        <xsl:attribute name="startVertType">slope</xsl:attribute>
                        <xsl:attribute name="endWidth"><xsl:value-of select="following-sibling::*[1]/@firstOffset - ../StationOffsetPoint[centerLinePoint/point/station/@internalStation = current()/following-sibling::*[1]/centerLinePoint/point/station/@internalStation][@offsetAlignmentName = $rightEOP]/@firstOffset"/></xsl:attribute>
                        <xsl:attribute name="endVertValue">
                            <xsl:value-of select="format-number(((following-sibling::*[1]/offsetPoint/@elevation - ../StationOffsetPoint[centerLinePoint/point/station/@internalStation = current()/following-sibling::*[1]/centerLinePoint/point/station/@internalStation][@offsetAlignmentName = $rightEOP]/offsetPoint/@elevation) div (following-sibling::*[1]/@firstOffset - ../StationOffsetPoint[centerLinePoint/point/station/@internalStation = current()/following-sibling::*[1]/centerLinePoint/point/station/@internalStation][@offsetAlignmentName = $rightEOP]/@firstOffset)) * 100, '#####0.000000')"/>
                        </xsl:attribute>
                        <xsl:attribute name="endVertType">slope</xsl:attribute>
                    </xsl:element>
                </xsl:when>
                <xsl:when test="@offsetAlignmentName = $rightForeSlope">
                    <xsl:element name="Zone">
                        <xsl:attribute name="priority">3</xsl:attribute>
                        <xsl:attribute name="category">road foreSlope</xsl:attribute>
                        <xsl:attribute name="staStart">
                            <xsl:value-of select="centerLinePoint/point/station/@internalStation"/>
                        </xsl:attribute>
                        <xsl:attribute name="staEnd">
                            <xsl:value-of select="following-sibling::*[1]/centerLinePoint/point/station/@internalStation"/>
                        </xsl:attribute>
                        <xsl:attribute name="startWidth"><xsl:value-of select="@firstOffset - ../StationOffsetPoint[centerLinePoint/point/station/@internalStation = current()/centerLinePoint/point/station/@internalStation][@offsetAlignmentName = $rightShoulder]/@firstOffset"/></xsl:attribute>
                        <xsl:attribute name="startVertValue">
                            <xsl:value-of select="format-number(((offsetPoint/@elevation - ../StationOffsetPoint[centerLinePoint/point/station/@internalStation = current()/centerLinePoint/point/station/@internalStation][@offsetAlignmentName = $rightShoulder]/offsetPoint/@elevation) div @firstOffset) * 100, '#####0.000000')"/>
                        </xsl:attribute>
                        <xsl:attribute name="startVertType">slope</xsl:attribute>
                        <xsl:attribute name="endWidth"><xsl:value-of select="following-sibling::*[1]/@firstOffset - ../StationOffsetPoint[centerLinePoint/point/station/@internalStation = current()/following-sibling::*[1]/centerLinePoint/point/station/@internalStation][@offsetAlignmentName = $rightShoulder]/@firstOffset"/></xsl:attribute>
                        <xsl:attribute name="endVertValue">
                            <xsl:value-of select="format-number(((following-sibling::*[1]/offsetPoint/@elevation - ../StationOffsetPoint[centerLinePoint/point/station/@internalStation = current()/following-sibling::*[1]/centerLinePoint/point/station/@internalStation][@offsetAlignmentName = $rightShoulder]/offsetPoint/@elevation) div following-sibling::*[1]/@firstOffset) * 100, '#####0.000000')"/>
                        </xsl:attribute>
                        <xsl:attribute name="endVertType">slope</xsl:attribute>
                    </xsl:element>
                </xsl:when>
                <xsl:otherwise/>
            </xsl:choose>
        </xsl:if>
    </xsl:template>
    <xsl:template name="StyleSheetHelp">
        <html>
            <head>
                <link rel="stylesheet" type="text/css" href="{$xslRootDirectory}/_Themes/engineer/theme.css"/>
                <title></title>
            </head>
            <body>
                <div class="section1">
                    <h4 lang="en">Workflow</h4>
                    <p class="normal1" lang="en">
                        This workflow requires a horizontal alignment, a vertical alignment and a surface 
                        with features parallel to the horizontal alignment representing the categories 
                        (leftForeslope, leftShoulder, etc) used by IHSDM.
                    </p>
                    <ol>
                        <li class="list1number" lang="en">
                            Once you have completed the alignment design, select the <em>File &gt; 
                            Translators &gt; LandXML Translator</em> command and export the alignment to a 
                            LandXML file, making note of the path and name of the file.&#xa0; For example, 
                            save your file as <span class="directory">D:\Projects\MyProject\MyGeom.xml
                            </span>.
                        </li>
                        <li class="list1number" lang="en">
                            If your alignment design is superelevated, you must include the critical 
                            superelevation stations as event points on the horizontal alignment for a 
                            complete analysis.&#xa0; One way to do this is to create a report from your IRD 
                            file using the <span class="directory">\XML Data\RoadwayDesign\
                            RoadwayDesignSuperelevationToEventPoints.xsl</span> style sheet.&#xa0; Once you 
                            have saved the output from this report, you can import the stations as event 
                            points using the <em>File &gt; Text Import Wizard</em> command.
                        </li>
                        <li class="list1number" lang="en">
                            Create a station base report using the <em>Tools &gt; XML Reports &gt; Station 
                            Base</em> command making sure to select all the features that represent the 
                            left and right foreslopes, left and right shoulders, left and right lanes, and 
                            the centerline.&#xa0; On the <em>Include</em> leaf, you must choose the 
                            <em>Horizontal On-Alignment Points</em> and also, if you have superelevation, 
                            <em>Horizontal Event Points</em>.&#xa0; When the <em>Report Browser</em> 
                            displays the report, make sure the <span class="directory">raw-xml.xsl</span> 
                            style sheet is selected and then select <em>File &gt; Save As</em> from the 
                            <em>Report Browser</em> menu.&#xa0; Save the XML file to the same directory as 
                            the file you created in Step 1.&#xa0; For example, save your file as <span 
                            class="directory">D:\Projects\MyProjects\MyStationBase.xml</span>.
                        </li>
                        <li class="list1number" lang="en">
                            Open the <span class="directory">IHSDMLandXML.xsl</span> style sheet and edit 
                            the <code>geometryFile</code> variable near the top to indicate the path and 
                            name of the file created in Step 1.&#xa0; By default, this variable points to a 
                            file in the <span class="directory">StationOffset</span> subdirectory in the 
                            delivered location of the InRoads Group.&#xa0; If you save your output files to 
                            this location, you will only need to change the file name.&#xa0; If you save 
                            them elsewhere, you need to change the entire path from<br/><br 
                            style="line-height:50%"/>
                            <code style="padding-left:.25in">document(concat($xslRootDirectory, 
                            '\StationOffset\MyGeom.xml'))</code><br/><br style="line-height:50%"/>
                            to something similar to<br/><br style="line-height:50%"/>
                            <code style="padding-left:.25in">document('D:\Projects\MyProject\MyGeom.xml')
                            </code>.
                        </li>
                        <li class="list1number" lang="en">
                            There are a number of variables near the top of the style sheet that need to be 
                            modified to suit your project's needs.&#xa0; For example, you should edit the 
                            variables for the IHSDM categories to make sure the names match the actual 
                            names of the features in your surface.&#xa0; You must have a feature for each 
                            category to produce a file useable by IHSDM.&#xa0; Modify the other variables 
                            as needed.
                        </li>
                        <li class="list1number" lang="en">
                            If it is not already running, start the <em>Report Browser</em>, and open the 
                            file you created in Step 3 (<span class="directory">MyStationBase.xml</span>).&#xa0; 
                            Select <span class="directory">IHSDMLandXML.xsl</span> as the style sheet.
                        </li>
                        <li class="list1number" lang="en">
                            Select <em>File &gt; Save As</em> from the <em>Report Browser</em> menu.&#xa0; 
                            When saving the report, leave the <em>Save as type</em> field set to <em>Text 
                            File (*.txt)</em> but give it an extension of <span class="directory">.xml
                            </span> instead of the default extension of <span class="directory">.txt
                            </span>.&#xa0; For example, save the report as <span class="directory">
                            D:\Projects\MyProject\MyOutput.xml</span>.
                        </li>
                        <li class="list1number" lang="en">
                            Open <span class="directory">MyOutput.xml</span> in any editor such as Notepad 
                            and check the value of the <code>encoding</code> attribute on the first 
                            line.&#xa0; If the value is anything other than <code>ISO-8859-1</code> (either 
                            upper or lower case is correct), replace it with <code>ISO-8859-1</code>.
                        </li>
                        <li class="list1number" lang="en">
                            <span class="directory">MyOutput.xml</span> is now ready to be imported into 
                            IHSDM.&#xa0; Manually make any configuration changes needed by IHSDM to run the 
                            various modules.
                        </li>
                    </ol>
                    <h4 lang="en">Notes</h4>
                    <p class="normal1" lang="en">
                        Two example files, <span class="directory">MyGeom.xml</span> and <span 
                        class="directory">MyStationBase.xml</span>, are delivered with the product.&#xa0; 
                        These files can be used to practice the workflow given above.
                    </p>
                    <p class="normal1" lang="en">
                        The final file created by the <em>Report Browser</em> is not quite a valid LandXML 
                        file because creation of <code>schemaInstance</code> and <code>schemaLocation
                        </code> attributes is not allowed by XSL.&#xa0; The <code>schemaInstance</code> 
                        gets appended erroneously to each upper level element copied from the geometry 
                        LandXML file created in Step 1 instead of to the root element where it 
                        belongs.&#xa0; However, if you manually add the <code>schemaInstance</code> and 
                        <code>schemaLocation</code> attributes to the <code>LandXML</code> (root) element, 
                        the file will validate.&#xa0; <strong>Please note</strong> &#x2014; The final file 
                        does not need to validate in order to be used by this workflow.
                    </p>
                    <p class="normal1" lang="en">
                        If your final output file contains <code>&#x22;NaN&#x22;</code> (not a number) 
                        values in attributes where a number is expected, particularly for the <code>
                        startVertValue</code> and <code>endVertValue</code> attributes, it generally means 
                        that the stations for two of the categories, ie, left edge of pavement and left 
                        shoulder, don't match exactly.&#xa0; This situation may occur in areas of spiral 
                        transitions.&#xa; You can usually import a file containing <code>&#x22;NaN&#x22;
                        </code> values, but you will need to manually input the missing slopes once inside 
                        IHSDM.&#xa0; If you have very many <code>&#x22;NaN&#x22;</code> values, IHSDM may 
                        fail to load your file, producing a Java error.&#xa0; If this happens, you may need 
                        to hand-edit the file to remove the lines containing the <code>&#x22;NaN&#x22;
                        </code> values or enter the correct values.
                    </p>
                    <p class="normal1" lang="en">Large files take a very long time to process.</p>
                    <p class="small" lang="en">
                        <em>&#xa9; 2008 Bentley Systems, Inc</em>
                    </p>
                </div>
            </body>
        </html>
    </xsl:template>
    <msxsl:script implements-prefix="inr" language="JScript">
        <![CDATA[
            // This function gets the current date.
            function dateLXML()
            {
                var today = new Date();
                var month = today.getMonth() + 1;
                var dayOfMonth = today.getDate();
                var year = today.getFullYear();
                var hours = today.getHours();
                if (month < 10)
                {
                    month = "0" + month;
                }
                if (dayOfMonth < 10)
                {
                    dayOfMonth = "0" + dayOfMonth;
                }
                return year + "-" + month + "-" + dayOfMonth;
            }
            // This function gets the current time.
            function timeLXML()
            {
                var today = new Date();
                var hours = today.getHours();
                var minutes = today.getMinutes();
                var seconds = today.getSeconds();
                if (minutes < 10)
                {
                    minutes = "0" + minutes;
                }
                if (seconds < 10)
                {
                    seconds = "0" + seconds;
                }
                return hours + ":" + minutes + ":" + seconds;
            }
        ]]>
    </msxsl:script>
</xsl:stylesheet>
