<?xml version="1.0" encoding="UTF-8"?>
<xsl:stylesheet version="1.1" xmlns:xsl="http://www.w3.org/1999/XSL/Transform" xmlns:fo="http://www.w3.org/1999/XSL/Format" xmlns:msxsl="urn:schemas-microsoft-com:xslt" xmlns:inr="http://mycompany.com/mynamespace">
    <xsl:include href="../format.xsl"/>
    <xsl:param name="xslRootDirectory" select="inr:xslRootDirectory"/>
    <!-- Least Squares Report -->
    <xsl:template match="/">
        <xsl:variable name="gridOut" select="inr:SetGridOut(number(InRoads/@outputGridScaleFactor))"/>
        <html>
            <head>
                <link rel="stylesheet" type="text/css" href="{$xslRootDirectory}/_Themes/engineer/theme.css"/>
                <!-- Title displayed in browser Title Bar -->
                <title lang="en">Least Squares Report</title>
            </head>
            <body>
                <xsl:choose>
                    <xsl:when test="$xslShowHelp = 'true'">
                        <xsl:call-template name="StyleSheetHelp"/>
                    </xsl:when>
                    <xsl:otherwise>
                        <xsl:for-each select="InRoads">
                            <xsl:for-each select="AdjustmentNet">
                                <center>
                                    <!-- Report Title -->
                                    <h2 lang="en">Least Squares Report</h2>
                                    <p lang="en">
                                        Report Created:&#xa0; <xsl:value-of select="inr:date()"/><br/>
                                        Time:&#xa0; <xsl:value-of select="inr:time()"/>
                                    </p>
                                </center>
                                <p lang="en" style="text-align:right;font-size:80%">
                                    <strong>Note:&#xa0; </strong>All units in this report are in 
                                    <xsl:if test="//@linearUnits = 'Imperial'">feet</xsl:if>
                                    <xsl:if test="//@linearUnits = 'Metric'">meters</xsl:if>
                                    unless specified otherwise.
                                </p>
                                <hr/>
                                <center><h4>Statistics</h4></center>
                                <hr size="1px"/>
                                <table class="margin" cellpadding="1" cellspacing="1" width="70%">
                                    <colgroup span="2">
                                        <col width="50%"/>
                                        <col width="50%"/>
                                    </colgroup>
                                    <tbody>
                                        <tr>
                                            <th align="left">
                                                <xsl:choose>
                                                    <xsl:when test="@adjustmentConverges='true'">Least Squares converged.</xsl:when>
                                                    <xsl:otherwise>Least Squares did not converge.</xsl:otherwise>
                                                </xsl:choose>
                                            </th>
                                        </tr>
                                        <tr style="line-height:50%"><td>&#xa0;</td></tr>
                                        <tr>
                                            <th align="left" nowrap="nowrap">Iterations:&#xa0;</th>
                                            <td align="left" nowrap="nowrap">
                                                <xsl:value-of select="@maximumIterationsAllowed"/> (<xsl:value-of select="@iterations"/>)
                                            </td>
                                        </tr>
                                        <tr>
                                            <th align="left" nowrap="nowrap">Dimension:&#xa0;</th>
                                            <td align="left" nowrap="nowrap"><xsl:value-of select="@adjustmentMode"/></td>
                                        </tr>
                                        <tr>
                                            <th align="left" nowrap="nowrap">Convergence Tolerance:&#xa0;</th>
                                            <td align="left">
                                                <xsl:value-of select="inr:distanceFormat(number(@convergenceTolerance), $xslDistancePrecision)"/>
                                            </td>
                                        </tr>
                                        <tr style="line-height:50%"><td>&#xa0;</td></tr>
                                        <tr>
                                            <th align="left" nowrap="nowrap">Confidence Level:&#xa0;</th>
                                            <td align="left"><xsl:value-of select="@confidenceLevel"/>%</td>
                                        </tr>
                                        <tr>
                                            <th align="left" nowrap="nowrap">Redundancies:&#xa0;</th>
                                            <td align="left"><xsl:value-of select="@redundancies"/></td>
                                        </tr>
                                        <tr>
                                            <th align="left" nowrap="nowrap">Final Reference Standard Deviation:&#xa0;</th>
                                            <td align="left">
                                                <xsl:value-of select="inr:distanceFormat(number(@standardDeviation), $xslDistancePrecision)"/>
                                            </td>
                                        </tr>
                                        <tr style="line-height:50%"><td>&#xa0;</td></tr>
                                        <tr>
                                            <th align="left" colspan="2" nowrap="nowrap" style="color:FF0000">
                                                <xsl:choose>
                                                    <xsl:when test="@chiSquareTest='upper'">Warning! Chi-Square Test exceeded upper bounds (
                                                        <xsl:value-of select="inr:distanceFormat(number(@chiSquareLowerBounds), $xslDistancePrecision)"/>, 
                                                        <xsl:value-of select="inr:distanceFormat(number(@chiSquareUpperBounds), $xslDistancePrecision)"/>)
                                                    </xsl:when>
                                                    <xsl:when test="@chiSquareTest='lower'">Warning! Chi-Square Test exceeded lower bounds (
                                                        <xsl:value-of select="inr:distanceFormat(number(@chiSquareLowerBounds), $xslDistancePrecision)"/>, 
                                                        <xsl:value-of select="inr:distanceFormat(number(@chiSquareUpperBounds), $xslDistancePrecision)"/>)
                                                    </xsl:when>
                                                    <xsl:when test="@chiSquareTest='pass'">Chi-Square Test succeeded (
                                                        <xsl:value-of select="inr:distanceFormat(number(@chiSquareLowerBounds), $xslDistancePrecision)"/>, 
                                                        <xsl:value-of select="inr:distanceFormat(number(@chiSquareUpperBounds), $xslDistancePrecision)"/>)
                                                    </xsl:when>
                                                    <xsl:otherwise>No Chi-Square Test (No Redundancies)</xsl:otherwise>
                                                </xsl:choose>
                                            </th>
                                        </tr>
                                        <tr><td>&#xa0;</td></tr>
                                    </tbody>
                                </table>
                                <hr size="1px"/>
                                <!-- Observation Data -->
                                <center><h4>Observations</h4></center>
                                <hr size="1px"/>
                                <table class="margin" cellpadding="1" cellspacing="1" width="70%">
                                    <colgroup span="2">
                                        <col width="50%"/>
                                        <col width="50%"/>
                                    </colgroup>
                                    <tbody>
                                        <tr>
                                            <th align="left" nowrap="nowrap">Azimuths:&#xa0;</th>
                                            <td align="left" nowrap="nowrap">
                                                <xsl:value-of select="@numberAzimuthObservations"/>
                                                <xsl:if test="@numberAzimuthObservationsIgnored!='0'"> (<xsl:value-of select="@numberAzimuthObservationsIgnored"/>)</xsl:if>
                                            </td>
                                        </tr>
                                        <tr>
                                            <th align="left" nowrap="nowrap">Direction:&#xa0;</th>
                                            <td align="left" nowrap="nowrap">
                                                <xsl:value-of select="@numberDirectionObservations"/>
                                                <xsl:if test="@numberDirectionObservationsIgnored!='0'"> (<xsl:value-of select="@numberDirectionObservationsIgnored"/>)</xsl:if>
                                            </td>
                                        </tr>
                                        <tr>
                                            <th align="left" nowrap="nowrap">Horizontal Angles:&#xa0;</th>
                                            <td align="left" nowrap="nowrap">
                                                <xsl:value-of select="@numberHorizontalAngleObservations"/>
                                                <xsl:if test="@numberHorizontalAngleObservationsIgnored!='0'"> (<xsl:value-of select="@numberHorizontalAngleObservationsIgnored"/>)</xsl:if>
                                            </td>
                                        </tr>
                                        <tr style="line-height:50%"><td>&#xa0;</td></tr>
                                        <tr>
                                            <th align="left" nowrap="nowrap">Horizontal Distances:&#xa0;</th>
                                            <td align="left" colspan="3" nowrap="nowrap">
                                                <xsl:value-of select="@numberHorizontalDistanceObservations"/>
                                                <xsl:if test="@numberHorizontalDistanceObservationsIgnored!='0'"> (<xsl:value-of select="@numberHorizontalDistanceObservationsIgnored"/>)</xsl:if>
                                            </td>
                                        </tr>
                                        <tr>
                                            <th align="left" nowrap="nowrap">Slope Distances:&#xa0;</th>
                                            <td align="left" nowrap="nowrap" valign="bottom">
                                                <xsl:value-of select="@numberSlopeDistanceObservations"/>
                                                <xsl:if test="@numberSlopeDistanceObservationsIgnored!='0'"> (<xsl:value-of select="@numberSlopeDistanceObservationsIgnored"/>)</xsl:if>
                                            </td>
                                        </tr>
                                        <tr style="line-height:50%"><td>&#xa0;</td></tr>
                                        <tr>
                                            <th align="left" nowrap="nowrap">Vertical Angles:&#xa0;</th>
                                            <td align="left" nowrap="nowrap" valign="bottom">
                                                <xsl:value-of select="@numberVerticalAngleObservations"/>
                                                <xsl:if test="@numberVerticalAngleObservationsIgnored!='0'"> (<xsl:value-of select="@numberVerticalAngleObservationsIgnored"/>)</xsl:if>
                                            </td>
                                        </tr>
                                        <tr>
                                            <th align="left" nowrap="nowrap">Zenith Angles:&#xa0;</th>
                                            <td align="left" nowrap="nowrap">
                                                <xsl:value-of select="@numberZenithAngleObservations"/>
                                                <xsl:if test="@numberZenithAngleObservationsIgnored!='0'"> (<xsl:value-of select="@numberZenithAngleObservationsIgnored"/>)</xsl:if>
                                            </td>
                                        </tr>
                                        <tr style="line-height:50%"><td>&#xa0;</td></tr>
                                        <tr>
                                            <th align="left" nowrap="nowrap">Height Differences:&#xa0;</th>
                                            <td align="left" nowrap="nowrap">
                                                <xsl:value-of select="@numberHeightDifferenceObservations"/>
                                                <xsl:if test="@numberHeightDifferenceObservationsIgnored!='0'"> (<xsl:value-of select="@numberHeightDifferenceObservationsIgnored"/>)</xsl:if>
                                            </td>
                                        </tr>
                                        <tr>
                                            <th align="right"/>
                                            <th align="right"/>
                                        </tr>
                                        <tr style="line-height:50%"><td>&#xa0;</td></tr>
                                        <tr>
                                            <th align="left" lang="en" nowrap="nowrap">Total:&#xa0;</th>
                                            <td align="left" nowrap="nowrap">
                                                <xsl:value-of select="@totalNumberObservations"/>
                                                <xsl:if test="@totalNumberObservationsIgnored!='0'"> (<xsl:value-of select="@totalNumberObservationsIgnored"/>)</xsl:if>
                                            </td>
                                        </tr>
                                        <tr><td>&#xa0;</td></tr>
                                    </tbody>
                                </table>
                                <hr size="1px"/>
                                <!-- Observation Points -->
                                <table cellpadding="1" cellspacing="1" width="100%">
                                    <thead style="display:table-header-group">
                                        <tr>
                                            <th class="underline" valign="bottom">Type</th>
                                            <th class="underline" valign="bottom">Backsight</th>
                                            <th class="underline" valign="bottom">Occupied</th>
                                            <th class="underline" valign="bottom">Foresight</th>
                                            <th class="underline" valign="bottom">Observation</th>
                                            <th class="underline" valign="bottom">Correction</th>
                                            <th class="underline" valign="bottom">Residual</th>
                                            <th class="underline" valign="bottom">Standardized<br/>Residual</th>
                                        </tr>
                                        <tr style="line-height:20%"><td>&#xa0;</td></tr>
                                    </thead>
                                    <tbody>
                                        <xsl:for-each select="Observations/Observation">
                                            <xsl:choose>
                                                <xsl:when test="@type='Vertical Angle' or @type='Zenith Angle' or @type='Slope Distance'">
                                                    <tr>
                                                        <td align="center" nowrap="nowrap">
                                                            <xsl:value-of select="@type"/>
                                                        </td>
                                                        <td align="center" nowrap="nowrap" style="font-weight:bold">
                                                            <xsl:value-of select="@backsightPointName"/>
                                                        </td>
                                                        <td align="center" nowrap="nowrap" style="font-weight:bold">
                                                            <xsl:value-of select="@occupiedPointName"/>
                                                        </td>
                                                        <td align="center" nowrap="nowrap" style="font-weight:bold">
                                                            <xsl:value-of select="@foresightPointName"/>
                                                        </td>
                                                        <td>&#xa0;</td>
                                                    </tr>
                                                    <xsl:variable name="type" select="@type"/>
                                                    <xsl:for-each select="ObservationData">
                                                        <xsl:variable name="style">
                                                            <xsl:choose>
                                                                <xsl:when test="@ignore='true'">
                                                                    text-decoration: line-through;
                                                                </xsl:when>
                                                                <xsl:when test="@standardResidual=//@greatestStandardResidual">
                                                                    color:FF0000
                                                                </xsl:when>
                                                            </xsl:choose>
                                                        </xsl:variable>
                                                        <tr style="{$style}">
                                                            <xsl:choose>
                                                                <xsl:when test="$type='Horizontal'">
                                                                    <td align="center" nowrap="nowrap">
                                                                        <xsl:value-of select="inr:distanceFormat(number(@backsightHeight), $xslDistancePrecision)"/>
                                                                    </td>
                                                                </xsl:when>
                                                                <xsl:otherwise>
                                                                    <td>&#xa0;</td>
                                                                </xsl:otherwise>
                                                            </xsl:choose>
                                                            <td align="center" nowrap="nowrap">
                                                                <xsl:value-of select="inr:distanceFormat(number(@instrumentHeight), $xslDistancePrecision)"/>
                                                            </td>
                                                            <td align="center" nowrap="nowrap">
                                                                <xsl:value-of select="inr:distanceFormat(number(@foresightHeight), $xslDistancePrecision)"/>
                                                            </td>
                                                            <xsl:choose>
                                                                <xsl:when test="$type!='Slope Distance' and $type!='Horizontal Distance' and $type!='Height Difference'">
                                                                    <td align="center" nowrap="nowrap">
                                                                        <xsl:value-of select="inr:angularFormat(number(@observedValue), $xslAngularFormat, $xslAngularPrecision, $xslAngularMethod)"/>
                                                                    </td>
                                                                </xsl:when>
                                                                <xsl:otherwise>
                                                                    <td align="center" nowrap="nowrap">
                                                                        <xsl:value-of select="inr:distanceFormat(number(@observedValue), $xslDistancePrecision)"/>
                                                                    </td>
                                                                </xsl:otherwise>
                                                            </xsl:choose>
                                                            <xsl:choose>
                                                                <xsl:when test="$type!='Slope Distance' and $type!='Horizontal Distance' and $type!='Height Difference'">
                                                                    <td align="center" nowrap="nowrap">
                                                                        <xsl:value-of select="inr:angularFormat(number(@adjustedValue),$xslAngularFormat, $xslAngularPrecision, $xslAngularMethod)"/>
                                                                    </td>
                                                                    <td align="center" nowrap="nowrap">
                                                                        <xsl:value-of select="inr:angularFormat(number(@residualValue),$xslAngularFormat, $xslAngularPrecision, $xslAngularMethod)"/>
                                                                    </td>
                                                                    <td align="center" nowrap="nowrap">
                                                                        <xsl:value-of select="inr:distanceFormat(number(@standardResidual), $xslDistancePrecision)"/>
                                                                    </td>
                                                                </xsl:when>
                                                                <xsl:otherwise>
                                                                    <td align="center" nowrap="nowrap">
                                                                        <xsl:value-of select="inr:distanceFormat(number(@adjustedValue), $xslDistancePrecision)"/>
                                                                    </td>
                                                                    <td align="center" nowrap="nowrap">
                                                                        <xsl:value-of select="inr:distanceFormat(number(@residualValue), $xslDistancePrecision)"/>
                                                                    </td>
                                                                    <td align="center" nowrap="nowrap">
                                                                        <xsl:value-of select="inr:distanceFormat(number(@standardResidual), $xslDistancePrecision)"/>
                                                                    </td>
                                                                </xsl:otherwise>
                                                            </xsl:choose>
                                                        </tr>
                                                    </xsl:for-each>
                                                    <tr style="line-height:20%"><td>&#xa0;</td></tr>
                                                </xsl:when>
                                                <xsl:otherwise>
                                                    <xsl:variable name="type" select="@type"/>
                                                    <xsl:for-each select="ObservationData">
                                                        <xsl:variable name="style">
                                                            <xsl:choose>
                                                                <xsl:when test="@ignore='true'">
                                                                    text-decoration: line-through;
                                                                </xsl:when>
                                                                <xsl:when test="@standardResidual=//@greatestStandardResidual">
                                                                    color:FF0000
                                                                </xsl:when>
                                                            </xsl:choose>
                                                        </xsl:variable>
                                                        <tr style="{$style}">
                                                            <td align="center" nowrap="nowrap">
                                                                <xsl:value-of select="../@type"/>
                                                            </td>
                                                            <td align="center" nowrap="nowrap" style="font-weight:bold">
                                                                <xsl:value-of select="../@backsightPointName"/>
                                                            </td>
                                                            <td align="center" nowrap="nowrap" style="font-weight:bold">
                                                                <xsl:value-of select="../@occupiedPointName"/>
                                                            </td>
                                                            <td align="center" nowrap="nowrap" style="font-weight:bold">
                                                                <xsl:value-of select="../@foresightPointName"/>
                                                            </td>
                                                            <xsl:choose>
                                                                <xsl:when test="$type!='Slope Distance' and $type!='Horizontal Distance' and $type!='Height Difference'">
                                                                    <td align="center" nowrap="nowrap">
                                                                        <xsl:value-of select="inr:angularFormat(number(@observedValue), $xslAngularFormat, $xslAngularPrecision, $xslAngularMethod)"/>
                                                                    </td>
                                                                </xsl:when>
                                                                <xsl:otherwise>
                                                                    <td align="center" nowrap="nowrap">
                                                                        <xsl:value-of select="inr:distanceFormat(number(@observedValue), $xslDistancePrecision)"/>
                                                                    </td>
                                                                </xsl:otherwise>
                                                            </xsl:choose>
                                                            <xsl:choose>
                                                                <xsl:when test="$type!='Slope Distance' and $type!='Horizontal Distance' and $type!='Height Difference'">
                                                                    <td align="center" nowrap="nowrap">
                                                                        <xsl:value-of select="inr:angularFormat(number(@adjustedValue),$xslAngularFormat, $xslAngularPrecision, $xslAngularMethod)"/>
                                                                    </td>
                                                                    <td align="center" nowrap="nowrap">
                                                                        <xsl:value-of select="inr:angularFormat(number(@residualValue),$xslAngularFormat, $xslAngularPrecision, $xslAngularMethod)"/>
                                                                    </td>
                                                                    <td align="center" nowrap="nowrap">
                                                                        <xsl:value-of select="inr:distanceFormat(number(@standardResidual), $xslDistancePrecision)"/>
                                                                    </td>
                                                                </xsl:when>
                                                                <xsl:otherwise>
                                                                    <td align="center" nowrap="nowrap">
                                                                        <xsl:value-of select="inr:distanceFormat(number(@adjustedValue), $xslDistancePrecision)"/>
                                                                    </td>
                                                                    <td align="center" nowrap="nowrap">
                                                                        <xsl:value-of select="inr:distanceFormat(number(@residualValue), $xslDistancePrecision)"/>
                                                                    </td>
                                                                    <td align="center" nowrap="nowrap">
                                                                        <xsl:value-of select="inr:distanceFormat(number(@standardResidual), $xslDistancePrecision)"/>
                                                                    </td>
                                                                </xsl:otherwise>
                                                            </xsl:choose>
                                                        </tr>
                                                    </xsl:for-each>
                                                    <tr style="line-height:20%"><td>&#xa0;</td></tr>
                                                </xsl:otherwise>
                                            </xsl:choose>
                                        </xsl:for-each>
                                    </tbody>
                                </table>
                                <hr size="1px"/>
                                <!-- Point Data -->
                                <center><h4>Points</h4></center>
                                <hr size="1px"/>
                                <table cellpadding="1" cellspacing="1" width="100%">
                                    <colgroup span="7">
                                        <col width="10%"/>
                                        <col width="15%"/>
                                        <col width="15%"/>
                                        <col width="15%"/>
                                        <col width="15%"/>
                                        <col width="15%"/>
                                        <col width="15%"/>
                                    </colgroup>
                                    <thead style="display:table-header-group">
                                        <tr>
                                            <th class="underline">&#xa0;</th>
                                            <th class="underline" valign="bottom">Northing</th>
                                            <th class="underline" valign="bottom">Difference</th>
                                            <th class="underline" valign="bottom">Easting</th>
                                            <th class="underline" valign="bottom">Difference</th>
                                            <th class="underline" valign="bottom">Elevation</th>
                                            <th class="underline" valign="bottom">Difference</th>
                                        </tr>
                                        <tr style="line-height:30%"><td>&#xa0;</td></tr>
                                    </thead>
                                    <xsl:for-each select="AdjustmentPoints/AdjustmentPoint">
                                        <tbody>
                                            <tr>
                                                <xsl:call-template name="displayPointName">
                                                    <xsl:with-param name="name" select="@occupiedPointName"/>
                                                    <xsl:with-param name="type" select="@type"/>
                                                </xsl:call-template>
                                            </tr>
                                            <xsl:call-template name="displayPoints"/>
                                            <tr><td style="line-height:30%">&#xa0;</td></tr>
                                        </tbody>
                                    </xsl:for-each>
                                </table>
                                <!-- Side Shot Data -->
                                <xsl:for-each select="Sideshots">
                                    <xsl:if test="@sidShotsExist='true'">
                                        <hr size="1px"/>
                                        <center><h3>Side Shots</h3></center>
                                        <hr size="1px"/>
                                        <table class="margin" cellpadding="2" cellspacing="0" style="border-width:0px;font-size: 8pt" width="95%">
                                            <colgroup span="7">
                                                <col width="10%"/>
                                                <col width="15%"/>
                                                <col width="15%"/>
                                                <col width="15%"/>
                                                <col width="15%"/>
                                                <col width="15%"/>
                                                <col width="15%"/>
                                            </colgroup>
                                            <thead style="display:table-header-group">
                                                <tr>
                                                    <th class="underline">&#xa0;</th>
                                                    <th class="underline" valign="bottom">Northing</th>
                                                    <th class="underline" valign="bottom">Difference</th>
                                                    <th class="underline" valign="bottom">Easting</th>
                                                    <th class="underline" valign="bottom">Difference</th>
                                                    <th class="underline" valign="bottom">Elevation</th>
                                                    <th class="underline" valign="bottom">Difference</th>
                                                </tr>
                                                <tr style="line-height:30%"><td>&#xa0;</td></tr>
                                            </thead>
                                            <xsl:for-each select="Sideshot">
                                                <tbody>
                                                    <tr>
                                                        <th align="left" nowrap="nowrap">
                                                            <xsl:value-of select="@sideShotName"/>
                                                        </th>
                                                    </tr>
                                                    <xsl:call-template name="displaySideShots"/>
                                                    <tr style="line-height:30%"><td>&#xa0;</td></tr>
                                                </tbody>
                                            </xsl:for-each>
                                        </table>
                                    </xsl:if>
                                </xsl:for-each>
                            </xsl:for-each>
                        </xsl:for-each>
                    </xsl:otherwise>
                </xsl:choose>
            </body>
        </html>
    </xsl:template>
    <!--Start Templates-->
    <xsl:template name="displayPointName">
        <xsl:param name="name"/>
        <xsl:param name="type" select="'Fixed'"/>
        <th align="left" nowrap="nowrap">
            <xsl:choose>
                <xsl:when test="$type='Fixed'">
                    <img src="{$xslRootDirectory}/Images/SrvFixed.png" alt="Fixed"/>&#xa0;
                </xsl:when>
                <xsl:when test="$type='Free'">
                    <img src="{$xslRootDirectory}/Images/SrvFree.png" alt="Free"/>&#xa0;
                </xsl:when>
                <xsl:otherwise>
                    <img src="{$xslRootDirectory}/Images/SrvAzimuth.png" alt="Azimuth"/>&#xa0;
                </xsl:otherwise>
            </xsl:choose>
            <xsl:value-of select="$name"/>
        </th>
    </xsl:template>
    <xsl:template name="displayColumn">
        <xsl:param name="value"/>
        <xsl:param name="color" select="'000000'"/>
        <xsl:param name="displayType" select="'distance'"/>
        <xsl:param name="error" select="'0'"/>
        <xsl:param name="style" select="''"/>
        <xsl:choose>
            <xsl:when test="$error='0'">
                <xsl:choose>
                    <xsl:when test="$displayType='angular'">
                        <td align="center" nowrap="nowrap" style="color:{$color};{$style}">
                            <xsl:value-of select="inr:angularFormat(number($value)$xslAngularFormat, $xslAngularPrecision, $xslAngularMethod)"/>
                        </td>
                    </xsl:when>
                    <xsl:when test="$displayType='distance'">
                        <td align="center" nowrap="nowrap" style="color:{$color};{$style}">
                            <xsl:value-of select="inr:distanceFormat(number($value), $xslDistancePrecision)"/>
                        </td>
                    </xsl:when>
                    <xsl:when test="$displayType='northing'">
                        <td align="center" nowrap="nowrap" style="color:{$color};{$style}">
                            <xsl:value-of select="inr:northingFormat(number($value), $xslNorthingPrecision)"/>
                        </td>
                    </xsl:when>
                    <xsl:when test="$displayType='easting'">
                        <td align="center" nowrap="nowrap" style="color:{$color};{$style}">
                            <xsl:value-of select="inr:eastingFormat(number($value), $xslEastingPrecision)"/>
                        </td>
                    </xsl:when>
                    <xsl:when test="$displayType='elevation'">
                        <td align="center" nowrap="nowrap" style="color:{$color};{$style}">
                            <xsl:value-of select="inr:elevationFormat(number($value), $xslElevationPrecision)"/>
                        </td>
                    </xsl:when>
                </xsl:choose>
            </xsl:when>
            <xsl:otherwise>
                <xsl:choose>
                    <xsl:when test="$displayType='angular'">
                        <td align="center" nowrap="nowrap" style="{$style}">
                            [<xsl:value-of select="inr:angularFormat(number($value),$xslAngularFormat, $xslAngularPrecision, $xslAngularMethod)"/>]
                        </td>
                    </xsl:when>
                    <xsl:when test="$displayType='distance'">
                        <td align="center" nowrap="nowrap" style="{$style}">
                            [<xsl:value-of select="inr:distanceFormat(number($value), $xslDistancePrecision)"/>]
                        </td>
                    </xsl:when>
                    <xsl:when test="$displayType='northing'">
                        <td align="center" nowrap="nowrap" style="{$style}">
                            [<xsl:value-of select="inr:northingFormat(number($value), $xslNorthingPrecision)"/>]
                        </td>
                    </xsl:when>
                    <xsl:when test="$displayType='easting'">
                        <td align="center" nowrap="nowrap" style="{$style}">
                            [<xsl:value-of select="inr:eastingFormat(number($value), $xslEastingPrecision)"/>]
                        </td>
                    </xsl:when>
                    <xsl:when test="$displayType='elevation'">
                        <td align="center" nowrap="nowrap" style="{$style}">
                            [<xsl:value-of select="inr:elevationFormat(number($value), $xslElevationPrecision)"/>]
                        </td>
                    </xsl:when>
                </xsl:choose>
            </xsl:otherwise>
        </xsl:choose>
    </xsl:template>
    <xsl:template name="displayPoints">
        <tr>
            <td align="left" nowrap="nowrap" style="border-left-width:2px">Original</td>
            <xsl:call-template name="displayColumn">
                <xsl:with-param name="value" select="@unadjustedNorthing"/>
                <xsl:with-param name="displayType" select="'northing'"/>
            </xsl:call-template>
            <td align="center" nowrap="nowrap">---</td>
            <xsl:call-template name="displayColumn">
                <xsl:with-param name="value" select="@unadjustedEasting"/>
                <xsl:with-param name="displayType" select="'easting'"/>
            </xsl:call-template>
            <td align="center" nowrap="nowrap">---</td>
            <xsl:call-template name="displayColumn">
                <xsl:with-param name="value" select="@unadjustedElevation"/>
                <xsl:with-param name="displayType" select="'elevation'"/>
            </xsl:call-template>
            <td align="center" nowrap="nowrap">---</td>
        </tr>
        <xsl:if test="//@leastSquares='true'">
            <xsl:if test="@type!='Fixed'">
                <tr>
                    <td>Adjusted</td>
                    <xsl:call-template name="displayColumn">
                        <xsl:with-param name="value" select="@adjustedNorthing"/>
                        <xsl:with-param name="displayType" select="'northing'"/>
                    </xsl:call-template>
                    <xsl:call-template name="displayColumn">
                        <xsl:with-param name="value" select="@adjustedNorthingDifference"/>
                        <xsl:with-param name="displayType" select="'northing'"/>
                    </xsl:call-template>
                    <xsl:call-template name="displayColumn">
                        <xsl:with-param name="value" select="@adjustedEasting"/>
                        <xsl:with-param name="displayType" select="'easting'"/>
                    </xsl:call-template>
                    <xsl:call-template name="displayColumn">
                        <xsl:with-param name="value" select="@adjustedEastingDifference"/>
                        <xsl:with-param name="displayType" select="'easting'"/>
                    </xsl:call-template>
                    <xsl:call-template name="displayColumn">
                        <xsl:with-param name="value" select="@adjustedElevation"/>
                        <xsl:with-param name="displayType" select="'elevation'"/>
                    </xsl:call-template>
                    <xsl:call-template name="displayColumn">
                        <xsl:with-param name="value" select="@adjustedElevationDifference"/>
                        <xsl:with-param name="displayType" select="'elevation'"/>
                    </xsl:call-template>
                </tr>
            </xsl:if>
        </xsl:if>
    </xsl:template>
    <xsl:template name="displaySideShots">
        <tr>
            <td align="left" nowrap="nowrap" style="border-left-width:2px">Original</td>
            <xsl:call-template name="displayColumn">
                <xsl:with-param name="value" select="@sideShotNorthing"/>
                <xsl:with-param name="displayType" select="'northing'"/>
            </xsl:call-template>
            <td align="center" nowrap="nowrap">---</td>
            <xsl:call-template name="displayColumn">
                <xsl:with-param name="value" select="@sideShotEasting"/>
                <xsl:with-param name="displayType" select="'easting'"/>
            </xsl:call-template>
            <td align="center" nowrap="nowrap">---</td>
            <xsl:call-template name="displayColumn">
                <xsl:with-param name="value" select="@sideShotElevation"/>
                <xsl:with-param name="displayType" select="'elevation'"/>
            </xsl:call-template>
            <td align="center" nowrap="nowrap">---</td>
        </tr>
        <xsl:if test="//@leastSquares='true'">
            <tr>
                <td>Adjusted</td>
                <xsl:call-template name="displayColumn">
                    <xsl:with-param name="value" select="@sideShotAdjustedNorthing"/>
                    <xsl:with-param name="displayType" select="'northing'"/>
                </xsl:call-template>
                <xsl:call-template name="displayColumn">
                    <xsl:with-param name="value" select="@sideShotNorthingDifference"/>
                    <xsl:with-param name="displayType" select="'northing'"/>
                </xsl:call-template>
                <xsl:call-template name="displayColumn">
                    <xsl:with-param name="value" select="@sideShotAdjustedEasting"/>
                    <xsl:with-param name="displayType" select="'easting'"/>
                </xsl:call-template>
                <xsl:call-template name="displayColumn">
                    <xsl:with-param name="value" select="@sideShotEastingDifference"/>
                    <xsl:with-param name="displayType" select="'easting'"/>
                </xsl:call-template>
                <xsl:call-template name="displayColumn">
                    <xsl:with-param name="value" select="@sideShotAdjustedElevation"/>
                    <xsl:with-param name="displayType" select="'elevation'"/>
                </xsl:call-template>
                <xsl:call-template name="displayColumn">
                    <xsl:with-param name="value" select="@sideShotElevationDifference"/>
                    <xsl:with-param name="displayType" select="'elevation'"/>
                </xsl:call-template>
            </tr>
        </xsl:if>
    </xsl:template>
    <xsl:template name="StyleSheetHelp">
        <div class="section1">
            <h4 lang="en">Notes</h4>
            <p class="normal1" lang="en">
                You must have a survey network and you must also have run the <em>Survey &gt; Network &gt; 
                Least Squares Adjustment</em> command to get results from this report.
            </p>
            <p class="small" lang="en">
                <em>&#xa9; 2006 Bentley Systems, Inc</em>
            </p>
        </div>
    </xsl:template>
</xsl:stylesheet>
